@@ -60,6 +60,12 @@ enum ability_type
 #endif
     // Storm Form
     ABIL_BLINKBOLT,
+    // Death Form
+    ABIL_SIPHON_ESSENCE,
+    // Talismans
+    ABIL_BEGIN_UNTRANSFORM,
+
+    // Note: this is getting dangerously close to ABIL_EVOKE_BERSERK! be careful
 
     // Evoking items.
 #if TAG_MAJOR_VERSION == 34
@@ -132,6 +138,8 @@ enum ability_type
     ABIL_OKAWARU_HEROISM = 1050,
     ABIL_OKAWARU_FINESSE,
     ABIL_OKAWARU_DUEL,
+    ABIL_OKAWARU_GIFT_WEAPON,
+    ABIL_OKAWARU_GIFT_ARMOUR,
     // Makhleb
     ABIL_MAKHLEB_MINOR_DESTRUCTION = 1060,
     ABIL_MAKHLEB_LESSER_SERVANT_OF_MAKHLEB,
@@ -256,7 +264,8 @@ enum ability_type
     ABIL_RU_SACRIFICE_SKILL,
     ABIL_RU_SACRIFICE_EYE,
     ABIL_RU_SACRIFICE_RESISTANCE,
-        ABIL_FINAL_SACRIFICE = ABIL_RU_SACRIFICE_RESISTANCE,
+    ABIL_RU_SACRIFICE_FORMS,
+        ABIL_FINAL_SACRIFICE = ABIL_RU_SACRIFICE_FORMS,
     ABIL_RU_REJECT_SACRIFICES,
 
 #if TAG_MAJOR_VERSION == 34
