@@ -21,6 +21,7 @@
 #include "colour.h"
 #include "describe.h"
 #include "dungeon.h"
+#include "god-abil.h"
 #include "god-item.h"
 #include "god-passive.h"
 #include "item-name.h"
@@ -51,10 +52,10 @@
 #include "unwind.h"
 #include "ui.h"
 
-static equipment_type _acquirement_armour_slot(bool);
-static armour_type _acquirement_armour_for_slot(equipment_type, bool);
+static equipment_type _acquirement_armour_slot(int);
+static armour_type _acquirement_armour_for_slot(equipment_type);
 static armour_type _acquirement_shield_type();
-static armour_type _acquirement_body_armour(bool);
+static armour_type _acquirement_body_armour();
 static armour_type _useless_armour_type();
 
 /**
@@ -79,14 +80,13 @@ static int _skill_rdiv(skill_type skill, int mult = 1)
  *
  * Guaranteed to be wearable, in principle.
  *
- * @param divine    Lowers the odds of high-tier body armours being chosen.
+ * @param agent     The source of the acquirement (e.g. a god)
  * @return          The armour_type of the armour to be generated.
  */
-static int _acquirement_armour_subtype(bool divine, int & /*quantity*/,
-                                       int /*agent*/)
+static int _acquirement_armour_subtype(int & /*quantity*/, int agent)
 {
-    const equipment_type slot_type = _acquirement_armour_slot(divine);
-    return _acquirement_armour_for_slot(slot_type, divine);
+    const equipment_type slot_type = _acquirement_armour_slot(agent);
+    return _acquirement_armour_for_slot(slot_type);
 }
 
 /**
@@ -125,19 +125,19 @@ M filtered_vector_select(vector<pair<M, int>> weights, function<bool(M)> filter)
  *
  * Guaranteed to be wearable, in principle.
  *
- * @param divine    Whether the item is a god gift.
+ * @param agent     The source of the acquirement (e.g. a god)
  * @return          A random equipment slot; e.g. EQ_SHIELD, EQ_BODY_ARMOUR...
  */
-static equipment_type _acquirement_armour_slot(bool divine)
+static equipment_type _acquirement_armour_slot(int agent)
 {
     if (you.wear_barding()
         && one_chance_in(you.seen_armour[ARM_BARDING] ? 4 : 2))
     {
-            return EQ_BOOTS;
+        return EQ_BOOTS;
     }
 
     vector<pair<equipment_type, int>> weights = {
-        { EQ_BODY_ARMOUR,   divine ? 5 : 1 },
+        { EQ_BODY_ARMOUR,   (agent == GOD_OKAWARU ? 5 : 1) },
         { EQ_SHIELD,        1 },
         { EQ_CLOAK,         1 },
         { EQ_HELMET,        1 },
@@ -162,11 +162,9 @@ static equipment_type _acquirement_armour_slot(bool divine)
  * heavy investment in armour skill, relative to dodging & spellcasting, makes
  * heavier armours more likely to be generated.
  *
- * @param divine    Whether the armour is a god gift.
  * @return          The armour_type of the armour to be generated.
  */
-static armour_type _acquirement_armour_for_slot(equipment_type slot_type,
-                                                bool divine)
+static armour_type _acquirement_armour_for_slot(equipment_type slot_type)
 {
     switch (slot_type)
     {
@@ -188,7 +186,7 @@ static armour_type _acquirement_armour_for_slot(equipment_type slot_type,
         case EQ_SHIELD:
             return _acquirement_shield_type();
         case EQ_BODY_ARMOUR:
-            return _acquirement_body_armour(divine);
+            return _acquirement_body_armour();
         default:
             die("Unknown armour slot %d!", slot_type);
     }
@@ -212,6 +210,10 @@ static armour_type _acquirement_armour_for_slot(equipment_type slot_type,
  */
 static armour_type _acquirement_shield_type()
 {
+    // Fixed chance for an orb.
+    if (one_chance_in(4))
+        return ARM_ORB;
+
     const int scale = 256;
     vector<pair<armour_type, int>> weights = {
         { ARM_BUCKLER,       (5 + player_shield_racial_factor()) * 4 * scale
@@ -230,22 +232,17 @@ static armour_type _acquirement_shield_type()
 /**
  * Determine the weight (likelihood) to acquire a specific type of body armour.
  *
- * If divine is set, returns the base weight for the armour type.
- * Otherwise, if warrior is set, multiplies the base weight by the base ac^2.
+ * If warrior is set, multiplies the base weight by the base ac^2.
  * Otherwise, uses the player's Armour skill to crudely guess how likely they
  * are to want the armour, based on its EVP.
  *
  * @param armour    The type of armour in question. (E.g. ARM_ROBE.)
- * @param divine    Whether the 'acquirement' is actually a god gift.
  * @param warrior   Whether we think the player only cares about AC.
  * @return          A weight for the armour.
  */
-static int _body_acquirement_weight(armour_type armour,
-                                    bool divine, bool warrior)
+static int _body_acquirement_weight(armour_type armour, bool warrior)
 {
     const int base_weight = armour_acq_weight(armour);
-    if (divine)
-        return base_weight; // gods don't care about your skills, apparently
 
     if (warrior)
     {
@@ -256,7 +253,7 @@ static int _body_acquirement_weight(armour_type armour,
     // highest chance when armour skill = (displayed) evp - 3
     const int evp = armour_prop(armour, PARM_EVASION);
     const int skill = min(27, _skill_rdiv(SK_ARMOUR) + 3);
-    const int sk_diff = skill + evp / 10;
+    const int sk_diff = abs(skill + evp / 10);
     const int inv_diff = max(1, 27 - sk_diff);
     // armour closest to ideal evp is 27^3 times as likely as the furthest away
     return base_weight * inv_diff * inv_diff * inv_diff;
@@ -266,10 +263,9 @@ static int _body_acquirement_weight(armour_type armour,
  * Choose a random type of body armour to be generated via acquirement or
  * god gifts.
  *
- * @param divine      Whether the armour is a god gift.
- * @return A potentially wearable type of body armour..
+ * @return A potentially wearable type of body armour.
  */
-static armour_type _acquirement_body_armour(bool divine)
+static armour_type _acquirement_body_armour()
 {
     // Using an arbitrary legacy formula, do we think the player doesn't care
     // about armour EVP?
@@ -288,7 +284,7 @@ static armour_type _acquirement_body_armour(bool divine)
         if (!check_armour_size(armour, you.body_size(PSIZE_TORSO, true)))
             continue;
 
-        const int weight = _body_acquirement_weight(armour, divine, warrior);
+        const int weight = _body_acquirement_weight(armour, warrior);
 
         if (weight)
         {
@@ -388,7 +384,7 @@ static armour_type _pick_unseen_armour()
         if (!you_can_wear(slot))
             continue;
 
-        const armour_type sub_type = _acquirement_armour_for_slot(slot, false);
+        const armour_type sub_type = _acquirement_armour_for_slot(slot);
         ASSERT(sub_type != NUM_ARMOURS);
 
         if (!you.seen_armour[sub_type] && one_chance_in(++count))
@@ -433,11 +429,10 @@ static bool _regular_staves_useless()
  * Randomly choose a class of weapons (those using a specific weapon skill)
  * for acquirement to give the player. Weight toward the player's skills.
  *
- * @param divine    Whether this is a god gift, which are less strongly
- *                  tailored to the player's skills.
+ * @param agent     The source of the acquirement (e.g. a god)
  * @return          An appropriate weapon skill; e.g. SK_LONG_BLADES.
  */
-static skill_type _acquirement_weapon_skill(bool divine, int agent)
+static skill_type _acquirement_weapon_skill(int agent)
 {
     // reservoir sample.
     int count = 0;
@@ -456,8 +451,8 @@ static skill_type _acquirement_weapon_skill(bool divine, int agent)
         // Adding a small constant allows for the occasional
         // weapon in an untrained skill.
         int weight = _skill_rdiv(sk) + 1;
-        // Exaggerate the weighting if it's a scroll acquirement.
-        if (!divine)
+        // Exaggerate the weighting if it's not a Trog gift.
+        if (agent != GOD_TROG)
             weight = (weight + 1) * (weight + 2);
         count += weight;
 
@@ -468,9 +463,9 @@ static skill_type _acquirement_weapon_skill(bool divine, int agent)
     return skill;
 }
 
-static int _acquirement_weapon_subtype(bool divine, int & /*quantity*/, int agent)
+static int _acquirement_weapon_subtype(int & /*quantity*/, int agent)
 {
-    const skill_type skill = _acquirement_weapon_skill(divine, agent);
+    const skill_type skill = _acquirement_weapon_skill(agent);
 
     int best_sk = 0;
     for (int i = SK_FIRST_WEAPON;
@@ -514,8 +509,8 @@ static int _acquirement_weapon_subtype(bool divine, int & /*quantity*/, int agen
         if (two_handed && you.get_mutation_level(MUT_MISSING_HAND))
             continue;
 
-        // For non-Trog/Okawaru acquirements, give a boost to high-end items.
-        if (!divine && !is_range_weapon(item_considered))
+        // For non-Trog acquirements, give a boost to high-end items.
+        if (agent != GOD_TROG && !is_range_weapon(item_considered))
         {
             if (acqweight < 500)
                 acqweight = 500;
@@ -545,7 +540,7 @@ static int _acquirement_weapon_subtype(bool divine, int & /*quantity*/, int agen
     return result;
 }
 
-static int _acquirement_missile_subtype(bool /*divine*/, int & /*quantity*/,
+static int _acquirement_missile_subtype(int & /*quantity*/,
                                         int /*agent*/)
 {
     // Choose from among all usable missile types.
@@ -563,7 +558,7 @@ static int _acquirement_missile_subtype(bool /*divine*/, int & /*quantity*/,
     return *random_choose_weighted(missile_weights);
 }
 
-static int _acquirement_jewellery_subtype(bool /*divine*/, int & /*quantity*/,
+static int _acquirement_jewellery_subtype(int & /*quantity*/,
                                           int /*agent*/)
 {
     int result = 0;
@@ -592,7 +587,7 @@ static vector<pair<stave_type, int>> _base_staff_weights()
         { STAFF_COLD,        _skill_rdiv(SK_ICE_MAGIC) },
         { STAFF_AIR,         _skill_rdiv(SK_AIR_MAGIC) },
         { STAFF_EARTH,       _skill_rdiv(SK_EARTH_MAGIC) },
-        { STAFF_POISON,      _skill_rdiv(SK_POISON_MAGIC) },
+        { STAFF_ALCHEMY,     _skill_rdiv(SK_ALCHEMY) },
         { STAFF_DEATH,       _skill_rdiv(SK_NECROMANCY) },
         { STAFF_CONJURATION, _skill_rdiv(SK_CONJURATIONS) },
         { NUM_STAVES,        5 },
@@ -624,7 +619,7 @@ static bool _unided_acq_staves()
     return _remove_ided_staff_weights(weights);
 }
 
-static int _acquirement_staff_subtype(bool /*divine*/, int & /*quantity*/,
+static int _acquirement_staff_subtype(int & /*quantity*/,
                                       int /*agent*/)
 {
     vector<pair<stave_type, int>> weights = _base_staff_weights();
@@ -653,6 +648,7 @@ static const vector<pair<misc_item_type, int> > _misc_base_weights()
     vector<pair<misc_item_type, int> > choices =
     {
         {MISC_BOX_OF_BEASTS,       (no_allies ? 0 : 20)},
+        {MISC_SACK_OF_SPIDERS,     (no_allies ? 0 : 20)},
         {MISC_PHANTOM_MIRROR,      (no_allies ? 0 : 20)},
         // Tremorstones are better for heavily armoured characters.
         {MISC_TIN_OF_TREMORSTONES, 5 + _skill_rdiv(SK_ARMOUR) / 3},
@@ -660,7 +656,6 @@ static const vector<pair<misc_item_type, int> > _misc_base_weights()
         {MISC_LIGHTNING_ROD,       20},
         {MISC_PHIAL_OF_FLOODS,     20},
         {MISC_CONDENSER_VANE,      20},
-        {MISC_XOMS_CHESSBOARD,     20},
     };
     // The player never needs more than one of any of these.
     for (auto &p : choices)
@@ -682,7 +677,7 @@ static bool _unided_acq_misc()
  * Return a miscellaneous evokable item for acquirement.
  * @return   The item type chosen.
  */
-static int _acquirement_misc_subtype(bool /*divine*/, int & /*quantity*/,
+static int _acquirement_misc_subtype(int & /*quantity*/,
                                      int /*agent*/)
 {
     const vector<pair<misc_item_type, int> > choices = _misc_base_weights();
@@ -693,12 +688,12 @@ static int _acquirement_misc_subtype(bool /*divine*/, int & /*quantity*/,
     if (choice == nullptr)
     {
         return random_choose(MISC_BOX_OF_BEASTS,
+                             MISC_SACK_OF_SPIDERS,
                              MISC_PHANTOM_MIRROR,
                              MISC_TIN_OF_TREMORSTONES,
                              MISC_LIGHTNING_ROD,
                              MISC_PHIAL_OF_FLOODS,
-                             MISC_CONDENSER_VANE,
-                             MISC_XOMS_CHESSBOARD);
+                             MISC_CONDENSER_VANE);
     }
 
     return *choice;
@@ -712,7 +707,7 @@ static int _acquirement_misc_subtype(bool /*divine*/, int & /*quantity*/,
  *
  * @return          A random wand type.
  */
-static int _acquirement_wand_subtype(bool /*divine*/, int & /*quantity*/,
+static int _acquirement_wand_subtype(int & /*quantity*/,
                                      int /*agent */)
 {
     const auto hex_wand_type = (wand_type)item_for_set(ITEM_SET_HEX_WANDS);
@@ -740,7 +735,7 @@ static int _acquirement_wand_subtype(bool /*divine*/, int & /*quantity*/,
     return *wand;
 }
 
-static int _acquirement_book_subtype(bool /*divine*/, int & /*quantity*/,
+static int _acquirement_book_subtype(int & /*quantity*/,
                                      int /*agent*/)
 {
     return BOOK_MINOR_MAGIC;
@@ -748,7 +743,7 @@ static int _acquirement_book_subtype(bool /*divine*/, int & /*quantity*/,
     //or asserts will get set off
 }
 
-typedef int (*acquirement_subtype_finder)(bool divine, int &quantity, int agent);
+typedef int (*acquirement_subtype_finder)(int &quantity, int agent);
 static const acquirement_subtype_finder _subtype_finders[] =
 {
     _acquirement_weapon_subtype,
@@ -771,16 +766,18 @@ static const acquirement_subtype_finder _subtype_finders[] =
     0, // no rods
 #endif
     0, // no runes either
+    0, // no talismans... for now. TODO: add talisman acquirement
+    0, // no gems either
 };
 
 static int _find_acquirement_subtype(object_class_type &class_wanted,
-                                     int &quantity, bool divine,
+                                     int &quantity,
                                      int agent)
 {
     COMPILE_CHECK(ARRAYSZ(_subtype_finders) == NUM_OBJECT_CLASSES);
     ASSERT(class_wanted != OBJ_RANDOM);
 
-    if (class_wanted == OBJ_ARMOUR && you.has_mutation(MUT_NO_ARMOUR)
+    if (class_wanted == OBJ_ARMOUR && !player_can_use_armour()
         || class_wanted == OBJ_WEAPONS && you.has_mutation(MUT_NO_GRASPING))
     {
         return OBJ_RANDOM;
@@ -799,7 +796,7 @@ static int _find_acquirement_subtype(object_class_type &class_wanted,
         if (_subtype_finders[class_wanted])
         {
             type_wanted =
-                (*_subtype_finders[class_wanted])(divine, quantity, agent);
+                (*_subtype_finders[class_wanted])(quantity, agent);
         }
 
         // Double-check our subtype for weapons is valid
@@ -893,6 +890,9 @@ static bool _skill_useless_with_god(int skill)
     case GOD_TROG:
         return _is_magic_skill(skill);
     case GOD_ZIN:
+        if (skill == SK_SHAPESHIFTING)
+            return true;
+        // fallthrough to other good gods
     case GOD_SHINING_ONE:
     case GOD_ELYVILON:
         return skill == SK_NECROMANCY;
@@ -960,6 +960,8 @@ static bool _acquire_manual(item_def &book)
 
         // Greatly reduce the chances of getting a manual for a skill
         // you couldn't use unless you switched your religion.
+        // Note: manuals that gods actively hate, e.g. spellcasting under
+        // Trog, will be mulched and replaced later. This is silly!
         if (_skill_useless_with_god(sk))
             w /= 2;
 
@@ -1040,10 +1042,11 @@ static bool _do_book_acquirement(item_def &book, int agent)
     }
     } // switch book choice
 
-    // If we couldn't make a useful book, try to make a manual instead.
-    // We have to temporarily identify the book for this.
+
     if (agent != GOD_XOM && agent != GOD_SIF_MUNA)
     {
+        // If we couldn't make a useful book, try to make a manual instead.
+        // We have to temporarily identify the book for this.
         bool useless = false;
         {
             unwind_var<iflags_t> oldflags{book.flags};
@@ -1134,9 +1137,6 @@ static bool _is_armour_plain(const item_def &item)
     return get_armour_ego_type(item) == SPARM_NORMAL;
 }
 
-// ugh
-#define ITEM_LEVEL (divine ? ISPEC_GIFT : ISPEC_GOOD_ITEM)
-
 /**
  * Take a newly-generated acquirement item, and adjust its brand if we don't
  * like it.
@@ -1148,12 +1148,10 @@ static bool _is_armour_plain(const item_def &item)
  *
  * @param item      The item which may have its brand adjusted. Not necessarily
  *                  a weapon or piece of armour.
- * @param divine    Whether the item is a god gift, rather than from
- *                  acquirement proper.
  * @param agent     The source of the acquirement. For god gifts, it's equal to
  *                  the god.
  */
-static void _adjust_brand(item_def &item, bool divine, int agent)
+static void _adjust_brand(item_def &item, int agent)
 {
     if (item.base_type != OBJ_WEAPONS && item.base_type != OBJ_ARMOUR)
         return; // don't reroll missile brands, I guess
@@ -1161,7 +1159,6 @@ static void _adjust_brand(item_def &item, bool divine, int agent)
     if (is_artefact(item))
         return; // their own kettle of fish
 
-
     // Trog has a restricted brand table.
     if (agent == GOD_TROG && item.base_type == OBJ_WEAPONS)
     {
@@ -1171,13 +1168,13 @@ static void _adjust_brand(item_def &item, bool divine, int agent)
         return;
     }
 
-    // Not from a god, so we should prefer better brands.
-    if (!divine && item.base_type == OBJ_WEAPONS)
+    // Not from Trog, so we should prefer better brands.
+    if (agent != GOD_TROG && item.base_type == OBJ_WEAPONS)
     {
         while (_weapon_brand_quality(get_weapon_brand(item),
                                      is_range_weapon(item)) < random2(6))
         {
-            reroll_brand(item, ITEM_LEVEL);
+            reroll_brand(item, ISPEC_GOOD_ITEM);
         }
     }
 }
@@ -1222,12 +1219,9 @@ int acquirement_create_item(object_class_type class_wanted,
 {
     ASSERT(class_wanted != OBJ_RANDOM);
 
-    const bool divine = (agent == GOD_OKAWARU || agent == GOD_XOM
-                         || agent == GOD_TROG
-#if TAG_MAJOR_VERSION == 34
-                         || agent == GOD_PAKELLAS
-#endif
-                        );
+    // Trog/Xom gifts are generally lower quality than scroll acquirement or
+    // Oka gifts. We also use lower quality for missile gifts.
+    const int item_level = ((agent == GOD_TROG || agent == GOD_XOM || class_wanted == OBJ_MISSILES) ? ISPEC_GIFT : ISPEC_GOOD_ITEM);
     int thing_created = NON_ITEM;
     int quant = 1;
 #define MAX_ACQ_TRIES 40
@@ -1240,7 +1234,7 @@ int acquirement_create_item(object_class_type class_wanted,
         {
             // This may clobber class_wanted (e.g. staves)
             type_wanted = _find_acquirement_subtype(class_wanted, quant,
-                                                    divine, agent);
+                                                    agent);
         }
         ASSERT(type_wanted != -1);
 
@@ -1251,7 +1245,7 @@ int acquirement_create_item(object_class_type class_wanted,
             want_arts = false;
 
         thing_created = items(want_arts, class_wanted, type_wanted,
-                              ITEM_LEVEL, 0, agent);
+                              item_level, 0, agent);
 
         if (thing_created == NON_ITEM)
         {
@@ -1261,18 +1255,17 @@ int acquirement_create_item(object_class_type class_wanted,
         }
 
         item_def &acq_item(env.item[thing_created]);
-        _adjust_brand(acq_item, divine, agent);
+        _adjust_brand(acq_item, agent);
 
         // For plain armour, try to change the subtype to something
         // matching a currently unfilled equipment slot.
         if (acq_item.base_type == OBJ_ARMOUR && !is_artefact(acq_item))
         {
-            if (agent != GOD_XOM
-                && x_chance_in_y(MAX_ACQ_TRIES - item_tries, MAX_ACQ_TRIES + 5)
-                || !divine
-                && you.seen_armour[acq_item.sub_type]
+            if (agent != GOD_XOM &&
+                (x_chance_in_y(MAX_ACQ_TRIES - item_tries, MAX_ACQ_TRIES + 5)
+                || you.seen_armour[acq_item.sub_type]
                 && !one_chance_in(3)
-                && item_tries < 20)
+                && item_tries < 20))
             {
                 // We have seen the exact item already, it's very unlikely
                 // extras will do any good.
@@ -1295,7 +1288,7 @@ int acquirement_create_item(object_class_type class_wanted,
                 {
                     destroy_item(thing_created, true);
                     thing_created = items(true, OBJ_ARMOUR, at,
-                                          ITEM_LEVEL, 0, agent);
+                                          item_level, 0, agent);
                 }
                 else if (agent != GOD_XOM && one_chance_in(3))
                 {
@@ -1330,7 +1323,7 @@ int acquirement_create_item(object_class_type class_wanted,
         {
             // TODO: consider doubling the gift timeout instead of adjusting
             // gift quantity. That'd be an Oka nerf, but maybe it's fine?
-            if (divine)
+            if (agent == GOD_OKAWARU || agent == GOD_XOM)
                 acq_item.quantity = max(1, acq_item.quantity / 2);
             else
                 acq_item.quantity *= 5;
@@ -1390,7 +1383,7 @@ int acquirement_create_item(object_class_type class_wanted,
             if (agent == GOD_TROG)
                 acq_item.plus += random2(3);
             // God gifts (except Xom's) never have a negative enchantment
-            if (divine && agent != GOD_XOM)
+            if (agent == GOD_OKAWARU || agent == GOD_TROG)
                 acq_item.plus = max(static_cast<int>(acq_item.plus), 0);
         }
 
@@ -1459,13 +1452,14 @@ class AcquireMenu : public InvMenu
     friend class AcquireEntry;
 
     CrawlVector &acq_items;
+    string items_key;
 
     void init_entries();
     string get_keyhelp(bool unused) const override;
     bool examine_index(int i) override;
     bool skip_process_command(int keyin) override;
 public:
-    AcquireMenu(CrawlVector &aitems);
+    AcquireMenu(CrawlVector &aitems, string ikey);
 };
 
 class AcquireEntry : public InvEntry
@@ -1496,10 +1490,11 @@ public:
     }
 };
 
-AcquireMenu::AcquireMenu(CrawlVector &aitems)
+AcquireMenu::AcquireMenu(CrawlVector &aitems, string ikey)
     : InvMenu(MF_SINGLESELECT | MF_QUIET_SELECT
               | MF_ALLOW_FORMATTING | MF_INIT_HOVER),
-      acq_items(aitems)
+      acq_items(aitems),
+      items_key(ikey)
 {
     menu_action = ACT_EXECUTE;
     action_cycle = CYCLE_TOGGLE;
@@ -1512,9 +1507,9 @@ AcquireMenu::AcquireMenu(CrawlVector &aitems)
     set_title("Choose an item to acquire.");
 }
 
-static void _create_acquirement_item(item_def &item)
+static void _create_acquirement_item(item_def &item, string items_key)
 {
-    auto &acq_items = you.props[ACQUIRE_ITEMS_KEY].get_vector();
+    auto &acq_items = you.props[items_key].get_vector();
 
     // Now that we have a selection, mark any generated unrands as not having
     // been generated, so they go back in circulation. Exclude the selected
@@ -1542,21 +1537,22 @@ static void _create_acquirement_item(item_def &item)
         canned_msg(MSG_NOTHING_HAPPENS);
 
     acq_items.clear();
-    you.props.erase(ACQUIRE_ITEMS_KEY);
+    you.props.erase(items_key);
 }
 
 void AcquireMenu::init_entries()
 {
     menu_letter ckey = 'a';
+    string key = items_key;
     for (item_def& item : acq_items)
     {
         auto newentry = make_unique<AcquireEntry>(item);
         newentry->hotkeys.clear();
         newentry->add_hotkey(ckey++);
-        add_entry(move(newentry));
+        add_entry(std::move(newentry));
     }
 
-    on_single_selection = [this](const MenuEntry& item)
+    on_single_selection = [this, key](const MenuEntry& item)
     {
         // update the more with a y/n prompt
         update_more();
@@ -1569,7 +1565,7 @@ void AcquireMenu::init_entries()
         }
 
         item_def &acq_item = *static_cast<item_def*>(item.data);
-        _create_acquirement_item(acq_item);
+        _create_acquirement_item(acq_item, key);
 
         return false;
     };
@@ -1613,7 +1609,7 @@ bool AcquireMenu::examine_index(int i)
     ASSERT(i >= 0 && i < static_cast<int>(items.size()));
     // Use a copy to set flags that make the description better
     // See the similar code in shopping.cc for details about const
-    // hygene
+    // hygiene
     item_def &item = *static_cast<item_def*>(items[i]->data);
 
     item.flags |= (ISFLAG_IDENT_MASK | ISFLAG_NOTED_ID
@@ -1630,11 +1626,11 @@ bool AcquireMenu::skip_process_command(int keyin)
     return Menu::skip_process_command(keyin);
 }
 
-static item_def _acquirement_item_def(object_class_type item_type)
+static item_def _acquirement_item_def(object_class_type item_type, int agent)
 {
     item_def item;
 
-    const int item_index = acquirement_create_item(item_type, AQ_SCROLL, true);
+    const int item_index = acquirement_create_item(item_type, agent, true);
 
     if (item_index != NON_ITEM)
     {
@@ -1643,7 +1639,7 @@ static item_def _acquirement_item_def(object_class_type item_type)
         // We make a copy of the item def, but we don't keep the real item.
         item = env.item[item_index];
         set_ident_flags(item,
-                // Act as if we've recieved this item already to prevent notes.
+                // Act as if we've received this item already to prevent notes.
                 ISFLAG_IDENT_MASK | ISFLAG_NOTED_ID | ISFLAG_NOTED_GET);
         destroy_item(item_index);
     }
@@ -1697,15 +1693,15 @@ void make_acquirement_items()
         if (acq_items.size() == num_wanted)
             break;
 
-        auto item = _acquirement_item_def(obj_type);
+        auto item = _acquirement_item_def(obj_type, AQ_SCROLL);
         if (item.defined())
             acq_items.push_back(item);
     }
 
     // Gold is guaranteed.
-    auto gold_item = _acquirement_item_def(OBJ_GOLD);
+    auto gold_item = _acquirement_item_def(OBJ_GOLD, AQ_SCROLL);
     if (gold_item.defined())
-            acq_items.push_back(gold_item);
+        acq_items.push_back(gold_item);
 }
 
 /*
@@ -1735,12 +1731,126 @@ bool acquirement_menu()
     }
     else if (index >= 1 && index <= acq_items.size())
     {
-        _create_acquirement_item(acq_items[index - 1]);
+        _create_acquirement_item(acq_items[index - 1], ACQUIRE_ITEMS_KEY);
         return true;
     }
 
-    AcquireMenu acq_menu(acq_items);
+    AcquireMenu acq_menu(acq_items, ACQUIRE_ITEMS_KEY);
     acq_menu.show();
 
     return !you.props.exists(ACQUIRE_ITEMS_KEY);
 }
+
+/// Does this item duplicate an already-generated item's base/subtype plus ego? (Ignore plus.)
+static bool _is_duplicate(const item_def &item, CrawlVector &acq_items)
+{
+    if (is_artefact(item))
+        return false;
+    for (item_def &aitem : acq_items)
+    {
+        if (!is_artefact(aitem)
+            && aitem.is_type(item.base_type, item.sub_type)
+            && item.brand == aitem.brand)
+        {
+            return true;
+        }
+    }
+    return false;
+}
+
+static void _make_okawaru_gifts(object_class_type gift_type)
+{
+    ASSERT(gift_type == OBJ_WEAPONS || gift_type == OBJ_ARMOUR);
+
+    const string key = gift_type == OBJ_WEAPONS ? OKAWARU_WEAPONS_KEY
+                                                : OKAWARU_ARMOUR_KEY;
+    CrawlVector &acq_items = you.props[key].get_vector();
+    acq_items.clear();
+
+    while (acq_items.size() < 4)
+    {
+        auto item = _acquirement_item_def(gift_type, you.religion);
+        if (item.defined() && !_is_duplicate(item, acq_items))
+            acq_items.push_back(item);
+    }
+}
+
+bool okawaru_gift_weapon()
+{
+    ASSERT(!you.props.exists(OKAWARU_WEAPON_GIFTED_KEY));
+
+    if (!you.props.exists(OKAWARU_WEAPONS_KEY))
+        _make_okawaru_gifts(OBJ_WEAPONS);
+
+    auto &acq_items = you.props[OKAWARU_WEAPONS_KEY].get_vector();
+
+    simple_god_message(" offers you a choice of weapons!");
+
+    int index = 0;
+    if (!clua.callfn("c_choose_okawaru_weapon", ">d", &index))
+    {
+        if (!clua.error.empty())
+            mprf(MSGCH_ERROR, "Lua error: %s", clua.error.c_str());
+    }
+    else if (index >= 1 && index <= acq_items.size())
+    {
+        _create_acquirement_item(acq_items[index - 1], OKAWARU_WEAPONS_KEY);
+
+        take_note(Note(NOTE_GOD_GIFT, you.religion));
+        you.props[OKAWARU_WEAPON_GIFTED_KEY] = true;
+
+        return true;
+    }
+
+    AcquireMenu acq_menu(acq_items, OKAWARU_WEAPONS_KEY);
+    acq_menu.show();
+
+    // Nothing selected yet.
+    if (you.props.exists(OKAWARU_WEAPONS_KEY))
+        return false;
+
+    take_note(Note(NOTE_GOD_GIFT, you.religion));
+    you.props[OKAWARU_WEAPON_GIFTED_KEY] = true;
+
+    return true;
+}
+
+bool okawaru_gift_armour()
+{
+    ASSERT(!you.props.exists(OKAWARU_ARMOUR_GIFTED_KEY));
+
+    if (!you.props.exists(OKAWARU_ARMOUR_KEY))
+        _make_okawaru_gifts(OBJ_ARMOUR);
+
+    auto &acq_items = you.props[OKAWARU_ARMOUR_KEY].get_vector();
+
+    simple_god_message(" offers you a choice of armour!");
+
+    int index = 0;
+    if (!clua.callfn("c_choose_okawaru_armour", ">d", &index))
+    {
+        if (!clua.error.empty())
+            mprf(MSGCH_ERROR, "Lua error: %s", clua.error.c_str());
+    }
+    else if (index >= 1 && index <= acq_items.size())
+    {
+        _create_acquirement_item(acq_items[index - 1], OKAWARU_ARMOUR_KEY);
+
+        take_note(Note(NOTE_GOD_GIFT, you.religion));
+        you.props[OKAWARU_ARMOUR_GIFTED_KEY] = true;
+
+        return true;
+    }
+
+    AcquireMenu acq_menu(acq_items, OKAWARU_ARMOUR_KEY);
+    acq_menu.show();
+
+    // Nothing selected yet.
+    if (you.props.exists(OKAWARU_ARMOUR_KEY))
+        return false;
+
+    take_note(Note(NOTE_GOD_GIFT, you.religion));
+    you.props[OKAWARU_ARMOUR_GIFTED_KEY] = true;
+
+    return true;
+}
