@@ -8,6 +8,10 @@
 #include "item-prop-enum.h"
 
 bool acquirement_menu();
+
+bool okawaru_gift_weapon();
+bool okawaru_gift_armour();
+
 void make_acquirement_items();
 
 int acquirement_create_item(object_class_type class_wanted, int agent,
