@@ -65,6 +65,9 @@ public:
                                         killer_type killer = KILL_NONE,
                                         int killernum = -1) = 0;
 
+    // Handles sticky flame / barbs on deliberate movement.
+    virtual void did_deliberate_movement() = 0;
+
     virtual void set_position(const coord_def &c);
     const coord_def& pos() const { return position; }
 
@@ -204,6 +207,8 @@ public:
     virtual void put_to_sleep(actor *attacker, int strength,
                               bool hibernate = false) = 0;
     virtual void weaken(actor *attacker, int pow) = 0;
+    virtual bool strip_willpower(actor *attacker, int dur,
+                                 bool quiet = false) = 0;
     virtual void expose_to_element(beam_type element, int strength = 0,
                                    bool slow_cold_blood = true) = 0;
     virtual void drain_stat(stat_type /*stat*/, int /*amount*/) { }
@@ -245,8 +250,9 @@ public:
     virtual int evasion(bool ignore_helpless = false,
                         const actor *attacker = nullptr) const = 0;
     virtual bool shielded() const = 0;
+    virtual int shield_block_limit() const;
+    bool shield_exhausted() const;
     virtual int shield_bonus() const = 0;
-    virtual int shield_block_penalty() const = 0;
     virtual int shield_bypass_ability(int tohit) const = 0;
     virtual void shield_block_succeeded(actor *attacker);
     virtual bool missile_repulsion() const = 0;
@@ -258,11 +264,11 @@ public:
 
     virtual monster_type mons_species(bool zombie_base = false) const = 0;
 
-    virtual mon_holy_type holiness(bool temp = true) const = 0;
+    virtual mon_holy_type holiness(bool temp = true, bool incl_form = true) const = 0;
     virtual bool undead_or_demonic(bool temp = true) const = 0;
     virtual bool holy_wrath_susceptible() const;
     virtual bool is_holy() const = 0;
-    virtual bool is_nonliving(bool temp = true) const = 0;
+    virtual bool is_nonliving(bool temp = true, bool incl_form = true) const = 0;
     virtual bool evil() const;
     virtual int  how_chaotic(bool check_spells_god = false) const = 0;
     virtual bool is_unbreathing() const = 0;
@@ -283,8 +289,9 @@ public:
     virtual bool res_polar_vortex() const = 0;
     virtual bool res_petrify(bool temp = true) const = 0;
     virtual int res_constrict() const = 0;
+    int get_res(int res) const;
     virtual int willpower() const = 0;
-    virtual int check_willpower(const actor* source, int power);
+    virtual int check_willpower(const actor* source, int power) const;
     virtual bool no_tele(bool blink = false, bool temp = true) const = 0;
     virtual int inaccuracy() const;
     int inaccuracy_penalty() const;
@@ -308,7 +315,7 @@ public:
     // Return an int so we know whether an item is the sole source.
     virtual int equip_flight() const;
     virtual int spirit_shield(bool items = true) const;
-    virtual bool rampaging(bool items = true) const;
+    virtual bool rampaging() const;
 
     virtual bool is_banished() const = 0;
     virtual bool is_web_immune() const = 0;
@@ -369,7 +376,7 @@ public:
 
     virtual bool     will_trigger_shaft() const;
     virtual level_id shaft_dest() const;
-    virtual bool     do_shaft(bool check_terrain = true) = 0;
+    virtual bool     do_shaft() = 0;
 
     coord_def position;
 
@@ -421,6 +428,8 @@ public:
 
     void collide(coord_def newpos, const actor *agent, int pow);
     bool knockback(const actor &cause, int dist, int pow, string source_name);
+    coord_def stumble_pos(coord_def targ) const;
+    void stumble_away_from(coord_def targ, string src);
 
     static const actor *ensure_valid_actor(const actor *act);
     static actor *ensure_valid_actor(actor *act);
