@@ -228,9 +228,6 @@ static void _THROATCUTTER_melee_effects(item_def* /*weapon*/, actor* attacker,
 
 ////////////////////////////////////////////////////
 
-// XXX: Staff giving a boost to poison spells is hardcoded in
-// player_spec_poison()
-
 static void _OLGREB_equip(item_def */*item*/, bool *show_msgs, bool /*unmeld*/)
 {
     if (you.can_smell())
@@ -250,10 +247,10 @@ static void _OLGREB_unequip(item_def */*item*/, bool *show_msgs)
 // Based on melee_attack::staff_damage(), but using only evocations skill.
 static int _calc_olgreb_damage(actor* attacker, actor* defender)
 {
-    int base_dam = 0;
-    if (x_chance_in_y(attacker->skill(SK_EVOCATIONS, 100), 1000))
-        base_dam = random2(attacker->skill(SK_EVOCATIONS, 150) / 80);
+    if (!x_chance_in_y(attacker->skill(SK_EVOCATIONS, 100), 1000))
+        return 0;
 
+    const int base_dam = random2(attacker->skill(SK_EVOCATIONS, 150) / 80);
     return resist_adjust_damage(defender, BEAM_POISON_ARROW, base_dam);
 }
 
@@ -289,7 +286,13 @@ static void _POWER_equip(item_def * /* item */, bool *show_msgs,
 static void _POWER_melee_effects(item_def* /*weapon*/, actor* attacker,
                                  actor* defender, bool mondied, int /*dam*/)
 {
-    if (!mondied && x_chance_in_y(min(attacker->stat_hp() / 10, 27), 27))
+    if (mondied)
+        return;
+
+    const int num_beams = div_rand_round(attacker->stat_hp(), 270);
+    coord_def targ = defender->pos();
+
+    for (int i = 0; i < num_beams; i++)
     {
         bolt beam;
         beam.thrower   = attacker->is_player() ? KILL_YOU : KILL_MON;
@@ -297,7 +300,7 @@ static void _POWER_melee_effects(item_def* /*weapon*/, actor* attacker,
         beam.source_id = attacker->mid;
         beam.attitude  = attacker->temp_attitude();
         beam.range = 4;
-        beam.target = defender->pos();
+        beam.target = targ;
         zappy(ZAP_SWORD_BEAM, 100, false, beam);
         beam.fire();
     }
@@ -785,25 +788,40 @@ static void _NIGHT_unequip(item_def */*item*/, bool *show_msgs)
 
 ///////////////////////////////////////////////////
 
-static void _PLUTONIUM_SWORD_melee_effects(item_def* /*weapon*/,
+static const vector<string> plutonium_player_msg = {
+};
+
+static void _PLUTONIUM_SWORD_melee_effects(item_def* weapon,
                                            actor* attacker, actor* defender,
-                                           bool mondied, int dam)
+                                           bool mondied, int /*dam*/)
 {
     if (!mondied && one_chance_in(5) && defender->can_mutate())
     {
-        mpr("Mutagenic energy flows through the plutonium sword!");
+        if (you.can_see(*attacker))
+        {
+            mprf("Mutagenic energy flows through %s!",
+                 weapon->name(DESC_THE, false, false, false).c_str());
+        }
 
         if (attacker->is_player())
             did_god_conduct(DID_CHAOS, 3);
 
         if (one_chance_in(10))
+        {
             defender->polymorph(0); // Low duration if applied to the player.
+            return;
+        }
+
+        if (defender->is_monster())
+            defender->malmutate("the plutonium sword");
         else
         {
-            miscast_effect(*defender, attacker, {miscast_source::melee},
-                           spschool::transmutation, 5, random2(dam),
-                           "the plutonium sword");
+            mpr(random_choose("Your body deforms painfully.",
+                              "Your limbs ache and wobble like jelly.",
+                              "Your body is flooded with magical radiation."));
+            contaminate_player(random_range(3500, 6500));
         }
+        defender->hurt(attacker, random_range(5, 25));
     }
 }
 
@@ -813,10 +831,7 @@ static void _SNAKEBITE_melee_effects(item_def* /*weapon*/, actor* attacker,
                                      actor* defender, bool mondied, int /*dam*/)
 {
     if (!mondied && x_chance_in_y(2, 5))
-    {
-        curare_actor(attacker, defender, 2, "curare",
-                     attacker->name(DESC_PLAIN));
-    }
+        curare_actor(attacker, defender, "curare", attacker->name(DESC_PLAIN));
 }
 
 ///////////////////////////////////////////////////
@@ -829,7 +844,7 @@ static void _WOE_melee_effects(item_def* /*weapon*/, actor* attacker,
     {
     case 0: verb = "cleave", adv = " in twain"; break;
     case 1: verb = "pulverise", adv = " into a thin bloody mist"; break;
-    case 2: verb = "hew", adv = " savagely"; break;
+    case 2: verb = "hew", adv = " violently"; break;
     case 3: verb = "fatally mangle", adv = ""; break;
     case 4: verb = "dissect", adv = " like a pig carcass"; break;
     case 5: verb = "chop", adv = " into pieces"; break;
@@ -858,8 +873,7 @@ static void _WOE_melee_effects(item_def* /*weapon*/, actor* attacker,
 
 ///////////////////////////////////////////////////
 
-static setup_missile_type _DAMNATION_launch(item_def* /*item*/, bolt* beam,
-                                           string* ammo_name, bool* /*returning*/)
+static void _DAMNATION_launch(bolt* beam)
 {
     ASSERT(beam->item
            && beam->item->base_type == OBJ_MISSILES
@@ -867,7 +881,6 @@ static setup_missile_type _DAMNATION_launch(item_def* /*item*/, bolt* beam,
     beam->item->props[DAMNATION_BOLT_KEY].get_bool() = true;
 
     beam->name    = "damnation bolt";
-    *ammo_name    = "a damnation bolt";
     beam->colour  = LIGHTRED;
     beam->glyph   = DCHAR_FIRED_ZAP;
 
@@ -878,7 +891,6 @@ static setup_missile_type _DAMNATION_launch(item_def* /*item*/, bolt* beam,
     expl->name   = "damnation";
 
     beam->special_explosion = expl;
-    return SM_FINISHED;
 }
 
 ///////////////////////////////////////////////////
@@ -1121,10 +1133,10 @@ static void _FLAMING_DEATH_melee_effects(item_def* /*weapon*/, actor* attacker,
     if (!mondied && (dam > 2 && one_chance_in(3)))
     {
         if (defender->is_player())
-            napalm_player(random2avg(7, 3) + 1, attacker->name(DESC_A, true));
+            sticky_flame_player(5, 10, attacker->name(DESC_A, true));
         else
         {
-            napalm_monster(
+            sticky_flame_monster(
                 defender->as_monster(),
                 attacker,
                 min(4, 1 + random2(attacker->get_hit_dice())/2));
@@ -1402,6 +1414,9 @@ static void _THERMIC_ENGINE_world_reacts(item_def *item)
 
 static void _ZHOR_world_reacts(item_def */*item*/)
 {
+    if (!you.time_taken)
+        return;
+
     if (there_are_monsters_nearby(true, false, false)
         && one_chance_in(7 * div_rand_round(BASELINE_DELAY, you.time_taken)))
     {
@@ -1704,14 +1719,9 @@ static void _AUTUMN_KATANA_melee_effects(item_def* /*weapon*/, actor* attacker,
 
 ///////////////////////////////////////////////////
 
-static void _VITALITY_world_reacts(item_def */*item*/)
+static void _FINGER_AMULET_world_reacts(item_def */*item*/)
 {
-    // once it starts regenerating you, you're doin evil
-    if (you.props[MANA_REGEN_AMULET_ACTIVE].get_int() == 1
-        || you.activated[EQ_AMULET])
-    {
-        did_god_conduct(DID_EVIL, 1);
-    }
+    did_god_conduct(DID_EVIL, 1);
 }
 
 ///////////////////////////////////////////////////
