@@ -39,8 +39,8 @@ static const vector<spell_type> spellbook_templates[] =
 
 {   // Book of Minor Magic
     SPELL_MAGIC_DART,
+    SPELL_BLINK,
     SPELL_CALL_IMP,
-    SPELL_MEPHITIC_CLOUD,
 },
 
 {   // Book of Conjurations
@@ -69,7 +69,6 @@ static const vector<spell_type> spellbook_templates[] =
 
 {   // Book of Fire
     SPELL_FOXFIRE,
-    SPELL_FIREBALL,
     SPELL_PLASMA_BEAM,
     SPELL_STARBURST,
 },
@@ -94,7 +93,7 @@ static const vector<spell_type> spellbook_templates[] =
 
 {   // Young Poisoner's Handbook
     SPELL_STING,
-    SPELL_POISONOUS_VAPOURS,
+    SPELL_MERCURY_VAPOURS,
     SPELL_OLGREBS_TOXIC_RADIANCE,
 },
 
@@ -111,22 +110,22 @@ static const vector<spell_type> spellbook_templates[] =
 },
 
 {   // Book of Misfortune
-    SPELL_INNER_FLAME,
+    SPELL_JINXBITE,
     SPELL_VIOLENT_UNRAVELLING,
     SPELL_ENFEEBLE,
 },
 
-{   // Book of Changes
-    SPELL_BEASTLY_APPENDAGE,
-    SPELL_WEREBLOOD,
-    SPELL_SPIDER_FORM,
+{   // Book of Spontaneous Combustion
+    SPELL_INNER_FLAME,
+    SPELL_IRRADIATE,
+    SPELL_IGNITION,
 },
 
+#if TAG_MAJOR_VERSION == 34
 {   // Book of Transfigurations
     SPELL_IRRADIATE,
-    SPELL_BLADE_HANDS,
-    SPELL_DRAGON_FORM,
 },
+#endif
 
 {   // Fen Folio
     SPELL_SUMMON_FOREST,
@@ -135,7 +134,7 @@ static const vector<spell_type> spellbook_templates[] =
 },
 
 {   // Book of Vapours
-    SPELL_POISONOUS_VAPOURS,
+    SPELL_MERCURY_VAPOURS,
     SPELL_MEPHITIC_CLOUD,
     SPELL_FREEZING_CLOUD,
 },
@@ -143,13 +142,14 @@ static const vector<spell_type> spellbook_templates[] =
 {   // Book of Necromancy
     SPELL_NECROTISE,
     SPELL_VAMPIRIC_DRAINING,
-    SPELL_AGONY,
+    SPELL_MARTYRS_KNELL,
+    SPELL_CURSE_OF_AGONY,
 },
 
 {   // Book of Callings
     SPELL_SUMMON_SMALL_MAMMAL,
     SPELL_CALL_CANINE_FAMILIAR,
-    SPELL_SUMMON_GUARDIAN_GOLEM,
+    SPELL_SUMMON_BLAZEHEART_GOLEM,
 },
 
 #if TAG_MAJOR_VERSION == 34
@@ -165,11 +165,11 @@ static const vector<spell_type> spellbook_templates[] =
     SPELL_AIRSTRIKE,
 },
 
+#if TAG_MAJOR_VERSION == 34
 {   // Book of the Sky
-    SPELL_SUMMON_LIGHTNING_SPIRE,
-    SPELL_STORM_FORM,
     SPELL_MAXWELLS_COUPLING,
 },
+#endif
 
 {   // Book of the Warp
     SPELL_MANIFOLD_ASSAULT,
@@ -179,7 +179,6 @@ static const vector<spell_type> spellbook_templates[] =
 
 #if TAG_MAJOR_VERSION == 34
 {   // Book of Envenomations
-    SPELL_SPIDER_FORM,
     SPELL_OLGREBS_TOXIC_RADIANCE,
     SPELL_INTOXICATE,
 },
@@ -195,38 +194,40 @@ static const vector<spell_type> spellbook_templates[] =
 {   // Book of Control
     SPELL_ENGLACIATION,
 },
+#endif
 
 {   // Book of Battle
-    SPELL_WEREBLOOD,
+    SPELL_FUGUE_OF_THE_FALLEN,
     SPELL_OZOCUBUS_ARMOUR,
+    SPELL_MANIFOLD_ASSAULT
 },
-#endif
 
 {   // Book of Geomancy
     SPELL_SANDBLAST,
     SPELL_PASSWALL,
     SPELL_STONE_ARROW,
+    SPELL_BOULDER
 },
 
 #if TAG_MAJOR_VERSION == 34
 {   // Book of Stone
     SPELL_LEDAS_LIQUEFACTION,
-    SPELL_STATUE_FORM,
 },
 
 {   // Book of Wizardry
-    SPELL_AGONY,
+    SPELL_CURSE_OF_AGONY,
     SPELL_SPELLFORGED_SERVITOR,
 },
 #endif
 
 {   // Book of Power
     SPELL_BATTLESPHERE,
-    SPELL_IRON_SHOT,
+    SPELL_BOMBARD,
     SPELL_SPELLFORGED_SERVITOR,
 },
 
 {   // Book of Cantrips
+    SPELL_STING,
     SPELL_NECROTISE,
     SPELL_SUMMON_SMALL_MAMMAL,
     SPELL_APPORTATION,
@@ -234,6 +235,7 @@ static const vector<spell_type> spellbook_templates[] =
 
 {   // Book of Party Tricks
     SPELL_APPORTATION,
+    SPELL_JINXBITE,
     SPELL_INTOXICATE,
 },
 
@@ -247,29 +249,30 @@ static const vector<spell_type> spellbook_templates[] =
 
 {   // Book of Debilitation
     SPELL_SLOW,
+    SPELL_SIGIL_OF_BINDING,
     SPELL_VAMPIRIC_DRAINING,
     SPELL_CONFUSING_TOUCH,
 },
 
 {   // Book of the Dragon
     SPELL_CAUSE_FEAR,
-    SPELL_DRAGON_FORM,
+    SPELL_FIREBALL,
     SPELL_DRAGON_CALL,
 },
 
 {   // Book of Burglary
-    SPELL_PASSWALL,
     SPELL_HIBERNATION,
     SPELL_SWIFTNESS,
+    SPELL_PASSWALL,
 },
 
 {   // Book of Dreams
     SPELL_HIBERNATION,
-    SPELL_SPIDER_FORM,
+    SPELL_FUGUE_OF_THE_FALLEN,
     SPELL_ANGUISH,
 },
 
-{   // Book of Alchemy
+{   // Book of Transmutation
     SPELL_SUBLIMATION_OF_BLOOD,
     SPELL_PETRIFY,
     SPELL_IRRADIATE,
@@ -293,8 +296,8 @@ static const vector<spell_type> spellbook_templates[] =
 },
 
 {   // Necronomicon
+    SPELL_HAUNT,
     SPELL_BORGNJORS_REVIVIFICATION,
-    SPELL_NECROMUTATION,
     SPELL_DEATHS_DOOR,
 },
 
@@ -308,8 +311,8 @@ static const vector<spell_type> spellbook_templates[] =
 { // Book of Spectacle
     SPELL_BLASTMOTE,
     SPELL_DAZZLING_FLASH,
-    SPELL_ISKENDERUNS_MYSTIC_BLAST,
     SPELL_STARBURST,
+    SPELL_MAXWELLS_COUPLING,
 },
 
 { // Book of Winter
@@ -319,6 +322,7 @@ static const vector<spell_type> spellbook_templates[] =
 },
 
 { // Book of Spheres
+    SPELL_BOULDER,
     SPELL_BATTLESPHERE,
     SPELL_FIREBALL,
     SPELL_CONJURE_BALL_LIGHTNING,
@@ -334,13 +338,14 @@ static const vector<spell_type> spellbook_templates[] =
 #if TAG_MAJOR_VERSION == 34
 { // Book of Pain
     SPELL_NECROTISE,
-    SPELL_AGONY,
+    SPELL_CURSE_OF_AGONY,
 },
 #endif
 
 { // Book of Decay
     SPELL_ROT,
     SPELL_DISPEL_UNDEAD,
+    SPELL_MARTYRS_KNELL,
     SPELL_DEATH_CHANNEL,
 },
 
@@ -350,11 +355,12 @@ static const vector<spell_type> spellbook_templates[] =
     SPELL_TELEPORT_OTHER,
 },
 
+#if TAG_MAJOR_VERSION == 34
 { // Book of Rime
     SPELL_FROZEN_RAMPARTS,
-    SPELL_ICE_FORM,
     SPELL_SUMMON_ICE_BEAST,
 },
+#endif
 
 { // Everburning Encyclopedia
     SPELL_IGNITE_POISON,
@@ -365,17 +371,20 @@ static const vector<spell_type> spellbook_templates[] =
 { // Book of Earth
     SPELL_LEDAS_LIQUEFACTION,
     SPELL_LRD,
-    SPELL_STATUE_FORM,
+    SPELL_BOMBARD,
 },
 
+#if TAG_MAJOR_VERSION == 34
 { // Ozocubu's Autobio
     SPELL_OZOCUBUS_ARMOUR,
     SPELL_OZOCUBUS_REFRIGERATION,
 },
+#endif
 
 { // Book of the Senses
     SPELL_DAZZLING_FLASH,
-    SPELL_AGONY,
+    SPELL_MEPHITIC_CLOUD,
+    SPELL_CURSE_OF_AGONY,
     SPELL_SILENCE,
 },
 
@@ -389,24 +398,24 @@ static const vector<spell_type> spellbook_templates[] =
     SPELL_BLASTMOTE,
     SPELL_FULMINANT_PRISM,
     SPELL_ISKENDERUNS_MYSTIC_BLAST,
-    SPELL_LRD,
 },
 
 { // Book of Iron
+    SPELL_SUMMON_LIGHTNING_SPIRE,
     SPELL_ANIMATE_ARMOUR,
-    SPELL_BLADE_HANDS,
-    SPELL_IRON_SHOT,
+    SPELL_LRD,
 },
 
+#if TAG_MAJOR_VERSION == 34
 { // Inescapable Atlas
     SPELL_BLINK,
     SPELL_MANIFOLD_ASSAULT,
-    SPELL_STORM_FORM,
 },
+#endif
 
 { // Book of the Tundra
     SPELL_HAILSTORM,
-    SPELL_ICE_FORM,
+    SPELL_SUMMON_ICE_BEAST,
     SPELL_SIMULACRUM,
 },
 
@@ -418,19 +427,20 @@ static const vector<spell_type> spellbook_templates[] =
 
 { // Book of Weapons
     SPELL_TUKIMAS_DANCE,
-    SPELL_PORTAL_PROJECTILE,
-    SPELL_BLADE_HANDS,
+    SPELL_DIMENSIONAL_BULLSEYE,
+    SPELL_ISKENDERUNS_MYSTIC_BLAST,
 },
 
 { // Book of Sloth
+    SPELL_FROZEN_RAMPARTS,
+    SPELL_LEDAS_LIQUEFACTION,
     SPELL_PETRIFY,
     SPELL_ENGLACIATION,
-    SPELL_STATUE_FORM,
 },
 
 { // Book of Blood
+    SPELL_CALL_IMP,
     SPELL_SUBLIMATION_OF_BLOOD,
-    SPELL_WEREBLOOD,
     SPELL_SUMMON_HYDRA,
 },
 
@@ -441,7 +451,7 @@ static const vector<spell_type> spellbook_templates[] =
 },
 
 { // Book of Dangerous Friends
-    SPELL_SUMMON_GUARDIAN_GOLEM,
+    SPELL_SUMMON_BLAZEHEART_GOLEM,
     SPELL_IOOD,
     SPELL_SPELLFORGED_SERVITOR,
 },
@@ -460,7 +470,7 @@ static const vector<spell_type> spellbook_templates[] =
 
 { // Unrestrained Analects
     SPELL_OLGREBS_TOXIC_RADIANCE,
-    SPELL_IGNITION,
+    SPELL_OZOCUBUS_REFRIGERATION,
     SPELL_DISCORD,
 },
 
@@ -483,9 +493,9 @@ static const vector<spell_type> spellbook_templates[] =
 },
 
 { // Book of the Hunter
+    SPELL_SIGIL_OF_BINDING,
     SPELL_CALL_CANINE_FAMILIAR,
-    SPELL_PORTAL_PROJECTILE,
-    SPELL_LEDAS_LIQUEFACTION,
+    SPELL_DIMENSIONAL_BULLSEYE,
 },
 
 { // Book of Scorching
