@@ -17,8 +17,10 @@ enum book_type
     BOOK_LIGHTNING,
     BOOK_DEATH,
     BOOK_MISFORTUNE,
-    BOOK_CHANGES,
+    BOOK_SPONTANEOUS_COMBUSTION,
+#if TAG_MAJOR_VERSION == 34
     BOOK_TRANSFIGURATIONS,
+#endif
     BOOK_FEN,
 #if TAG_MAJOR_VERSION == 34
     BOOK_WAR_CHANTS = BOOK_FEN,
@@ -30,7 +32,9 @@ enum book_type
     BOOK_MALEDICT,
 #endif
     BOOK_AIR,
+#if TAG_MAJOR_VERSION == 34
     BOOK_SKY,
+#endif
     BOOK_WARP,
 #if TAG_MAJOR_VERSION == 34
     BOOK_ENVENOMATIONS,
@@ -38,8 +42,8 @@ enum book_type
     BOOK_UNLIFE,
 #if TAG_MAJOR_VERSION == 34
     BOOK_CONTROL,
-    BOOK_BATTLE, // was BOOK_MUTATIONS
 #endif
+    BOOK_BATTLE,
     BOOK_GEOMANCY,
 #if TAG_MAJOR_VERSION == 34
     BOOK_STONE,
@@ -55,7 +59,7 @@ enum book_type
     BOOK_DRAGON,
     BOOK_BURGLARY,
     BOOK_DREAMS,
-    BOOK_ALCHEMY,
+    BOOK_TRANSMUTATION,
     BOOK_BEASTS,
 
     BOOK_ANNIHILATIONS,
@@ -81,15 +85,21 @@ enum book_type
 #endif
     BOOK_DECAY,
     BOOK_DISPLACEMENT,
+#if TAG_MAJOR_VERSION == 34
     BOOK_RIME,
+#endif
     BOOK_EVERBURNING,
     BOOK_EARTH,
+#if TAG_MAJOR_VERSION == 34
     BOOK_OZOCUBU,
+#endif
     BOOK_SENSES,
     BOOK_MOON,
     BOOK_BLASTING,
     BOOK_IRON,
+#if TAG_MAJOR_VERSION == 34
     BOOK_NEARBY,
+#endif
     BOOK_TUNDRA,
     BOOK_STORMS,
     BOOK_WEAPONS,
