@@ -758,15 +758,9 @@ static bool _dump_item_origin(const item_def &item)
     if (fs(IODS_JEWELLERY) && item.base_type == OBJ_JEWELLERY)
         return true;
 
-    if (fs(IODS_RUNES) && item.base_type == OBJ_RUNES)
-        return true;
-
     if (fs(IODS_STAVES) && item.base_type == OBJ_STAVES)
         return true;
 
-    if (fs(IODS_BOOKS) && item.base_type == OBJ_BOOKS)
-        return true;
-
     const int refpr = Options.dump_item_origin_price;
     if (refpr == -1)
         return false;
@@ -1232,6 +1226,8 @@ static string _describe_action(caction_type type)
 #endif
     case CACT_RIPOSTE:
         return "Riposte";
+    case CACT_FORM:
+        return "Form";
     default:
         return "Error";
     }
@@ -1265,6 +1261,7 @@ static const char* _aux_attack_names[] =
     "Bite",
     "Pseudopods",
     "Tentacles",
+    "Maw",
 };
 COMPILE_CHECK(ARRAYSZ(_aux_attack_names) == NUM_UNARMED_ATTACKS);
 
@@ -1375,6 +1372,8 @@ static string _describe_action_subtype(caction_type type, int compound_subtype)
         COMPILE_CHECK(ARRAYSZ(_stab_names) == NUM_STABS);
         ASSERT_RANGE(subtype, 1, NUM_STABS);
         return _stab_names[subtype];
+    case CACT_FORM:
+        return get_form((transformation)subtype)->short_name;
 #if TAG_MAJOR_VERSION == 34
     case CACT_EAT:
         return "Removed food";
