@@ -37,23 +37,29 @@ struct random_element_colour_calc : public base_colour_calc
     };
 
     virtual int get(const coord_def& loc = coord_def(),
-                    bool non_random = false) override;
+                    bool non_random = false) const override;
+    int get_nth(int n) const override;
 
 protected:
     random_colour_map rand_vals;
 };
 
-int base_colour_calc::rand(bool non_random)
+int base_colour_calc::rand(bool non_random) const
 {
     return non_random ? 0 : ui_random(rand_max);
 }
 
-int element_colour_calc::get(const coord_def& loc, bool non_random)
+int element_colour_calc::get(const coord_def& loc, bool non_random) const
 {
     return (*calc)(rand(non_random), loc);
 }
 
-int random_element_colour_calc::get(const coord_def& /*loc*/, bool non_random)
+int element_colour_calc::get_nth(int /*n*/) const
+{
+    return get(you.pos()); // arbitrary - hopefully unused
+}
+
+int random_element_colour_calc::get(const coord_def& /*loc*/, bool non_random) const
 {
     const auto max_val = rand(non_random);
     int accum = 0;
@@ -63,6 +69,11 @@ int random_element_colour_calc::get(const coord_def& /*loc*/, bool non_random)
     return BLACK;
 }
 
+int random_element_colour_calc::get_nth(int n) const
+{
+    return rand_vals[n % rand_vals.size()].second;
+}
+
 colour_t random_colour(bool ui_rand)
 {
     return 1 + (ui_rand ? ui_random : random2)(15);
@@ -571,6 +582,11 @@ void init_element_colours()
                               {40,  LIGHTGREY},
                               {40,  DARKGREY},
                             }));
+    add_element_colour(new random_element_colour_calc(
+                            ETC_STEEL, "steel",
+                            { {1,  CYAN},
+                              {1,  LIGHTGREY},
+                            }));
     add_element_colour(new random_element_colour_calc(
                             ETC_BONE, "bone",
                             { {90,  WHITE},
@@ -806,3 +822,24 @@ unsigned real_colour(unsigned raw_colour, const coord_def& loc)
 
     return raw_colour;
 }
+
+string colourize_str(string base, colour_t col)
+{
+    if (col < NUM_TERM_COLOURS)
+    {
+        if (col == BLACK)
+            col = DARKGRAY;
+        const string col_name = colour_to_str(col);
+        return make_stringf("<%s>%s</%s>",
+                            col_name.c_str(), base.c_str(), col_name.c_str());
+    }
+    ASSERT(element_colours[col]);
+    string out;
+    for (int i = 0; i < (int)base.length(); i++)
+    {
+        const colour_t term_col = element_colours[col]->get_nth(i);
+        const string col_name = colour_to_str(term_col);
+        out += "<" + col_name + ">" + base[i] + "</" + col_name + ">";
+    }
+    return out;
+}
