@@ -30,7 +30,7 @@ enum duration_type
 #endif
     DUR_EXHAUSTED,              // fatigue counter for berserk
 
-    DUR_LIQUID_FLAMES,
+    DUR_STICKY_FLAME,
     DUR_ICY_ARMOUR,
 #if TAG_MAJOR_VERSION == 34
     DUR_REPEL_MISSILES,
@@ -144,7 +144,7 @@ enum duration_type
     DUR_SPIRIT_HOWL,
     DUR_INFUSION,
 #endif
-    DUR_WEREBLOOD,
+    DUR_FUGUE,
 #if TAG_MAJOR_VERSION == 34
     DUR_SONG_OF_SHIELDING,
 #endif
@@ -166,7 +166,7 @@ enum duration_type
 #if TAG_MAJOR_VERSION == 34
     DUR_MAGIC_SAPPED,
 #endif
-    DUR_PORTAL_PROJECTILE,
+    DUR_DIMENSIONAL_BULLSEYE,
     DUR_FORESTED,
     DUR_DRAGON_CALL,
     DUR_DRAGON_CALL_COOLDOWN,
@@ -221,7 +221,9 @@ enum duration_type
     DUR_STABBING,
 #endif
     DUR_ATTRACTIVE,
+#if TAG_MAJOR_VERSION == 34
     DUR_LOCKED_DOWN,
+#endif
     DUR_WORD_OF_CHAOS_COOLDOWN,
     DUR_SICKNESS,
     DUR_BLINKBOLT_COOLDOWN,
@@ -235,5 +237,17 @@ enum duration_type
     DUR_CORPSE_ROT,
 #endif
     DUR_NO_MOMENTUM,
+    DUR_ENLIGHTENED,
+    DUR_REVELATION,
+    DUR_SIPHON_COOLDOWN,
+    DUR_JINXBITE,
+#if TAG_MAJOR_VERSION == 34
+    DUR_BINDING_SIGIL_WARNING,
+#endif
+    DUR_JINXBITE_LOST_INTEREST,
+    DUR_VITRIFIED,
+    DUR_RAMPAGE_HEAL,
+    DUR_CANINE_FAMILIAR_DEAD,
+    DUR_TEMP_CLOUD_IMMUNITY,
     NUM_DURATIONS
 };
