@@ -112,8 +112,17 @@ int to_hit_pct(const monster_info& mi, attack &atk, bool melee)
         adjusted_mhit += atk.post_roll_to_hit_modifiers(adjusted_mhit, false);
 
         // Duplicates ranged_attack::post_roll_to_hit_modifiers().
-        if (!melee && mi.is(MB_REPEL_MSL))
-            adjusted_mhit -= (adjusted_mhit + 1) / 2;
+        if (!melee)
+        {
+            if (mi.is(MB_BULLSEYE_TARGET))
+            {
+                adjusted_mhit += calc_spell_power(SPELL_DIMENSIONAL_BULLSEYE)
+                                 / 2 / BULLSEYE_TO_HIT_DIV;
+            }
+
+            if (mi.is(MB_REPEL_MSL))
+                adjusted_mhit -= (adjusted_mhit + 1) / 2;
+        }
 
         if (adjusted_mhit >= ev)
             hits++;
@@ -236,7 +245,7 @@ static bool _autoswitch_to_melee()
 
 static bool _can_shoot_with(const item_def *weapon)
 {
-    // TOOD: dedup elsewhere.
+    // TODO: dedup elsewhere.
     return weapon
         && is_range_weapon(*weapon)
         && !you.attribute[ATTR_HELD]
@@ -287,7 +296,7 @@ bool fight_melee(actor *attacker, actor *defender, bool *did_hit, bool simu)
         // Friendly and good neutral monsters won't attack unless confused.
         if (attacker->as_monster()->wont_attack()
             && !mons_is_confused(*attacker->as_monster())
-            && !attacker->as_monster()->has_ench(ENCH_INSANE))
+            && !attacker->as_monster()->has_ench(ENCH_FRENZIED))
         {
             return false;
         }
@@ -773,7 +782,7 @@ static bool _dont_harm(const actor &attacker, const actor &defender)
     {
         return defender.wont_attack()
                || mons_attitude(*defender.as_monster()) == ATT_NEUTRAL
-                  && !defender.as_monster()->has_ench(ENCH_INSANE);
+                  && !defender.as_monster()->has_ench(ENCH_FRENZIED);
     }
 
     return false;
@@ -800,7 +809,7 @@ bool force_player_cleave(coord_def target)
             return true;
 
         if (!you.fumbles_attack())
-            attack_cleave_targets(you, cleave_targets);
+            attack_multiple_targets(you, cleave_targets);
         return true;
     }
 
@@ -814,6 +823,11 @@ bool attack_cleaves(const actor &attacker, int which_attack)
     {
         return true;
     }
+    else if (attacker.is_monster()
+             && attacker.as_monster()->has_ench(ENCH_INSTANT_CLEAVE))
+    {
+        return true;
+    }
 
     const item_def* weap = attacker.weapon(which_attack);
     return weap && weapon_cleaves(*weap);
@@ -825,6 +839,20 @@ bool weapon_cleaves(const item_def &weap)
            || is_unrandom_artefact(weap, UNRAND_LOCHABER_AXE);
 }
 
+int weapon_hits_per_swing(const item_def &weap)
+{
+    if (!weap.is_type(OBJ_WEAPONS, WPN_QUICK_BLADE))
+        return 1;
+    if (is_unrandom_artefact(weap, UNRAND_GYRE))
+        return 4;
+    return 2;
+}
+
+bool weapon_multihits(const item_def *weap)
+{
+    return weap && weapon_hits_per_swing(*weap) > 1;
+}
+
 /**
  * List potential cleave targets (adjacent hostile creatures), including the
  * defender itself.
@@ -835,7 +863,8 @@ bool weapon_cleaves(const item_def &weap)
  * @param which_attack   The attack_number (default -1, which uses the default weapon).
  */
 void get_cleave_targets(const actor &attacker, const coord_def& def,
-                        list<actor*> &targets, int which_attack)
+                        list<actor*> &targets, int which_attack,
+                        bool force_cleaving)
 {
     // Prevent scanning invalid coordinates if the attacker dies partway through
     // a cleave (due to hitting explosive creatures, or perhaps other things)
@@ -845,69 +874,43 @@ void get_cleave_targets(const actor &attacker, const coord_def& def,
     if (actor_at(def))
         targets.push_back(actor_at(def));
 
+    if (!force_cleaving && !attack_cleaves(attacker, which_attack))
+        return;
+
     const item_def* weap = attacker.weapon(which_attack);
+    const coord_def atk = attacker.pos();
+    //If someone adds a funky reach which isn't just a number
+    //They will need to special case it here.
+    const int cleave_radius = weap ? weapon_reach(*weap) : 1;
 
-    if (attack_cleaves(attacker, which_attack))
+    for (distance_iterator di(atk, true, true, cleave_radius); di; ++di)
     {
-        const coord_def atk = attacker.pos();
-        //If someone adds a funky reach which isn't just a number
-        //They will need to special case it here.
-        const int cleave_radius = weap ? weapon_reach(*weap) : 1;
-
-        for (distance_iterator di(atk, true, true, cleave_radius); di; ++di)
-        {
-            if (*di == def) continue; // no double jeopardy
-            actor *target = actor_at(*di);
-            if (!target || _dont_harm(attacker, *target))
-                continue;
-            if (di.radius() == 2 && !can_reach_attack_between(atk, *di, REACH_TWO))
-                continue;
-            targets.push_back(target);
-        }
-    }
-
-    // fake cleaving: gyre and gimble's extra attacks are implemented as
-    // cleaving attacks on enemies already in `targets`
-    if (weap && is_unrandom_artefact(*weap, UNRAND_GYRE))
-    {
-        list<actor*> new_targets;
-        for (actor* targ : targets)
-        {
-            new_targets.push_back(targ);
-            new_targets.push_back(targ);
-        }
-        targets = new_targets;
+        if (*di == def) continue; // no double jeopardy
+        actor *target = actor_at(*di);
+        if (!target || _dont_harm(attacker, *target))
+            continue;
+        if (di.radius() == 2 && !can_reach_attack_between(atk, *di, REACH_TWO))
+            continue;
+        targets.push_back(target);
     }
 }
 
 /**
- * Attack a provided list of cleave targets.
+ * Attack a provided list of cleave or quick-blade targets.
  *
  * @param attacker                  The attacking creature.
  * @param targets                   The targets to cleave.
  * @param attack_number             ?
  * @param effective_attack_number   ?
  */
-void attack_cleave_targets(actor &attacker, list<actor*> &targets,
-                           int attack_number, int effective_attack_number,
-                           wu_jian_attack_type wu_jian_attack,
-                           bool is_projected)
+void attack_multiple_targets(actor &attacker, list<actor*> &targets,
+                             int attack_number, int effective_attack_number,
+                             wu_jian_attack_type wu_jian_attack,
+                             bool is_projected, bool is_cleaving)
 {
     if (!attacker.alive())
         return;
     const item_def* weap = attacker.weapon(attack_number);
-    if (attacker.is_player())
-    {
-        if ((wu_jian_attack == WU_JIAN_ATTACK_WHIRLWIND
-             || wu_jian_attack == WU_JIAN_ATTACK_WALL_JUMP
-             || wu_jian_attack == WU_JIAN_ATTACK_TRIGGERED_AUX)
-            && !(weap && is_unrandom_artefact(*weap, UNRAND_GYRE)))
-        {
-            return; // WJC AOE attacks don't cleave, but G&G use cleaving
-            // XXX: If a player under Xom wrath gets cleaving while using G&G and
-            // worshiping Wu they'll be able to cleave their Wu attacks.
-        }
-    }
     const bool reaching = weap && weapon_reach(*weap) > REACH_NONE;
     while (attacker.alive() && !targets.empty())
     {
@@ -919,10 +922,11 @@ void attack_cleave_targets(actor &attacker, list<actor*> &targets,
                 || reaching))
         {
             melee_attack attck(&attacker, def, attack_number,
-                               ++effective_attack_number, true);
+                               ++effective_attack_number, is_cleaving);
 
             attck.wu_jian_attack = wu_jian_attack;
             attck.is_projected = is_projected;
+            attck.is_multihit = !is_cleaving; // heh heh heh
             attck.attack();
         }
         targets.pop_front();
@@ -1055,7 +1059,7 @@ bool bad_attack(const monster *mon, string& adj, string& suffix,
         return true;
     }
 
-    if (mon->neutral() && is_good_god(you.religion) && !mon->has_ench(ENCH_INSANE))
+    if (mon->neutral() && is_good_god(you.religion) && !mon->has_ench(ENCH_FRENZIED))
     {
         adj += "neutral ";
         if (you_worship(GOD_SHINING_ONE) || you_worship(GOD_ELYVILON))
@@ -1073,7 +1077,7 @@ bool bad_attack(const monster *mon, string& adj, string& suffix,
 
 bool stop_attack_prompt(const monster* mon, bool beam_attack,
                         coord_def beam_target, bool *prompted,
-                        coord_def attack_pos)
+                        coord_def attack_pos, bool check_only)
 {
     ASSERT(mon); // XXX: change to const monster &mon
     bool penance = false;
@@ -1084,13 +1088,20 @@ bool stop_attack_prompt(const monster* mon, bool beam_attack,
     if (crawl_state.disables[DIS_CONFIRMATIONS])
         return false;
 
-    if (you.confused() || !you.can_see(*mon))
+    // The player is ordinarily given a different prompt before this if confused,
+    // but if we're merely testing if this attack *could* be bad, we should do
+    // the full check anyway.
+    if ((you.confused() && !check_only) || !you.can_see(*mon))
         return false;
 
     string adj, suffix;
     if (!bad_attack(mon, adj, suffix, penance, attack_pos))
         return false;
 
+    // We have already determined this attack *would* prompt, so stop here
+    if (check_only)
+        return true;
+
     // Listed in the form: "your rat", "Blork the orc".
     string mon_name = mon->name(DESC_PLAIN);
     if (starts_with(mon_name, "the ")) // no "your the Royal Jelly" nor "the the RJ"
@@ -1131,7 +1142,8 @@ bool stop_attack_prompt(const monster* mon, bool beam_attack,
 
 bool stop_attack_prompt(targeter &hitfunc, const char* verb,
                         function<bool(const actor *victim)> affects,
-                        bool *prompted, const monster *defender)
+                        bool *prompted, const monster *defender,
+                        bool check_only)
 {
     if (crawl_state.disables[DIS_CONFIRMATIONS])
         return false;
@@ -1139,7 +1151,10 @@ bool stop_attack_prompt(targeter &hitfunc, const char* verb,
     if (crawl_state.which_god_acting() == GOD_XOM)
         return false;
 
-    if (you.confused())
+    // The player is ordinarily given a different prompt before this if confused,
+    // but if we're merely testing if this attack *could* be bad, we should do
+    // the full check anyway.
+    if (you.confused() && !check_only)
         return false;
 
     string adj, suffix;
@@ -1177,6 +1192,10 @@ bool stop_attack_prompt(targeter &hitfunc, const char* verb,
     if (victims.empty())
         return false;
 
+    // We have already determined that this attack *would* prompt, so stop here
+    if (check_only)
+        return true;
+
     // Listed in the form: "your rat", "Blork the orc".
     string mon_name = victims.describe(DESC_PLAIN);
     if (starts_with(mon_name, "the ")) // no "your the Royal Jelly" nor "the the RJ"
@@ -1360,15 +1379,18 @@ int brand_adjust_weapon_damage(int base_dam, int brand, bool random)
     return base_dam * 9 / 5;
 }
 
-int unarmed_base_damage()
+int unarmed_base_damage(bool random)
 {
-    int damage = get_form()->get_base_unarmed_damage();
+    int damage = get_form()->get_base_unarmed_damage(random);
 
     if (you.has_usable_claws())
         damage += you.has_claws() * 2;
 
     if (you.form_uses_xl())
-        damage += div_rand_round(you.experience_level, 3);
+    {
+        damage += random ? div_rand_round(you.experience_level, 3)
+                         : you.experience_level / 3;
+    }
 
     return damage;
 }
