@@ -15,32 +15,33 @@ struct form_entry
     const char *description;
 
     // Row 3:
+    int min_skill;
+    int max_skill;
+    talisman_type talisman;
+
+    // Row 4:
     int blocked_slots;
     int resists;
 
-    // Row 4:
+    // Row 5:
     FormDuration duration;
     int str_mod;
     int dex_mod;
     size_type size;
     int hp_mod;
 
-    // Row 5
-    int flat_ac;
-    int power_ac;
-    int xl_ac;
+    // Row 6:
+    FormScaling ac;
     bool can_cast;
-    int spellcasting_penalty;
-    bool unarmed_hit_bonus;
-    int base_unarmed_damage;
+    FormScaling unarmed_bonus_dam;
 
-    // Row 6
+    // Row 7:
     brand_type uc_brand;
     int uc_colour;
     const char *uc_attack;
     FormAttackVerbs uc_attack_verbs;
 
-    // Row 7
+    // Row 8:
     form_capability can_fly;
     form_capability can_swim;
     form_capability can_bleed;
@@ -63,20 +64,23 @@ static const form_entry formdata[] =
 {
     transformation::none, MONS_PLAYER, "", "", "none",
     "",
+    0, 0, NUM_TALISMANS,
     EQF_NONE, MR_NO_FLAGS,
     FormDuration(0, PS_NONE, 0), 0, 0, SIZE_CHARACTER, 10,
-    0, 0, 0, true, 0, false, 3,
+    {}, true, {},
     SPWPN_NORMAL, LIGHTGREY, "", DEFAULT_VERBS,
     FC_DEFAULT, FC_DEFAULT, FC_DEFAULT, true,
     "", 0, "", "", "", "",
     {}
 },
+#if TAG_MAJOR_VERSION == 34
 {
     transformation::spider, MONS_SPIDER, "Spider", "spider-form", "spider",
     "a venomous arachnid creature.",
+    0, 27, NUM_TALISMANS,
     EQF_PHYSICAL, MR_VUL_POISON,
     FormDuration(10, PS_DOUBLE, 60), 0, 5, SIZE_TINY, 10,
-    2, 0, 0, true, 10, true, 5,
+    {}, true, {},
     SPWPN_VENOM, LIGHTGREEN, "Fangs", ANIMAL_VERBS,
     FC_DEFAULT, FC_FORBID, FC_FORBID, false,
     "hiss", -4, "front pincers", "", "crawl onto", "flesh",
@@ -84,12 +88,14 @@ static const form_entry formdata[] =
       {"", "You are tiny and dextrous."} // short-form "tiny" is automatically added
     }
 },
+#endif
 {
     transformation::blade_hands, MONS_PLAYER, "Blade", "", "blade",
     "",
+    10, 19, TALISMAN_BLADE,
     EQF_HANDS, MR_NO_FLAGS,
     FormDuration(10, PS_SINGLE, 100), 0, 0, SIZE_CHARACTER, 10,
-    0, 0, 0, true, 20, true, 22,
+    {}, true, FormScaling().Base(12).Scaling(8),
     SPWPN_NORMAL, RED, "", { "hit", "slash", "slice", "shred" },
     FC_DEFAULT, FC_DEFAULT, FC_DEFAULT, true,
     "", 0, "", "", "", "",
@@ -98,9 +104,10 @@ static const form_entry formdata[] =
 {
     transformation::statue, MONS_STATUE, "Statue", "statue-form", "statue",
     "a stone statue.",
+    16, 25, TALISMAN_STATUE,
     EQF_STATUE, MR_RES_ELEC | MR_RES_NEG | MR_RES_PETRIFY,
     DEFAULT_DURATION, 0, 0, SIZE_CHARACTER, 13,
-    20, 12, 0, true, 0, true, 12,
+    FormScaling().Base(27).Scaling(11), true, FormScaling().Base(9),
     SPWPN_NORMAL, LIGHTGREY, "", DEFAULT_VERBS,
     FC_DEFAULT, FC_FORBID, FC_FORBID, true,
     "", 0, "", "", "place yourself before", "stone",
@@ -109,43 +116,45 @@ static const form_entry formdata[] =
     }
 },
 {
-    transformation::ice_beast, MONS_ICE_BEAST, "Ice", "ice-form", "ice",
-    "a creature of crystalline ice.",
-    EQF_PHYSICAL, MR_RES_POISON | MR_VUL_FIRE | mrd(MR_RES_COLD, 3),
-    FormDuration(30, PS_DOUBLE, 100), 0, 0, SIZE_LARGE, 12,
-    5, 12, 0, true, 0, true, 12,
-    SPWPN_FREEZING, WHITE, "", DEFAULT_VERBS,
-    FC_DEFAULT, FC_ENABLE, FC_FORBID, false,
-    "", 0, "front paw", "paw", "bow your head before", "ice",
-    { { "freezing attack", "You have a powerful freezing melee attack."} }
+    transformation::serpent, MONS_ANACONDA, "Serpent", "snake-form", "snake",
+    "an enormous serpent.",
+    10, 19, TALISMAN_SERPENT,
+    EQF_PHYSICAL, MR_RES_POISON,
+    DEFAULT_DURATION, 5, 0, SIZE_LARGE, 12,
+    FormScaling().Base(9).Scaling(6), true, FormScaling().Base(7),
+    SPWPN_NORMAL, LIGHTGREY, "", { "hit", "lash", "body-slam", "crush" },
+    FC_DEFAULT, FC_ENABLE, FC_ENABLE, false,
+    "hiss", -2, "", "", "coil in front of", "flesh",
+    { { "constrict", "You have a powerful constriction melee attack."} }
 },
 
 {
     transformation::dragon, MONS_PROGRAM_BUG, "Dragon", "dragon-form", "dragon",
     "a fearsome dragon!",
+    16, 25, TALISMAN_DRAGON,
     EQF_PHYSICAL, MR_RES_POISON,
     DEFAULT_DURATION, 10, 0, SIZE_GIANT, 15,
-    16, 0, 0, true, 0, true, 32,
+    FormScaling().Base(12).Scaling(6), true, FormScaling().Base(15).Scaling(9),
     SPWPN_NORMAL, GREEN, "Teeth and claws", { "hit", "claw", "bite", "maul" },
     FC_ENABLE, FC_FORBID, FC_ENABLE, false,
     "roar", 6, "foreclaw", "", "bow your head before", "flesh",
     { { "dragon claw", "You have a powerful clawing attack." },
-      { "dragon scales", "Your giant scaled body is strong and resiliant, but less evasive." },
+      { "dragon scales", "Your giant scaled body is strong and resilient, but less evasive." },
     }
 },
 
 {
-    transformation::lich, MONS_LICH, "Lich", "lich-form", "lich",
-    "an undead lich.",
+    transformation::death, MONS_ANCIENT_CHAMPION, "Death", "death-form", "death",
+    "an undying horror.",
+    23, 27, TALISMAN_DEATH,
     EQF_NONE, MR_RES_COLD | mrd(MR_RES_NEG, 3),
     DEFAULT_DURATION, 0, 0, SIZE_CHARACTER, 10,
-    6, 0, 0, true, 0, true, 5,
+    {}, true, FormScaling().Base(6),
     SPWPN_DRAINING, MAGENTA, "", DEFAULT_VERBS,
     FC_DEFAULT, FC_DEFAULT, FC_FORBID, true,
     "", 0, "", "", "", "bone",
-    { { "draining attack", "Your unarmed attacks are suffused with negative energy."},
+    { { "vile attack", "Your melee and unarmed attacks drain, slow and weaken victims."},
       { "torment immunity", "You are immune to unholy pain and torment."},
-      { "", "Your necromantic spells are more powerful." },
       { "no potions", "<lightred>You cannot drink.</lightred>" },
     }
 },
@@ -153,9 +162,10 @@ static const form_entry formdata[] =
 {
     transformation::bat, MONS_PROGRAM_BUG, "Bat", "bat-form", "bat",
     "",
+    0, 0, NUM_TALISMANS,
     EQF_PHYSICAL | EQF_RINGS, MR_NO_FLAGS,
     DEFAULT_DURATION, 0, 5, SIZE_TINY, 10,
-    0, 0, 0, false, 0, true, 1,
+    {}, false, FormScaling().Base(-2),
     SPWPN_NORMAL, LIGHTGREY, "Teeth", ANIMAL_VERBS,
     FC_ENABLE, FC_FORBID, FC_ENABLE, false,
     "squeak", -8, "foreclaw", "", "perch on", "flesh",
@@ -167,33 +177,38 @@ static const form_entry formdata[] =
 {
     transformation::pig, MONS_HOG, "Pig", "pig-form", "pig",
     "a filthy swine.",
+    0, 0, NUM_TALISMANS,
     EQF_PHYSICAL | EQF_RINGS, MR_NO_FLAGS,
     BAD_DURATION, 0, 0, SIZE_SMALL, 10,
-    0, 0, 0, false, 0, false, 3,
+    {}, false, FormScaling().XLBased(),
     SPWPN_NORMAL, LIGHTGREY, "Teeth", ANIMAL_VERBS,
     FC_DEFAULT, FC_FORBID, FC_ENABLE, false,
     "squeal", 0, "front trotter", "trotter", "bow your head before", "flesh",
     {} // XX UC penalty?
 },
 
+#if TAG_MAJOR_VERSION == 34
 {
     transformation::appendage, MONS_PLAYER, "App", "appendages", "appendages",
     "",
-    EQF_HEAD_FOOT, MR_NO_FLAGS,
+    0, 0, NUM_TALISMANS,
+    SLOTF(EQ_BOOTS) | SLOTF(EQ_HELMET), MR_NO_FLAGS,
     FormDuration(10, PS_DOUBLE, 60), 0, 0, SIZE_CHARACTER, 10,
-    0, 0, 0, true, 0, false, 3,
+    {}, true, {},
     SPWPN_NORMAL, LIGHTGREY, "", DEFAULT_VERBS,
     FC_DEFAULT, FC_DEFAULT, FC_DEFAULT, true,
     "", 0, "", "", "", "",
     {}
 },
+#endif
 
 {
     transformation::tree, MONS_ANIMATED_TREE, "Tree", "tree-form", "tree",
     "a tree.",
+    0, 0, NUM_TALISMANS,
     EQF_LEAR | SLOTF(EQ_CLOAK), MR_RES_POISON,
     BAD_DURATION, 0, 0, SIZE_CHARACTER, 15,
-    20, 0, 50, true, 0, true, 12,
+    FormScaling().Base(20).Scaling(14).XLBased(), true, FormScaling().Base(9),
     SPWPN_NORMAL, BROWN, "Branches", { "hit", "smack", "pummel", "thrash" },
     FC_FORBID, FC_FORBID, FC_FORBID, false,
     "creak", 0, "branch", "root", "sway towards", "wood",
@@ -208,9 +223,10 @@ static const form_entry formdata[] =
 {
     transformation::porcupine, MONS_PORCUPINE, "Porc", "porcupine-form", "porcupine",
     "a spiny porcupine.",
+    0, 0, NUM_TALISMANS,
     EQF_ALL, MR_NO_FLAGS,
     BAD_DURATION, 0, 0, SIZE_TINY, 10,
-    0, 0, 0, false, 0, false, 3,
+    {}, false, FormScaling().XLBased(),
     SPWPN_NORMAL, LIGHTGREY, "Teeth", ANIMAL_VERBS,
     FC_DEFAULT, FC_FORBID, FC_ENABLE, false,
     "squeak", -8, "front leg", "", "curl into a sanctuary of spikes before", "flesh",
@@ -221,11 +237,12 @@ static const form_entry formdata[] =
 {
     transformation::wisp, MONS_INSUBSTANTIAL_WISP, "Wisp", "wisp-form", "wisp",
     "an insubstantial wisp.",
+    0, 0, NUM_TALISMANS,
     EQF_ALL, mrd(MR_RES_FIRE, 2) | mrd(MR_RES_COLD, 2) | MR_RES_ELEC
-             | MR_RES_STICKY_FLAME | mrd(MR_RES_NEG, 3) | MR_RES_ACID
+             | mrd(MR_RES_NEG, 3) | MR_RES_ACID
              | MR_RES_PETRIFY,
     BAD_DURATION, 0, 0, SIZE_TINY, 10,
-    5, 0, 50, false, 0, true, 5,
+    FormScaling().Base(5).Scaling(14).XLBased(), false, FormScaling().Base(2).XLBased(),
     SPWPN_NORMAL, LIGHTGREY, "Misty tendrils", { "touch", "touch",
                                                  "engulf", "engulf" },
     FC_ENABLE, FC_FORBID, FC_FORBID, false,
@@ -239,9 +256,10 @@ static const form_entry formdata[] =
 {
     transformation::jelly, MONS_JELLY, "Jelly", "jelly-form", "jelly",
     "a lump of jelly.",
+    0, 0, NUM_TALISMANS,
     EQF_PHYSICAL | EQF_RINGS, MR_NO_FLAGS,
     BAD_DURATION, 0, 0, SIZE_CHARACTER, 10,
-    0, 0, 0, false, 0, false, 3,
+    {}, false, FormScaling().XLBased(),
     SPWPN_NORMAL, LIGHTGREY, "", DEFAULT_VERBS,
     FC_DEFAULT, FC_FORBID, FC_FORBID, false,
     "", 0, "", "", "", "",
@@ -252,9 +270,10 @@ static const form_entry formdata[] =
 {
     transformation::fungus, MONS_WANDERING_MUSHROOM, "Fungus", "fungus-form", "fungus",
     "a sentient fungus.",
+    0, 0, NUM_TALISMANS,
     EQF_PHYSICAL, MR_RES_POISON | mrd(MR_RES_NEG, 3),
     BAD_DURATION, 0, 0, SIZE_TINY, 10,
-    12, 0, 0, false, 0, true, 12,
+    FormScaling().Base(12), false, FormScaling().Base(9).XLBased(),
     SPWPN_CONFUSE, BROWN, "Spores", FormAttackVerbs("release spores at"),
     FC_DEFAULT, FC_FORBID, FC_FORBID, false,
     "sporulate", -8, "hypha", "", "release spores on", "flesh",
@@ -268,10 +287,11 @@ static const form_entry formdata[] =
 {
     transformation::shadow, MONS_PLAYER_SHADOW, "Shadow", "shadow-form", "shadow",
     "a swirling mass of dark shadows.",
+    0, 0, NUM_TALISMANS,
     EQF_NONE, mrd(MR_RES_POISON, 3) | mrd(MR_RES_NEG, 3) | MR_RES_MIASMA
                                                          | MR_RES_PETRIFY,
     DEFAULT_DURATION, 0, 0, SIZE_CHARACTER, 10,
-    0, 0, 0, true, 0, false, 3,
+    {}, true, {},
     SPWPN_NORMAL, MAGENTA, "", DEFAULT_VERBS,
     FC_DEFAULT, FC_FORBID, FC_FORBID, true,
     "", 0, "", "", "", "shadow",
@@ -288,9 +308,10 @@ static const form_entry formdata[] =
 {
     transformation::hydra, MONS_HYDRA, "Hydra", "hydra-form", "hydra",
     "",
+    0, 0, NUM_TALISMANS,
     EQF_PHYSICAL, MR_RES_POISON,
     DEFAULT_DURATION, 0, 0, SIZE_GIANT, 13,
-    6, 5, 0, true, 0, true, -1,
+    {}, true, {},
     SPWPN_NORMAL, GREEN, "", { "nip at", "bite", "gouge", "chomp" },
     FC_DEFAULT, FC_ENABLE, FC_ENABLE, false,
     "roar", 4, "foreclaw", "", "bow your heads before", "flesh",
@@ -303,9 +324,10 @@ static const form_entry formdata[] =
 {
     transformation::storm, MONS_TWISTER, "Storm", "storm-form", "storm",
     "a lightning-filled tempest!",
-    EQF_PHYSICAL, MR_RES_ELEC | MR_RES_PETRIFY | MR_RES_STICKY_FLAME,
+    23, 27, TALISMAN_STORM,
+    EQF_PHYSICAL, MR_RES_ELEC | MR_RES_PETRIFY,
     DEFAULT_DURATION, 0, 0, SIZE_CHARACTER, 10,
-    10, 10, 0, true, 0, true, -1,
+    FormScaling().Base(12).Scaling(3), true, FormScaling().Base(24).Scaling(6),
     SPWPN_ELECTROCUTION, LIGHTCYAN, "", { "hit", "buffet", "batter", "blast" },
     FC_ENABLE, FC_DEFAULT, FC_FORBID, false,
     "bellow", 0, "", "", "place yourself before", "air",
@@ -313,7 +335,47 @@ static const form_entry formdata[] =
       { "", "You are incredibly evasive." },
       { "insubstantial", "Your insubstantial body is immune to petrification, constriction, and being set on fire"}
     }
-}
+},
+
+{
+    transformation::beast, MONS_WOLF, "Beast", "beast-form", "beast",
+    "a hulking beast.",
+    0, 7, TALISMAN_BEAST,
+    EQF_AUXES, MR_NO_FLAGS,
+    DEFAULT_DURATION, 0, 0, SIZE_CHARACTER, 10,
+    {}, true, {},
+    SPWPN_NORMAL, LIGHTGREY, "", DEFAULT_VERBS,
+    FC_DEFAULT, FC_DEFAULT, FC_DEFAULT, true,
+    "", 0, "", "", "", "",
+    { }
+},
+
+{
+    transformation::maw, MONS_PUTRID_MOUTH, "Maw", "maw-form", "maw",
+    "a creature with a mouth for a stomach.",
+    10, 19, TALISMAN_MAW,
+    SLOTF(EQ_BODY_ARMOUR), MR_NO_FLAGS,
+    DEFAULT_DURATION, 0, 0, SIZE_CHARACTER, 10,
+    {}, true, FormScaling().Base(2),
+    SPWPN_NORMAL, GREEN, "", DEFAULT_VERBS,
+    FC_DEFAULT, FC_DEFAULT, FC_DEFAULT, true,
+    "shout twice", 0, "", "", "", "",
+    { { "devouring maw", "Your midsection houses a second, enormous mouth." },}
+},
+
+{
+    transformation::flux, MONS_SHAPESHIFTER, "Flux", "flux-form", "flux",
+    "something dangerously unstable.",
+    7, 14, TALISMAN_FLUX,
+    SLOTF(EQ_WEAPON) | SLOTF(EQ_SHIELD) | SLOTF(EQ_BODY_ARMOUR), MR_NO_FLAGS,
+    DEFAULT_DURATION, 0, 0, SIZE_CHARACTER, 10,
+    {}, true, {},
+    SPWPN_NORMAL, CYAN, "", DEFAULT_VERBS,
+    FC_DEFAULT, FC_DEFAULT, FC_DEFAULT, true,
+    "", 0, "", "", "", "",
+    { { "glow", "You glow with magical radiation, making you easy to see and hit." },
+      { "contaminating", "Foes you strike become dangerously contaminated with magical radiation." } }
+},
 
 };
 COMPILE_CHECK(ARRAYSZ(formdata) == NUM_TRANSFORMS);
