@@ -32,7 +32,7 @@
 
 #define MAX_GHOST_DAMAGE     50
 #define MAX_GHOST_HP        400
-#define MAX_GHOST_EVASION    60
+#define MAX_GHOST_EVASION    50
 
 // Pan lord AOE conjuration spell list.
 static spell_type search_order_aoe_conj[] =
@@ -41,30 +41,30 @@ static spell_type search_order_aoe_conj[] =
     SPELL_FIRE_STORM,
     SPELL_GLACIATE,
     SPELL_CHAIN_LIGHTNING,
-    SPELL_FREEZING_CLOUD,
-    SPELL_POISONOUS_CLOUD,
-    SPELL_METAL_SPLINTERS,
-    SPELL_ENERGY_BOLT,
     SPELL_ORB_OF_ELECTRICITY,
     SPELL_CONJURE_BALL_LIGHTNING,
+    SPELL_MARCH_OF_SORROWS,
+    SPELL_POISONOUS_CLOUD,
 };
 
 // Pan lord conjuration spell list.
 static spell_type search_order_conj[] =
 {
     SPELL_CALL_DOWN_DAMNATION,
-    SPELL_LEHUDIBS_CRYSTAL_SPEAR,
-    SPELL_CORROSIVE_BOLT,
     SPELL_QUICKSILVER_BOLT,
+    SPELL_BOLT_OF_DEVASTATION,
     SPELL_IOOD,
-    SPELL_ENERGY_BOLT,
-    SPELL_MINDBURST,
     SPELL_BOLT_OF_FIRE,
     SPELL_BOLT_OF_COLD,
-    SPELL_IRON_SHOT,
-    SPELL_POISON_ARROW,
-    SPELL_BOLT_OF_DRAINING,
+    SPELL_BOMBARD,
+    SPELL_METAL_SPLINTERS,
+    SPELL_LEHUDIBS_CRYSTAL_SPEAR,
     SPELL_LIGHTNING_BOLT,
+    SPELL_PLASMA_BEAM,
+    SPELL_BOLT_OF_DRAINING,
+    SPELL_POISON_ARROW,
+    SPELL_CORROSIVE_BOLT,
+    SPELL_MINDBURST,
 };
 
 // Pan lord self-enchantment spell list.
@@ -93,15 +93,16 @@ static spell_type search_order_misc[] =
 {
     SPELL_DISPEL_UNDEAD_RANGE,
     SPELL_PARALYSE,
+    SPELL_VITRIFY,
     SPELL_SLEEP,
     SPELL_MASS_CONFUSION,
     SPELL_DRAIN_MAGIC,
     SPELL_PETRIFY,
     SPELL_POLYMORPH,
-    SPELL_FORCE_LANCE,
     SPELL_SLOW,
     SPELL_SENTINEL_MARK,
     SPELL_DIMENSION_ANCHOR,
+    SPELL_FORCE_LANCE,
 };
 
 /**
@@ -180,7 +181,11 @@ static attack_type _pan_lord_random_attack_type()
     {
         do
         {
-            attack = static_cast<attack_type>(random_range(AT_FIRST_ATTACK, AT_LAST_REAL_ATTACK));
+            // An ugly list, but less brittle and without e.g. false trampling.
+            attack = static_cast<attack_type>(random_choose(AT_BITE, AT_STING,
+                                      AT_SPORE, AT_TOUCH, AT_PECK, AT_HEADBUTT,
+                                      AT_PUNCH, AT_KICK, AT_TENTACLE_SLAP,
+                                      AT_TAIL_SLAP, AT_GORE, AT_TRUNK_SLAP));
         }
         while (attack == AT_HIT || !is_plain_attack_type(attack));
     }
@@ -234,6 +239,7 @@ void ghost_demon::set_pan_lord_special_attack()
         20, _flavour_attack(AF_DRAIN_SPEED),
         20, _flavour_attack(AF_CORRODE),
         20, _flavour_attack(AF_WEAKNESS),
+        20, _flavour_attack(AF_DRAG),
         // High chance
         40, _brand_attack(SPWPN_ANTIMAGIC),
         40, _brand_attack(SPWPN_DISTORTION),
@@ -273,14 +279,14 @@ void ghost_demon::set_pan_lord_cloud_ring()
     else if (att_flav == AF_CORRODE)
         cloud_ring_ench = ENCH_RING_OF_ACID;
     else if (brand == SPWPN_DRAINING)
-        cloud_ring_ench = ENCH_RING_OF_DRAINING;
+        cloud_ring_ench = ENCH_RING_OF_MISERY;
     else
     {
         cloud_ring_ench = random_choose_weighted(
             20, ENCH_RING_OF_THUNDER,
             20, ENCH_RING_OF_FLAMES,
             20, ENCH_RING_OF_ICE,
-            10, ENCH_RING_OF_DRAINING,
+            10, ENCH_RING_OF_MISERY,
              5, ENCH_RING_OF_CHAOS,
              5, ENCH_RING_OF_ACID,
              5, ENCH_RING_OF_MIASMA,
@@ -437,7 +443,6 @@ void ghost_demon::init_player_ghost()
     set_resist(resists, MR_RES_ACID, player_res_acid());
     // multi-level for players, boolean as an innate monster resistance
     set_resist(resists, MR_RES_STEAM, player_res_steam() ? 1 : 0);
-    set_resist(resists, MR_RES_STICKY_FLAME, player_res_sticky_flame());
     set_resist(resists, MR_RES_MIASMA, you.res_miasma());
     set_resist(resists, MR_RES_PETRIFY, you.res_petrify());
 
@@ -481,7 +486,7 @@ void ghost_demon::init_player_ghost()
                 // very bad approximations
                 case STAFF_FIRE: brand = SPWPN_FLAMING; break;
                 case STAFF_COLD: brand = SPWPN_FREEZING; break;
-                case STAFF_POISON: brand = SPWPN_VENOM; break;
+                case STAFF_ALCHEMY: brand = SPWPN_VENOM; break;
                 case STAFF_DEATH: brand = SPWPN_PAIN; break;
                 case STAFF_AIR: brand = SPWPN_ELECTROCUTION; break;
                 case STAFF_EARTH: brand = SPWPN_HEAVY; break;
@@ -544,10 +549,6 @@ static attack_flavour _very_ugly_thing_flavour_upgrade(attack_flavour u_att_flav
 {
     switch (u_att_flav)
     {
-    case AF_FIRE:
-        u_att_flav = AF_STICKY_FLAME;
-        break;
-
     case AF_POISON:
         u_att_flav = AF_POISON_STRONG;
         break;
@@ -669,8 +670,7 @@ static resists_t _ugly_thing_resists(bool very_ugly, attack_flavour u_att_flav)
     switch (u_att_flav)
     {
     case AF_FIRE:
-    case AF_STICKY_FLAME:
-        return MR_RES_FIRE * (very_ugly ? 2 : 1) | MR_RES_STICKY_FLAME;
+        return MR_RES_FIRE * (very_ugly ? 2 : 1);
 
     case AF_ACID:
         return MR_RES_ACID;
@@ -748,6 +748,21 @@ void ghost_demon::init_spectral_weapon(const item_def& weapon)
     max_hp = random_range(20, 30);
 }
 
+void ghost_demon::init_inugami_from_player(int power)
+{
+    const monster_type type = MONS_INUGAMI;
+    const monsterentry* stats = get_monster_data(type);
+
+    speed = stats->speed;
+    ev = stats->ev;
+    ac = stats->AC + div_rand_round(power, 10);
+    damage = 5 + div_rand_round(power, 7);
+    max_hp = 14 + div_rand_round(power, 4);
+    xl = 3 + div_rand_round(power, 15);
+    move_energy = stats->energy_usage.move;
+    see_invis = true;
+}
+
 // Used when creating ghosts: goes through and finds spells for the
 // ghost to cast. Death is a traumatic experience, so ghosts only
 // remember a few spells.
@@ -776,20 +791,26 @@ bool ghost_demon::has_spells() const
     return spells.size() > 0;
 }
 
-// When passed the number for a player spell, returns the equivalent
-// monster spell. Returns SPELL_NO_SPELL on failure (no equivalent).
+// When passed the number for player spells, returns approximate and
+// equivalent monster spells. Returns SPELL_NO_SPELL with no equivalent.
 spell_type ghost_demon::translate_spell(spell_type spell) const
 {
     switch (spell)
     {
 #if TAG_MAJOR_VERSION == 34
     case SPELL_CONTROLLED_BLINK:
-        return SPELL_BLINK;        // approximate
+        return SPELL_BLINK;
 #endif
     case SPELL_DRAGON_CALL:
         return SPELL_SUMMON_DRAGON;
     case SPELL_SWIFTNESS:
         return SPELL_SPRINT;
+    case SPELL_NECROTISE:
+        return SPELL_PAIN;
+    case SPELL_CONFUSING_TOUCH:
+        return SPELL_CONFUSE;
+    case SPELL_CURSE_OF_AGONY:
+        return SPELL_AGONY;
     default:
         break;
     }
