@@ -120,7 +120,7 @@ static void _handle_piety_penance(int piety_change, int piety_denom,
 }
 
 /**
- * Whether good gods that you folow are offended by you attacking a specific
+ * Whether good gods that you follow are offended by you attacking a specific
  * holy monster.
  *
  * @param victim    The holy in question. (May be nullptr.)
@@ -564,7 +564,7 @@ static int _piety_bonus_for_holiness(mon_holy_type holiness)
  * @param god_is_good   Whether this is a good god.
  *                      (They don't scale piety with XL in the same way...?)
  * @param special       A special-case function.
- * @return              An appropropriate like_response.
+ * @return              An appropriate like_response.
  */
 static like_response _on_kill(const char* desc, mon_holy_type holiness,
                               bool god_is_good = false,
@@ -805,17 +805,20 @@ static like_map divine_likes[] =
     // GOD_CHEIBRIADOS,
     {
         { DID_KILL_FAST, {
-            "you kill fast things, relative to your speed", false,
+            "you kill non-sluggish things", false,
             -6, 18, 2, nullptr,
             [] (int &piety, int &/*denom*/, const monster* victim)
             {
-                const int speed_delta =
-                    cheibriados_monster_player_speed_delta(*victim);
-                dprf("Chei DID_KILL_FAST: %s speed delta: %d",
+                const int mons_speed = mons_base_speed(*victim);
+                dprf("Chei DID_KILL_FAST: %s base speed: %d",
                      victim->name(DESC_PLAIN, true).c_str(),
-                     speed_delta);
+                     mons_speed);
 
-                if (speed_delta > 0 && x_chance_in_y(speed_delta, 12))
+                // Scale piety up a bit in general.
+                piety = div_rand_round(4 * piety, 3);
+
+                // Double piety for speedy monsters sometimes
+                if (mons_speed > 10 && x_chance_in_y(mons_speed - 10, 10))
                 {
                     simple_god_message(" thoroughly appreciates the change of pace.");
                     piety *= 2;
@@ -1007,7 +1010,7 @@ void set_attack_conducts(god_conduct_trigger conduct[3], const monster &mon,
             _first_attack_was_friendly.insert(mid);
         }
     }
-    else if (mon.neutral() && !mon.has_ench(ENCH_INSANE))
+    else if (mon.neutral() && !mon.has_ench(ENCH_FRENZIED))
         conduct[0].set(DID_ATTACK_NEUTRAL, 5, known, &mon);
 
     // Penance value is handled by remove_sanctuary().
@@ -1152,9 +1155,6 @@ bool god_punishes_spell(spell_type spell, god_type god)
     if (map_find(divine_peeves[god], DID_SPELL_CASTING))
         return true;
 
-    if (god_loathes_spell(spell, god))
-        return true;
-
     if (map_find(divine_peeves[god], DID_EVIL)
         && (is_evil_spell(spell) || you.spellcasting_unholy()))
     {
