@@ -24,6 +24,7 @@
 #include "items.h"
 #include "libutil.h"
 #include "potion-type.h"
+#include "religion.h"
 #include "skills.h"
 #include "spl-book.h"
 #include "spl-util.h"
@@ -103,6 +104,31 @@ bool is_potentially_evil_item(const item_def& item, bool calc_unid)
     return false;
 }
 
+bool is_evil_brand(int brand)
+{
+    switch (brand)
+    {
+    case SPWPN_DRAINING:
+    case SPWPN_PAIN:
+    case SPWPN_VAMPIRISM:
+    case SPWPN_REAPING:
+    case SPWPN_DISTORTION:
+        return true;
+    default:
+        return false;
+    }
+}
+
+bool is_chaotic_brand(int brand)
+{
+    return brand == SPWPN_CHAOS || brand == SPWPN_DISTORTION;
+}
+
+bool is_hasty_brand(int brand)
+{
+    return brand == SPWPN_CHAOS || brand == SPWPN_SPEED;
+}
+
 /**
  * Do good gods always hate use of this item?
  *
@@ -125,13 +151,7 @@ bool is_evil_item(const item_def& item, bool calc_unid)
         if (is_demonic(item))
             return true;
         if (calc_unid || item_brand_known(item))
-        {
-            const int item_brand = get_weapon_brand(item);
-            return item_brand == SPWPN_DRAINING
-                   || item_brand == SPWPN_PAIN
-                   || item_brand == SPWPN_VAMPIRISM
-                   || item_brand == SPWPN_REAPING;
-        }
+            return is_evil_brand(get_weapon_brand(item));
     }
 
     if (!calc_unid && !item_type_known(item))
@@ -147,6 +167,8 @@ bool is_evil_item(const item_def& item, bool calc_unid)
         return item.sub_type == MISC_HORN_OF_GERYON;
     case OBJ_BOOKS:
         return _is_book_type(item, is_evil_spell);
+    case OBJ_TALISMANS:
+        return item.sub_type == TALISMAN_DEATH;
     default:
         return false;
     }
@@ -170,8 +192,6 @@ bool is_unclean_item(const item_def& item, bool calc_unid)
 
 bool is_chaotic_item(const item_def& item, bool calc_unid)
 {
-    bool retval = false;
-
     if (is_unrandom_artefact(item))
     {
         const unrandart_entry* entry = get_unrand_entry(item.unrand_idx);
@@ -183,7 +203,7 @@ bool is_chaotic_item(const item_def& item, bool calc_unid)
     if (item.base_type == OBJ_WEAPONS
         && (calc_unid || item_brand_known(item)))
     {
-        return get_weapon_brand(item) == SPWPN_CHAOS;
+        return is_chaotic_brand(get_weapon_brand(item));
     }
 
     if (!calc_unid && !item_type_known(item))
@@ -192,31 +212,23 @@ bool is_chaotic_item(const item_def& item, bool calc_unid)
     switch (item.base_type)
     {
     case OBJ_MISSILES:
-        {
-        const int item_brand = get_ammo_brand(item);
-        retval = (item_brand == SPMSL_CHAOS);
-        }
-        break;
+        return get_ammo_brand(item) == SPMSL_CHAOS;
     case OBJ_WANDS:
-        retval = (item.sub_type == WAND_POLYMORPH);
-        break;
+        return item.sub_type == WAND_POLYMORPH;
     case OBJ_POTIONS:
-        retval = (item.sub_type == POT_MUTATION
+        return (item.sub_type == POT_MUTATION
                             && !have_passive(passive_t::cleanse_mut_potions))
                  || item.sub_type == POT_LIGNIFY;
-        break;
     case OBJ_BOOKS:
-        retval = _is_book_type(item, is_chaotic_spell);
-        break;
+        return item.sub_type == BOOK_MANUAL && item.plus == SK_SHAPESHIFTING
+               || _is_book_type(item, is_chaotic_spell);
     case OBJ_MISCELLANY:
-        retval = (item.sub_type == MISC_BOX_OF_BEASTS
-                  || item.sub_type == MISC_XOMS_CHESSBOARD);
-        break;
+        return item.sub_type == MISC_BOX_OF_BEASTS;
+    case OBJ_TALISMANS:
+        return true;
     default:
-        break;
+        return false;
     }
-
-    return retval;
 }
 
 static bool _is_potentially_hasty_item(const item_def& item)
@@ -240,10 +252,6 @@ static bool _is_potentially_hasty_item(const item_def& item)
             return true;
         }
         break;
-    case OBJ_MISCELLANY:
-        if (item.sub_type == MISC_XOMS_CHESSBOARD)
-            return true;
-        break;
     default:
         break;
     }
@@ -293,13 +301,13 @@ bool is_hasty_item(const item_def& item, bool calc_unid)
 bool is_wizardly_item(const item_def& item, bool calc_unid)
 {
     if ((calc_unid || item_brand_known(item))
-        && (get_weapon_brand(item) == SPWPN_PAIN
-           || get_armour_ego_type(item) == SPARM_ENERGY))
+        && get_armour_ego_type(item) == SPARM_ENERGY)
     {
         return true;
     }
 
     if (is_unrandom_artefact(item, UNRAND_WUCAD_MU)
+        || is_unrandom_artefact(item, UNRAND_MAGE)
         || is_unrandom_artefact(item, UNRAND_MAJIN)
         || is_unrandom_artefact(item, UNRAND_BATTLE)
         || is_unrandom_artefact(item, UNRAND_ELEMENTAL_STAFF)
@@ -398,6 +406,14 @@ bool god_hates_item(const item_def &item)
     return god_hates_item_handling(item) != DID_NOTHING;
 }
 
+bool god_despises_item(const item_def &item, god_type which_god)
+{
+    if (item.base_type != OBJ_TALISMANS)
+        return false;
+    return item.sub_type == TALISMAN_DEATH && is_good_god(which_god)
+           || which_god == GOD_ZIN;
+}
+
 /**
  * Does the given god like items of the given kind enough to make artefacts
  * from them? (Thematically.)
@@ -410,7 +426,12 @@ bool god_hates_item(const item_def &item)
  */
 bool god_likes_item_type(const item_def &item, god_type which_god)
 {
+    if (god_despises_item(item, which_god))
+        return false;
     // XXX: also check god_hates_item()?
+    // XXXX: if someone does this, make sure to generalize so that it doesn't
+    // use `you.religion`; this code is potentially called in item generation
+    // for artefact names
     switch (which_god)
     {
         case GOD_ELYVILON: // Peaceful healer god: no weapons.
