@@ -55,7 +55,7 @@ static const map<job_type, job_def> job_data =
 { JOB_ARTIFICER, {
     "Ar", "Artificer",
     4, 3, 5,
-    { SP_METEORAN, SP_KOBOLD, SP_SPRIGGAN, SP_BASE_DRACONIAN, SP_DEMONSPAWN, },
+    { SP_KOBOLD, SP_SPRIGGAN, SP_BASE_DRACONIAN, SP_DEMONSPAWN, },
     { },
     { "club", "leather armour", "wand of flame charges:15",
       "wand of charming charges:15 no_exclude",
@@ -68,7 +68,7 @@ static const map<job_type, job_def> job_data =
 { JOB_BERSERKER, {
     "Be", "Berserker",
     9, -1, 4,
-    { SP_HILL_ORC, SP_OGRE, SP_MERFOLK, SP_MINOTAUR, SP_GARGOYLE, SP_ARMATAUR, },
+    { SP_HILL_ORC, SP_ONI, SP_MERFOLK, SP_MINOTAUR, SP_GARGOYLE, SP_ARMATAUR, },
     { },
     { "animal skin" },
     WCHOICE_PLAIN,
@@ -93,7 +93,7 @@ static const map<job_type, job_def> job_data =
     { SP_HILL_ORC, SP_TROLL, SP_GNOLL, SP_MERFOLK, SP_MINOTAUR,
       SP_BASE_DRACONIAN, SP_DEMONSPAWN, },
     { },
-    { "leather armour plus:2", "piece from Xom's chessboard" },
+    { "leather armour plus:2", "scroll of butterflies no_exclude" },
     WCHOICE_PLAIN,
     { { SK_FIGHTING, 3 }, { SK_ARMOUR, 1 }, { SK_DODGING, 1 },
       { SK_WEAPON, 3 } },
@@ -102,7 +102,7 @@ static const map<job_type, job_def> job_data =
 { JOB_CINDER_ACOLYTE, {
     "CA", "Cinder Acolyte",
     6, 6, 0,
-    { SP_HILL_ORC, SP_BASE_DRACONIAN, SP_OGRE, SP_DJINNI, SP_GNOLL, SP_METEORAN },
+    { SP_HILL_ORC, SP_BASE_DRACONIAN, SP_ONI, SP_DJINNI, SP_GNOLL },
     { SPELL_SCORCH },
     { "robe" },
     WCHOICE_PLAIN,
@@ -117,7 +117,6 @@ static const map<job_type, job_def> job_data =
     {
         SPELL_MAGIC_DART,
         SPELL_SEARING_RAY,
-        SPELL_DAZZLING_FLASH,
         SPELL_FULMINANT_PRISM,
         SPELL_ISKENDERUNS_MYSTIC_BLAST,
     },
@@ -137,10 +136,11 @@ static const map<job_type, job_def> job_data =
         SPELL_PASSWALL,
         SPELL_STONE_ARROW,
         SPELL_PETRIFY,
+        SPELL_BOULDER,
     },
     { "robe", "potion of magic", },
     WCHOICE_NONE,
-    { { SK_TRANSMUTATIONS, 1 }, { SK_EARTH_MAGIC, 3 }, { SK_SPELLCASTING, 2 },
+    { { SK_CONJURATIONS, 1 }, { SK_EARTH_MAGIC, 3 }, { SK_SPELLCASTING, 2 },
       { SK_DODGING, 2 }, { SK_STEALTH, 2 }, }
 } },
 
@@ -163,8 +163,7 @@ static const map<job_type, job_def> job_data =
 { JOB_FIGHTER, {
     "Fi", "Fighter",
     8, 0, 4,
-    { SP_METEORAN, SP_HILL_ORC, SP_TROLL, SP_MINOTAUR, SP_GARGOYLE,
-      SP_ARMATAUR, },
+    { SP_HILL_ORC, SP_TROLL, SP_MINOTAUR, SP_GARGOYLE, SP_ARMATAUR, SP_FORMICID, },
     { },
     { "scale mail", "buckler", "potion of might" },
     WCHOICE_GOOD,
@@ -193,7 +192,7 @@ static const map<job_type, job_def> job_data =
 { JOB_GLADIATOR, {
     "Gl", "Gladiator",
     6, 0, 6,
-    { SP_METEORAN, SP_HILL_ORC, SP_MERFOLK, SP_TROLL, SP_GARGOYLE, SP_GNOLL, },
+    { SP_HILL_ORC, SP_MERFOLK, SP_TROLL, SP_GARGOYLE, SP_GNOLL, SP_VINE_STALKER, },
     { },
     { "leather armour", "helmet", "throwing net q:3" },
     WCHOICE_GOOD,
@@ -203,18 +202,19 @@ static const map<job_type, job_def> job_data =
 
 { JOB_HEXSLINGER, {
     "Hs", "Hexslinger",
-    2, 5, 5,
+    0, 5, 7,
     { SP_FORMICID, SP_DEEP_ELF, SP_KOBOLD, SP_SPRIGGAN, SP_GNOLL },
     {
-        SPELL_SLOW,
+        SPELL_JINXBITE,
+        SPELL_SIGIL_OF_BINDING,
         SPELL_INNER_FLAME,
-        SPELL_PORTAL_PROJECTILE,
         SPELL_CAUSE_FEAR,
+        SPELL_DIMENSIONAL_BULLSEYE,
     },
     { "robe", "scroll of poison", "sling plus:1" },
     WCHOICE_NONE,
     { { SK_FIGHTING, 1 }, { SK_DODGING, 2 }, { SK_SPELLCASTING, 1 },
-      { SK_HEXES, 3 }, { SK_WEAPON, 2 }, },
+      { SK_FIRE_MAGIC, 1}, { SK_HEXES, 3 }, { SK_WEAPON, 2 }, },
 } },
 
 { JOB_HUNTER, {
@@ -222,7 +222,7 @@ static const map<job_type, job_def> job_data =
     3, 1, 8,
     { SP_HILL_ORC, SP_MINOTAUR, SP_GNOLL, SP_KOBOLD, SP_SPRIGGAN, },
     { },
-    { "leather armour", "scroll of immolation", "shortbow" },
+    { "leather armour", "scroll of butterflies no_exclude", "shortbow" },
     WCHOICE_NONE,
     { { SK_FIGHTING, 2 }, { SK_DODGING, 2 }, { SK_STEALTH, 1 },
       { SK_WEAPON, 4 }, },
@@ -231,7 +231,7 @@ static const map<job_type, job_def> job_data =
 { JOB_ICE_ELEMENTALIST, {
     "IE", "Ice Elementalist",
     0, 7, 5,
-    { SP_MERFOLK, SP_NAGA, SP_BASE_DRACONIAN, SP_DEMIGOD,
+    { SP_MERFOLK, SP_BARACHI, SP_BASE_DRACONIAN, SP_DEMIGOD,
       SP_GARGOYLE, SP_DJINNI, },
     {
         SPELL_FREEZE,
@@ -250,7 +250,7 @@ static const map<job_type, job_def> job_data =
     4, 2, 6,
     { SP_FELID, SP_SPRIGGAN, SP_KOBOLD, SP_VAMPIRE, SP_GNOLL },
     { },
-    { "leather armour", "scroll of fog no_exclude", "scroll of magic mapping",
+    { "leather armour", "scroll of fog no_exclude", "scroll of revelation",
       "scroll of fear", "potion of haste", "wand of digging charges:3" },
     WCHOICE_PLAIN,
     { { SK_FIGHTING, 3 }, { SK_DODGING, 2 }, { SK_STEALTH, 5 }, { SK_WEAPON, 2 }, },
@@ -259,8 +259,7 @@ static const map<job_type, job_def> job_data =
 { JOB_MONK, {
     "Mo", "Monk",
     3, 2, 7,
-    { SP_METEORAN, SP_HILL_ORC, SP_TROLL, SP_ARMATAUR, SP_MERFOLK,
-      SP_GARGOYLE, SP_DEMONSPAWN, },
+    { SP_HILL_ORC, SP_TROLL, SP_ARMATAUR, SP_MERFOLK, SP_GARGOYLE, SP_DEMONSPAWN, },
     { },
     { "robe", "potion of ambrosia", "orb ego:light" },
     WCHOICE_PLAIN,
@@ -276,7 +275,7 @@ static const map<job_type, job_def> job_data =
         SPELL_NECROTISE,
         SPELL_VAMPIRIC_DRAINING,
         SPELL_ANIMATE_DEAD,
-        SPELL_AGONY,
+        SPELL_CURSE_OF_AGONY,
     },
     { "robe", "potion of magic" },
     WCHOICE_NONE,
@@ -309,7 +308,7 @@ static const map<job_type, job_def> job_data =
         SPELL_SUMMON_SMALL_MAMMAL,
         SPELL_CALL_IMP,
         SPELL_CALL_CANINE_FAMILIAR,
-        SPELL_SUMMON_GUARDIAN_GOLEM,
+        SPELL_SUMMON_BLAZEHEART_GOLEM,
         SPELL_SUMMON_LIGHTNING_SPIRE,
     },
     { "robe", "potion of magic" },
@@ -318,45 +317,41 @@ static const map<job_type, job_def> job_data =
       { SK_STEALTH, 2 }, },
 } },
 
-{ JOB_TRANSMUTER, {
-    "Tm", "Transmuter",
-    2, 5, 5,
+{ JOB_SHAPESHIFTER, {
+    "Sh", "Shapeshifter",
+    6, 2, 4,
     { SP_NAGA, SP_MERFOLK, SP_BASE_DRACONIAN, SP_DEMIGOD, SP_DEMONSPAWN,
-      SP_TROLL, SP_METEORAN, },
-    {
-        SPELL_BEASTLY_APPENDAGE,
-        SPELL_WEREBLOOD,
-        SPELL_SPIDER_FORM,
-        SPELL_ICE_FORM,
-    },
-    { "robe", "potion of lignification" },
+      SP_TROLL },
+    { },
+    { "animal skin", "potion of lignification", "beast talisman", "flux talisman" },
     WCHOICE_NONE,
     { { SK_FIGHTING, 1 }, { SK_UNARMED_COMBAT, 3 }, { SK_DODGING, 2 },
-      { SK_SPELLCASTING, 2 }, { SK_TRANSMUTATIONS, 2 }, },
+      { SK_SHAPESHIFTING, 3 }, },
 } },
 
-{ JOB_VENOM_MAGE, {
-    "VM", "Venom Mage",
+{ JOB_ALCHEMIST, {
+    "Al", "Alchemist",
     0, 7, 5,
-    { SP_DEEP_ELF, SP_SPRIGGAN, SP_NAGA, SP_MERFOLK, SP_TENGU, SP_DJINNI,
+    { SP_DEEP_ELF, SP_SPRIGGAN, SP_NAGA, SP_MERFOLK, SP_OCTOPODE, SP_DJINNI,
       SP_DEMONSPAWN, },
     {
         SPELL_STING,
-        SPELL_POISONOUS_VAPOURS,
+        SPELL_MERCURY_VAPOURS,
         SPELL_MEPHITIC_CLOUD,
         SPELL_OLGREBS_TOXIC_RADIANCE,
+        SPELL_STICKY_FLAME
     },
     { "robe", "potion of magic" },
     WCHOICE_NONE,
-    { { SK_TRANSMUTATIONS, 1 }, { SK_POISON_MAGIC, 3 }, { SK_SPELLCASTING, 2 },
+    { { SK_ALCHEMY, 3 }, { SK_CONJURATIONS, 1}, { SK_SPELLCASTING, 2 },
       { SK_DODGING, 2 }, { SK_STEALTH, 2 }, },
 } },
 
 { JOB_WANDERER, {
     "Wn", "Wanderer",
     0, 0, 0, // Randomised
-    { SP_HILL_ORC, SP_METEORAN, SP_GNOLL, SP_MERFOLK, SP_BASE_DRACONIAN,
-      SP_HUMAN, SP_DEMONSPAWN, },
+    { SP_HILL_ORC, SP_GNOLL, SP_MERFOLK, SP_BASE_DRACONIAN, SP_HUMAN,
+      SP_DEMONSPAWN, SP_BARACHI, },
     { }, // Randomised
     { }, // Randomised
     WCHOICE_NONE,
@@ -366,15 +361,15 @@ static const map<job_type, job_def> job_data =
 { JOB_WARPER, {
     "Wr", "Warper",
     3, 5, 4,
-    { SP_FELID, SP_METEORAN, SP_SPRIGGAN, SP_ARMATAUR, SP_BASE_DRACONIAN, },
+    { SP_FELID, SP_SPRIGGAN, SP_ARMATAUR, SP_BASE_DRACONIAN, },
     {
         SPELL_BLINK,
         SPELL_BECKONING,
-        SPELL_ELECTRIC_CHARGE,
         SPELL_TELEPORT_OTHER,
         SPELL_MANIFOLD_ASSAULT,
+        SPELL_ELECTRIC_CHARGE,
     },
-    { "leather armour", "scroll of blinking", "boomerang ego:dispersal q:7" },
+    { "leather armour", "scroll of blinking", "dart ego:dispersal q:7" },
     WCHOICE_PLAIN,
     { { SK_FIGHTING, 2 }, { SK_ARMOUR, 1 }, { SK_DODGING, 2 },
       { SK_SPELLCASTING, 2 }, { SK_TRANSLOCATIONS, 3 }, { SK_THROWING, 1 },
@@ -385,7 +380,7 @@ static const map<job_type, job_def> job_data =
     "HW", "Hedge Wizard",
     2, 6, 4,
     { SP_DEEP_ELF, SP_NAGA, SP_BASE_DRACONIAN, SP_OCTOPODE, SP_HUMAN,
-      SP_DJINNI, SP_METEORAN, },
+      SP_DJINNI, },
     {
         SPELL_MAGIC_DART,
         SPELL_SLOW,
