@@ -211,6 +211,8 @@ public:
         }
         else if (item->base_type == OBJ_RUNES)
             name = "runes";
+        else if (item->base_type == OBJ_GEMS)
+            name = "gems";
         else if (item->sub_type == get_max_subtype(item->base_type))
         {
             name = "unknown "
@@ -371,6 +373,7 @@ void check_item_knowledge(bool unknown_items)
     vector<const item_def*> items_food;    //List of foods should come next
 #endif
     vector<const item_def*> items_misc;
+    vector<const item_def*> items_talismans;
     vector<const item_def*> items_other;   //List of other items should go after everything
     vector<SelItem> selected_items;
 
@@ -439,9 +442,9 @@ void check_item_knowledge(bool unknown_items)
                 || i == MISC_RUNE_OF_ZOT
                 || i == MISC_STONE_OF_TREMORS
                 || i == MISC_FAN_OF_GALES
-                || i == MISC_SACK_OF_SPIDERS
                 || i == MISC_LAMP_OF_FIRE
                 || i == MISC_CRYSTAL_BALL_OF_ENERGY
+                || i == MISC_XOMS_CHESSBOARD
 #endif
                 || (i == MISC_QUAD_DAMAGE && !crawl_state.game_is_sprint()))
             {
@@ -450,6 +453,9 @@ void check_item_knowledge(bool unknown_items)
             _add_fake_item(OBJ_MISCELLANY, i, selected_items, items_misc);
         }
 
+        for (int i = 0; i < NUM_TALISMANS; i++)
+            _add_fake_item(OBJ_TALISMANS, i, selected_items, items_talismans);
+
         // N.b. NUM_BOOKS drastically exceeds MAX_SUBTYPES, but it doesn't
         // matter for force_autopickup purposes because we only use 0 and
         // BOOK_MANUAL
@@ -462,6 +468,7 @@ void check_item_knowledge(bool unknown_items)
             { OBJ_GOLD, 1 },
             { OBJ_BOOKS, 0 },
             { OBJ_RUNES, NUM_RUNE_TYPES },
+            { OBJ_GEMS, NUM_GEM_TYPES },
         };
         for (auto e : misc_list)
             _add_fake_item(e.first, e.second, selected_items, items_other);
@@ -473,6 +480,8 @@ void check_item_knowledge(bool unknown_items)
     sort(items_food.begin(), items_food.end(), _identified_item_names);
 #endif
     sort(items_misc.begin(), items_misc.end(), _identified_item_names);
+    // Intentionally don't sort talismans so that they're ordered by tier instead.
+    // (This is dubious!)
 
     KnownMenu menu(unknown_items, all_items_known);
     string stitle;
@@ -499,6 +508,7 @@ void check_item_knowledge(bool unknown_items)
     ml = menu.load_items(items_food, known_item_mangle, ml, false);
 #endif
     ml = menu.load_items(items_misc, known_item_mangle, ml, false);
+    ml = menu.load_items(items_talismans, known_item_mangle, ml, false);
     if (!items_other.empty())
     {
         menu.add_entry(new MenuEntry("Other Items", MEL_SUBTITLE));
@@ -516,6 +526,7 @@ void check_item_knowledge(bool unknown_items)
     deleteAll(items_food);
 #endif
     deleteAll(items_misc);
+    deleteAll(items_talismans);
     deleteAll(items_other);
 
     if (!all_items_known && (last_char == '\\' || last_char == '-'))
