@@ -340,16 +340,14 @@ static int moninf_get_target_desc(lua_State *ls)
 }
 
 /*** Returns the string displayed if you target this monster with a weapon (or unarmed attack).
- * @tparam[opt] weapon (item object) to use; omit for unarmed attack.
  * @treturn string (such as "about 18% to evade your dagger")
  * @function target_weapon
  */
 static int moninf_get_target_weapon(lua_State *ls)
 {
     MONINF(ls, 1, mi);
-    item_def *item = (lua_isnone(ls, 2) || lua_isnil(ls, 2)) ? nullptr : *(item_def **) luaL_checkudata(ls, 2, ITEM_METATABLE);
     ostringstream result;
-    describe_to_hit(*mi, result, false, item);
+    describe_to_hit(*mi, result, you.weapon());
     lua_pushstring(ls, result.str().c_str());
     return 1;
 }
@@ -363,7 +361,7 @@ static int moninf_get_target_spell(lua_State *ls)
 {
     MONINF(ls, 1, mi);
     spell_type spell = spell_by_name(luaL_checkstring(ls, 2), false);
-    string desc = target_desc(*mi, spell);
+    string desc = target_spell_desc(*mi, spell);
     lua_pushstring(ls, desc.c_str());
     return 1;
 }
@@ -383,6 +381,26 @@ static int moninf_get_target_throw(lua_State *ls)
     return 1;
 }
 
+/*** Returns the string displayed if you target this monster with an evocable.
+ * @tparam item object to be evoked
+ * @treturn string (such as "about 45% to hit")
+ * @function target_evoke
+ */
+static int moninf_get_target_evoke(lua_State *ls)
+{
+    MONINF(ls, 1, mi);
+    item_def *item = *(item_def **) luaL_checkudata(ls, 2, ITEM_METATABLE);
+    if (!item)
+    {
+        lua_pushnil(ls);
+        return 1;
+    }
+
+    string desc = target_evoke_desc(*mi, *item);
+    lua_pushstring(ls, desc.c_str());
+    return 1;
+}
+
 /*** Get the monster's holiness.
  * If passed a holiness, returns a boolean test of whether the monster has the
  * given holiness. Otherwise returns a string describing the monster's
@@ -677,7 +695,9 @@ LUAFN(moninf_get_can_traverse)
 {
     MONINF(ls, 1, mi);
     PLAYERCOORDS(p, 2, 3)
-    lua_pushboolean(ls, monster_habitable_grid(mi->type, env.map_knowledge(p).feat()));
+    lua_pushboolean(ls,
+        map_bounds(p)
+        && monster_habitable_grid(mi->type, env.map_knowledge(p).feat()));
     return 1;
 }
 
@@ -847,6 +867,7 @@ static const struct luaL_reg moninf_lib[] =
     MIREG(target_weapon),
     MIREG(target_spell),
     MIREG(target_throw),
+    MIREG(target_evoke),
     MIREG(x_pos),
     MIREG(y_pos),
     MIREG(pos),
