@@ -9,6 +9,7 @@
 
 #include <algorithm>
 
+#include "acquire.h"
 #include "art-enum.h" // unrand -> magic staff silliness
 #include "artefact.h"
 #include "colour.h"
@@ -21,6 +22,7 @@
 #include "libutil.h" // map_find
 #include "mpr.h"
 #include "randbook.h"
+#include "random-pick.h" // talismans
 #include "skills.h" // is_removed_skill
 #include "spl-book.h"
 #include "state.h"
@@ -118,7 +120,7 @@ static weapon_type _determine_weapon_subtype(int item_level)
     if (one_chance_in(30) && x_chance_in_y(item_level + 3, 100))
     {
         return random_choose(WPN_LAJATANG,
-                             WPN_HAND_CROSSBOW,
+                             WPN_HAND_CANNON,
                              WPN_TRIPLE_CROSSBOW,
                              WPN_DEMON_WHIP,
                              WPN_DEMON_BLADE,
@@ -229,8 +231,8 @@ static bool _try_make_weapon_artefact(item_def& item, int force_type,
         if (_weapon_disallows_randart(item.sub_type))
             return false;
 
-        // Mean enchantment +6.
-        item.plus = 12 - biased_random2(7,2);
+        // Mean enchantment +5.
+        item.plus = 12 - biased_random2(10,2);
         item.plus -= biased_random2(7,2);
         item.plus -= biased_random2(7,2);
 
@@ -247,7 +249,7 @@ static bool _try_make_weapon_artefact(item_def& item, int force_type,
 }
 
 /**
- * The number of times to try finding a brand for a given item.
+ * The number of times to try finding a brand for a given weapon.
  *
  * Result may vary from call to call.
  */
@@ -255,8 +257,14 @@ static int _num_brand_tries(const item_def& item, int item_level)
 {
     if (item_level >= ISPEC_GIFT)
         return 5;
-    if (is_demonic(item) || x_chance_in_y(101 + item_level, 300))
+    if (is_demonic(item)
+        || is_blessed(item)
+        // Hand crossbows usually appear late, so encourage use.
+        || item.sub_type == WPN_HAND_CANNON
+        || x_chance_in_y(101 + item_level, 300))
+    {
         return 1;
+    }
     return 0;
 }
 
@@ -285,12 +293,18 @@ bool is_weapon_brand_ok(int type, int brand, bool /*strict*/)
     item.base_type = OBJ_WEAPONS;
     item.sub_type = type;
 
+    if (is_blessed_weapon_type(type) && brand != SPWPN_HOLY_WRATH)
+        return false;
+
     if (brand <= SPWPN_NORMAL)
         return true;
 
     if (type == WPN_QUICK_BLADE && brand == SPWPN_SPEED)
         return false;
 
+    if (is_demonic_weapon_type(type) && brand == SPWPN_HOLY_WRATH)
+        return false;
+
     switch ((brand_type)brand)
     {
     // Universal brands.
@@ -298,20 +312,20 @@ bool is_weapon_brand_ok(int type, int brand, bool /*strict*/)
     case SPWPN_VENOM:
     case SPWPN_PROTECTION:
     case SPWPN_SPEED:
-    case SPWPN_VORPAL:
+    case SPWPN_HEAVY:
     case SPWPN_CHAOS:
     case SPWPN_HOLY_WRATH:
     case SPWPN_ELECTROCUTION:
     case SPWPN_FLAMING:
     case SPWPN_FREEZING:
+    case SPWPN_DRAINING:
+    case SPWPN_ANTIMAGIC:
         break;
 
     // Melee-only brands.
-    case SPWPN_DRAINING:
     case SPWPN_VAMPIRISM:
     case SPWPN_PAIN:
     case SPWPN_DISTORTION:
-    case SPWPN_ANTIMAGIC:
     case SPWPN_SPECTRAL:
     case SPWPN_REAPING: // only exists on Sword of Zonguldrok
         if (is_range_weapon(item))
@@ -461,7 +475,8 @@ static void _generate_weapon_item(item_def& item, bool allow_uniques,
         }
         item.plus -= 1 + random2(3);
     }
-    else if ((force_good || is_demonic(item) || forced_ego
+    else if ((force_good || is_demonic(item)
+              || item.sub_type == WPN_HAND_CANNON || forced_ego
                     || x_chance_in_y(51 + item_level, 200))
                 && (!item.is_mundane() || force_good))
     {
@@ -482,6 +497,13 @@ static void _generate_weapon_item(item_def& item, bool allow_uniques,
         if (!force_good && item.brand == SPWPN_NORMAL && item.plus < 3)
             item.plus = 0;
     }
+
+    // Blessed weapons must always be branded with holy wrath.
+    if (is_blessed(item))
+    {
+        set_item_ego_type(item, OBJ_WEAPONS,
+                          determine_weapon_brand(item, item_level));
+    }
 }
 
 // Remember to update the code in is_missile_brand_ok if adding or altering
@@ -512,6 +534,9 @@ static special_missile_type _determine_missile_brand(const item_def& item,
     case MI_LARGE_ROCK:
         rc = SPMSL_NORMAL;
         break;
+    case MI_BOOMERANG:
+        rc = SPMSL_NORMAL;
+        break;
     case MI_DART:
         // Curare is special cased, all the others aren't.
         if (got_curare_roll(item_level))
@@ -522,17 +547,13 @@ static special_missile_type _determine_missile_brand(const item_def& item,
 
         rc = random_choose_weighted(60, SPMSL_BLINDING,
                                     20, SPMSL_FRENZY,
+                                    20, SPMSL_DISPERSAL,
                                     pw, SPMSL_POISONED);
         break;
     case MI_JAVELIN:
         rc = random_choose_weighted(90, SPMSL_SILVER,
                                     nw, SPMSL_NORMAL);
         break;
-    case MI_BOOMERANG:
-        rc = random_choose_weighted(30, SPMSL_SILVER,
-                                    30, SPMSL_DISPERSAL,
-                                    nw, SPMSL_NORMAL);
-        break;
     }
 
     ASSERT(is_missile_brand_ok(item.sub_type, rc, true));
@@ -568,6 +589,7 @@ bool is_missile_brand_ok(int type, int brand, bool strict)
     case SPMSL_PARALYSIS:
 #endif
     case SPMSL_FRENZY:
+    case SPMSL_DISPERSAL:
         return type == MI_DART;
 
     case SPMSL_BLINDING:
@@ -598,10 +620,8 @@ bool is_missile_brand_ok(int type, int brand, bool strict)
         return false;
     case SPMSL_CHAOS:
         return type == MI_BOOMERANG || type == MI_JAVELIN;
-    case SPMSL_DISPERSAL:
-        return type == MI_BOOMERANG;
     case SPMSL_SILVER:
-        return type == MI_JAVELIN || type == MI_BOOMERANG;
+        return type == MI_JAVELIN;
     default: break;
     }
 
@@ -657,52 +677,44 @@ static void _generate_missile_item(item_def& item, int force_type,
     item.quantity = random_range(2, 6);
 }
 
-static bool _armour_disallows_randart(int sub_type)
-{
-    // Scarves and orbs are never randarts.
-    return sub_type == ARM_SCARF || sub_type == ARM_ORB;
-}
-
 static bool _try_make_armour_artefact(item_def& item, int force_type,
-                                      int item_level, bool force_randart,
-                                      int agent)
+                                      int item_level, int agent)
 {
-    if (item_level > 0 && x_chance_in_y(101 + item_level * 3, 4000)
-        || force_randart)
+    const bool force_randart = item_level == ISPEC_RANDART;
+    if (!force_randart && (item_level <= 0
+                           || !x_chance_in_y(101 + item_level * 3, 4000)))
     {
-        // Make a randart or unrandart.
+        return false;
+    }
+    // Make a randart or unrandart.
 
-        // 1 in 20 randarts are unrandarts.
-        if (one_chance_in(item_level == ISPEC_GOOD_ITEM ? 7 : 20)
-            && !force_randart)
-        {
-            if (_try_make_item_unrand(item, force_type, item_level, agent))
-                return true;
-        }
+    // 1 in 20 randarts are unrandarts.
+    if (one_chance_in(item_level == ISPEC_GOOD_ITEM ? 7 : 20)
+        && !force_randart)
+    {
+        if (_try_make_item_unrand(item, force_type, item_level, agent))
+            return true;
+    }
 
-        if (_armour_disallows_randart(item.sub_type))
-            return false;
+    // The rest are normal randarts.
 
-        // The rest are normal randarts.
+    // 5% of boots become barding.
+    if (item.sub_type == ARM_BOOTS && one_chance_in(20))
+        item.sub_type = ARM_BARDING;
 
-        // 5% of boots become barding.
-        if (item.sub_type == ARM_BOOTS && one_chance_in(20))
-            item.sub_type = ARM_BARDING;
+    // Determine enchantment.
+    if (!armour_is_enchantable(item) || one_chance_in(5))
+        item.plus = 0;
+    else
+    {
+        int max_plus = armour_max_enchant(item);
+        item.plus = random2(max_plus + 1);
 
-        // Determine enchantment.
         if (one_chance_in(5))
-            item.plus = 0;
-        else
-        {
-            int max_plus = armour_max_enchant(item);
-            item.plus = random2(max_plus + 1);
+            item.plus += random2(max_plus + 6) / 2;
 
-            if (one_chance_in(5))
-                item.plus += random2(max_plus + 6) / 2;
-
-            if (one_chance_in(6))
-                item.plus -= random2(max_plus + 6);
-        }
+        if (one_chance_in(6))
+            item.plus -= random2(max_plus + 6);
 
         // On body armour, an enchantment of less than 0 is never viable.
         // On aux armour & shields, going below -2 is likewise unviable.
@@ -711,122 +723,13 @@ static bool _try_make_armour_artefact(item_def& item, int force_type,
             item.plus = max(static_cast<int>(item.plus), random2(2));
         else
             item.plus = max(static_cast<int>(item.plus), random_range(-2, 1));
-
-        // Needs to be done after the barding chance else we get randart
-        // bardings named Boots of xy.
-        make_item_randart(item);
-
-        // Don't let unenchantable armour get minuses.
-        if (!armour_is_enchantable(item))
-            item.plus = 0;
-
-        return true;
     }
 
-    return false;
-}
+    // Needs to be done after the barding chance else we get randart
+    // bardings named Boots of xy.
+    make_item_randart(item);
 
-/**
- * Generate an appropriate ego for a type of armour.
- *
- * @param item          The type of armour in question.
- * @return              An ego appropriate to the item type.
- *                      May be SPARM_NORMAL.
- */
-static special_armour_type _generate_armour_type_ego(armour_type type)
-{
-    // TODO: move this into data
-    switch (type)
-    {
-    case ARM_KITE_SHIELD:
-    case ARM_TOWER_SHIELD:
-    case ARM_BUCKLER:
-        return random_choose_weighted(1, SPARM_RESISTANCE,
-                                      3, SPARM_FIRE_RESISTANCE,
-                                      3, SPARM_COLD_RESISTANCE,
-                                      3, SPARM_POISON_RESISTANCE,
-                                      3, SPARM_POSITIVE_ENERGY,
-                                      6, SPARM_REFLECTION,
-                                      12, SPARM_PROTECTION);
-
-    case ARM_ORB:
-        return random_choose_weighted(1, SPARM_LIGHT,
-                                      1, SPARM_RAGE,
-                                      1, SPARM_MAYHEM,
-                                      1, SPARM_GUILE,
-                                      1, SPARM_ENERGY);
-
-    case ARM_SCARF:
-        return random_choose_weighted(1, SPARM_RESISTANCE,
-                                      1, SPARM_REPULSION,
-                                      1, SPARM_INVISIBILITY,
-                                      1, SPARM_HARM,
-                                      1, SPARM_SHADOWS);
-
-    case ARM_CLOAK:
-        return random_choose(SPARM_POISON_RESISTANCE,
-                             SPARM_WILLPOWER,
-                             SPARM_STEALTH,
-                             SPARM_PRESERVATION);
-
-    case ARM_HAT:
-        return random_choose_weighted(10, SPARM_NORMAL,
-                                      3, SPARM_STEALTH,
-                                      3, SPARM_WILLPOWER,
-                                      2, SPARM_INTELLIGENCE,
-                                      2, SPARM_SEE_INVISIBLE);
-
-    case ARM_HELMET:
-        return random_choose(SPARM_SEE_INVISIBLE, SPARM_INTELLIGENCE);
-
-    case ARM_GLOVES:
-        return random_choose(SPARM_DEXTERITY, SPARM_STRENGTH, SPARM_HURLING,
-                             SPARM_STEALTH, SPARM_INFUSION);
-
-    case ARM_BOOTS:
-        return random_choose(SPARM_FLYING, SPARM_STEALTH, SPARM_RAMPAGING);
-
-    case ARM_BARDING:
-        return random_choose(SPARM_FLYING, SPARM_STEALTH,
-                             SPARM_COLD_RESISTANCE, SPARM_FIRE_RESISTANCE);
-
-    case ARM_ROBE:
-        return random_choose_weighted(1, SPARM_RESISTANCE,
-                                      1, SPARM_ARCHMAGI,
-                                      2, SPARM_NORMAL,
-                                      2, SPARM_COLD_RESISTANCE,
-                                      2, SPARM_FIRE_RESISTANCE,
-                                      2, SPARM_POSITIVE_ENERGY,
-                                      4, SPARM_WILLPOWER);
-
-    case ARM_PLATE_ARMOUR:
-        return random_choose_weighted(26, SPARM_FIRE_RESISTANCE,
-                                      26, SPARM_COLD_RESISTANCE,
-                                      19, SPARM_POISON_RESISTANCE,
-                                      15, SPARM_WILLPOWER,
-                                       7, SPARM_POSITIVE_ENERGY,
-                                       7, SPARM_PONDEROUSNESS);
-
-    // other body armour
-    default:
-        break;
-    }
-
-    // dragon/troll armour, animal hides, and crystal plate are never generated
-    // with egos. (unless they're artefacts, but those aren't handled here.)
-    // TODO: deduplicate with armour_is_special() (same except for animal skin)
-    if (armour_type_is_hide(type)
-        || type == ARM_ANIMAL_SKIN
-        || type == ARM_CRYSTAL_PLATE_ARMOUR)
-    {
-        return SPARM_NORMAL;
-    }
-
-    return random_choose_weighted(7, SPARM_FIRE_RESISTANCE,
-                                  7, SPARM_COLD_RESISTANCE,
-                                  5, SPARM_POISON_RESISTANCE,
-                                  4, SPARM_WILLPOWER,
-                                  2, SPARM_POSITIVE_ENERGY);
+    return true;
 }
 
 /**
@@ -842,11 +745,9 @@ static special_armour_type _generate_armour_ego(const item_def& item)
     if (item.brand != SPARM_NORMAL)
         return static_cast<special_armour_type>(item.brand);
 
-    const special_armour_type ego
-        = _generate_armour_type_ego(static_cast<armour_type>(item.sub_type));
-
-    ASSERT(is_armour_brand_ok(item.sub_type, ego, true));
-    return ego;
+    const auto e = choose_armour_ego(static_cast<armour_type>(item.sub_type));
+    ASSERT(is_armour_brand_ok(item.sub_type, e, true));
+    return e;
 }
 
 bool is_armour_brand_ok(int type, int brand, bool strict)
@@ -1002,7 +903,7 @@ static int _armour_plus_threshold(equipment_type armour_type)
 static armour_type _get_random_armour_type(int item_level)
 {
 
-    // Dummy value for initilization, always changed by the conditional
+    // Dummy value for initialization, always changed by the conditional
     // (and not changing it would trigger an ASSERT)
     armour_type armtype = NUM_ARMOURS;
 
@@ -1022,7 +923,7 @@ static armour_type _get_random_armour_type(int item_level)
                                          2, ARM_KITE_SHIELD,
                                          4, ARM_BUCKLER,
                                          1, ARM_TOWER_SHIELD,
-                                         3, ARM_ORB);
+                                         4, ARM_ORB);
     }
     else if (x_chance_in_y(11 + item_level, 10000))
     {
@@ -1095,17 +996,12 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
         }
     }
 
-
-    // Fall back to an ordinary item if artefacts not allowed for this type.
-    if (item_level == ISPEC_RANDART && _armour_disallows_randart(item.sub_type))
-        item_level = ISPEC_GOOD_ITEM;
-
     // Forced randart.
     if (item_level == ISPEC_RANDART)
     {
         int ego = item.brand;
         for (int i = 0; i < 100; ++i)
-            if (_try_make_armour_artefact(item, force_type, 0, true, agent)
+            if (_try_make_armour_artefact(item, force_type, item_level, agent)
                 && is_artefact(item))
             {
                 // borrowed from similar code for weapons -- is this really the
@@ -1131,7 +1027,7 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
     }
 
     if (allow_uniques
-        && _try_make_armour_artefact(item, force_type, item_level, false, agent))
+        && _try_make_armour_artefact(item, force_type, item_level, agent))
     {
         return;
     }
@@ -1143,7 +1039,9 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
     const bool forced_ego = (item.brand > 0);
     const bool no_ego     = (item.brand == SPARM_FORBID_EGO);
 
-    if (no_ego)
+    if (item_always_has_ego(item))
+        set_item_ego_type(item, OBJ_ARMOUR, _generate_armour_ego(item));
+    else if (no_ego)
         item.brand = SPARM_NORMAL;
 
     if (item_level < 0)
@@ -1157,9 +1055,6 @@ static void _generate_armour_item(item_def& item, bool allow_uniques,
 
         item.plus -= 1 + random2(3);
     }
-    // Scarves and orbs always get an ego.
-    else if (item.sub_type == ARM_SCARF || item.sub_type == ARM_ORB)
-        set_item_ego_type(item, OBJ_ARMOUR, _generate_armour_ego(item));
     else if ((forced_ego || item.sub_type == ARM_HAT
                     || x_chance_in_y(51 + item_level, 250))
                 && !item.is_mundane() || force_good)
@@ -1241,7 +1136,10 @@ bool is_high_tier_wand(int type)
     case WAND_CHARMING:
     case WAND_PARALYSIS:
     case WAND_ACID:
+    case WAND_LIGHT:
+    case WAND_QUICKSILVER:
     case WAND_ICEBLAST:
+    case WAND_ROOTS:
     case WAND_MINDBURST:
         return true;
     default:
@@ -1249,7 +1147,7 @@ bool is_high_tier_wand(int type)
     }
 }
 
-static void _generate_wand_item(item_def& item, int force_type, int item_level)
+void generate_wand_item(item_def& item, int force_type, int item_level)
 {
     if (force_type != OBJ_RANDOM)
         item.sub_type = force_type;
@@ -1365,7 +1263,7 @@ static void _generate_scroll_item(item_def& item, int force_type,
 
             // These scrolls increase knowledge, so Xom considers them boring.
             if (agent == GOD_XOM
-                && (scr == SCR_IDENTIFY || scr == SCR_MAGIC_MAPPING))
+                && (scr == SCR_IDENTIFY || scr == SCR_REVELATION))
             {
                 continue;
             }
@@ -1474,36 +1372,44 @@ static stave_type _get_random_stave_type()
     return r;
 }
 
-static void _generate_staff_item(item_def& item, bool allow_uniques,
-                                 int force_type, int item_level, int agent)
+static void _try_make_staff_artefact(item_def& item, bool allow_uniques,
+                                     int item_level, int agent)
 {
-    // If we make the unique roll, no further generation necessary.
-    // Copied unrand code from _try_make_weapon_artefact since randart enhancer staves
-    // can't happen.
+    const bool force_randart = item_level == ISPEC_RANDART;
+
     if (allow_uniques
+        && !force_randart
         && one_chance_in(item_level == ISPEC_GOOD_ITEM ? 27 : 100))
     {
         // Temporarily fix the base_type to get enhancer staves
         // TODO: ???
         item.base_type = OBJ_WEAPONS;
-        // need to use force_type here, because _try_make_item_unrand can set
-        // it for fallback randarts.
-        force_type = WPN_STAFF;
-        if (_try_make_item_unrand(item, force_type, item_level, agent))
+        int fake_force_type = WPN_STAFF;
+        if (_try_make_item_unrand(item, fake_force_type, item_level, agent))
             return;
-        if (item.base_type != OBJ_STAVES)
-        {
-            // this will happen if an unrand staff requests a real weapon as
-            // a fallback. TODO: can this be accommodated in this code path?
-            item.base_type = OBJ_STAVES;
-            force_type = OBJ_RANDOM;
-        }
+        // We failed. Go back to trying a staff.
+        // TODO: support hypothetical fallback to a specific staff type
+        item.base_type = OBJ_STAVES;
     }
 
+    if (force_randart
+        // These odds are taken uncritically from _try_make_weapon_artifact.
+        // We should probably revisit them.
+        || item_level > 0 && x_chance_in_y(101 + item_level * 3, 8000))
+    {
+        make_item_randart(item);
+    }
+}
+
+static void _generate_staff_item(item_def& item, bool allow_uniques,
+                                 int force_type, int item_level, int agent)
+{
     if (force_type == OBJ_RANDOM)
         item.sub_type = _get_random_stave_type();
     else
         item.sub_type = force_type;
+
+    _try_make_staff_artefact(item, allow_uniques, item_level, agent);
 }
 
 static void _generate_rune_item(item_def& item, int force_type)
@@ -1526,6 +1432,12 @@ static void _generate_rune_item(item_def& item, int force_type)
         item.sub_type = force_type;
 }
 
+static void _generate_gem_item(item_def& item, int force_type)
+{
+    ASSERT_RANGE(force_type, 0, NUM_GEM_TYPES);
+    item.sub_type = force_type;
+}
+
 static bool _try_make_jewellery_unrandart(item_def& item, int force_type,
                                           int item_level, int agent)
 {
@@ -1548,7 +1460,7 @@ static bool _try_make_jewellery_unrandart(item_def& item, int force_type,
  * GOOD_RING_PLUS.
  *
  * @param subtype       The type of ring in question.
- * @return              4 or 6.
+ * @return              4, 5 or 6.
  *                      (minor numerical variations are boring.)
  */
 static short _good_jewellery_plus(int subtype)
@@ -1559,6 +1471,8 @@ static short _good_jewellery_plus(int subtype)
         case RING_DEXTERITY:
         case RING_INTELLIGENCE:
             return GOOD_STAT_RING_PLUS;
+        case RING_EVASION:
+            return 5;
         default:
             return GOOD_RING_PLUS;
     }
@@ -1618,24 +1532,137 @@ static void _generate_jewellery_item(item_def& item, bool allow_uniques,
     }
 }
 
-static void _generate_misc_item(item_def& item, int force_type)
+/// For a given dungeon depth (or item level), how much weight should we give
+/// to each talisman?
+static const vector<random_pick_entry<talisman_type>> talisman_weights =
+{
+    // tier 0
+    {  0, 20,  45, FALL, TALISMAN_BEAST },
+    {  0, 35,   5, FLAT, TALISMAN_BEAST },
+    {  0, 20,  45, FALL, TALISMAN_FLUX },
+    {  0, 35,   5, FLAT, TALISMAN_FLUX },
+    // tier 1
+    {  0, 27,  90, PEAK, TALISMAN_MAW },
+    {  0, 35,  10, FLAT, TALISMAN_MAW },
+    {  0, 27,  90, PEAK, TALISMAN_SERPENT },
+    {  0, 35,  10, FLAT, TALISMAN_SERPENT },
+    {  0, 27,  90, PEAK, TALISMAN_BLADE },
+    {  0, 35,  10, FLAT, TALISMAN_BLADE },
+    // tier 2
+    {  8, 20,  25, RISE, TALISMAN_STATUE },
+    { 21, 35,  25, FLAT, TALISMAN_STATUE },
+    {  0, 35,   5, FLAT, TALISMAN_STATUE },
+    {  8, 20,  25, RISE, TALISMAN_DRAGON },
+    { 21, 35,  25, FLAT, TALISMAN_DRAGON },
+    {  0, 35,   5, FLAT, TALISMAN_DRAGON },
+    // tier 3
+    { 20, 27,  25, RISE, TALISMAN_DEATH },
+    { 28, 35,  25, FLAT, TALISMAN_DEATH },
+    {  0, 35,   5, FLAT, TALISMAN_DEATH },
+    { 20, 27,  25, RISE, TALISMAN_STORM },
+    { 28, 35,  25, FLAT, TALISMAN_STORM },
+    {  0, 35,   5, FLAT, TALISMAN_STORM },
+};
+
+static int _talisman_level(int item_level)
+{
+    switch (item_level) {
+    case ISPEC_DAMAGED:
+    case ISPEC_BAD:
+        return 0;
+    case ISPEC_GIFT:
+        return 15; // ?? arbitrary
+    case ISPEC_RANDART:
+    case ISPEC_GOOD_ITEM:
+        return 27; // ?? arbitrary
+    default:
+        return min(item_level, 35); // roughly the bottom of the Hells
+    }
+}
+
+static int _pick_talisman_type(int force_type, int lvl)
 {
     if (force_type != OBJ_RANDOM)
-        item.sub_type = force_type;
+        return force_type;
+
+    random_picker<talisman_type, NUM_TALISMANS * 3 /*ew*/> picker;
+    return picker.pick(talisman_weights, lvl, NUM_TALISMANS);
+}
+
+static void _generate_talisman_item(item_def& item, int force_type, int item_level)
+{
+    const int lvl = _talisman_level(item_level);
+    item.sub_type = _pick_talisman_type(force_type, lvl);
+    if (item_level == ISPEC_RANDART || x_chance_in_y(lvl, 270))
+        make_item_randart(item);
+}
+
+misc_item_type get_misc_item_type(int force_type, bool exclude)
+{
+    if (force_type != OBJ_RANDOM)
+    {
+        if (exclude && you.generated_misc.count((misc_item_type)force_type))
+            return NUM_MISCELLANY;
+        return (misc_item_type)force_type;
+    }
+    set<misc_item_type> choices;
+    if (exclude)
+    {
+        choices = {
+            MISC_PHIAL_OF_FLOODS,
+            MISC_LIGHTNING_ROD,
+            (misc_item_type)item_for_set(ITEM_SET_ALLY_MISCELLANY),
+            MISC_PHANTOM_MIRROR,
+            (misc_item_type)item_for_set(ITEM_SET_AREA_MISCELLANY)
+        };
+        for (auto it : you.generated_misc)
+            choices.erase(it);
+    }
     else
     {
-        item.sub_type = random_choose(MISC_PHIAL_OF_FLOODS,
-                                      MISC_LIGHTNING_ROD,
-                                      MISC_BOX_OF_BEASTS,
-                                      MISC_PHANTOM_MIRROR,
-                                      MISC_TIN_OF_TREMORSTONES,
-                                      MISC_CONDENSER_VANE,
-                                      MISC_XOMS_CHESSBOARD);
+        choices = {
+            MISC_PHIAL_OF_FLOODS,
+            MISC_LIGHTNING_ROD,
+            MISC_BOX_OF_BEASTS,
+            MISC_SACK_OF_SPIDERS,
+            MISC_PHANTOM_MIRROR,
+            MISC_CONDENSER_VANE,
+            MISC_TIN_OF_TREMORSTONES,
+        };
+    }
+    if (choices.size())
+        return *random_iterator(choices);
+    return NUM_MISCELLANY;
+}
+
+static void _generate_misc_item(item_def& item, int force_type, int item_level)
+{
+    const auto typ = get_misc_item_type(force_type);
+    if (typ == NUM_MISCELLANY)
+    {
+        item.base_type = OBJ_WANDS;
+        generate_wand_item(item, OBJ_RANDOM, item_level);
+        return;
+    }
+    item.sub_type = typ;
+    switch (typ)
+    {
+    case MISC_SACK_OF_SPIDERS:
+    case MISC_BOX_OF_BEASTS:
+    case MISC_LIGHTNING_ROD:
+    case MISC_PHIAL_OF_FLOODS:
+    case MISC_PHANTOM_MIRROR:
+    case MISC_TIN_OF_TREMORSTONES:
+    case MISC_CONDENSER_VANE:
+        you.generated_misc.insert(typ);
+        break;
+    default:
+        break;
     }
 }
 
 /**
- * Alter the inputed item to have no "plusses" (mostly weapon/armour enchantment)
+ * Alter the inputted item to have no "plusses" (mostly weapon/armour enchantment)
  *
  * @param[in,out] item_slot The item slot of the item to remove "plusses" from.
  */
@@ -1698,7 +1725,7 @@ static void _setup_fallback_randart(const int unrand_id,
     {
         item.base_type = OBJ_STAVES;
         if (unrand_id == UNRAND_OLGREB)
-            force_type = STAFF_POISON;
+            force_type = STAFF_ALCHEMY;
         else
             force_type = OBJ_RANDOM;
         // XXX: small chance of other unrands under some circumstances...
@@ -1806,21 +1833,21 @@ int items(bool allow_uniques,
     else
     {
         ASSERT(force_type == OBJ_RANDOM);
-        // Total weight: 1720
+        // Total weight: 1660
         item.base_type = random_choose_weighted(
                                     10, OBJ_STAVES,
                                     45, OBJ_JEWELLERY,
                                     45, OBJ_BOOKS,
                                     70, OBJ_WANDS,
-                                   210, OBJ_ARMOUR,
-                                   210, OBJ_WEAPONS,
-                                   210, OBJ_POTIONS,
+                                   212, OBJ_ARMOUR,
+                                   212, OBJ_WEAPONS,
+                                   176, OBJ_POTIONS,
                                    180, OBJ_MISSILES,
-                                   300, OBJ_SCROLLS,
+                                   270, OBJ_SCROLLS,
                                    440, OBJ_GOLD);
 
         // misc items placement wholly dependent upon current depth {dlb}:
-        if (item_level > 7 && x_chance_in_y(21 + item_level, 5000))
+        if (item_level > 7 && x_chance_in_y(11 + item_level, 9000))
             item.base_type = OBJ_MISCELLANY;
 
         if (item_level < 7
@@ -1829,6 +1856,12 @@ int items(bool allow_uniques,
         {
             item.base_type = random_choose(OBJ_POTIONS, OBJ_SCROLLS);
         }
+
+        // Sorry. Trying to get a high enough weight of talismans early
+        // so that folks can upgrade, etc, without deluging players with
+        // them later.
+        if (one_chance_in(100) && !x_chance_in_y(max(item_level, 5) * 2, 100))
+            item.base_type = OBJ_TALISMANS;
     }
 
     ASSERT(force_type == OBJ_RANDOM
@@ -1877,7 +1910,7 @@ int items(bool allow_uniques,
         break;
 
     case OBJ_WANDS:
-        _generate_wand_item(item, force_type, item_level);
+        generate_wand_item(item, force_type, item_level);
         break;
 
     case OBJ_POTIONS:
@@ -1908,8 +1941,16 @@ int items(bool allow_uniques,
         _generate_rune_item(item, force_type);
         break;
 
+    case OBJ_GEMS:
+        _generate_gem_item(item, force_type);
+        break;
+
+    case OBJ_TALISMANS:
+        _generate_talisman_item(item, force_type, item_level);
+        break;
+
     case OBJ_MISCELLANY:
-        _generate_misc_item(item, force_type);
+        _generate_misc_item(item, force_type, item_level);
         break;
 
     // that is, everything turns to gold if not enumerated above, so ... {dlb}
@@ -2133,5 +2174,11 @@ void makeitem_tests()
                               type,
                               level);
     }
+    mpr("Running acquirement tests.");
+    // note: without char customization this won't exercise all acquirement
+    // code. But this at least gives a baseline.
+    for (i = 0; i < 500; ++i)
+        make_acquirement_items();
+
 }
 #endif
