@@ -23,6 +23,7 @@ void item_colour(item_def &item);
 
 jewellery_type get_random_ring_type();
 jewellery_type get_random_amulet_type();
+misc_item_type get_misc_item_type(int force_type, bool exclude = true);
 void item_set_appearance(item_def &item);
 
 bool is_weapon_brand_ok(int type, int brand, bool strict);
@@ -37,6 +38,7 @@ void set_artefact_brand(item_def &item, int brand);
 bool got_curare_roll(const int item_level);
 void reroll_brand(item_def &item, int item_level);
 
+void generate_wand_item(item_def& item, int force_type, int item_level);
 bool is_high_tier_wand(int type);
 
 void squash_plusses(int item_slot);
