@@ -69,7 +69,7 @@ static void _mon_check_foe_invalid(monster* mon)
         {
             const monster* foe_mons = foe->as_monster();
             if (foe_mons->alive() && summon_can_attack(mon, foe)
-                && (mon->has_ench(ENCH_INSANE)
+                && (mon->has_ench(ENCH_FRENZIED)
                     || mon->friendly() != foe_mons->friendly()
                     || mon->neutral() != foe_mons->neutral()))
             {
@@ -153,7 +153,7 @@ static void _decide_monster_firing_position(monster* mon, actor* owner)
     if (mon->foe == MHITYOU)
     {
         const bool ignore_special_firing_AI = mon->friendly()
-                                              || mon->berserk_or_insane();
+                                              || mon->berserk_or_frenzied();
 
         // The foe is the player.
         if (mons_class_flag(mon->type, M_MAINTAIN_RANGE)
@@ -188,7 +188,7 @@ static void _decide_monster_firing_position(monster* mon, actor* owner)
         mon->target = target->pos();
 
         if (mons_class_flag(mon->type, M_MAINTAIN_RANGE)
-            && !mon->berserk_or_insane()
+            && !mon->berserk_or_frenzied()
             && !(mons_is_avatar(mon->type)
                  && owner && mon->foe == owner->mindex()))
         {
@@ -257,7 +257,7 @@ void handle_behaviour(monster* mon)
     bool changed = true;
     bool isFriendly = mon->friendly();
     bool isNeutral  = mon->neutral();
-    bool wontAttack = mon->wont_attack() && !mon->has_ench(ENCH_INSANE);
+    bool wontAttack = mon->wont_attack() && !mon->has_ench(ENCH_FRENZIED);
 
     // Whether the player position is in LOS of the monster.
     bool proxPlayer = !crawl_state.game_is_arena() && mon->see_cell(you.pos())
@@ -273,8 +273,6 @@ void handle_behaviour(monster* mon)
     bool isScared   = mon->has_ench(ENCH_FEAR);
     bool isPacified = mon->pacified();
     bool patrolling = mon->is_patrolling();
-    static vector<level_exit> e;
-    static int                e_index = -1;
 
     //mprf("AI debug: mon %d behv=%d foe=%d pos=%d %d target=%d %d",
     //     mon->mindex(), mon->behaviour, mon->foe, mon->pos().x,
@@ -320,7 +318,7 @@ void handle_behaviour(monster* mon)
     // Berserking allies ignore your commands!
     if (isFriendly
         && (mon->foe == MHITNOT || mon->foe == MHITYOU)
-        && !mon->berserk_or_insane()
+        && !mon->berserk_or_frenzied()
         && mon->behaviour != BEH_WITHDRAW
         && !mons_self_destructs(*mon)
         && !mons_is_avatar(mon->type))
@@ -333,7 +331,7 @@ void handle_behaviour(monster* mon)
 
     // Instead, berserkers attack nearest monsters.
     if (mon->behaviour != BEH_SLEEP
-        && (mon->has_ench(ENCH_INSANE)
+        && (mon->has_ench(ENCH_FRENZIED)
             || ((mon->berserk() || mons_self_destructs(*mon))
                 && (mon->foe == MHITNOT
                     || isFriendly && mon->foe == MHITYOU))))
@@ -341,7 +339,7 @@ void handle_behaviour(monster* mon)
         // Intelligent monsters prefer to attack the player,
         // even when berserking.
         if (!isFriendly
-            && !mon->has_ench(ENCH_INSANE)
+            && !mon->has_ench(ENCH_FRENZIED)
             && proxPlayer
             && mons_intel(*mon) >= I_HUMAN)
         {
@@ -380,7 +378,7 @@ void handle_behaviour(monster* mon)
 
     // Neutral monsters prefer not to attack players, or other neutrals.
     if (isNeutral
-        && !mon->has_ench(ENCH_INSANE)
+        && !mon->has_ench(ENCH_FRENZIED)
         && mon->foe != MHITNOT
         && (mon->foe == MHITYOU || env.mons[mon->foe].neutral()))
     {
@@ -392,7 +390,7 @@ void handle_behaviour(monster* mon)
     if (!isFriendly && !isNeutral
         && !mons_is_avatar(mon->type)
         && mon->foe != MHITYOU && mon->foe != MHITNOT
-        && proxPlayer && !mon->berserk_or_insane()
+        && proxPlayer && !mon->berserk_or_frenzied()
         && isHealthy
         && !one_chance_in(3))
     {
@@ -443,6 +441,7 @@ void handle_behaviour(monster* mon)
         case BEH_SLEEP:
             // default sleep state
             mon->target = mon->pos();
+            mon->firing_pos = mon->pos();
             new_foe = MHITNOT;
             break;
 
@@ -452,7 +451,7 @@ void handle_behaviour(monster* mon)
             {
                 if (crawl_state.game_is_arena()
                     || !proxPlayer && !isFriendly
-                    || isNeutral && !mon->has_ench(ENCH_INSANE)
+                    || isNeutral && !mon->has_ench(ENCH_FRENZIED)
                     || patrolling
                     || mons_self_destructs(*mon))
                 {
@@ -633,38 +632,39 @@ void handle_behaviour(monster* mon)
         case BEH_BATTY:
             if (isPacified)
             {
-                // If a pacified monster isn't travelling toward
-                // someplace from which it can leave the level, make it
-                // start doing so. If there's no such place, either
-                // search the level for such a place again, or travel
-                // randomly.
-                if (mon->travel_target != MTRAV_PATROL)
+                // If a pacified monster isn't travelling toward some place from
+                // which it can leave the level (either because it was just
+                // pacified, or something later interfered with it exiting),
+                // make it start doing so.
+                //
+                // If it cannot find a path to any exit at all, wander randomly
+                // instead.
+                if ((mon->travel_target != MTRAV_PATROL
+                     || mon->target != mon->patrol_point)
+                    && !mon->props.exists(PACIFY_LEAVE_FAIL_KEY))
                 {
                     new_foe = MHITNOT;
-                    mon->travel_path.clear();
-
-                    e_index = mons_find_nearest_level_exit(mon, e);
-
-                    if (e_index == -1 || one_chance_in(20))
-                        e_index = mons_find_nearest_level_exit(mon, e, true);
-
-                    if (e_index != -1)
-                    {
-                        mon->travel_target = MTRAV_PATROL;
+                    if (mons_path_to_nearest_level_exit(mon))
                         patrolling = true;
-                        mon->patrol_point = e[e_index].target;
-                        mon->target = e[e_index].target;
-                    }
+                    // Failed to find any reachable stair. Wander randomly and
+                    // don't try again, since this is unlikely to be temporary.
+                    // (This should almost never happen in practice; mostly for
+                    // pacified monsters stuck behind liquids. While technically
+                    // they could get blinked out again and then ought to find
+                    // a stair, if they look a little dumb in this random
+                    // situation, it's probably okay. (They will disappear once
+                    // the player gets far enough away anyway).
                     else
                     {
                         mon->travel_target = MTRAV_NONE;
                         patrolling = false;
                         mon->patrol_point.reset();
                         set_random_target(mon);
+                        mon->props[PACIFY_LEAVE_FAIL_KEY] = true;
                     }
                 }
 
-                if (pacified_leave_level(mon, e, e_index))
+                if (pacified_leave_level(mon))
                     return;
             }
 
@@ -690,14 +690,16 @@ void handle_behaviour(monster* mon)
                 && in_bounds(you.pos())
                 && (!isFriendly && !mons_is_avatar(mon->type) && !isNeutral
                     && !isPacified
-                    || mon->has_ench(ENCH_INSANE)))
+                    || mon->has_ench(ENCH_FRENZIED)))
             {
                 new_foe = MHITYOU;
                 new_beh = BEH_SEEK;
                 break;
             }
 
-            check_wander_target(mon, isPacified);
+            // Pacified monsters who have 'given up' on leaving should wander
+            check_wander_target(mon, isPacified
+                                      && !mon->props.exists(PACIFY_LEAVE_FAIL_KEY));
 
             // During their wanderings, monsters will eventually relax
             // their guard (stupid ones will do so faster, smart
@@ -706,21 +708,16 @@ void handle_behaviour(monster* mon)
             // leave the level, in case their current choice is blocked.
             if (!proxFoe && !mons_is_avatar(mon->type) && mon->foe != MHITNOT
                    && one_chance_in(isSmart ? 60 : 20)
-                   && !mons_foe_is_marked(*mon)
-                || isPacified && one_chance_in(isSmart ? 40 : 120))
+                   && !mons_foe_is_marked(*mon))
             {
                 new_foe = MHITNOT;
-                if (mon->is_travelling() && mon->travel_target != MTRAV_PATROL
-                    || isPacified)
+                if (mon->is_travelling() && mon->travel_target != MTRAV_PATROL)
                 {
 #ifdef DEBUG_PATHFIND
                     mpr("It's been too long! Stop travelling.");
 #endif
                     mon->travel_path.clear();
                     mon->travel_target = MTRAV_NONE;
-
-                    if (isPacified && e_index != -1)
-                        e[e_index].unreachable = true;
                 }
             }
             break;
@@ -777,7 +774,7 @@ void handle_behaviour(monster* mon)
             if (!proxFoe)
             {
                 if ((isFriendly || proxPlayer)
-                    && (!isNeutral || mon->has_ench(ENCH_INSANE))
+                    && (!isNeutral || mon->has_ench(ENCH_FRENZIED))
                     && !patrolling
                     && !crawl_state.game_is_arena())
                 {
@@ -907,13 +904,13 @@ static bool _mons_check_foe(monster* mon, const coord_def& p,
            && (ignore_sight || mon->can_see(*foe))
            && (foe->friendly() != friendly
                || neutral && !foe->neutral()
-               || mon->has_ench(ENCH_INSANE))
+               || mon->has_ench(ENCH_FRENZIED))
            && !mons_is_projectile(*foe)
            && summon_can_attack(mon, p)
            && (friendly || !is_sanctuary(p))
            && !mons_is_firewood(*foe)
            && !foe->props.exists(KIKU_WRETCH_KEY)
-           || p == you.pos() && mon->has_ench(ENCH_INSANE);
+           || p == you.pos() && mon->has_ench(ENCH_FRENZIED);
 }
 
 // Choose random nearest monster as a foe.
@@ -1099,7 +1096,10 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
                 summon_dismissal_fineff::schedule(mon);
                 return;
             }
-            else
+            // Don't attempt to 'anger' monsters that are already hostile; this can
+            // have weird and unexpected effects, such as prematurely ending hostile
+            // effects.
+            else if (mon->temp_attitude()  != ATT_HOSTILE)
             {
                 mon->attitude = ATT_HOSTILE;
                 breakCharm    = true;
@@ -1141,7 +1141,7 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
         // XXX: Neutral monsters are a tangled mess of arbitrary logic.
         // It's not even clear any more what behaviours are intended for
         // neutral monsters and what are merely accidents of the code.
-        if (mon->neutral() && !mon->has_ench(ENCH_INSANE))
+        if (mon->neutral() && !mon->has_ench(ENCH_FRENZIED))
         {
             if (mon->asleep())
                 mon->behaviour = BEH_WANDER;
@@ -1178,7 +1178,7 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
     case ME_SCARE:
         // Stationary monsters can't flee, and berserking monsters
         // are too enraged.
-        if (mon->is_stationary() || mon->berserk_or_insane())
+        if (mon->is_stationary() || mon->berserk_or_frenzied())
         {
             mon->del_ench(ENCH_FEAR, true, true);
             break;
@@ -1251,7 +1251,8 @@ void behaviour_event(monster* mon, mon_event_type event, const actor *src,
     if (setTarget && src)
     {
         mon->target = src_pos;
-        if (src->is_player() && mon->angered_by_attacks())
+        if (src->is_player() && mon->angered_by_attacks()
+            && mon->temp_attitude() != ATT_HOSTILE)
         {
             // Why only attacks by the player change attitude? -- 1KB
             mon->attitude = ATT_HOSTILE;
