@@ -17,9 +17,9 @@
 #include "item-status-flag-type.h"
 #include "items.h"
 #include "libutil.h" // map_find
+#include "misc.h" // december_holidays
 #include "mon-place.h"
 #include "mpr.h"
-#include "randbook.h" // roxanne, roxanne...
 #include "religion.h" // upgrade_hepliaklqana_weapon
 #include "state.h"
 #include "tag-version.h"
@@ -104,25 +104,43 @@ static bool _should_give_unique_item(monster* mon)
     return mon->type != MONS_NATASHA || !mon->props.exists(FELID_REVIVES_KEY);
 }
 
-static void _give_book(monster* mon, int level)
+static talisman_type _talisman_for(monster_type mtyp)
 {
-    if (mon->type == MONS_ROXANNE)
+    switch (mtyp)
     {
-        // Statue form books, heh.
-        const int which_book = (one_chance_in(3) ? BOOK_SLOTH
-                                                 : BOOK_EARTH);
-
-        const int thing_created = items(false, OBJ_BOOKS, which_book, level);
-
-        if (thing_created == NON_ITEM)
-            return;
-
-        // Maybe give Roxanne a random book containing Statue Form instead.
+    case MONS_RUPERT:
         if (coinflip())
-            make_book_roxanne_special(&env.item[thing_created]);
-
-        give_specific_item(mon, thing_created);
+            return TALISMAN_MAW; // good for shoutin'
+        break;
+    case MONS_AIZUL:
+        return TALISMAN_SERPENT; // late, but so thematic!
+    case MONS_ROXANNE:
+        return TALISMAN_STATUE;
+    case MONS_SOJOBO:
+        if (coinflip())
+            return TALISMAN_STORM;
+        break;
+    case MONS_BAI_SUZHEN:
+        if (coinflip())
+            return TALISMAN_DRAGON;
+        break;
+    case MONS_JOSEPHINA:
+        if (coinflip())
+            return TALISMAN_DEATH;
+        break;
+    default:
+        break;
     }
+    return NUM_TALISMANS;
+}
+
+static void _give_talisman(monster* mon, int level)
+{
+    const talisman_type talisman = _talisman_for(mon->type);
+    if (mon->type == MONS_AIZUL)
+        level = ISPEC_RANDART; // partially compensate for lateness
+    if (talisman != NUM_TALISMANS)
+        give_specific_item(mon, items(false, OBJ_TALISMANS, talisman, level));
 }
 
 static void _give_wand(monster* mon, int level)
@@ -151,6 +169,13 @@ static void _give_wand(monster* mon, int level)
         return;
 
     item_def& wand = env.item[idx];
+    // Ugly hack: monsters can't use digging wands, so swap em out.
+    while (wand.sub_type == WAND_DIGGING)
+    {
+        dprf("rerolling");
+        generate_wand_item(wand, OBJ_RANDOM, level);
+        item_colour(wand);
+    }
 
     const char* rejection_reason =
         (no_high_tier && is_high_tier_wand(wand.sub_type)) ? "high tier" :
@@ -172,22 +197,6 @@ static void _give_wand(monster* mon, int level)
     give_specific_item(mon, idx);
 }
 
-static void _give_potion(monster* mon, int level)
-{
-    if (mons_is_unique(mon->type) && one_chance_in(4)
-                && _should_give_unique_item(mon))
-    {
-        const int thing_created = items(false, OBJ_POTIONS, OBJ_RANDOM,
-                                        level);
-
-        if (thing_created == NON_ITEM)
-            return;
-
-        env.item[thing_created].flags = 0;
-        give_specific_item(mon, thing_created);
-    }
-}
-
 static item_def* make_item_for_monster(
     monster* mons,
     object_class_type base,
@@ -388,7 +397,7 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
     static const vector<pair<brand_type, int>> HELL_KNIGHT_BRANDS = // sum 45
     {   { SPWPN_FLAMING,        13 },
         { SPWPN_DRAINING,       4 },
-        { SPWPN_VORPAL,         4 },
+        { SPWPN_HEAVY,          4 },
         { SPWPN_DISTORTION,     2 },
         { SPWPN_PAIN,           2 },
         { NUM_SPECIAL_WEAPONS,  20 }, // 5/9 chance of brand
@@ -496,12 +505,21 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
             { { { WPN_GLAIVE,            2 },
                 { WPN_BARDICHE,          1 },
         }, { 1, 4, 9 }, { { SPWPN_DRAINING, 1 } } } },
+        { MONS_JEREMIAH,
+            { { { WPN_TRIDENT,            1 },
+        }, { 1, 2, 4 }, {
+            { SPWPN_DRAINING,  9 },
+            { SPWPN_VAMPIRISM, 1 },
+        } } },
         { MONS_CRAZY_YIUF,
             { { { WPN_QUARTERSTAFF, 1 } },
             { 1, 2, 4 },
             { { SPWPN_CHAOS, 1 } } } },
         { MONS_JOSEPH, { { { WPN_QUARTERSTAFF, 1 } } } },
-        { MONS_SPRIGGAN_DRUID, { { { WPN_QUARTERSTAFF, 1 } } } },
+        { MONS_SPRIGGAN_DRUID, { { { WPN_QUARTERSTAFF, 1 } }, {}, {
+                { SPWPN_SPECTRAL, 1 },
+                { NUM_SPECIAL_WEAPONS, 5 }
+        } } },
         { MONS_BAI_SUZHEN, { { { WPN_QUARTERSTAFF, 1 } } } },
         { MONS_ORC,                     { ORC_WEAPONS } },
         { MONS_ORC_PRIEST,              { ORC_WEAPONS } },
@@ -525,7 +543,7 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
               { WPN_DEMON_TRIDENT,      1 },
               { WPN_MORNINGSTAR,        1 },
               { WPN_BROAD_AXE,          1 }, },
-            {}, {}, 1,
+            {}, { { SPWPN_SPECTRAL, 1 } }, 1,
         } },
         { MONS_AMAEMON, {
             { { WPN_DEMON_WHIP,       1 } },
@@ -668,10 +686,18 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
             { { { WPN_TRIDENT,          1 },
                 { WPN_SPEAR,            2 },
         } } },
-        { MONS_CENTAUR, { { { WPN_SHORTBOW, 1 } } } },
+        { MONS_KOBOLD_BLASTMINER,
+            { { { WPN_ORCBOW,           8 },
+                { WPN_ARBALEST,         31 },
+                { WPN_HAND_CANNON,      1 },
+        } } },
+        { MONS_CENTAUR,
+            { { { WPN_SHORTBOW,         1 },
+                { WPN_ORCBOW,           1 },
+        } } },
         { MONS_CENTAUR_WARRIOR,
-            { { { WPN_SHORTBOW,         2 },
-                { WPN_LONGBOW,          1 },
+            { { { WPN_SHORTBOW,         1 },
+                { WPN_ORCBOW,           1 },
         } } },
         { MONS_FAUN,                    { FAUN_WEAPONS } },
         { MONS_SATYR,                   { FAUN_WEAPONS } },
@@ -684,7 +710,7 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
         { MONS_YAKTAUR,         { { { WPN_ARBALEST, 1 } } } },
         { MONS_YAKTAUR_CAPTAIN, { {
             { WPN_ARBALEST,      19 },
-            { WPN_HAND_CROSSBOW, 1  },
+            { WPN_HAND_CANNON, 1  },
         } } },
         { MONS_EFREET,                  EFREET_WSPEC },
         { MONS_ERICA,                   EFREET_WSPEC },
@@ -774,7 +800,15 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
               HELL_KNIGHT_BRANDS
         } },
         { MONS_URUG,                    { URUG_WEAPONS } },
-        { MONS_FREDERICK,               { URUG_WEAPONS } },
+        { MONS_NORRIS,                  { URUG_WEAPONS } },
+        { MONS_FREDERICK,
+            { { { WPN_DEMON_BLADE,          2 },
+                { WPN_DEMON_WHIP,           1 },
+                { WPN_DEMON_TRIDENT,        2 },
+                { WPN_DOUBLE_SWORD,         1 },
+                { WPN_BROAD_AXE,            2 },
+                { WPN_EVENINGSTAR,          2 },
+        } } },
         { MONS_FIRE_GIANT, {
             { { WPN_GREAT_SWORD,        1 } }, {},
             { { SPWPN_FLAMING, 1 } },
@@ -788,10 +822,12 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
         { MONS_ORC_SORCERER,    { { { WPN_DAGGER, 1 } } } },
         { MONS_NERGALLE,        { { { WPN_DAGGER, 1 } } } },
         { MONS_DOWAN,           { { { WPN_DAGGER, 1 } } } },
+        { MONS_BURIAL_ACOLYTE,  { { { WPN_DAGGER, 1 } } } },
         { MONS_KOBOLD_DEMONOLOGIST, { { { WPN_DAGGER, 1 } } } },
         { MONS_NECROMANCER,      { { { WPN_DAGGER, 1 } } } },
-        { MONS_WIZARD,          { { { WPN_DAGGER, 1 } } } },
-        { MONS_JOSEPHINE,       { { { WPN_DAGGER, 1 } } } },
+        { MONS_ARCANIST,         { { { WPN_DAGGER, 1 } } } },
+        { MONS_OCCULTIST,        { { { WPN_DAGGER, 1 } } } },
+        { MONS_JOSEPHINE,        { { { WPN_DAGGER, 1 } } } },
         { MONS_PSYCHE, {
             { { WPN_DAGGER,             1 }, },
             { 1, 0, 4 },
@@ -853,7 +889,7 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
               { WPN_GREAT_SWORD,        1 }, },
             { 1, 0, 3 },
             { { SPWPN_DRAINING,      13 }, // total 45
-              { SPWPN_VORPAL,        7 },
+              { SPWPN_HEAVY,         7 },
               { SPWPN_FREEZING,      4 },
               { SPWPN_FLAMING,       4 },
               { SPWPN_PAIN,          2 },
@@ -920,25 +956,28 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
             { { SPWPN_NORMAL,         20 },
               { SPWPN_FLAMING,        20 },
               { SPWPN_FREEZING,       10 },
-              { SPWPN_VORPAL  ,       10 },
+              { SPWPN_HEAVY,          10 },
               { SPWPN_ELECTROCUTION,  10 },
               { SPWPN_VENOM,          10 },
               { SPWPN_VAMPIRISM,       5 },
               { SPWPN_ANTIMAGIC,       5 },
+              { SPWPN_SPECTRAL,        5 },
               { SPWPN_PAIN,            4 },
               { SPWPN_HOLY_WRATH,      3 },
               { SPWPN_DISTORTION,      2 },
               { SPWPN_CHAOS,           1 }, },
         } },
+        { MONS_CERULEAN_IMP,  { { { WPN_SPEAR, 1 } }, {}, { { SPWPN_NORMAL, 1 } } } },
     };
 
     static const weapon_list ORC_KNIGHT_BOWS =
     {   { WPN_ARBALEST,                 1 },
         { NUM_WEAPONS,                  8 }, }; // 1/9 chance of ranged weapon
 
+
     static const map<monster_type, mon_weapon_spec> secondary_weapon_specs = {
         { MONS_JOSEPH, { { { WPN_SLING, 1 } } } },
-        { MONS_DEEP_ELF_ARCHER, // XXX: merge w/centaur warrior primary?
+        { MONS_DEEP_ELF_ARCHER,
             { { { WPN_SHORTBOW,         3 },
                 { WPN_LONGBOW,          1 },
         } } },
@@ -951,19 +990,22 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
                 { WPN_ARBALEST,         2 },
                 { WPN_LONGBOW,          1 }
         } } },
-        { MONS_VAULT_WARDEN,            { ORC_KNIGHT_BOWS } },
+        { MONS_VAULT_WARDEN,            { { { WPN_ARBALEST, 1 }, { NUM_WEAPONS, 8 }} } },
         { MONS_ORC_WARLORD,             { ORC_KNIGHT_BOWS } },
         { MONS_SAINT_ROKA,              { ORC_KNIGHT_BOWS } },
         { MONS_ORC_KNIGHT,              { ORC_KNIGHT_BOWS } },
-        { MONS_ORC_WARRIOR,             { ORC_KNIGHT_BOWS } },
+        { MONS_ORC_WARRIOR,
+            { { { WPN_ORCBOW,           3 },
+                { WPN_ARBALEST,         1 },
+                { NUM_WEAPONS,          32 }
+        } } },
         { MONS_TENGU_WARRIOR,
-            { { { WPN_ARBALEST,                 3 },
-                { WPN_LONGBOW,                  1 },
-                { NUM_WEAPONS,                  32 }, // 1/9 chance of weap
+            { { { WPN_ARBALEST,                 1 },
+                { NUM_WEAPONS,                  8 }, // 1/9 chance of weap
         } } },
         { MONS_VAULT_SENTINEL,
             { { { WPN_ARBALEST,                 19 },
-                { WPN_HAND_CROSSBOW,            1 },
+                { WPN_HAND_CANNON,            1 },
                 { NUM_WEAPONS,                  40 },
         } } },
         { MONS_FAUN, { { { WPN_SLING, 1 } } } },
@@ -1063,7 +1105,7 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
         {
             item.base_type = OBJ_WEAPONS;
             item.sub_type = WPN_QUARTERSTAFF;
-            set_item_ego_type(item, OBJ_WEAPONS, SPWPN_VORPAL);
+            set_item_ego_type(item, OBJ_WEAPONS, SPWPN_HEAVY);
         }
         item.flags |= ISFLAG_KNOW_TYPE;
         break;
@@ -1083,6 +1125,11 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
             level = ISPEC_GOOD_ITEM;
         break;
 
+    case MONS_WAR_GARGOYLE:
+        if (one_chance_in(3))
+            level = ISPEC_GOOD_ITEM;
+        break;
+
     case MONS_MERFOLK:
         if (active_monster_band == BAND_MERFOLK_IMPALER)
         {
@@ -1140,7 +1187,7 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
     case MONS_ARACHNE:
         force_item = true;
         item.base_type = OBJ_STAVES;
-        item.sub_type = STAFF_POISON;
+        item.sub_type = STAFF_ALCHEMY;
         item.flags    |= ISFLAG_KNOW_TYPE;
         if (one_chance_in(100) && !get_unique_item_status(UNRAND_OLGREB))
             make_item_unrandart(item, UNRAND_OLGREB);
@@ -1153,11 +1200,6 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
         make_item_unrandart(item, UNRAND_CEREBOV);
         break;
 
-    case MONS_DISPATER:
-        force_item = true;
-        make_item_unrandart(item, UNRAND_DISPATER);
-        break;
-
     case MONS_ASMODEUS:
         force_item = true;
         make_item_unrandart(item, UNRAND_ASMODEUS);
@@ -1221,8 +1263,16 @@ int make_mons_weapon(monster_type type, int level, bool melee_only)
     case MONS_SIGMUND:
     case MONS_REAPER:
         custom_name = "scythe";
-        floor_tile  = "wpn_scythe";
-        equip_tile  = "scythe";
+        if (type == MONS_SIGMUND && december_holidays())
+        {
+            floor_tile  = "wpn_xmas_scythe";
+            equip_tile  = "xmas_scythe";
+        }
+        else
+        {
+            floor_tile  = "wpn_scythe";
+            equip_tile  = "scythe";
+        }
         break;
 
     case MONS_ANCESTOR_HEXER:
@@ -1330,6 +1380,12 @@ static void _give_weapon(monster *mon, int level, bool second_weapon = false)
         _give_weapon(mon, level, true);
     }
 
+    if (mon->type == MONS_ERICA && i.is_type(OBJ_WEAPONS, WPN_SCIMITAR))
+    {
+        make_item_for_monster(mon, OBJ_JEWELLERY, OBJ_RANDOM,
+                              0, 1, ISFLAG_KNOW_TYPE);
+    }
+
     if (mon->type == MONS_FANNAR && i.is_type(OBJ_WEAPONS, WPN_QUARTERSTAFF))
     {
         make_item_for_monster(mon, OBJ_JEWELLERY, RING_ICE,
@@ -1547,6 +1603,33 @@ static void _give_shield(monster* mon, int level)
         make_item_for_monster(mon, OBJ_ARMOUR, ARM_KITE_SHIELD,
                               level * 2 + 1, 1);
         break;
+
+    case MONS_DISPATER:
+        shield = make_item_for_monster(mon, OBJ_ARMOUR, ARM_ORB, level);
+        if (shield)
+            make_item_unrandart(*shield, UNRAND_DISPATER);
+        break;
+
+    case MONS_JEREMIAH:
+        shield = make_item_for_monster(mon, OBJ_ARMOUR, ARM_ORB, level);
+        if (shield)
+        {
+            // Light is good-coded and Wrath is too vicious.
+            const auto ego = random_choose(SPARM_MAYHEM, SPARM_ENERGY, SPARM_GUILE);
+            set_item_ego_type(*shield, OBJ_ARMOUR, ego);
+        }
+        break;
+
+    case MONS_FREDERICK:
+    {
+        // Divinity or conjurer support.
+        const auto ego = random_choose(SPARM_LIGHT, SPARM_ENERGY);
+
+        give_specific_item(mon, items(false, OBJ_ARMOUR,
+                           ARM_ORB, ISPEC_RANDART, ego));
+    }
+    break;
+
     case MONS_DAEVA:
     case MONS_MENNAS:
         make_item_for_monster(mon, OBJ_ARMOUR, ARM_TOWER_SHIELD,
@@ -1721,6 +1804,8 @@ int make_mons_armour(monster_type type, int level)
     case MONS_DEEP_ELF_ARCHER:
     case MONS_DEEP_ELF_BLADEMASTER:
     case MONS_DEEP_ELF_MASTER_ARCHER:
+    case MONS_MERFOLK_JAVELINEER:
+    case MONS_EUSTACHIO:
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = ARM_LEATHER_ARMOUR;
         break;
@@ -1751,30 +1836,26 @@ int make_mons_armour(monster_type type, int level)
             return NON_ITEM; // er...
         break;
 
-    case MONS_ERICA:
-    case MONS_JOSEPHINE:
-    case MONS_PSYCHE:
-        if (one_chance_in(5))
-            level = ISPEC_GOOD_ITEM;
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
     case MONS_GNOLL_BOUDA:
     case MONS_MELIAI:
+    case MONS_HALAZID_WARLOCK:
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = random_choose(ARM_ROBE, ARM_LEATHER_ARMOUR);
         break;
 
     case MONS_SOJOBO:
         level = ISPEC_GOOD_ITEM;
-        // deliberate fall-through to gnoll sergeant
-    case MONS_GNOLL_SERGEANT:
+        // deliberate fall-through to ring/scale
     case MONS_TENGU_REAVER:
+        if (one_chance_in(3))
+            level = ISPEC_GOOD_ITEM;
+        // deliberate fall-through to ring/scale
+    case MONS_GNOLL_SERGEANT:
+    case MONS_VAULT_SENTINEL:
+    case MONS_IRONBOUND_CONVOKER:
+    case MONS_IRONBOUND_FROSTHEART:
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = random_choose(ARM_RING_MAIL, ARM_SCALE_MAIL);
-        if (type == MONS_TENGU_REAVER && one_chance_in(3))
-            level = ISPEC_GOOD_ITEM;
         break;
 
     case MONS_JOSEPH:
@@ -1823,20 +1904,12 @@ int make_mons_armour(monster_type type, int level)
                                                1, ARM_CRYSTAL_PLATE_ARMOUR);
         break;
 
-    case MONS_JORGRUN:
-        if (one_chance_in(3))
-            level = ISPEC_GOOD_ITEM;
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
     case MONS_ORC_WARLORD:
     case MONS_SAINT_ROKA:
         // Being at the top has its privileges. :)
         if (one_chance_in(3))
             level = ISPEC_GOOD_ITEM;
-        // deliberate fall through
-
+        // deliberate fall through to chain/plate
     case MONS_ORC_KNIGHT:
     case MONS_ORC_WARRIOR:
     case MONS_HELL_KNIGHT:
@@ -1852,13 +1925,6 @@ int make_mons_armour(monster_type type, int level)
         item.sub_type  = random_choose(ARM_CHAIN_MAIL, ARM_PLATE_ARMOUR);
         break;
 
-    case MONS_VAULT_SENTINEL:
-    case MONS_IRONBOUND_CONVOKER:
-    case MONS_IRONBOUND_FROSTHEART:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = random_choose(ARM_RING_MAIL,   ARM_SCALE_MAIL);
-        break;
-
     case MONS_MAGGIE:
         item.base_type = OBJ_ARMOUR;
         item.sub_type = random_choose_weighted(3, ARM_ACID_DRAGON_ARMOUR,
@@ -1883,15 +1949,6 @@ int make_mons_armour(monster_type type, int level)
         force_item = true;
         break;
 
-    case MONS_HELLBINDER:
-    case MONS_SALAMANDER_MYSTIC:
-    case MONS_SERVANT_OF_WHISPERS:
-    case MONS_RAGGED_HIEROPHANT:
-    case MONS_FENSTRIDER_WITCH:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
     case MONS_DEATH_KNIGHT:
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = random_choose_weighted(7, ARM_CHAIN_MAIL,
@@ -1906,19 +1963,6 @@ int make_mons_armour(monster_type type, int level)
             level = ISPEC_GOOD_ITEM;
         break;
 
-    case MONS_MERFOLK_JAVELINEER:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_LEATHER_ARMOUR;
-        break;
-
-    case MONS_ANGEL:
-    case MONS_CHERUB:
-    case MONS_SIGMUND:
-    case MONS_WIGHT:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
     case MONS_SERAPH:
         level          = ISPEC_GOOD_ITEM;
         item.base_type = OBJ_ARMOUR;
@@ -2014,12 +2058,33 @@ int make_mons_armour(monster_type type, int level)
         break;
     }
 
+    case MONS_JOSEPHINE:
+    case MONS_PSYCHE:
+        if (one_chance_in(5))
+            level = ISPEC_GOOD_ITEM;
+        item.base_type = OBJ_ARMOUR;
+        item.sub_type  = ARM_ROBE;
+        break;
+
+    case MONS_BORIS:
+    case MONS_JOSEPHINA:
+        level = ISPEC_GOOD_ITEM;
+    case MONS_ORC_SORCERER:
+    case MONS_DEMONSPAWN_BLOOD_SAINT:
+    case MONS_JORGRUN:
+        if (one_chance_in(3))
+            level = ISPEC_GOOD_ITEM;
+        // fallthrough to robes
+    case MONS_ORC_WIZARD:
+    case MONS_BLORK_THE_ORC:
+    case MONS_NERGALLE:
     case MONS_DOWAN:
     case MONS_JESSICA:
     case MONS_KOBOLD_DEMONOLOGIST:
     case MONS_OGRE_MAGE:
     case MONS_EROLCHA:
-    case MONS_WIZARD:
+    case MONS_ARCANIST:
+    case MONS_OCCULTIST:
     case MONS_ILSUIW:
     case MONS_MARA:
     case MONS_RAKSHASA:
@@ -2027,6 +2092,22 @@ int make_mons_armour(monster_type type, int level)
     case MONS_SPRIGGAN:
     case MONS_SPRIGGAN_AIR_MAGE:
     case MONS_SPRIGGAN_DEFENDER:
+    case MONS_ANGEL:
+    case MONS_CHERUB:
+    case MONS_SIGMUND:
+    case MONS_WIGHT:
+    case MONS_SPRIGGAN_DRUID:
+    case MONS_AGNES:
+    case MONS_BURIAL_ACOLYTE:
+    case MONS_NECROMANCER:
+    case MONS_VAMPIRE_MAGE:
+    case MONS_PIKEL:
+    case MONS_HELLBINDER:
+    case MONS_SALAMANDER_MYSTIC:
+    case MONS_SERVANT_OF_WHISPERS:
+    case MONS_RAGGED_HIEROPHANT:
+    case MONS_FENSTRIDER_WITCH:
+    case MONS_JEREMIAH:
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = ARM_ROBE;
         break;
@@ -2038,15 +2119,11 @@ int make_mons_armour(monster_type type, int level)
     case MONS_DRACONIAN_MONK:
     case MONS_DRACONIAN_KNIGHT:
     case MONS_BAI_SUZHEN:
+    case MONS_NIKOLA:
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = ARM_CLOAK;
         break;
 
-    case MONS_SPRIGGAN_DRUID:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
     case MONS_THE_ENCHANTRESS:
         force_item = true;
         make_item_unrandart(item, UNRAND_FAERIE);
@@ -2057,43 +2134,11 @@ int make_mons_armour(monster_type type, int level)
         make_item_unrandart(item, UNRAND_DRAGONSKIN);
         break;
 
-    case MONS_ORC_SORCERER:
-        if (one_chance_in(3))
-            level = ISPEC_GOOD_ITEM;
-    case MONS_ORC_WIZARD:
-    case MONS_BLORK_THE_ORC:
-    case MONS_NERGALLE:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
-    case MONS_BORIS:
-    case MONS_JOSEPHINA:
-        level = ISPEC_GOOD_ITEM;
-        // fall-through
-    case MONS_AGNES:
-    case MONS_NECROMANCER:
-    case MONS_VAMPIRE_MAGE:
-    case MONS_PIKEL:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
-    case MONS_EUSTACHIO:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_LEATHER_ARMOUR;
-        break;
-
     case MONS_NESSOS:
         item.base_type = OBJ_ARMOUR;
         item.sub_type  = ARM_BARDING;
         break;
 
-    case MONS_NIKOLA:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_CLOAK;
-        break;
-
     case MONS_DEMONSPAWN_CORRUPTER:
     case MONS_DEMONSPAWN_BLACK_SUN:
         item.base_type = OBJ_ARMOUR;
@@ -2104,13 +2149,6 @@ int make_mons_armour(monster_type type, int level)
                                                 2, ARM_PLATE_ARMOUR);
         break;
 
-    case MONS_DEMONSPAWN_BLOOD_SAINT:
-        if (one_chance_in(3))
-            level = ISPEC_GOOD_ITEM;
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = ARM_ROBE;
-        break;
-
     case MONS_DEMONSPAWN_WARMONGER:
         if (coinflip())
             level = ISPEC_GOOD_ITEM;
@@ -2122,11 +2160,6 @@ int make_mons_armour(monster_type type, int level)
                                                   5, ARM_ACID_DRAGON_ARMOUR);
         break;
 
-    case MONS_HALAZID_WARLOCK:
-        item.base_type = OBJ_ARMOUR;
-        item.sub_type  = random_choose(ARM_LEATHER_ARMOUR, ARM_ROBE);
-        break;
-
     default:
         return NON_ITEM;
     }
@@ -2209,9 +2242,8 @@ void give_item(monster *mons, int level_number, bool mons_summoned)
     ASSERT(level_number > -1); // debugging absdepth0 changes
 
     _give_gold(mons, level_number);
-    _give_book(mons, level_number);
+    _give_talisman(mons, level_number);
     _give_wand(mons, level_number);
-    _give_potion(mons, level_number);
     _give_weapon(mons, level_number);
     _give_ammo(mons, level_number, mons_summoned);
     _give_armour(mons, 1 + level_number / 2);
