@@ -27,24 +27,24 @@
 static const mon_spellbook mspell_list[] =
 {
 
-    /* Crimson imp, blink frog, and killer klown. */
+    /* Crimson imps, blink frogs, Prince Rabbit. */
     {  MST_BLINKER,
       {
        { SPELL_BLINK, 29, MON_SPELL_MAGICAL },
       }
     },
 
-    /* Orc warlords and cherubs. */
-    {  MST_BATTLECRY,
+    /* Phantasmal warriors and formless jellyfish. */
+    {  MST_BLINK_CLOSE,
       {
-       { SPELL_BATTLECRY, 100, MON_SPELL_VOCAL },
+       { SPELL_BLINK_CLOSE, 67, MON_SPELL_MAGICAL },
       }
     },
 
-    /* Eyes of draining and ghost moths. */
-    {  MST_DRAIN_GAZE,
+    /* Orc warlords and cherubim. */
+    {  MST_BATTLECRY,
       {
-       { SPELL_DRAINING_GAZE, 100, MON_SPELL_MAGICAL | MON_SPELL_INSTANT },
+       { SPELL_BATTLECRY, 100, MON_SPELL_VOCAL },
       }
     },
 
@@ -62,21 +62,6 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    // War gargoyles and iron dragons.
-    {  MST_SPLINTER_BREATH,
-      {
-       { SPELL_METAL_SPLINTERS, 68, MON_SPELL_NATURAL | MON_SPELL_BREATH
-                                     | MON_SPELL_NOISY },
-      }
-    },
-
-    // Howler monkeys and demonic crawlers.
-    { MST_SCREAMER,
-      {
-        { SPELL_WARNING_CRY, 40, MON_SPELL_VOCAL | MON_SPELL_BREATH },
-      }
-    },
-
     // Deep elf annihilators and draconian annihilators.
     {  MST_ANNIHILATOR,
       {
@@ -121,7 +106,7 @@ static const mon_spellbook mspell_list[] =
     // ('e') Elves.
     {  MST_DEEP_ELF_FIRE_MAGE,
       {
-       { SPELL_STICKY_FLAME_RANGE, 15, MON_SPELL_WIZARD },
+       { SPELL_PYRE_ARROW, 15, MON_SPELL_WIZARD },
        { SPELL_BOLT_OF_FIRE, 15, MON_SPELL_WIZARD },
        { SPELL_FIRE_ELEMENTALS, 15, MON_SPELL_WIZARD },
        { SPELL_BLINK, 15, MON_SPELL_WIZARD },
@@ -155,9 +140,9 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_DEEP_ELF_ELEMENTALIST,
       {
-       { SPELL_FREEZING_CLOUD, 11, MON_SPELL_WIZARD },
+       { SPELL_FREEZING_CLOUD, 22, MON_SPELL_WIZARD },
        { SPELL_FIREBALL, 11, MON_SPELL_WIZARD },
-       { SPELL_AWAKEN_EARTH, 44, MON_SPELL_WIZARD },
+       { SPELL_LRD, 33, MON_SPELL_WIZARD },
        { SPELL_REPEL_MISSILES, 11, MON_SPELL_WIZARD },
        { SPELL_HASTE, 11, MON_SPELL_WIZARD },
       }
@@ -193,7 +178,7 @@ static const mon_spellbook mspell_list[] =
       {
        { SPELL_BOLT_OF_DRAINING, 22, MON_SPELL_WIZARD },
        { SPELL_VAMPIRIC_DRAINING, 22, MON_SPELL_WIZARD },
-       { SPELL_CALL_LOST_SOUL, 11, MON_SPELL_WIZARD },
+       { SPELL_CALL_LOST_SOULS, 22, MON_SPELL_WIZARD },
       }
     },
 
@@ -242,6 +227,12 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    { MST_HOWLER_MONKEY,
+      {
+        { SPELL_WARNING_CRY, 40, MON_SPELL_VOCAL | MON_SPELL_BREATH },
+      }
+    },
+
     {  MST_HELL_HOUND,
       {
        { SPELL_FIRE_BREATH, 20, MON_SPELL_NATURAL | MON_SPELL_BREATH },
@@ -279,7 +270,7 @@ static const mon_spellbook mspell_list[] =
       {
        { SPELL_STONE_ARROW, 15, MON_SPELL_WIZARD },
        { SPELL_DRUIDS_CALL, 15, MON_SPELL_WIZARD },
-       { SPELL_AWAKEN_FOREST, 15, MON_SPELL_WIZARD },
+       { SPELL_AWAKEN_FOREST, 25, MON_SPELL_WIZARD },
        { SPELL_MINOR_HEALING, 15, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
       }
     },
@@ -413,27 +404,43 @@ static const mon_spellbook mspell_list[] =
     },
 
     // ('p') Humans.
+    {  MST_BURIAL_ACOLYTE,
+      {
+       { SPELL_MALIGN_OFFERING, 16, MON_SPELL_PRIEST },
+       { SPELL_DISPEL_UNDEAD, 12, MON_SPELL_PRIEST },
+       { SPELL_FUNERAL_DIRGE, 22, MON_SPELL_PRIEST },
+      }
+    },
+
     {  MST_NECROMANCER,
       {
        { SPELL_BOLT_OF_DRAINING, 15, MON_SPELL_WIZARD },
-       { SPELL_AGONY_RANGE, 15, MON_SPELL_WIZARD },
+       { SPELL_AGONY, 15, MON_SPELL_WIZARD },
        { SPELL_BIND_SOULS, 30, MON_SPELL_WIZARD },
       }
     },
 
-    // Wizard set is also used by Erolcha.
-    {  MST_WIZARD,
+    {  MST_ARCANIST,
+      {
+       { SPELL_BOLT_OF_COLD, 12, MON_SPELL_WIZARD },
+       { SPELL_FORCE_LANCE, 10, MON_SPELL_WIZARD },
+       { SPELL_VITRIFY, 12, MON_SPELL_WIZARD },
+       { SPELL_HASTE, 14, MON_SPELL_WIZARD },
+      }
+    },
+
+    {  MST_OCCULTIST,
       {
        { SPELL_FIREBALL, 12, MON_SPELL_WIZARD },
-       { SPELL_BANISHMENT, 10, MON_SPELL_WIZARD },
-       { SPELL_BLINK, 12, MON_SPELL_WIZARD },
+       { SPELL_POISON_ARROW, 12, MON_SPELL_WIZARD },
        { SPELL_INVISIBILITY, 14, MON_SPELL_WIZARD },
+       { SPELL_BANISHMENT, 10, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_DEATH_KNIGHT,
       {
-       { SPELL_AGONY_RANGE, 15, MON_SPELL_PRIEST },
+       { SPELL_AGONY, 15, MON_SPELL_PRIEST },
        { SPELL_INJURY_MIRROR, 20, MON_SPELL_PRIEST },
       }
     },
@@ -483,7 +490,7 @@ static const mon_spellbook mspell_list[] =
       {
        { SPELL_SLOW, 13, MON_SPELL_WIZARD },
        { SPELL_CONFUSE, 13, MON_SPELL_WIZARD },
-       { SPELL_AGONY_RANGE, 13, MON_SPELL_WIZARD },
+       { SPELL_AGONY, 13, MON_SPELL_WIZARD },
       }
     },
 
@@ -552,7 +559,7 @@ static const mon_spellbook mspell_list[] =
        { SPELL_BLINK_OTHER, 15, MON_SPELL_WIZARD },
        { SPELL_BLINK_RANGE, 15, MON_SPELL_WIZARD },
        { SPELL_BLINK_ALLIES_ENCIRCLE, 15, MON_SPELL_WIZARD },
-       { SPELL_BLINK_AWAY, 15, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
+       { SPELL_BLINK_RANGE, 15, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
       }
     },
 
@@ -591,12 +598,6 @@ static const mon_spellbook mspell_list[] =
     },
 
     // ('t') Testudines.
-    {  MST_ALLIGATOR,
-      {
-       { SPELL_SPRINT, 31, MON_SPELL_NATURAL },
-      }
-    },
-
     {  MST_FIRE_CRAB,
       {
        { SPELL_FLAMING_CLOUD, 62, MON_SPELL_NATURAL },
@@ -630,6 +631,18 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_RIBBON_WORM,
+      {
+       { SPELL_ENSNARE, 60, MON_SPELL_NATURAL | MON_SPELL_BREATH },
+      }
+    },
+
+    { MST_BRAIN_WORM,
+      {
+        { SPELL_BRAIN_BITE, 32, MON_SPELL_NATURAL },
+      }
+    },
+
     { MST_SWAMP_WORM,
       {
         { SPELL_HARPOON_SHOT, 80, MON_SPELL_NATURAL },
@@ -676,10 +689,15 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_GHOST_MOTH,
+      {
+       { SPELL_DRAINING_GAZE, 100, MON_SPELL_MAGICAL | MON_SPELL_INSTANT },
+      }
+    },
+
     {  MST_SUN_MOTH,
       {
-       { SPELL_STICKY_FLAME_RANGE, 20, MON_SPELL_NATURAL },
-       { SPELL_ENERGY_BOLT, 20, MON_SPELL_NATURAL },
+       { SPELL_PYRE_ARROW, 35, MON_SPELL_NATURAL },
       }
     },
 
@@ -691,6 +709,18 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_WEEPING_SKULL,
+      {
+       { SPELL_MOURNING_WAIL, 48, MON_SPELL_MAGICAL},
+      }
+    },
+
+    {  MST_LAUGHING_SKULL,
+      {
+       { SPELL_BOLT_OF_DRAINING, 30, MON_SPELL_MAGICAL | MON_SPELL_NOISY },
+      }
+    },
+
     {  MST_CURSE_SKULL,
       {
        { SPELL_SUMMON_UNDEAD, 48, MON_SPELL_MAGICAL | MON_SPELL_NOISY },
@@ -735,6 +765,12 @@ static const mon_spellbook mspell_list[] =
     },
 
     // ('B') Beetles and other insects
+    {  MST_BOMBARDIER_BEETLE,
+      {
+       { SPELL_PYRE_ARROW, 40, MON_SPELL_NATURAL},
+      }
+    },
+
     {  MST_BOULDER_BEETLE,
       {
        { SPELL_ROLL, 50, MON_SPELL_NATURAL},
@@ -784,6 +820,12 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_PROTEAN_PROGENITOR,
+      {
+       { SPELL_IRRADIATE, 22, MON_SPELL_WIZARD },
+      }
+    },
+
     // ('D') Dragons.
     {  MST_STEAM_DRAGON,
       {
@@ -833,6 +875,13 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_IRON_DRAGON,
+      {
+       { SPELL_METAL_SPLINTERS, 68, MON_SPELL_NATURAL | MON_SPELL_BREATH
+                                     | MON_SPELL_NOISY },
+      }
+    },
+
     {  MST_QUICKSILVER_DRAGON,
       {
        { SPELL_QUICKSILVER_BOLT, 66, MON_SPELL_NATURAL | MON_SPELL_BREATH
@@ -881,9 +930,9 @@ static const mon_spellbook mspell_list[] =
     },
 
     // ('G') Organs.
-    {  MST_FLOATING_EYE,
+    {  MST_GLASS_EYE,
       {
-       { SPELL_PARALYSIS_GAZE, 80, MON_SPELL_MAGICAL | MON_SPELL_INSTANT },
+       { SPELL_VITRIFYING_GAZE, 75, MON_SPELL_MAGICAL | MON_SPELL_INSTANT },
       }
     },
 
@@ -896,7 +945,7 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_EYE_OF_DEVASTATION,
       {
-       { SPELL_ENERGY_BOLT, 60, MON_SPELL_MAGICAL },
+       { SPELL_BOLT_OF_DEVASTATION, 60, MON_SPELL_MAGICAL },
       }
     },
 
@@ -908,20 +957,19 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_GREAT_ORB_OF_EYES,
       {
-       { SPELL_PARALYSE, 12, MON_SPELL_MAGICAL },
+       { SPELL_VITRIFY, 12, MON_SPELL_MAGICAL },
        { SPELL_MINDBURST, 12, MON_SPELL_MAGICAL },
-       { SPELL_DRAIN_MAGIC, 12, MON_SPELL_MAGICAL },
+       { SPELL_POLYMORPH, 12, MON_SPELL_MAGICAL },
        { SPELL_CONFUSE, 12, MON_SPELL_MAGICAL },
       }
     },
 
     {  MST_GLOWING_ORANGE_BRAIN,
       {
-       { SPELL_BRAIN_FEED, 10, MON_SPELL_MAGICAL },
-       { SPELL_CAUSE_FEAR, 10, MON_SPELL_MAGICAL },
-       { SPELL_SHADOW_CREATURES, 10, MON_SPELL_MAGICAL },
-       { SPELL_MASS_CONFUSION, 10, MON_SPELL_MAGICAL },
-       { SPELL_BLINK, 10, MON_SPELL_MAGICAL },
+       { SPELL_BRAIN_BITE, 14, MON_SPELL_MAGICAL },
+       { SPELL_CAUSE_FEAR, 14, MON_SPELL_MAGICAL },
+       { SPELL_SHADOW_CREATURES, 14, MON_SPELL_MAGICAL },
+       { SPELL_MASS_CONFUSION, 14, MON_SPELL_MAGICAL },
       }
     },
 
@@ -935,17 +983,17 @@ static const mon_spellbook mspell_list[] =
     { MST_FENSTRIDER_WITCH,
       {
        { SPELL_PARALYSE, 15, MON_SPELL_WIZARD },
-       { SPELL_AGONY, 30, MON_SPELL_WIZARD },
+       { SPELL_AGONIZING_TOUCH, 30, MON_SPELL_WIZARD },
        { SPELL_HURL_SLUDGE, 15, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_SPHINX,
       {
-       { SPELL_CONFUSE, 11, MON_SPELL_WIZARD },
-       { SPELL_SLOW, 11, MON_SPELL_WIZARD },
-       { SPELL_PARALYSE, 11, MON_SPELL_WIZARD },
-       { SPELL_SMITING, 11, MON_SPELL_WIZARD },
+       { SPELL_CONFUSE, 10, MON_SPELL_WIZARD },
+       { SPELL_SLOW, 10, MON_SPELL_WIZARD },
+       { SPELL_PARALYSE, 10, MON_SPELL_WIZARD },
+       { SPELL_SMITING, 10, MON_SPELL_WIZARD },
       }
     },
 
@@ -966,6 +1014,12 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_KOBOLD_BLASTMINER,
+      {
+       { SPELL_BOMBARD, 32, MON_SPELL_NATURAL | MON_SPELL_NOISY },
+      }
+    },
+
     // ('L') Liches and the like.
     {  MST_REVENANT,
       {
@@ -1142,9 +1196,9 @@ static const mon_spellbook mspell_list[] =
     // ('Q') Tengu.
     {  MST_TENGU_CONJURER,
       {
-       { SPELL_LIGHTNING_BOLT, 19, MON_SPELL_WIZARD },
-       { SPELL_BATTLESPHERE, 19, MON_SPELL_WIZARD },
-       { SPELL_BLINK, 10, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
+       { SPELL_BATTLESPHERE, 30, MON_SPELL_WIZARD },
+       { SPELL_LIGHTNING_BOLT, 20, MON_SPELL_WIZARD },
+       { SPELL_FORCE_LANCE, 10, MON_SPELL_WIZARD | MON_SPELL_EMERGENCY },
       }
     },
 
@@ -1156,6 +1210,7 @@ static const mon_spellbook mspell_list[] =
         { SPELL_CORROSIVE_BOLT, 11, MON_SPELL_WIZARD },
         { SPELL_LIGHTNING_BOLT, 11, MON_SPELL_WIZARD },
         { SPELL_BOLT_OF_DRAINING, 11, MON_SPELL_WIZARD },
+        { SPELL_REPEL_MISSILES, 11, MON_SPELL_WIZARD },
       }
     },
 
@@ -1268,12 +1323,6 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_PHANTASMAL_WARRIOR,
-      {
-       { SPELL_BLINK_CLOSE, 67, MON_SPELL_MAGICAL },
-      }
-    },
-
     {  MST_EIDOLON,
       {
        { SPELL_BOLT_OF_DRAINING, 21, MON_SPELL_MAGICAL },
@@ -1371,7 +1420,7 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_SMOKE_DEMON,
       {
-       { SPELL_STICKY_FLAME_RANGE, 19, MON_SPELL_MAGICAL },
+       { SPELL_PYRE_ARROW, 19, MON_SPELL_MAGICAL },
        { SPELL_STEAM_BALL, 19, MON_SPELL_MAGICAL },
        { SPELL_SMITING, 19, MON_SPELL_MAGICAL },
       }
@@ -1385,8 +1434,8 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_NEQOXEC,
       {
-       { SPELL_MALMUTATE, 19, MON_SPELL_MAGICAL },
-       { SPELL_BRAIN_FEED, 19, MON_SPELL_MAGICAL },
+       { SPELL_MALMUTATE, 14, MON_SPELL_MAGICAL },
+       { SPELL_BRAIN_BITE, 24, MON_SPELL_MAGICAL },
       }
     },
 
@@ -1407,7 +1456,7 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_BALRUG,
       {
-       { SPELL_STICKY_FLAME_RANGE, 16, MON_SPELL_MAGICAL },
+       { SPELL_PYRE_ARROW, 16, MON_SPELL_MAGICAL },
        { SPELL_BOLT_OF_FIRE, 16, MON_SPELL_MAGICAL },
        { SPELL_FIREBALL, 16, MON_SPELL_MAGICAL },
        { SPELL_SMITING, 16, MON_SPELL_MAGICAL },
@@ -1425,9 +1474,8 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_CACODEMON,
       {
-       { SPELL_ENERGY_BOLT, 13, MON_SPELL_MAGICAL },
-       { SPELL_SLOW, 13, MON_SPELL_MAGICAL },
-       { SPELL_CONFUSE, 13, MON_SPELL_MAGICAL },
+       { SPELL_BOLT_OF_DEVASTATION, 20, MON_SPELL_MAGICAL },
+       { SPELL_VITRIFY, 20, MON_SPELL_MAGICAL },
        { SPELL_MALMUTATE, 13, MON_SPELL_MAGICAL },
        { SPELL_DIG, 13, MON_SPELL_MAGICAL },
       }
@@ -1511,7 +1559,59 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    // ('8') Animate / statues.
+    // ('8') Statues.
+    {  MST_ICE_STATUE,
+      {
+       { SPELL_BOLT_OF_COLD, 20, MON_SPELL_MAGICAL },
+       { SPELL_THROW_ICICLE, 20, MON_SPELL_MAGICAL },
+       { SPELL_FREEZING_CLOUD, 20, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_ICE_BEAST, 40, MON_SPELL_MAGICAL },
+      }
+    },
+
+    {  MST_OBSIDIAN_STATUE,
+      {
+       { SPELL_SUMMON_MINOR_DEMON, 33, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_DEMON, 33, MON_SPELL_MAGICAL },
+       { SPELL_MESMERISE, 33, MON_SPELL_MAGICAL },
+      }
+    },
+
+    {  MST_ORANGE_CRYSTAL_STATUE,
+      {
+       { SPELL_SHADOW_CREATURES, 50, MON_SPELL_MAGICAL },
+       { SPELL_DRAINING_GAZE, 25, MON_SPELL_MAGICAL },
+       { SPELL_MASS_CONFUSION, 25, MON_SPELL_MAGICAL },
+      }
+    },
+
+    {  MST_STRANGE_MACHINE,
+      {
+       { SPELL_SUMMON_ILLUSION, 50, MON_SPELL_MAGICAL },
+       { SPELL_SHADOW_CREATURES, 20, MON_SPELL_MAGICAL },
+      }
+    },
+
+    // ('9') Animate statuary, golems, gargoyles.
+    {  MST_GARGOYLE,
+      {
+       { SPELL_STONE_ARROW, 56, MON_SPELL_NATURAL },
+      }
+    },
+
+    {  MST_MOLTEN_GARGOYLE,
+      {
+       { SPELL_BOLT_OF_MAGMA, 57, MON_SPELL_NATURAL },
+      }
+    },
+
+    {  MST_WAR_GARGOYLE,
+      {
+       { SPELL_METAL_SPLINTERS, 52, MON_SPELL_NATURAL | MON_SPELL_BREATH
+                                     | MON_SPELL_NOISY },
+      }
+    },
+
     {  MST_USHABTI,
       {
        { SPELL_DEATH_RATTLE, 36, MON_SPELL_MAGICAL },
@@ -1540,52 +1640,6 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    {  MST_ICE_STATUE,
-      {
-       { SPELL_BOLT_OF_COLD, 20, MON_SPELL_MAGICAL },
-       { SPELL_THROW_ICICLE, 20, MON_SPELL_MAGICAL },
-       { SPELL_FREEZING_CLOUD, 20, MON_SPELL_MAGICAL },
-       { SPELL_SUMMON_ICE_BEAST, 40, MON_SPELL_MAGICAL },
-      }
-    },
-
-    {  MST_OBSIDIAN_STATUE,
-      {
-       { SPELL_SUMMON_MINOR_DEMON, 33, MON_SPELL_MAGICAL },
-       { SPELL_SUMMON_DEMON, 33, MON_SPELL_MAGICAL },
-       { SPELL_MESMERISE, 33, MON_SPELL_MAGICAL },
-      }
-    },
-
-    {  MST_ORANGE_CRYSTAL_STATUE,
-      {
-       { SPELL_SHADOW_CREATURES, 40, MON_SPELL_MAGICAL },
-       { SPELL_BRAIN_FEED, 20, MON_SPELL_MAGICAL },
-       { SPELL_DRAINING_GAZE, 20, MON_SPELL_MAGICAL },
-       { SPELL_MASS_CONFUSION, 20, MON_SPELL_MAGICAL },
-      }
-    },
-
-    {  MST_STRANGE_MACHINE,
-      {
-       { SPELL_SUMMON_ILLUSION, 50, MON_SPELL_MAGICAL },
-       { SPELL_SHADOW_CREATURES, 20, MON_SPELL_MAGICAL },
-      }
-    },
-
-    // ('9') Gargoyles.
-    {  MST_GARGOYLE,
-      {
-       { SPELL_STONE_ARROW, 56, MON_SPELL_NATURAL },
-      }
-    },
-
-    {  MST_MOLTEN_GARGOYLE,
-      {
-       { SPELL_BOLT_OF_MAGMA, 57, MON_SPELL_NATURAL },
-      }
-    },
-
     {  MST_NARGUN,
       {
        { SPELL_PETRIFY, 66, MON_SPELL_NATURAL },
@@ -1758,6 +1812,15 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_ANTIQUE_CHAMPION,
+      {
+       { SPELL_GHOSTLY_FIREBALL, 12, MON_SPELL_WIZARD },
+       { SPELL_HAUNT, 12, MON_SPELL_WIZARD },
+       { SPELL_MIGHT, 18, MON_SPELL_WIZARD },
+       { SPELL_HASTE, 18, MON_SPELL_WIZARD },
+      }
+    },
+
     // ('A') Angels.
     {  MST_MENNAS,
       {
@@ -1785,7 +1848,7 @@ static const mon_spellbook mspell_list[] =
 
     { MST_BAI_SUZHEN_DRAGON,
       {
-        { SPELL_PRIMAL_WAVE, 60, MON_SPELL_NATURAL | MON_SPELL_BREATH
+        { SPELL_PRIMAL_WAVE, 68, MON_SPELL_NATURAL | MON_SPELL_BREATH
                                   | MON_SPELL_NOISY },
       }
     },
@@ -1822,6 +1885,14 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    // ('F') Froggos.
+    {  MST_JEREMIAH,
+      {
+       { SPELL_BLINK_RANGE, 16, MON_SPELL_NATURAL },
+       { SPELL_SMITING, 16, MON_SPELL_PRIEST },
+      }
+    },
+
     // ('H') Hybrids.
     {  MST_ARACHNE,
       {
@@ -1863,10 +1934,10 @@ static const mon_spellbook mspell_list[] =
     // ('L') Liches.
     {  MST_BORIS,
       {
-       { SPELL_BOLT_OF_COLD, 12, MON_SPELL_WIZARD },
-       { SPELL_IRON_SHOT, 12, MON_SPELL_WIZARD },
-       { SPELL_IOOD, 12, MON_SPELL_WIZARD },
-       { SPELL_INVISIBILITY, 24, MON_SPELL_WIZARD },
+       { SPELL_BOLT_OF_COLD, 16, MON_SPELL_WIZARD },
+       { SPELL_IRON_SHOT, 14, MON_SPELL_WIZARD },
+       { SPELL_IOOD, 14, MON_SPELL_WIZARD },
+       { SPELL_MARCH_OF_SORROWS, 14, MON_SPELL_WIZARD },
       }
     },
 
@@ -1900,7 +1971,16 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
-    // ('O') Lodul.
+    // ('O') Ogres.
+    {  MST_EROLCHA,
+      {
+       { SPELL_FIREBALL, 12, MON_SPELL_WIZARD },
+       { SPELL_INVISIBILITY, 14, MON_SPELL_WIZARD },
+       { SPELL_BANISHMENT, 10, MON_SPELL_WIZARD },
+       { SPELL_BLINK, 12, MON_SPELL_WIZARD },
+      }
+    },
+
     {  MST_LODUL,
       {
        { SPELL_CALL_DOWN_LIGHTNING, 40, MON_SPELL_MAGICAL },
@@ -1922,7 +2002,6 @@ static const mon_spellbook mspell_list[] =
     {  MST_AZRAEL,
       {
        { SPELL_BOLT_OF_FIRE, 13, MON_SPELL_MAGICAL },
-       { SPELL_STICKY_FLAME_RANGE, 13, MON_SPELL_MAGICAL },
        { SPELL_FIREBALL, 13, MON_SPELL_MAGICAL },
        { SPELL_HURL_DAMNATION, 13, MON_SPELL_MAGICAL },
        { SPELL_CALL_DOWN_DAMNATION, 13, MON_SPELL_MAGICAL },
@@ -1982,7 +2061,7 @@ static const mon_spellbook mspell_list[] =
     // ('1') Greater demons.
     {  MST_IGNACIO,
       {
-       { SPELL_AGONY_RANGE, 21, MON_SPELL_MAGICAL },
+       { SPELL_AGONY, 21, MON_SPELL_MAGICAL },
        { SPELL_HASTE, 41, MON_SPELL_MAGICAL },
       }
     },
@@ -2034,17 +2113,14 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_ERICA,
       {
-       { SPELL_VENOM_BOLT, 10, MON_SPELL_WIZARD },
-       { SPELL_FORCE_LANCE, 10, MON_SPELL_WIZARD },
-       { SPELL_CONFUSE, 10, MON_SPELL_WIZARD },
-       { SPELL_SLOW, 10, MON_SPELL_WIZARD },
+       { SPELL_VENOM_BOLT, 20, MON_SPELL_WIZARD },
+       { SPELL_SLOW, 15, MON_SPELL_WIZARD },
        { SPELL_INVISIBILITY, 10, MON_SPELL_WIZARD },
       }
     },
 
     {  MST_MAURICE,
       {
-       { SPELL_SPRINT, 14, MON_SPELL_WIZARD },
        { SPELL_INVISIBILITY, 14, MON_SPELL_WIZARD },
        { SPELL_BLINK, 14, MON_SPELL_WIZARD },
       }
@@ -2138,7 +2214,7 @@ static const mon_spellbook mspell_list[] =
        { SPELL_SUMMON_MANA_VIPER, 15, MON_SPELL_WIZARD },
        { SPELL_DIMENSION_ANCHOR, 15, MON_SPELL_WIZARD },
        { SPELL_BLINK_CLOSE, 15, MON_SPELL_WIZARD },
-       { SPELL_ENERGY_BOLT, 15, MON_SPELL_WIZARD },
+       { SPELL_BOLT_OF_DEVASTATION, 15, MON_SPELL_WIZARD },
       }
     },
 
@@ -2164,12 +2240,18 @@ static const mon_spellbook mspell_list[] =
       }
     },
 
+    {  MST_NORRIS,
+      {
+       { SPELL_BRAIN_BITE, 24, MON_SPELL_PRIEST },
+       { SPELL_PRIMAL_WAVE, 20, MON_SPELL_PRIEST },
+      }
+    },
+
     {  MST_FREDERICK,
       {
-       { SPELL_FORCE_LANCE, 12, MON_SPELL_WIZARD },
-       { SPELL_BOLT_OF_COLD, 12, MON_SPELL_WIZARD },
-       { SPELL_IRON_SHOT, 12, MON_SPELL_WIZARD },
-       { SPELL_SPELLFORGED_SERVITOR, 24, MON_SPELL_WIZARD },
+       { SPELL_PLASMA_BEAM, 24, MON_SPELL_WIZARD },
+       { SPELL_BOMBARD, 24, MON_SPELL_WIZARD },
+       { SPELL_SPELLFORGED_SERVITOR, 32, MON_SPELL_WIZARD },
       }
     },
 
@@ -2225,11 +2307,11 @@ static const mon_spellbook mspell_list[] =
 
     {  MST_MNOLEG,
       {
-       { SPELL_MALIGN_GATEWAY, 27, MON_SPELL_MAGICAL },
-       { SPELL_SUMMON_EYEBALLS, 13, MON_SPELL_MAGICAL },
-       { SPELL_SUMMON_HORRIBLE_THINGS, 27, MON_SPELL_MAGICAL },
-       { SPELL_CALL_OF_CHAOS, 27, MON_SPELL_MAGICAL },
-       { SPELL_DIG, 13, MON_SPELL_MAGICAL },
+       { SPELL_MALIGN_GATEWAY, 40, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_EYEBALLS, 20, MON_SPELL_MAGICAL },
+       { SPELL_SUMMON_HORRIBLE_THINGS, 40, MON_SPELL_MAGICAL },
+       { SPELL_CALL_OF_CHAOS, 30, MON_SPELL_MAGICAL },
+       { SPELL_DIG, 15, MON_SPELL_MAGICAL },
       }
     },
 
