@@ -30,7 +30,7 @@ struct mon_attack_def
 
 // Amount of mons->speed_increment used by different actions; defaults
 // to 10.
-#define DEFAULT_ENERGY {10, 10, 10, 10, 10, 10, 10, 100}
+#define DEFAULT_ENERGY {10, 10, 10, 10, 10}
 struct mon_energy_usage
 {
     uint8_t move;
@@ -38,12 +38,6 @@ struct mon_energy_usage
     uint8_t attack;
     uint8_t missile; // Arrows/crossbows/etc
     uint8_t spell;
-    uint8_t special;
-    uint8_t item;    // Using an item (i.e., drinking a potion)
-
-    // Percent of mons->speed used when picking up an item; defaults
-    // to 100%
-    uint8_t pickup_percent;
 
     static mon_energy_usage attack_cost(int cost, int sw = 10)
     {
@@ -83,9 +77,6 @@ struct mon_energy_usage
         me.attack = combine(attack, o.attack);
         me.missile = combine(missile, o.missile);
         me.spell = combine(spell, o.spell);
-        me.special = combine(special, o.special);
-        me.item = combine(item, o.item);
-        me.pickup_percent = combine(pickup_percent, o.pickup_percent, 100);
         return me;
     }
 
@@ -95,10 +86,7 @@ struct mon_energy_usage
                && swim == rvalue.swim
                && attack == rvalue.attack
                && missile == rvalue.missile
-               && spell == rvalue.spell
-               && special == rvalue.special
-               && item == rvalue.item
-               && pickup_percent == rvalue.pickup_percent;
+               && spell == rvalue.spell;
     }
 private:
     static uint8_t combine(uint8_t a, uint8_t b, uint8_t def = 10)
@@ -251,15 +239,18 @@ bool mons_invuln_will(const monster& mon);
 
 mon_attack_def mons_attack_spec(const monster& mon, int attk_number, bool base_flavour = true);
 string mon_attack_name(attack_type attack, bool with_object = true);
+string mon_attack_name_short(attack_type attack);
 bool is_plain_attack_type(attack_type attack);
 bool flavour_triggers_damageless(attack_flavour flavour);
 int flavour_damage(attack_flavour flavour, int HD, bool random = true);
 bool flavour_has_reach(attack_flavour flavour);
+bool flavour_has_mobility(attack_flavour flavour);
 
 bool mons_class_flag(monster_type mc, monclass_flags_t bits);
 
 mon_holy_type holiness_by_name(string name);
 const char * holiness_name(mon_holy_type_flags which_holiness);
+const char * single_holiness_description(mon_holy_type holiness);
 string holiness_description(mon_holy_type holiness);
 mon_holy_type mons_class_holiness(monster_type mc);
 
@@ -311,11 +302,13 @@ bool monster_inherently_flies(const monster &mons);
 bool mons_class_can_regenerate(monster_type mc);
 bool mons_can_regenerate(const monster& mon);
 bool mons_class_fast_regen(monster_type mc);
+int mons_class_regen_amount(monster_type mc);
 int mons_zombie_size(monster_type mc);
 monster_type mons_zombie_base(const monster& mon);
 bool mons_class_is_zombified(monster_type mc);
 bool mons_class_is_animated_weapon(monster_type type);
 bool mons_class_is_animated_object(monster_type type);
+bool mons_class_is_remnant(monster_type type);
 monster_type mons_base_type(const monster& mon);
 bool mons_class_can_leave_corpse(monster_type mc);
 bool mons_class_leaves_hide(monster_type mc);
@@ -512,7 +505,6 @@ mon_threat_level_type mons_threat_level(const monster &mon,
                                         bool real = false);
 
 bool mons_foe_is_marked(const monster& mons);
-vector<monster* > get_on_level_followers();
 
 bool mons_stores_tracking_data(const monster& mons);
 
