@@ -61,6 +61,7 @@ enum monster_type                      // env.mons[].type
     MONS_WARG,
     MONS_HELL_HOUND,
 #if TAG_MAJOR_VERSION > 34
+    MONS_INUGAMI,
     MONS_RAIJU,
     MONS_DOOM_HOUND,
 #endif
@@ -80,9 +81,7 @@ enum monster_type                      // env.mons[].type
     MONS_BABY_ALLIGATOR,
 #endif
     MONS_ALLIGATOR,
-#if TAG_MAJOR_VERSION == 34
     MONS_CROCODILE,
-#endif
     MONS_HYDRA,
 #if TAG_MAJOR_VERSION == 34
     MONS_SHEEP,
@@ -118,9 +117,9 @@ enum monster_type                      // env.mons[].type
 #endif
     MONS_POLAR_BEAR,
     MONS_BLACK_BEAR,
-    MONS_WORM,
-#if TAG_MAJOR_VERSION == 34
+    MONS_RIBBON_WORM,
     MONS_BRAIN_WORM,
+#if TAG_MAJOR_VERSION == 34
     MONS_ROCK_WORM,
     MONS_SPINY_WORM,
 #endif
@@ -167,7 +166,10 @@ enum monster_type                      // env.mons[].type
 #if TAG_MAJOR_VERSION == 34
     MONS_PULSATING_LUMP,
 #endif
-    MONS_FLOATING_EYE,
+#if TAG_MAJOR_VERSION > 34
+    MONS_FLOATING_EYE,               // genus
+#endif
+    MONS_GLASS_EYE,
 #if TAG_MAJOR_VERSION == 34
     MONS_EYE_OF_DRAINING,
 #endif
@@ -237,6 +239,7 @@ enum monster_type                      // env.mons[].type
     MONS_HORNET,
 #if TAG_MAJOR_VERSION > 34
     MONS_SPARK_WASP,
+    MONS_BOMBARDIER_BEETLE,
 #endif
 #if TAG_MAJOR_VERSION == 34
     MONS_BEETLE,
@@ -309,7 +312,7 @@ enum monster_type                      // env.mons[].type
     MONS_TOENAIL_GOLEM,
     MONS_ELECTRIC_GOLEM, // replacing the guardian robot -- bwr
 #if TAG_MAJOR_VERSION > 34
-    MONS_GUARDIAN_GOLEM,
+    MONS_BLAZEHEART_GOLEM,
     MONS_SPELLFORGED_SERVITOR,
     MONS_USHABTI,
     MONS_NARGUN,
@@ -385,6 +388,9 @@ enum monster_type                      // env.mons[].type
     MONS_KOBOLD,
     MONS_KOBOLD_BRIGAND,
     MONS_KOBOLD_DEMONOLOGIST,
+#if TAG_MAJOR_VERSION > 34
+    MONS_KOBOLD_BLASTMINER,
+#endif
     MONS_ORC,
     MONS_ORC_WARRIOR,
     MONS_ORC_PRIEST,
@@ -484,6 +490,9 @@ enum monster_type                      // env.mons[].type
     MONS_OGRE,
     MONS_TWO_HEADED_OGRE,
     MONS_OGRE_MAGE,
+#if TAG_MAJOR_VERSION > 34
+    MONS_ONI,
+#endif
     MONS_TROLL,
 #if TAG_MAJOR_VERSION == 34
     MONS_ROCK_TROLL,
@@ -509,17 +518,25 @@ enum monster_type                      // env.mons[].type
     MONS_IRON_GIANT,
     MONS_CACTUS_GIANT,
     MONS_TAINTED_LEVIATHAN,
+    MONS_PROTEAN_PROGENITOR,
+    MONS_ASPIRING_FLESH,
 #endif
     MONS_HUMAN,
 #if TAG_MAJOR_VERSION == 34
     MONS_SLAVE,
+#endif
+#if TAG_MAJOR_VERSION > 34
+    MONS_BURIAL_ACOLYTE,
 #endif
     MONS_HELL_KNIGHT,
 #if TAG_MAJOR_VERSION > 34
     MONS_DEATH_KNIGHT,
 #endif
     MONS_NECROMANCER,
-    MONS_WIZARD,
+    MONS_OCCULTIST,
+#if TAG_MAJOR_VERSION > 34
+    MONS_ARCANIST,
+#endif
     MONS_VAULT_GUARD,
 #if TAG_MAJOR_VERSION > 34
     MONS_VAULT_SENTINEL,
@@ -595,6 +612,8 @@ enum monster_type                      // env.mons[].type
     MONS_ELECTRIC_EEL,
 #if TAG_MAJOR_VERSION == 34
     MONS_JELLYFISH,
+#else
+    MONS_FORMLESS_JELLYFISH,
 #endif
     MONS_WATER_ELEMENTAL,
     MONS_SWAMP_WORM,
@@ -745,7 +764,10 @@ enum monster_type                      // env.mons[].type
     MONS_SHADOW_WRAITH,
     MONS_SILENT_SPECTRE,
     MONS_EIDOLON,
-    MONS_FLYING_SKULL,
+#if TAG_MAJOR_VERSION > 34
+    MONS_WEEPING_SKULL,
+#endif
+    MONS_LAUGHING_SKULL,
     MONS_SKELETAL_WARRIOR,
     MONS_PHANTASMAL_WARRIOR,
     MONS_LICH,
@@ -759,8 +781,10 @@ enum monster_type                      // env.mons[].type
     MONS_PROFANE_SERVITOR,
 #if TAG_MAJOR_VERSION > 34
     MONS_ANCIENT_CHAMPION,
+    MONS_ANTIQUE_CHAMPION,
     MONS_REVENANT,
     MONS_LOST_SOUL,
+    MONS_MARTYRED_SHADE,
     MONS_JIANGSHI,
     MONS_SEARING_WRETCH,
     MONS_STOKER,
@@ -842,9 +866,7 @@ enum monster_type                      // env.mons[].type
     MONS_WIGLAF,
 #endif
     MONS_XTAHUA,
-#if TAG_MAJOR_VERSION == 34
     MONS_NORRIS,
-#endif
     MONS_FREDERICK,
     MONS_MARGERY,
     MONS_BORIS,
@@ -907,6 +929,7 @@ enum monster_type                      // env.mons[].type
     MONS_VV,
     MONS_ZENATA,
     MONS_GRUNN,
+    MONS_JEREMIAH,
 #endif
     // Sprint uniques:
     MONS_CHUCK,
@@ -927,6 +950,8 @@ enum monster_type                      // env.mons[].type
     MONS_FULMINANT_PRISM,
     MONS_BATTLESPHERE,
     MONS_FOXFIRE,
+    MONS_BOULDER,
+    MONS_BLAZEHEART_CORE,
 #endif
     MONS_PILLAR_OF_SALT,
 #if TAG_MAJOR_VERSION > 34
@@ -1079,7 +1104,7 @@ enum monster_type                      // env.mons[].type
     MONS_VASHNIA,
 
     MONS_BLOCK_OF_ICE,
-    MONS_GUARDIAN_GOLEM,
+    MONS_BLAZEHEART_GOLEM,
     MONS_SPELLFORGED_SERVITOR,
     MONS_OCTOPODE_CRUSHER,
     MONS_CRAB,
@@ -1190,6 +1215,22 @@ enum monster_type                      // env.mons[].type
     MONS_SKYSHARK,
     MONS_SLEEPCAP,
     MONS_CERULEAN_IMP,
+    MONS_FORMLESS_JELLYFISH,
+    MONS_JEREMIAH,
+    MONS_BOULDER,
+    MONS_ARCANIST,
+    MONS_FLOATING_EYE,                 // genus
+    MONS_ANTIQUE_CHAMPION,
+    MONS_KOBOLD_BLASTMINER,
+    MONS_INUGAMI,
+    MONS_PROTEAN_PROGENITOR,
+    MONS_ASPIRING_FLESH,
+    MONS_ONI,                          // player species only
+    MONS_BOMBARDIER_BEETLE,
+    MONS_WEEPING_SKULL,
+    MONS_BURIAL_ACOLYTE,
+    MONS_BLAZEHEART_CORE,
+    MONS_MARTYRED_SHADE,
 #endif
 
     NUM_MONSTERS,               // used for polymorph
@@ -1199,7 +1240,6 @@ enum monster_type                      // env.mons[].type
     MONS_NO_MONSTER = 1000,
 
     RANDOM_MONSTER = 2000, // used to distinguish between a random monster and using program bugs for error trapping {dlb}
-    RANDOM_TOUGHER_MONSTER, // used for poly upgrading monsters.
     RANDOM_MOBILE_MONSTER, // used for monster generation (shadow creatures)
     RANDOM_COMPATIBLE_MONSTER, // used for player shadow creatures (prevents repulsing summons)
     RANDOM_BANDLESS_MONSTER,
