@@ -138,7 +138,7 @@ static bool _cancel_barbed_move(bool rampaging)
     return false;
 }
 
-void apply_barbs_damage(bool rampaging)
+static void _apply_barbs_damage(bool rampaging)
 {
     if (you.duration[DUR_BARBS])
     {
@@ -156,6 +156,14 @@ void apply_barbs_damage(bool rampaging)
     }
 }
 
+// For effects that should happen whenever the player actively moves with their
+// limbs, but NOT if the player blinks/teleports or is otherwise displaced.
+void player_did_deliberate_movement(bool rampaging)
+{
+    _apply_barbs_damage(rampaging);
+    shake_off_sticky_flame();
+}
+
 static bool _cancel_ice_move()
 {
     vector<string> effects;
@@ -215,62 +223,30 @@ static void _clear_constriction_data()
         you.stop_being_constricted();
 }
 
-static void _trigger_opportunity_attacks(coord_def new_pos)
+static void _mark_potential_pursuers(coord_def new_pos)
 {
-    if (you.attribute[ATTR_SERPENTS_LASH]          // too fast!
-        || wu_jian_move_triggers_attacks(new_pos)  // too cool!
-        || is_sanctuary(you.pos())                 // Zin protects!
-        || is_sanctuary(new_pos))                  // .. very generously.
+    if (you.attribute[ATTR_SERPENTS_LASH]           // too fast!
+        || wu_jian_move_triggers_attacks(new_pos)   // too cool!
+        || crawl_state.game_is_tutorial())          // too new!
     {
         return;
     }
 
-    unwind_bool moving(crawl_state.player_moving, true);
-
     const coord_def orig_pos = you.pos();
-    for (adjacent_iterator ai(orig_pos); ai; ++ai)
+    for (radius_iterator ri(you.pos(), LOS_NO_TRANS); ri; ++ri)
     {
-        if (adjacent(*ai, new_pos))
+        // Only randomize energy for monsters you're moving away from.
+        if (grid_distance(new_pos, *ri) <= grid_distance(orig_pos, *ri))
             continue;
-        monster* mon = monster_at(*ai);
+        monster* mon = monster_at(*ri);
         // No, there is no logic to this ordering (pf):
-        if (!mon
-            || mon->wont_attack()
-            || !mons_has_attacks(*mon)
-            || mon->confused()
-            || mon->incapacitated()
-            || mons_is_fleeing(*mon)
-            || mon->is_constricted() && (mon->constricted_by != MID_PLAYER
-                                         || mon->get_constrict_type() != CONSTRICT_MELEE)
-            || !mon->can_see(you)
-            // only let monsters attack if they might follow you
-            || !mon->may_have_action_energy() || mon->is_stationary()
-            // if you're swapping with a pal or moving off a fedhas plant,
-            // you can't be followed, so no aoops
-            || monster_at(you.pos())
-            // Zin protects!
-            || is_sanctuary(mon->pos())
-            // creates some weird bugs
-            || mons_self_destructs(*mon)
-            // monsters that are slower than you mayn't attack
-            || mon->outpaced_by_player()
-            || !one_chance_in(3))
-        {
+        if (!mon || !mon->can_see(you))
             continue;
-        }
         actor* foe = mon->get_foe();
         if (!foe || !foe->is_player())
             continue;
 
-        simple_monster_message(*mon, " attacks as you move away!");
-        const int old_energy = mon->speed_increment;
-        launch_opportunity_attack(*mon);
-        // Refund up to 10 energy (1 turn) from the attack.
-        // Thus, only slow attacking monsters use energy for these.
-        mon->speed_increment = min(mon->speed_increment + 10, old_energy);
-
-        if (you.pending_revival || you.pos() != orig_pos)
-            return;
+        crawl_state.potential_pursuers.insert(mon);
     }
 }
 
@@ -564,6 +540,17 @@ bool prompt_dangerous_portal(dungeon_feature_type ftype)
     }
 }
 
+bool prompt_descent_shortcut(dungeon_feature_type ftype)
+{
+    if (ftype == DNGN_ENTER_DEPTHS && !player_in_branch(BRANCH_SLIME)
+        || ftype == DNGN_ENTER_SLIME && !player_in_branch(BRANCH_VAULTS))
+    {
+        return yesno("This entrance appears to skip some branches and may be "
+                     "quite dangerous. Continue anyway?", false, 'n');
+    }
+    return true;
+}
+
 static coord_def _rampage_destination(coord_def move, monster* target)
 {
     if (!player_equip_unrand(UNRAND_SEVEN_LEAGUE_BOOTS))
@@ -575,6 +562,9 @@ static coord_def _rampage_destination(coord_def move, monster* target)
 /// What can the player rampage towards in the given direction, if anything?
 monster* get_rampage_target(coord_def move)
 {
+    if (!you.rampaging())
+        return nullptr;
+
     // Don't rampage if the player has status effects that should prevent it.
     if (you.is_nervous()
         || you.confused()
@@ -697,7 +687,7 @@ static spret _rampage_forward(coord_def move)
         {
             // .. and if a mons was in the way and invisible, notify the player.
             clear_messages();
-            mprf("Something unexpectedly blocked you, preventing you from %s!",
+            mprf("Something unexpectedly blocks you, preventing you from %s!",
                  verb.c_str());
         }
         return spret::fail;
@@ -739,18 +729,23 @@ static spret _rampage_forward(coord_def move)
 
     // First, apply any necessary pre-move effects:
     _clear_constriction_data();
-    // (But not opportunity attacks - messy codewise, and no design benefit.)
+    _mark_potential_pursuers(rampage_destination);
 
     // stepped = true, we're flavouring this as movement, not a blink.
     move_player_to_grid(rampage_destination, true);
 
+    // Verify the new position is valid, in case something unexpected happened.
+    ASSERT(!in_bounds(you.pos()) || !cell_is_solid(you.pos())
+            || you.wizmode_teleported_into_rock);
+
     you.clear_far_engulf(false, true);
     // No full-LOS stabbing.
     if (enhanced)
         behaviour_event(mon_target, ME_ALERT, &you, you.pos());
 
     // Lastly, apply post-move effects unhandled by move_player_to_grid().
-    apply_barbs_damage(true);
+    apply_rampage_heal();
+    player_did_deliberate_movement(true);
     remove_ice_movement();
     you.clear_far_engulf(false, true);
     apply_cloud_trail(old_pos);
@@ -766,13 +761,6 @@ static void _apply_move_time_taken()
 {
     you.time_taken *= player_movement_speed();
     you.time_taken = div_rand_round(you.time_taken, 10);
-
-    if (you.running && you.running.travel_speed)
-    {
-        you.time_taken = max(you.time_taken,
-                             div_round_up(100, you.running.travel_speed));
-    }
-
     if (you.duration[DUR_NO_HOP])
         you.duration[DUR_NO_HOP] += you.time_taken;
 }
@@ -876,31 +864,36 @@ void move_player_action(coord_def move)
     }
 
     bool rampaged = false;
+    bool did_wu_jian_attack = false;
 
-    // Rampaging takes priority over normal Wu Jian movement, but not over
-    // Serpent's Lash.
-    if (you.rampaging() && !you.attribute[ATTR_SERPENTS_LASH])
+    if (you.rampaging())
     {
+        const monster *rampage_targ = get_rampage_target(move);
         switch (_rampage_forward(move))
         {
-            // Check the player's position again; rampage may have moved us.
-
             // Cancel the move entirely if rampage was aborted from a prompt.
             case spret::abort:
-                ASSERT(!in_bounds(you.pos()) || !cell_is_solid(you.pos())
-                       || you.wizmode_teleported_into_rock);
                 return;
 
             case spret::success:
                 rampaged = true;
+                if (you_worship(GOD_WU_JIAN)
+                    && wu_jian_post_move_effects(false, initial_position))
+                {
+                    did_wu_jian_attack = true;
+                    // If you kill something with a lunge, don't continue
+                    // rampaging into its space. That could be a nasty surprise
+                    // for players who land on traps, clouds, exclusions, etc,
+                    // even if we prevented moving into solid terrain or lava.
+                    if (rampage_targ && !rampage_targ->alive())
+                        moving = false;
+                }
                 // If we've rampaged, reset initial_position for the second
                 // move.
                 initial_position = you.pos();
-                // intentional fallthrough
-            default:
+                break;
             case spret::fail:
-                ASSERT(!in_bounds(you.pos()) || !cell_is_solid(you.pos())
-                       || you.wizmode_teleported_into_rock);
+            default:
                 break;
         }
     }
@@ -921,7 +914,7 @@ void move_player_action(coord_def move)
     // XX generalize?
     const string walkverb = you.airborne()                     ? "fly"
                           : you.swimming()                     ? "swim"
-                          : you.form == transformation::spider ? "crawl"
+                          : you.form == transformation::serpent ? "slither"
                           : you.form != transformation::none   ? "walk" // XX
                           : walk_verb_to_present(lowercase_first(species::walking_verb(you.species)));
 
@@ -1003,7 +996,7 @@ void move_player_action(coord_def move)
             }
         }
         else if (targ_monst->temp_attitude() == ATT_NEUTRAL
-                 && !targ_monst->has_ench(ENCH_INSANE)
+                 && !targ_monst->has_ench(ENCH_FRENZIED)
                  && !you.confused()
                  && targ_monst->visible_to(&you))
         {
@@ -1110,9 +1103,6 @@ void move_player_action(coord_def move)
         else if (!running)
             clear_travel_trail();
 
-        // Calculate time_taken before checking opportunity attacks so that
-        // we can guess whether monsters will be able to follow you (& hence
-        // trigger opp attacks).
         _apply_move_time_taken();
 
         coord_def old_pos = you.pos();
@@ -1121,16 +1111,14 @@ void move_player_action(coord_def move)
         if (you.pos() != targ && targ_pass)
         {
             _clear_constriction_data();
-            _trigger_opportunity_attacks(targ);
-            // Check nothing weird happened during opportunity attacks.
-            if (!you.pending_revival)
-            {
-                move_player_to_grid(targ, true);
-                apply_barbs_damage();
-                remove_ice_movement();
-                you.clear_far_engulf(false, true);
-                apply_cloud_trail(old_pos);
-            }
+            _mark_potential_pursuers(targ);
+            move_player_to_grid(targ, true);
+            if (rampaged)
+                apply_rampage_heal();
+            player_did_deliberate_movement();
+            remove_ice_movement();
+            you.clear_far_engulf(false, true);
+            apply_cloud_trail(old_pos);
         }
 
         // Now it is safe to apply the swappee's location effects and add
@@ -1221,11 +1209,12 @@ void move_player_action(coord_def move)
         did_god_conduct(DID_HASTY, 1, true);
     }
 
-    bool did_wu_jian_attack = false;
-    if (you_worship(GOD_WU_JIAN) && !attacking && !dug && !rampaged)
+    if (you_worship(GOD_WU_JIAN) && !attacking && !dug)
         did_wu_jian_attack = wu_jian_post_move_effects(false, initial_position);
+    else if (you_worship(GOD_WU_JIAN) && attacking && rampaged)
+        wu_jian_trigger_serpents_lash(false, initial_position);
 
-    // If you actually moved you are eligible for amulet of the acrobat.
+    // If you actually moved without attacking, acrobatics may kick in.
     if (!attacking && moving && !did_wu_jian_attack)
         update_acrobat_status();
 }
