@@ -205,10 +205,12 @@ enum mutation_type
     MUT_NO_HEXES_MAGIC,
     MUT_NO_ICE_MAGIC,
     MUT_NO_NECROMANCY_MAGIC,
-    MUT_NO_POISON_MAGIC,
+    MUT_NO_ALCHEMY_MAGIC,
     MUT_NO_SUMMONING_MAGIC,
     MUT_NO_TRANSLOCATION_MAGIC,
+#if TAG_MAJOR_VERSION == 34
     MUT_NO_TRANSMUTATION_MAGIC,
+#endif
     MUT_PHYSICAL_VULNERABILITY,
     MUT_SLOW_REFLEXES,
     MUT_WEAK_WILLED,
@@ -234,7 +236,9 @@ enum mutation_type
     MUT_SANGUINE_ARMOUR,
 #endif
     MUT_HOP,
+#if TAG_MAJOR_VERSION == 34
     MUT_NO_REGENERATION,
+#endif
     MUT_STRONG_NOSE,
 #if TAG_MAJOR_VERSION == 34
     MUT_ACID_RESISTANCE,
@@ -284,8 +288,14 @@ enum mutation_type
     MUT_EXPLORE_REGEN,
     MUT_FAITH,
     MUT_ROLLPAGE,
-    MUT_LONG_TONGUE,
+    MUT_DOUBLE_POTION_HEAL,
+#if TAG_MAJOR_VERSION == 34
     MUT_AWKWARD_TONGUE,
+#endif
+    MUT_NO_FORMS,
+    MUT_ACROBATIC,
+    MUT_PERSISTENT_DRAIN,
+    MUT_DRUNKEN_BRAWLING,
     NUM_MUTATIONS,
     CATEGORY_MUTATIONS,
     RANDOM_MUTATION = CATEGORY_MUTATIONS,
