@@ -2,8 +2,6 @@
 
 #include "attack.h"
 
-const int PPROJ_TO_HIT_DIV = 8;
-
 class ranged_attack : public attack
 {
 // Public Properties
@@ -62,5 +60,3 @@ private:
     int orig_to_hit;
     bool mulched;
 };
-
-ranged_attack build_attack_for(actor &act, const item_def *weapon);
