@@ -103,7 +103,6 @@ bool god_hates_eating(god_type god, monster_type mc);
 bool god_likes_spell(spell_type spell, god_type god);
 bool god_hates_spellcasting(god_type god);
 bool god_hates_spell(spell_type spell, god_type god, bool fake_spell = false);
-bool god_loathes_spell(spell_type spell, god_type god);
 string god_spell_warn_string(spell_type spell, god_type god);
 
 void initialize_ashenzari_props();
@@ -128,7 +127,7 @@ void give_yred_bonus_zombies(int stars);
 bool yred_reap_chance();
 bool yred_reclaim_souls(bool all = false);
 bool pay_yred_souls(unsigned int how_many, bool just_check = false);
-bool is_yred_undead_slave(const monster& mon);
+bool is_yred_undead_follower(const monster& mon);
 bool is_orcish_follower(const monster& mon);
 bool is_fellow_slime(const monster& mon);
 bool is_follower(const monster& mon);
