@@ -49,7 +49,8 @@
 #define MAX_COST_LIMIT           265
 #define MAX_SPENDING_LIMIT       265
 
-static int _train(skill_type exsk, int &max_exp, bool simu = false);
+static int _train(skill_type exsk, int &max_exp,
+                  bool simu = false, bool check_targets = true);
 static void _train_skills(int exp, const int cost, const bool simu);
 static int _training_target_skill_point_diff(skill_type exsk, int training_target);
 
@@ -104,19 +105,22 @@ static const char *skill_titles[NUM_SKILLS][7] =
     {"Summonings",     "Caller",        "Summoner",        "Convoker",        "Worldbinder",    "Planerender",  "Summ"},
     {"Necromancy",     "Grave Robber",  "Reanimator",      "Necromancer",     "Thanatomancer",  "@Genus_Short@ of Death", "Necr"},
     {"Translocations", "Grasshopper",   "Placeless @Genus@", "Blinker",       "Portalist",      "Plane @Walker@", "Tloc"},
-    {"Transmutations", "Changer",       "Transmogrifier",  "Alchemist",       "Malleable",      "Shapeless @Genus@", "Tmut"},
+#if TAG_MAJOR_VERSION == 34
+    {"Transmutations", "Destabilizer",  "Alchemist",       "Transmogrifier",  "Entropist",      "Reality Shaper", "Tmut"},
+#endif
 
     {"Fire Magic",     "Firebug",       "Arsonist",        "Scorcher",        "Pyromancer",     "Infernalist",  "Fire"},
     {"Ice Magic",      "Chiller",       "Frost Mage",      "Gelid",           "Cryomancer",     "Englaciator",  "Ice"},
     {"Air Magic",      "Gusty",         "Zephyrmancer",    "Stormcaller",     "Cloud Mage",     "Meteorologist", "Air"},
     {"Earth Magic",    "Digger",        "Geomancer",       "Earth Mage",      "Metallomancer",  "Petrodigitator", "Erth"},
-    {"Poison Magic",   "Stinger",       "Tainter",         "Polluter",        "Contaminator",   "Envenomancer", "Pois"},
+    {"Alchemy",        "Apothecary",    "Toxicologist",    "Hermetic",        "Philosopher",    "Quintessent", "Alch"},
 
     // These titles apply to atheists only, worshippers of the various gods
     // use the god titles instead, depending on piety or, in Gozag's case, gold.
     // or, in U's case, invocations skill.
     {"Invocations",    "Unbeliever",    "Agnostic",        "Dissident",       "Heretic",        "Apostate",     "Invo"},
-    {"Evocations",     "Charlatan",     "Prestidigitator", "Fetichist",       "Evocator",       "Talismancer",  "Evo"},
+    {"Evocations",     "Charlatan",     "Prestidigitator", "Fetichist",       "Evocator",       "Ex Machina",  "Evo"},
+    {"Shapeshifting",  "Changeling",    "Mimic",           "Metamorph",       "Skinwalker",     "Shapeless @Genus@", "Shft"},
 };
 
 static const char *martial_arts_titles[6] =
@@ -218,6 +222,34 @@ float scaled_skill_cost(skill_type sk)
     return (float)next_level / baseline;
 }
 
+/// Ensure that all magic skills are at the same level, e.g. at game start or for save compat.
+void cleanup_innate_magic_skills()
+{
+    unsigned int magic_xp = 0;
+    unsigned int n_skills = 0;
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; sk++)
+    {
+        if (is_useless_skill(sk))
+            continue;
+        magic_xp += you.skill_points[sk];
+        ++n_skills;
+    }
+    // Lossy, sorry.
+    const unsigned int xp_per = magic_xp / n_skills;
+
+    int lvl = 0;
+    while (xp_per > skill_exp_needed(lvl + 1, SK_SPELLCASTING))
+        ++lvl;
+
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; sk++)
+    {
+        if (is_useless_skill(sk))
+            continue;
+        you.skill_points[sk] = xp_per;
+        you.skills[sk] = lvl;
+    }
+}
+
 // Characters are actually granted skill points, not skill levels.
 // Here we take racial aptitudes into account in determining final
 // skill levels.
@@ -273,6 +305,9 @@ void reassess_starting_skills()
             you.skills[sk] = 1;
         }
     }
+
+    if (you.has_mutation(MUT_INNATE_CASTER))
+        cleanup_innate_magic_skills();
 }
 
 static void _change_skill_level(skill_type exsk, int n)
@@ -326,24 +361,25 @@ static void _change_skill_level(skill_type exsk, int n)
 
     // calc_hp() has to be called here because it currently doesn't work
     // right if you.skills[] hasn't been updated yet.
-    if (exsk == SK_FIGHTING)
-        calc_hp(true, false);
+    if (exsk == SK_FIGHTING || exsk == SK_SHAPESHIFTING)
+        calc_hp(true);
 }
 
 // Called whenever a skill is trained.
 void redraw_skill(skill_type exsk, skill_type old_best_skill, bool recalculate_order)
 {
-    if (exsk == SK_FIGHTING)
-        calc_hp(true, false);
+    const bool trained_form = exsk == SK_SHAPESHIFTING && you.form != transformation::none;
+    if (exsk == SK_FIGHTING || trained_form)
+        calc_hp(true);
 
     if (exsk == SK_INVOCATIONS || exsk == SK_SPELLCASTING)
         calc_mp();
 
-    if (exsk == SK_DODGING || exsk == SK_ARMOUR)
+    if (exsk == SK_DODGING || exsk == SK_ARMOUR || trained_form)
         you.redraw_evasion = true;
 
     if (exsk == SK_ARMOUR || exsk == SK_SHIELDS || exsk == SK_ICE_MAGIC
-        || exsk == SK_EARTH_MAGIC || you.duration[DUR_TRANSFORMATION] > 0)
+        || exsk == SK_EARTH_MAGIC || trained_form)
     {
         you.redraw_armour_class = true;
     }
@@ -478,6 +514,24 @@ static void _check_abil_skills()
     }
 }
 
+/// Check to see if the player is a djinn with at least one magic skill
+/// un-hidden. If so, unhide all of them.
+static void _check_innate_magic_skills()
+{
+    if (!you.has_mutation(MUT_INNATE_CASTER))
+        return;
+
+    bool any_magic = false;
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+        if (!is_removed_skill(sk) && !you.skills_to_hide.count(sk))
+            any_magic = true;
+    if (!any_magic)
+        return;
+
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+        you.skills_to_hide.erase(sk);
+}
+
 string skill_names(const skill_set &skills)
 {
     return comma_separated_fn(begin(skills), end(skills), skill_name);
@@ -506,6 +560,7 @@ static void _check_skills_to_hide()
     _check_inventory_skills();
     _check_spell_skills();
     _check_abil_skills();
+    _check_innate_magic_skills();
 
     if (you.skills_to_hide.empty())
         return;
@@ -662,6 +717,21 @@ static void _scale_array(FixedVector<T, SIZE> &array, int scale, bool exact)
     ASSERT(scaled_total == scale);
 }
 
+static int _calc_skill_cost_level(int xp, int start)
+{
+    while (start < MAX_SKILL_COST_LEVEL
+           && xp >= (int) skill_cost_needed(start + 1))
+    {
+        ++start;
+    }
+    while (start > 0
+           && xp < (int) skill_cost_needed(start))
+    {
+        --start;
+    }
+    return start;
+}
+
 /*
  * Init the training array by scaling down the skill_points array to 100.
  * Used at game setup, when upgrading saves and when loading dump files.
@@ -742,6 +812,38 @@ bool check_selected_skills()
     return true;
 }
 
+/// Set all magic skills to the same training value.
+static void _balance_magic_training()
+{
+    // To minimize int rounding issues with manual training,
+    // scale up skill training numbers here. We'll scale em back down later.
+    for (int i = 0; i < NUM_SKILLS; ++i)
+        you.training[i] *= 100;
+
+    int n_skills = 0;
+    int train_total = 0;
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+    {
+        if (is_removed_skill(sk) || you.skills[sk] >= MAX_SKILL_LEVEL)
+        {
+            you.training[sk] = 0;
+            continue;
+        }
+        n_skills++;
+        train_total += you.training[sk];
+    }
+    if (!train_total)
+        return;
+
+    ASSERT(n_skills > 0);
+    // Total training for all magic skills should be the base average,
+    // divided between each skill.
+    const int to_train = max(train_total / (n_skills * n_skills), 1);
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+        if (!is_removed_skill(sk) && you.skills[sk] < MAX_SKILL_LEVEL)
+            you.training[sk] = to_train;
+}
+
 /**
  * Reset the training array. Disabled skills are skipped.
  * In automatic mode, we use values from the exercise queue.
@@ -818,10 +920,14 @@ void reset_training()
             }
     }
 
-    _scale_array(you.training, 100, you.auto_training);
-    if (you.has_mutation(MUT_DISTRIBUTED_TRAINING))
+    if (you.has_mutation(MUT_INNATE_CASTER))
+        _balance_magic_training();
+
+    _scale_array(you.training, 100, !you.has_mutation(MUT_INNATE_CASTER));
+    if (you.has_mutation(MUT_DISTRIBUTED_TRAINING)
+        || you.has_mutation(MUT_INNATE_CASTER))
     {
-        // we use the full set of skills to calculate gnoll percentages,
+        // we use the full set of skills to calculate gnoll/dj percentages,
         // but they don't actually get to train sacrificed skills.
         for (int i = 0; i < NUM_SKILLS; ++i)
             if (is_useless_skill((skill_type) i))
@@ -877,6 +983,124 @@ bool is_magic_skill(skill_type sk)
 
 int _gnoll_total_skill_cost();
 
+static int _magic_training()
+{
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+        if (you.training[sk])
+            return you.training[sk];
+    return 0;
+}
+
+static const int NO_TRAINING = 10000;
+
+/// What is the skill you are currently training at the lowest non-zero percent?
+static unsigned int _min_training_level()
+{
+    unsigned int min = NO_TRAINING;
+    for (skill_type i = SK_FIRST_SKILL; i < NUM_SKILLS; ++i)
+        if (you.training[i] && you.training[i] < min)
+            min = you.training[i];
+    return min;
+}
+
+static bool _is_sacrificed_skill(skill_type skill);
+
+/// If you want to raise each currently-trained skill by an amount
+/// proportionate to their training %s, how many points do you need total?
+static int _min_points_to_raise_all(int min_training)
+{
+    int points = 0;
+    for (skill_type i = SK_FIRST_SKILL; i < NUM_SKILLS; ++i)
+        if (you.training[i])
+            points += you.training[i] / min_training;
+
+    // If the player sacrificed a magic skill, if we're training any magic,
+    // waste skill point(s) on that skill.
+    const int magic_training = _magic_training();
+    if (magic_training)
+        for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+            if (_is_sacrificed_skill(sk))
+                points += magic_training / min_training;
+
+    return points;
+}
+
+/// Is your current `exp_available` enough to raise all of your skills
+/// proportionately to you.training?
+static bool _xp_available_for_skill_points(int points)
+{
+    int cost_level = you.skill_cost_level;
+    int cost = calc_skill_cost(cost_level);
+    int xp_needed = 0;
+    // XXX: could do this more efficiently
+    for (int i = 0; i < points; ++i)
+    {
+        xp_needed += cost;
+        if (xp_needed > you.exp_available)
+            return false;
+
+        const int total_xp = you.total_experience + xp_needed;
+        const int new_level = _calc_skill_cost_level(total_xp, cost_level);
+        if (new_level != cost_level)
+        {
+            cost_level = new_level;
+            cost = calc_skill_cost(cost_level);
+        }
+    }
+    return true;
+}
+
+/**
+ * Train Djinn skills such that the same amount of experience is put into all
+ * spellcasting skills. This means that we need to make sure we have enough
+ * xp to level *all* selected skills proportionate to you.training before we put
+ * xp into *any* skill.
+ */
+static void _train_with_innate_casting(bool simu)
+{
+    while (true) {
+        const int min = _min_training_level();
+        if (min == NO_TRAINING) // no skills set to train
+            return;
+
+        const int points = _min_points_to_raise_all(min);
+        if (!_xp_available_for_skill_points(points))
+            break;
+
+        // OK, we should be able to train everything.
+        for (int i = 0; i < NUM_SKILLS; ++i)
+        {
+            if (!you.training[i])
+                continue;
+            const int p = you.training[i] / min;
+            int xp = calc_skill_cost(you.skill_cost_level) * p;
+            // We don't want to disable training for magic skills midway.
+            // Finish training all skills and check targets afterward.
+            const auto sk = static_cast<skill_type>(i);
+            _train(sk, xp, simu, false);
+            _level_up_check(sk, simu);
+        }
+
+        // If the player sacrificed a magic skill, if we're training any magic,
+        // waste skill point(s) on that skill.
+        const int magic_training = _magic_training();
+        if (magic_training)
+        {
+            for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+            {
+                if (!_is_sacrificed_skill(sk))
+                    continue;
+                const int p = magic_training / min;
+                const int xp = calc_skill_cost(you.skill_cost_level) * p;
+                you.exp_available -= xp;
+                you.total_experience += xp;
+            }
+        }
+
+        check_training_targets();
+    }
+}
+
 void train_skills(bool simu)
 {
     int cost, exp;
@@ -895,6 +1119,8 @@ void train_skills(bool simu)
         }
         while (exp != you.exp_available);
     }
+    else if (you.has_mutation(MUT_INNATE_CASTER))
+        _train_with_innate_casting(simu);
     else
     {
         do
@@ -1112,8 +1338,10 @@ bool check_training_target(skill_type sk)
         bool base = you.skill(sk, 10, false, false) != you.skill(sk, 10);
         auto targ = you.training_targets[sk];
         you.training_targets[sk] = 0;
-        you.train[sk] = TRAINING_DISABLED;
-        you.train_alt[sk] = TRAINING_DISABLED;
+        if (you.has_mutation(MUT_INNATE_CASTER) && is_magic_skill(sk))
+            set_magic_training(TRAINING_DISABLED);
+        else
+            you.train_alt[sk] = you.train[sk] = TRAINING_DISABLED;
         mprf("%sraining target %d.%d for %s reached!",
             base ? "Base t" : "T", targ / 10, targ % 10, skill_name(sk));
         return true;
@@ -1139,21 +1367,6 @@ bool check_training_targets()
     return change;
 }
 
-static int _calc_skill_cost_level(int xp, int start)
-{
-    while (start < MAX_SKILL_COST_LEVEL
-           && xp >= (int) skill_cost_needed(start + 1))
-    {
-        ++start;
-    }
-    while (start > 0
-           && xp < (int) skill_cost_needed(start))
-    {
-        --start;
-    }
-    return start;
-}
-
 void check_skill_cost_change()
 {
 #ifdef DEBUG_TRAINING_COST
@@ -1263,7 +1476,7 @@ static int _training_target_skill_point_diff(skill_type exsk, int training_targe
     return target_skill_point_diff;
 }
 
-static int _train(skill_type exsk, int &max_exp, bool simu)
+static int _train(skill_type exsk, int &max_exp, bool simu, bool check_targets)
 {
     // This will be added to you.skill_points[exsk];
     int skill_inc = 1;
@@ -1324,7 +1537,8 @@ static int _train(skill_type exsk, int &max_exp, bool simu)
 
     if (!simu)
     {
-        check_training_targets();
+        if (check_targets)
+            check_training_targets();
         redraw_skill(exsk, old_best_skill, (you.skill(exsk, 10, true) > old_level));
     }
 
@@ -1679,9 +1893,9 @@ string skill_title_by_rank(skill_type best_skill, uint8_t skill_rank,
         switch (best_skill)
         {
         case SK_SUMMONINGS:
-            // retro goody-bag for decidedly non-goodies
             if (is_evil_god(god))
             {
+                // retro goody-bag for decidedly non-goodies
                 if (skill_rank == 4)
                     result = "Demonologist";
                 else if (skill_rank == 5)
@@ -1694,11 +1908,6 @@ string skill_title_by_rank(skill_type best_skill, uint8_t skill_rank,
                 result = "Prickly Pangolin";
             break;
 
-        case SK_MACES_FLAILS:
-            if (species == SP_METEORAN && skill_rank == 5)
-                result = now_is_morning() ? "Morning Star" : "Evening Star";
-            break;
-
         case SK_UNARMED_COMBAT:
             if (species == SP_FELID)
                 result = claw_and_tooth_titles[skill_rank];
@@ -1738,14 +1947,12 @@ string skill_title_by_rank(skill_type best_skill, uint8_t skill_rank,
                 result = "Holy Roller";
             else if (species == SP_MUMMY && skill_rank == 5 && god == GOD_NEMELEX_XOBEH)
                 result = "Forbidden One";
+            else if (species == SP_MUMMY && skill_rank == 5 && god == GOD_USKAYAW)
+                result = "Necrodancer";
             else if (species == SP_VINE_STALKER && skill_rank == 5 && god == GOD_NEMELEX_XOBEH)
                 result = "Black Lotus";
             else if (species == SP_GARGOYLE && skill_rank == 5 && god == GOD_JIYVA)
                 result = "Rockslime";
-            else if (species == SP_METEORAN && skill_rank == 5 && god == GOD_ZIN)
-                result = "Silver Star"; // removed dc6d6fabc (0.15), ha!
-            else if (species == SP_METEORAN && skill_rank == 5 && god == GOD_DITHMENOS)
-                result = "Starry Night"; // what a miserable god choice... challenge!
             else if (god != GOD_NO_GOD)
                 result = god_title(god, species, piety);
             else if (species == SP_BARACHI)
@@ -1758,13 +1965,11 @@ string skill_title_by_rank(skill_type best_skill, uint8_t skill_rank,
         case SK_RANGED_WEAPONS:
             if (species::is_elven(species) && skill_rank == 5)
                 result = "Master Archer";
-            else if (species == SP_METEORAN && skill_rank == 5)
-                result = "Shooting Star";
             break;
 
         case SK_SPELLCASTING:
-            if (species == SP_OGRE)
-                result = "Ogre Mage";
+            if (species == SP_DJINNI && skill_rank == 5)
+                result = "Wishgranter";
             break;
 
         case SK_CONJURATIONS:
@@ -1776,32 +1981,32 @@ string skill_title_by_rank(skill_type best_skill, uint8_t skill_rank,
         // For the below draconian titles, intentionally don't restrict
         // by drac colour to avoid frustrating players trying for these
         case SK_FIRE_MAGIC:
-            if (species::is_draconian(species) && skill_rank == 5)
+            if (species == SP_DJINNI && skill_rank == 5)
+                result = "Smokeless Flame";
+            else if (species::is_draconian(species) && skill_rank == 5)
                 result = "Fire Dragon";
             else if (species == SP_MUMMY && skill_rank == 5)
                 result = "Highly Combustible";
             break;
 
         case SK_ICE_MAGIC:
-            if (species::is_draconian(species) && skill_rank == 5)
+            if (species == SP_DJINNI && skill_rank == 5)
+                result = "Marid";
+            else if (species::is_draconian(species) && skill_rank == 5)
                 result = "Ice Dragon";
             break;
 
         case SK_EARTH_MAGIC:
             if (species::is_draconian(species) && skill_rank == 5)
                 result = "Iron Dragon";
-            else if (species == SP_METEORAN && skill_rank == 5)
-                result = "Rock Star";
             break;
 
         case SK_AIR_MAGIC:
             if (species::is_draconian(species) && skill_rank == 5)
                 result = "Storm Dragon";
-            else if (species == SP_METEORAN && skill_rank == 5)
-                result = "Meteorite"; // meteorologist / star, ha
             break;
 
-        case SK_POISON_MAGIC:
+        case SK_ALCHEMY:
             if (species::is_draconian(species) && skill_rank == 5)
                 result = "Swamp Dragon";
             break;
@@ -1814,8 +2019,6 @@ string skill_title_by_rank(skill_type best_skill, uint8_t skill_rank,
         case SK_TRANSLOCATIONS:
             if (species == SP_FORMICID && skill_rank == 5)
                 result = "Teletunneler";
-            else if (species == SP_METEORAN && skill_rank == 5)
-                result = "Black Hole";
             break;
 
         case SK_NECROMANCY:
@@ -1952,6 +2155,7 @@ bool is_removed_skill(skill_type skill)
     case SK_CHARMS:
     case SK_SLINGS:
     case SK_CROSSBOWS:
+    case SK_TRANSMUTATIONS:
         return true;
     default:
         break;
@@ -1967,10 +2171,9 @@ static map<skill_type, mutation_type> skill_sac_muts = {
     { SK_FIRE_MAGIC,     MUT_NO_FIRE_MAGIC },
     { SK_EARTH_MAGIC,    MUT_NO_EARTH_MAGIC },
     { SK_ICE_MAGIC,      MUT_NO_ICE_MAGIC },
-    { SK_POISON_MAGIC,   MUT_NO_POISON_MAGIC },
+    { SK_ALCHEMY,        MUT_NO_ALCHEMY_MAGIC },
     { SK_HEXES,          MUT_NO_HEXES_MAGIC },
     { SK_TRANSLOCATIONS, MUT_NO_TRANSLOCATION_MAGIC },
-    { SK_TRANSMUTATIONS, MUT_NO_TRANSMUTATION_MAGIC },
     { SK_CONJURATIONS,   MUT_NO_CONJURATION_MAGIC },
     { SK_NECROMANCY,     MUT_NO_NECROMANCY_MAGIC },
     { SK_SUMMONINGS,     MUT_NO_SUMMONING_MAGIC },
@@ -1979,6 +2182,7 @@ static map<skill_type, mutation_type> skill_sac_muts = {
     { SK_ARMOUR,         MUT_NO_ARMOUR_SKILL },
     { SK_EVOCATIONS,     MUT_NO_ARTIFICE },
     { SK_STEALTH,        MUT_NO_STEALTH },
+    { SK_SHAPESHIFTING,  MUT_NO_FORMS },
 };
 
 bool can_sacrifice_skill(mutation_type mut)
@@ -1989,10 +2193,8 @@ bool can_sacrifice_skill(mutation_type mut)
     return true;
 }
 
-bool is_useless_skill(skill_type skill)
+static bool _is_sacrificed_skill(skill_type skill)
 {
-    if (is_removed_skill(skill))
-        return true;
     auto mut = skill_sac_muts.find(skill);
     if (mut != skill_sac_muts.end() && you.has_mutation(mut->second))
         return true;
@@ -2004,8 +2206,14 @@ bool is_useless_skill(skill_type skill)
     {
         return true;
     }
+    return false;
+}
 
-    return species_apt(skill) == UNUSABLE_SKILL;
+bool is_useless_skill(skill_type skill)
+{
+    return is_removed_skill(skill)
+       || _is_sacrificed_skill(skill)
+       || species_apt(skill) == UNUSABLE_SKILL;
 }
 
 bool is_harmful_skill(skill_type skill)
@@ -2294,7 +2502,8 @@ void fixup_skills()
     reset_training();
 
     if (you.exp_available >= 10 * calc_skill_cost(you.skill_cost_level)
-        && !you.has_mutation(MUT_DISTRIBUTED_TRAINING))
+        && !you.has_mutation(MUT_DISTRIBUTED_TRAINING)
+        && !you.has_mutation(MUT_INNATE_CASTER))
     {
         skill_menu(SKMF_EXPERIENCE);
     }
@@ -2317,3 +2526,17 @@ bool can_enable_skill(skill_type sk, bool override)
        && !is_useless_skill(sk)
        && (override || (you.can_currently_train[sk] && !is_harmful_skill(sk)));
 }
+
+void set_training_status(skill_type sk, training_status st)
+{
+    if (you.has_mutation(MUT_INNATE_CASTER) && is_magic_skill(sk))
+        set_magic_training(st);
+    else
+        you.train[sk] = st;
+}
+
+void set_magic_training(training_status st)
+{
+    for (skill_type sk = SK_SPELLCASTING; sk <= SK_LAST_MAGIC; ++sk)
+        you.train[sk] = you.train_alt[sk] = st;
+}
