@@ -346,6 +346,18 @@ namespace species
         return walking_verb(sp);
     }
 
+    /**
+     * What is an appropriate name for children of this species?
+     *
+     *  @param sp what kind of species to look at
+     *  @returns something like 'kitten' or 'child'.
+     */
+    string child_name(species_type sp)
+    {
+        auto verb = get_species_def(sp).child_name;
+        return verb ? verb : "Child";
+    }
+
     /**
      * What message should be printed when a character of the specified species
      * prays at an altar, if not in some form?
