@@ -130,17 +130,20 @@ enum spell_type : int
 #if TAG_MAJOR_VERSION == 34
     SPELL_RECALL,
 #endif
-    SPELL_AGONY,
+    SPELL_AGONIZING_TOUCH,
+#if TAG_MAJOR_VERSION == 34
     SPELL_SPIDER_FORM,
+#endif
     SPELL_MINDBURST,
+#if TAG_MAJOR_VERSION == 34
     SPELL_BLADE_HANDS,
     SPELL_STATUE_FORM,
     SPELL_ICE_FORM,
     SPELL_DRAGON_FORM,
-#if TAG_MAJOR_VERSION > 34
+    SPELL_NECROMUTATION,
+#else
     SPELL_IRRADIATE,
 #endif
-    SPELL_NECROMUTATION,
     SPELL_DEATH_CHANNEL,
     SPELL_SYMBOL_OF_TORMENT,
 #if TAG_MAJOR_VERSION == 34
@@ -201,14 +204,14 @@ enum spell_type : int
 #if TAG_MAJOR_VERSION == 34
     SPELL_VAMPIRE_SUMMON,
 #endif
-    SPELL_BRAIN_FEED,
+    SPELL_BRAIN_BITE,
 #if TAG_MAJOR_VERSION == 34
     SPELL_FAKE_RAKSHASA_SUMMON,
 #endif
     SPELL_STEAM_BALL,
     SPELL_SUMMON_UFETUBUS,
     SPELL_SUMMON_HELL_BEAST,
-    SPELL_ENERGY_BOLT,
+    SPELL_BOLT_OF_DEVASTATION,
     SPELL_SPIT_POISON,
     SPELL_SUMMON_UNDEAD,
     SPELL_CANTRIP,
@@ -288,7 +291,7 @@ enum spell_type : int
     SPELL_MALIGN_GATEWAY,
     SPELL_NOXIOUS_CLOUD,
     SPELL_POLAR_VORTEX,
-    SPELL_STICKY_FLAME_RANGE,
+    SPELL_PYRE_ARROW,
     SPELL_LEDAS_LIQUEFACTION,
 #if TAG_MAJOR_VERSION == 34
     SPELL_HOMUNCULUS,
@@ -307,9 +310,7 @@ enum spell_type : int
     SPELL_PETRIFYING_CLOUD,
 #if TAG_MAJOR_VERSION == 34
     SPELL_AURA_OF_ABJURATION,
-#endif
     SPELL_BEASTLY_APPENDAGE,
-#if TAG_MAJOR_VERSION == 34
     SPELL_SILVER_BLAST,
 #endif
     SPELL_ENSNARE,
@@ -332,7 +333,7 @@ enum spell_type : int
     SPELL_INJURY_BOND,
     SPELL_SPECTRAL_CLOUD,
     SPELL_GHOSTLY_FIREBALL,
-    SPELL_CALL_LOST_SOUL,
+    SPELL_CALL_LOST_SOULS,
     SPELL_DIMENSION_ANCHOR,
     SPELL_BLINK_ALLIES_ENCIRCLE,
     SPELL_AWAKEN_VINES,
@@ -350,7 +351,7 @@ enum spell_type : int
 #if TAG_MAJOR_VERSION == 34
     SPELL_INFUSION,
 #endif
-    SPELL_WEREBLOOD,
+    SPELL_FUGUE_OF_THE_FALLEN,
 #if TAG_MAJOR_VERSION == 34
     SPELL_SPECTRAL_WEAPON,
     SPELL_SONG_OF_SHIELDING,
@@ -397,7 +398,7 @@ enum spell_type : int
     SPELL_CRYSTAL_BOLT,
     SPELL_SUMMON_FOREST,
     SPELL_SUMMON_LIGHTNING_SPIRE,
-    SPELL_SUMMON_GUARDIAN_GOLEM,
+    SPELL_SUMMON_BLAZEHEART_GOLEM,
 #if TAG_MAJOR_VERSION == 34
     SPELL_RANDOM_BOLT,
     SPELL_CLOUD_CONE,
@@ -462,7 +463,9 @@ enum spell_type : int
     SPELL_SUMMON_EXECUTIONERS,
     SPELL_VIOLENT_UNRAVELLING,
     SPELL_DOOM_HOWL,
+#if TAG_MAJOR_VERSION == 34
     SPELL_AWAKEN_EARTH,
+#endif
     SPELL_AURA_OF_BRILLIANCE,
     SPELL_ICEBLAST,
     SPELL_SLUG_DART,
@@ -481,7 +484,7 @@ enum spell_type : int
     SPELL_BECKONING,
     SPELL_UPHEAVAL,
     SPELL_RANDOM_EFFECTS,
-    SPELL_POISONOUS_VAPOURS,
+    SPELL_MERCURY_VAPOURS,
 #if TAG_MAJOR_VERSION == 34
     SPELL_RING_OF_THUNDER,
 #endif
@@ -499,7 +502,7 @@ enum spell_type : int
     SPELL_FOXFIRE,
     SPELL_HAILSTORM,
     SPELL_NOXIOUS_BOG,
-    SPELL_AGONY_RANGE,
+    SPELL_AGONY,
     SPELL_DISPEL_UNDEAD_RANGE,
     SPELL_FROZEN_RAMPARTS,
     SPELL_MAXWELLS_COUPLING,
@@ -521,7 +524,9 @@ enum spell_type : int
     SPELL_ERUPTION,
     SPELL_PYROCLASTIC_SURGE,
     SPELL_WEAKENING_GAZE,
+#if TAG_MAJOR_VERSION == 34
     SPELL_STORM_FORM,
+#endif
     SPELL_STUNNING_BURST,
     SPELL_CORRUPT_LOCALE,
     SPELL_SUMMON_CACTUS,
@@ -547,5 +552,18 @@ enum spell_type : int
     SPELL_MEPHITIC_BREATH,
     SPELL_PLASMA_BEAM,
     SPELL_MINOR_DESTRUCTION,
+    SPELL_BOMBARD,
+    SPELL_JINXBITE,
+    SPELL_SIGIL_OF_BINDING,
+    SPELL_DIMENSIONAL_BULLSEYE,
+    SPELL_BOULDER,
+    SPELL_VITRIFY,
+    SPELL_VITRIFYING_GAZE,
+    SPELL_TREMORSTONE,
+    SPELL_MOURNING_WAIL,
+    SPELL_FUNERAL_DIRGE,
+    SPELL_MARCH_OF_SORROWS,
+    SPELL_MARTYRS_KNELL,
+    SPELL_CURSE_OF_AGONY,
     NUM_SPELLS
 };
