@@ -40,12 +40,12 @@ spret cast_dreadful_rot(int pow, bool fail)
 
     fail_check();
 
-    const int min_dur = 4;
-    const int max_dur = 7 + div_rand_round(pow, 10);
+    const int min_dur = 6;
+    const int max_dur = 9 + div_rand_round(pow, 10);
     you.props[MIASMA_IMMUNE_KEY] = true;
     place_cloud(CLOUD_MIASMA, you.pos(), random_range(min_dur, max_dur), &you);
     mpr("A part of your flesh rots into a cloud of miasma!");
-    drain_player(65, true, true);
+    drain_player(27, true, true);
 
     return spret::success;
 }
@@ -64,8 +64,9 @@ spret kindle_blastmotes(int pow, bool fail)
     // between successive blastmote casts that often.
     you.props[BLASTMOTE_POWER_KEY] = pow;
     // Longish duration to support setting up silly traps.
+    you.props[BLASTMOTE_IMMUNE_KEY] = true;
     place_cloud(CLOUD_BLASTMOTES, you.pos(), random_range(20, 30), &you);
-    mpr("A cloud of volatile blastmotes flares up around you!");
+    mpr("A cloud of volatile blastmotes flares up around you! Run!");
 
     return spret::success;
 }
@@ -94,8 +95,20 @@ void explode_blastmotes_at(coord_def p)
                                nullptr);
 }
 
+cloud_type spell_to_cloud(spell_type spell)
+{
+    static map<spell_type, cloud_type> cloud_map =
+    {
+        { SPELL_POISONOUS_CLOUD, CLOUD_POISON },
+        { SPELL_FREEZING_CLOUD, CLOUD_COLD },
+        { SPELL_HOLY_BREATH, CLOUD_HOLY },
+    };
+
+    return lookup(cloud_map, spell, CLOUD_NONE);
+}
+
 spret cast_big_c(int pow, spell_type spl, const actor *caster, bolt &beam,
-                      bool fail)
+                 bool fail)
 {
     if (grid_distance(beam.target, you.pos()) > beam.range
         || !in_bounds(beam.target))
@@ -111,28 +124,36 @@ spret cast_big_c(int pow, spell_type spl, const actor *caster, bolt &beam,
         return spret::abort;
     }
 
-    cloud_type cty = CLOUD_NONE;
+    cloud_type cty = spell_to_cloud(spl);
+    if (is_sanctuary(beam.target) && !is_harmless_cloud(cty))
+    {
+        mprf("You can't place harmful clouds in a sanctuary.");
+        return spret::abort;
+    }
+
     //XXX: there should be a better way to specify beam cloud types
     switch (spl)
     {
         case SPELL_POISONOUS_CLOUD:
             beam.flavour = BEAM_POISON;
             beam.name = "blast of poison";
-            cty = CLOUD_POISON;
             break;
         case SPELL_HOLY_BREATH:
             beam.flavour = BEAM_HOLY;
             beam.origin_spell = SPELL_HOLY_BREATH;
-            cty = CLOUD_HOLY;
             break;
         case SPELL_FREEZING_CLOUD:
             beam.flavour = BEAM_COLD;
             beam.name = "freezing blast";
-            cty = CLOUD_COLD;
             break;
         default:
-            mpr("That kind of cloud doesn't exist!");
-            return spret::abort;
+            break;
+    }
+
+    if (cty == CLOUD_NONE)
+    {
+        mpr("That kind of cloud doesn't exist!");
+        return spret::abort;
     }
 
     beam.thrower           = KILL_YOU;
@@ -210,7 +231,6 @@ void holy_flames(monster* caster, actor* defender)
     for (adjacent_iterator ai(pos); ai; ++ai)
     {
         if (!in_bounds(*ai)
-            || cloud_at(*ai)
             || cell_is_solid(*ai)
             || is_sanctuary(*ai)
             || monster_at(*ai))
