@@ -132,7 +132,7 @@ static const struct spell_desc spelldata[] =
     spflag::area,
     5,
     200,
-    1, 1,
+    2, 2,
     10,
     TILEG_ARCJOLT,
 },
@@ -143,7 +143,7 @@ static const struct spell_desc spelldata[] =
     spflag::noisy | spflag::destructive,
     6,
     200,
-    3, 10, // capped at LOS
+    LOS_RADIUS, LOS_RADIUS,
     20,
     TILEG_PLASMA_BEAM,
 },
@@ -165,7 +165,7 @@ static const struct spell_desc spelldata[] =
     spschool::air | spschool::translocation,
     spflag::noisy | spflag::dir_or_target, // hack - should have spflag::needs_tracer
                    // and maybe spflag::hasty?
-    3,
+    4,
     50,
     4, 4,
     0,
@@ -185,7 +185,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_POLYMORPH, "Polymorph",
-    spschool::transmutation | spschool::hexes,
+    spschool::alchemy | spschool::hexes,
     spflag::dir_or_target | spflag::chaotic
         | spflag::needs_tracer | spflag::WL_check,
     4,
@@ -220,11 +220,11 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_PETRIFY, "Petrify",
-    spschool::transmutation | spschool::earth,
+    spschool::alchemy | spschool::earth,
     spflag::dir_or_target | spflag::needs_tracer | spflag::WL_check,
     4,
     200,
-    LOS_RADIUS, LOS_RADIUS,
+    6, 6,
     0,
     TILEG_PETRIFY,
 },
@@ -299,7 +299,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_MEPHITIC_CLOUD, "Mephitic Cloud",
-    spschool::conjuration | spschool::poison | spschool::air,
+    spschool::conjuration | spschool::alchemy | spschool::air,
     spflag::dir_or_target | spflag::area
         | spflag::needs_tracer | spflag::cloud,
     3,
@@ -311,7 +311,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_VENOM_BOLT, "Venom Bolt",
-    spschool::conjuration | spschool::poison,
+    spschool::conjuration | spschool::alchemy,
     spflag::dir_or_target | spflag::needs_tracer | spflag::monster,
     5,
     200,
@@ -322,7 +322,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_OLGREBS_TOXIC_RADIANCE, "Olgreb's Toxic Radiance",
-    spschool::poison,
+    spschool::alchemy,
     spflag::area | spflag::destructive,
     4,
     100,
@@ -435,7 +435,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_POISONOUS_CLOUD, "Poisonous Cloud",
-    spschool::conjuration | spschool::poison | spschool::air,
+    spschool::conjuration | spschool::alchemy | spschool::air,
     spflag::target | spflag::area | spflag::needs_tracer | spflag::cloud
                    | spflag::monster,
     5,
@@ -573,7 +573,8 @@ static const struct spell_desc spelldata[] =
 {
     SPELL_ANIMATE_DEAD, "Animate Dead",
     spschool::necromancy,
-    spflag::helpful | spflag::utility | spflag::selfench,
+    spflag::helpful | spflag::utility | spflag::selfench
+        | spflag::no_ghost,
     4,
     100,
     -1, -1,
@@ -637,6 +638,17 @@ static const struct spell_desc spelldata[] =
     TILEG_HAUNT,
 },
 
+{
+    SPELL_MARTYRS_KNELL, "Martyr's Knell",
+    spschool::summoning | spschool::necromancy,
+    spflag::none,
+    4,
+    100,
+    -1, -1,
+    0,
+    TILEG_MARTYRS_KNELL,
+},
+
 {
     SPELL_BORGNJORS_REVIVIFICATION, "Borgnjor's Revivification",
     spschool::necromancy,
@@ -672,8 +684,8 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_STICKY_FLAME, "Sticky Flame",
-    spschool::conjuration | spschool::fire,
-    spflag::dir_or_target | spflag::needs_tracer,
+    spschool::alchemy | spschool::fire,
+    spflag::dir_or_target | spflag::needs_tracer | spflag::destructive,
     4,
     100,
     1, 1,
@@ -685,7 +697,7 @@ static const struct spell_desc spelldata[] =
     SPELL_SUMMON_ICE_BEAST, "Summon Ice Beast",
     spschool::ice | spschool::summoning,
     spflag::none,
-    4,
+    3,
     100,
     -1, -1,
     0,
@@ -749,7 +761,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_POISON_ARROW, "Poison Arrow",
-    spschool::conjuration | spschool::poison,
+    spschool::conjuration | spschool::alchemy,
     spflag::dir_or_target | spflag::needs_tracer | spflag::monster,
     6,
     200,
@@ -773,11 +785,11 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_STING, "Sting",
-    spschool::transmutation | spschool::poison,
+    spschool::conjuration | spschool::alchemy,
     spflag::dir_or_target | spflag::needs_tracer,
     1,
     25,
-    3, 3,
+    4, 4,
     0,
     TILEG_STING,
 },
@@ -831,7 +843,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_ROT, "Cigotuvi's Dreadful Rot",
-    spschool::necromancy | spschool::air | spschool::poison,
+    spschool::necromancy | spschool::air | spschool::alchemy,
     spflag::unclean,
     2,
     50,
@@ -843,6 +855,17 @@ static const struct spell_desc spelldata[] =
 {
     SPELL_IRON_SHOT, "Iron Shot",
     spschool::conjuration | spschool::earth,
+    spflag::dir_or_target | spflag::needs_tracer | spflag::monster,
+    6,
+    200,
+    4, 4,
+    0,
+    TILEG_IRON_SHOT,
+},
+
+{
+    SPELL_BOMBARD, "Bombard",
+    spschool::conjuration | spschool::earth,
     spflag::dir_or_target | spflag::needs_tracer,
     6,
     200,
@@ -896,10 +919,10 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_AGONY, "Agony",
+    SPELL_AGONIZING_TOUCH, "Agonizing Touch",
     spschool::necromancy,
     spflag::dir_or_target | spflag::not_self | spflag::needs_tracer
-        | spflag::WL_check,
+        | spflag::WL_check | spflag::monster,
     5,
     200,
     1, 1,
@@ -908,14 +931,15 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_SPIDER_FORM, "Spider Form",
-    spschool::transmutation | spschool::poison,
-    spflag::helpful | spflag::chaotic | spflag::utility,
-    3,
+    SPELL_CURSE_OF_AGONY, "Curse of Agony",
+    spschool::necromancy,
+    spflag::dir_or_target | spflag::not_self | spflag::needs_tracer
+        | spflag::WL_check,
+    5,
     100,
-    -1, -1,
+    3, 3,
     0,
-    TILEG_SPIDER_FORM,
+    TILEG_AGONY,
 },
 
 {
@@ -930,72 +954,6 @@ static const struct spell_desc spelldata[] =
     TILEG_GENERIC_MONSTER_SPELL,
 },
 
-{
-    SPELL_BLADE_HANDS, "Blade Hands",
-    spschool::transmutation,
-    spflag::helpful | spflag::chaotic | spflag::utility,
-    5,
-    200,
-    -1, -1,
-    0,
-    TILEG_BLADE_HANDS,
-},
-
-{
-    SPELL_STATUE_FORM, "Statue Form",
-    spschool::transmutation | spschool::earth,
-    spflag::helpful | spflag::chaotic | spflag::utility,
-    6,
-    150,
-    -1, -1,
-    0,
-    TILEG_STATUE_FORM,
-},
-
-{
-    SPELL_ICE_FORM, "Ice Form",
-    spschool::ice | spschool::transmutation,
-    spflag::helpful | spflag::chaotic | spflag::utility,
-    4,
-    100,
-    -1, -1,
-    0,
-    TILEG_ICE_FORM,
-},
-
-{
-    SPELL_STORM_FORM, "Storm Form",
-    spschool::transmutation | spschool::air,
-    spflag::helpful | spflag::chaotic | spflag::utility,
-    7,
-    200,
-    -1, -1,
-    0,
-    TILEG_STORM_FORM,
-},
-
-{
-    SPELL_DRAGON_FORM, "Dragon Form",
-    spschool::transmutation,
-    spflag::helpful | spflag::chaotic | spflag::utility,
-    7,
-    200,
-    -1, -1,
-    0,
-    TILEG_DRAGON_FORM,
-},
-
-{
-    SPELL_NECROMUTATION, "Necromutation",
-    spschool::transmutation | spschool::necromancy,
-    spflag::helpful | spflag::chaotic,
-    8,
-    200,
-    -1, -1,
-    0,
-    TILEG_NECROMUTATION,
-},
-
 {
     SPELL_DEATH_CHANNEL, "Death Channel",
     spschool::necromancy,
@@ -1076,21 +1034,21 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_PASSWALL, "Passwall",
-    spschool::transmutation | spschool::earth,
+    spschool::earth,
     spflag::target | spflag::escape | spflag::not_self | spflag::utility
         | spflag::silent,
-    2,
-    120,
-    1, 7,
+    3,
+    100,
+    3, 3,
     0,
     TILEG_PASSWALL,
 },
 
 {
     SPELL_IGNITE_POISON, "Ignite Poison",
-    spschool::fire | spschool::transmutation | spschool::poison,
+    spschool::fire | spschool::alchemy,
     spflag::area | spflag::destructive,
-    3,
+    4,
     100,
     -1, -1,
     0,
@@ -1200,7 +1158,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_INTOXICATE, "Alistair's Intoxication",
-    spschool::transmutation | spschool::poison,
+    spschool::alchemy,
     spflag::none,
     5,
     150,
@@ -1233,12 +1191,13 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_SIMULACRUM, "Simulacrum",
-    spschool::ice | spschool::necromancy,
-    spflag::dir_or_target | spflag::needs_tracer,
+    SPELL_SIMULACRUM, "Sculpt Simulacrum",
+    spschool::ice | spschool::alchemy,
+    spflag::dir_or_target | spflag::not_self | spflag::needs_tracer
+        | spflag::unholy,
     6,
     200,
-    LOS_RADIUS, LOS_RADIUS,
+    1, 1,
     0,
     TILEG_SIMULACRUM,
 },
@@ -1268,7 +1227,7 @@ static const struct spell_desc spelldata[] =
 {
     SPELL_PORTAL_PROJECTILE, "Portal Projectile",
     spschool::translocation | spschool::hexes,
-    spflag::none,
+    spflag::monster,
     3,
     50,
     -1, -1,
@@ -1300,7 +1259,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_FULMINANT_PRISM, "Fulminant Prism",
-    spschool::conjuration | spschool::hexes,
+    spschool::conjuration | spschool::alchemy,
     spflag::target | spflag::area | spflag::not_self,
     4,
     200,
@@ -1347,7 +1306,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_WOODWEAL, "Woodweal",
-    spschool::necromancy | spschool::transmutation,
+    spschool::necromancy,
     spflag::recovery | spflag::helpful | spflag::monster | spflag::selfench
         | spflag::utility | spflag::not_evil,
     4,
@@ -1371,19 +1330,19 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_BRAIN_FEED, "Brain Feed",
-    spschool::necromancy,
+    SPELL_BRAIN_BITE, "Brain Bite",
+    spschool::necromancy | spschool::hexes,
     spflag::target | spflag::monster,
     3,
     0,
     LOS_RADIUS, LOS_RADIUS,
     0,
-    TILEG_BRAIN_FEED,
+    TILEG_BRAIN_BITE,
 },
 
 {
     SPELL_NOXIOUS_CLOUD, "Noxious Cloud",
-    spschool::conjuration | spschool::poison | spschool::air,
+    spschool::conjuration | spschool::alchemy | spschool::air,
     spflag::target | spflag::area | spflag::monster | spflag::needs_tracer
         | spflag::cloud,
     5,
@@ -1427,10 +1386,10 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_ENERGY_BOLT, "Energy Bolt",
+    SPELL_BOLT_OF_DEVASTATION, "Bolt of Devastation",
     spschool::conjuration,
     spflag::dir_or_target | spflag::monster | spflag::needs_tracer,
-    4,
+    5,
     0,
     LOS_RADIUS, LOS_RADIUS,
     0,
@@ -1439,7 +1398,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_SPIT_POISON, "Spit Poison",
-    spschool::poison,
+    spschool::alchemy,
     spflag::dir_or_target | spflag::monster | spflag::noisy
         | spflag::needs_tracer,
     2,
@@ -1474,7 +1433,7 @@ static const struct spell_desc spelldata[] =
 {
     SPELL_QUICKSILVER_BOLT, "Quicksilver Bolt",
     spschool::conjuration,
-    spflag::dir_or_target | spflag::needs_tracer,
+    spflag::dir_or_target | spflag::needs_tracer | spflag::not_self,
     5,
     200,
     LOS_RADIUS, LOS_RADIUS,
@@ -1563,7 +1522,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_SPIT_ACID, "Spit Acid",
-    spschool::conjuration,
+    spschool::alchemy,
     spflag::dir_or_target | spflag::monster | spflag::noisy
         | spflag::needs_tracer,
     5,
@@ -1575,7 +1534,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_ACID_SPLASH, "Acid Splash",
-    spschool::conjuration,
+    spschool::alchemy,
     spflag::dir_or_target | spflag::monster | spflag::noisy
         | spflag::needs_tracer,
     5,
@@ -1585,14 +1544,13 @@ static const struct spell_desc spelldata[] =
     TILEG_SPIT_ACID,
 },
 
-// Monster version of the spell (with full range)
 {
-    SPELL_STICKY_FLAME_RANGE, "Sticky Flame Range",
+    SPELL_PYRE_ARROW, "Pyre Arrow",
     spschool::conjuration | spschool::fire,
     spflag::dir_or_target | spflag::monster | spflag::needs_tracer,
     4,
     100,
-    4, 4,
+    5, 5,
     0,
     TILEG_STICKY_FLAME_RANGE,
 },
@@ -1670,7 +1628,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_PORKALATOR, "Porkalator",
-    spschool::hexes | spschool::transmutation,
+    spschool::hexes | spschool::alchemy,
     spflag::dir_or_target | spflag::chaotic | spflag::needs_tracer
         | spflag::WL_check | spflag::monster,
     5,
@@ -1979,7 +1937,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_LEDAS_LIQUEFACTION, "Leda's Liquefaction",
-    spschool::earth | spschool::hexes,
+    spschool::earth | spschool::alchemy,
     spflag::area,
     4,
     200,
@@ -2043,17 +2001,6 @@ static const struct spell_desc spelldata[] =
     TILEG_INNER_FLAME,
 },
 
-{
-    SPELL_BEASTLY_APPENDAGE, "Beastly Appendage",
-    spschool::transmutation,
-    spflag::helpful | spflag::chaotic,
-    1,
-    50,
-    -1, -1,
-    0,
-    TILEG_BEASTLY_APPENDAGE,
-},
-
 {
     SPELL_ENSNARE, "Ensnare",
     spschool::conjuration | spschool::hexes,
@@ -2100,7 +2047,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_MALMUTATE, "Malmutate",
-    spschool::transmutation | spschool::hexes,
+    spschool::alchemy | spschool::hexes,
     spflag::dir_or_target | spflag::not_self | spflag::chaotic
         | spflag::needs_tracer | spflag::monster,
     6,
@@ -2191,7 +2138,7 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_CALL_LOST_SOUL, "Call Lost Soul",
+    SPELL_CALL_LOST_SOULS, "Call Lost Souls",
     spschool::summoning | spschool::necromancy,
     spflag::unholy | spflag::monster,
     5,
@@ -2292,14 +2239,14 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_WEREBLOOD, "Wereblood",
-    spschool::transmutation,
-    spflag::utility | spflag::chaotic,
-    2,
+    SPELL_FUGUE_OF_THE_FALLEN, "Fugue of the Fallen",
+    spschool::necromancy,
+    spflag::selfench,
+    3,
     100,
     -1, -1,
     8,
-    TILEG_WEREBLOOD,
+    TILEG_FUGUE_OF_THE_FALLEN,
 },
 
 {
@@ -2361,7 +2308,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_VIRULENCE, "Virulence",
-    spschool::poison | spschool::hexes,
+    spschool::alchemy | spschool::hexes,
     spflag::dir_or_target | spflag::needs_tracer | spflag::WL_check
                           | spflag::monster,
     4,
@@ -2527,14 +2474,14 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_SUMMON_GUARDIAN_GOLEM, "Summon Guardian Golem",
-    spschool::summoning | spschool::hexes,
+    SPELL_SUMMON_BLAZEHEART_GOLEM, "Summon Blazeheart Golem",
+    spschool::summoning | spschool::fire,
     spflag::none,
-    3,
+    4,
     100,
     -1, -1,
     0,
-    TILEG_SUMMON_GUARDIAN_GOLEM,
+    TILEG_SUMMON_BLAZEHEART_GOLEM,
 },
 
 {
@@ -2640,7 +2587,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_CORROSIVE_BOLT, "Corrosive Bolt",
-    spschool::conjuration,
+    spschool::conjuration | spschool::alchemy,
     spflag::dir_or_target | spflag::needs_tracer,
     6,
     200,
@@ -2710,7 +2657,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_SUMMON_EMPEROR_SCORPIONS, "Summon Emperor Scorpions",
-    spschool::summoning | spschool::poison,
+    spschool::summoning | spschool::alchemy,
     spflag::mons_abjure | spflag::monster,
     7,
     100,
@@ -2721,7 +2668,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_IRRADIATE, "Irradiate",
-    spschool::conjuration | spschool::transmutation,
+    spschool::conjuration | spschool::alchemy,
     spflag::area | spflag::chaotic,
     5,
     200,
@@ -2786,7 +2733,7 @@ static const struct spell_desc spelldata[] =
     0,
     -1, -1,
     0,
-    TILEG_GENERIC_MONSTER_SPELL,
+    TILEG_BATTLECRY,
 },
 
 {
@@ -2811,6 +2758,17 @@ static const struct spell_desc spelldata[] =
     TILEG_GENERIC_MONSTER_SPELL,
 },
 
+{
+    SPELL_FUNERAL_DIRGE, "Funeral Dirge",
+    spschool::necromancy,
+    spflag::area | spflag::monster,
+    4,
+    200,
+    -1, -1,
+    0,
+    TILEG_GENERIC_MONSTER_SPELL,
+},
+
 {
     SPELL_SEAL_DOORS, "Seal Doors",
     spschool::hexes,
@@ -2846,7 +2804,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_CORRUPTING_PULSE, "Corrupting Pulse",
-    spschool::hexes | spschool::transmutation,
+    spschool::hexes | spschool::alchemy,
     spflag::area | spflag::monster,
     6,
     200,
@@ -2921,6 +2879,17 @@ static const struct spell_desc spelldata[] =
     TILEG_GENERIC_MONSTER_SPELL,
 },
 
+{
+    SPELL_MOURNING_WAIL, "Mourning Wail",
+    spschool::necromancy,
+    spflag::dir_or_target | spflag::monster,
+    3,
+    0,
+    LOS_RADIUS, LOS_RADIUS,
+    0,
+    TILEG_GENERIC_MONSTER_SPELL,
+},
+
 {
     SPELL_DEATH_RATTLE, "Death Rattle",
     spschool::conjuration | spschool::necromancy | spschool::air,
@@ -2932,6 +2901,17 @@ static const struct spell_desc spelldata[] =
     TILEG_GENERIC_MONSTER_SPELL,
 },
 
+{
+    SPELL_MARCH_OF_SORROWS, "March of Sorrows",
+    spschool::conjuration | spschool::necromancy | spschool::air,
+    spflag::dir_or_target | spflag::monster,
+    7,
+    0,
+    LOS_RADIUS, LOS_RADIUS,
+    0,
+    TILEG_GENERIC_MONSTER_SPELL,
+},
+
 {
     SPELL_SUMMON_SCARABS, "Summon Scarabs",
     spschool::summoning | spschool::necromancy,
@@ -2978,7 +2958,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_VIOLENT_UNRAVELLING, "Yara's Violent Unravelling",
-    spschool::hexes | spschool::transmutation,
+    spschool::hexes | spschool::alchemy,
     spflag::target | spflag::no_ghost | spflag::chaotic | spflag::destructive,
     5,
     200,
@@ -3020,17 +3000,6 @@ static const struct spell_desc spelldata[] =
     TILEG_GENERIC_MONSTER_SPELL,
 },
 
-{
-    SPELL_AWAKEN_EARTH, "Awaken Earth",
-    spschool::summoning | spschool::earth,
-    spflag::monster | spflag::target,
-    7,
-    0,
-    LOS_RADIUS, LOS_RADIUS,
-    0,
-    TILEG_GENERIC_MONSTER_SPELL,
-},
-
 {
     SPELL_AURA_OF_BRILLIANCE, "Aura of Brilliance",
     spschool::conjuration,
@@ -3176,12 +3145,12 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_POISONOUS_VAPOURS, "Poisonous Vapours",
-    spschool::poison | spschool::air,
-    spflag::target | spflag::not_self | spflag::destructive,
+    SPELL_MERCURY_VAPOURS, "Mercury Vapours",
+    spschool::alchemy | spschool::air,
+    spflag::target | spflag::destructive,
     2,
     50,
-    LOS_RADIUS, LOS_RADIUS,
+    3, 3,
     0,
     TILEG_POISONOUS_VAPOURS,
 },
@@ -3309,7 +3278,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_NOXIOUS_BOG, "Eringya's Noxious Bog",
-    spschool::poison | spschool::transmutation,
+    spschool::alchemy,
     spflag::area | spflag::no_ghost | spflag::destructive,
     6,
     200,
@@ -3319,7 +3288,7 @@ static const struct spell_desc spelldata[] =
 },
 
 {
-    SPELL_AGONY_RANGE, "Agony Range",
+    SPELL_AGONY, "Agony",
     spschool::necromancy,
     spflag::dir_or_target | spflag::not_self | spflag::needs_tracer
         | spflag::monster | spflag::WL_check,
@@ -3387,7 +3356,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_HURL_SLUDGE, "Hurl Sludge",
-    spschool::poison | spschool::conjuration | spschool::transmutation,
+    spschool::alchemy | spschool::conjuration,
     spflag::dir_or_target | spflag::needs_tracer | spflag::monster,
     6,
     200,
@@ -3442,7 +3411,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_CONCENTRATE_VENOM, "Concentrate Venom",
-    spschool::poison,
+    spschool::alchemy,
     spflag::dir_or_target | spflag::not_self | spflag::helpful
         | spflag::needs_tracer | spflag::utility | spflag::monster,
     5,
@@ -3575,7 +3544,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_SUMMON_SPIDERS, "Summon Spiders",
-    spschool::summoning | spschool::poison,
+    spschool::summoning | spschool::alchemy,
     spflag::mons_abjure | spflag::monster,
     6,
     200,
@@ -3597,7 +3566,7 @@ static const struct spell_desc spelldata[] =
 
 {
     SPELL_SUMMON_SCORPIONS, "Summon Scorpions",
-    spschool::summoning | spschool::poison,
+    spschool::summoning | spschool::alchemy,
     spflag::mons_abjure | spflag::monster,
     4,
     200,
@@ -3628,10 +3597,88 @@ static const struct spell_desc spelldata[] =
     TILEG_KISS_OF_DEATH,
 },
 
+{
+    SPELL_JINXBITE, "Jinxbite",
+    spschool::hexes,
+    spflag::neutral | spflag::selfench,
+    2,
+    50,
+    -1, -1,
+    0,
+    TILEG_JINXBITE,
+},
+
+{
+    SPELL_SIGIL_OF_BINDING, "Sigil of Binding",
+    spschool::hexes,
+    spflag::none,
+    3,
+    100,
+    -1, -1,
+    0,
+    TILEG_SIGIL_OF_BINDING,
+},
+
+{
+    SPELL_DIMENSIONAL_BULLSEYE, "Dimensional Bullseye",
+    spschool::translocation | spschool::hexes,
+    spflag::target | spflag::not_self,
+    4,
+    200,
+    LOS_RADIUS, LOS_RADIUS,
+    0,
+    TILEG_PORTAL_PROJECTILE,
+},
+
+{
+    SPELL_BOULDER, "Brom's Barrelling Boulder",
+    spschool::earth | spschool::conjuration,
+    spflag::target | spflag::not_self,
+    4,
+    100,
+    1, 1,
+    0,
+    TILEG_BOULDER,
+},
+
+{
+    SPELL_VITRIFY, "Vitrify",
+    spschool::hexes,
+    spflag::dir_or_target | spflag::needs_tracer | spflag::WL_check
+                          | spflag::monster,
+    5,
+    200,
+    LOS_RADIUS, LOS_RADIUS,
+    0,
+    TILEG_GENERIC_MONSTER_SPELL,
+},
+
+{
+    SPELL_VITRIFYING_GAZE, "Vitrifying Gaze",
+    spschool::hexes,
+    spflag::target | spflag::not_self | spflag::monster,
+    6,
+    200,
+    LOS_RADIUS, LOS_RADIUS,
+    0,
+    TILEG_GENERIC_MONSTER_SPELL,
+},
+
+{
+    SPELL_TREMORSTONE, "Tremorstone",
+    spschool::earth,
+    spflag::area,
+    2,
+    200,
+    -1, -1,
+    15,
+    TILEG_LEES_RAPID_DECONSTRUCTION, // close enough
+},
+
 // Not an actual spell - dummy entry for (player) Green Draconian breath.
 {
     SPELL_MEPHITIC_BREATH, "Mephitic Breath",
-    spschool::conjuration | spschool::air | spschool:: poison,
+    spschool::conjuration | spschool::air | spschool:: alchemy,
     spflag::dir_or_target | spflag::noisy | spflag::needs_tracer,
     5,
     0,
@@ -3756,6 +3803,15 @@ AXED_SPELL(SPELL_EXCRUCIATING_WOUNDS, "Excruciating Wounds")
 AXED_SPELL(SPELL_CONJURE_FLAME, "Conjure Flame")
 AXED_SPELL(SPELL_CORPSE_ROT, "Corpse Rot")
 AXED_SPELL(SPELL_FLAME_TONGUE, "Flame Tongue")
+AXED_SPELL(SPELL_BEASTLY_APPENDAGE, "Beastly Appendage")
+AXED_SPELL(SPELL_SPIDER_FORM, "Spider Form")
+AXED_SPELL(SPELL_ICE_FORM, "Ice Form")
+AXED_SPELL(SPELL_BLADE_HANDS, "Blade Hands")
+AXED_SPELL(SPELL_STATUE_FORM, "Statue Form")
+AXED_SPELL(SPELL_STORM_FORM, "Storm Form")
+AXED_SPELL(SPELL_DRAGON_FORM, "Dragon Form")
+AXED_SPELL(SPELL_NECROMUTATION, "Necromutation")
+AXED_SPELL(SPELL_AWAKEN_EARTH, "Awaken Earth")
 #endif
 
 };
