@@ -352,7 +352,8 @@ static const map<spschool, miscast_datum> miscast_effects = {
                 {
                     // number arbitrarily chosen & needs more playtesting
                     const int dur = div_rand_round(dam, 2);
-                    you.set_duration(DUR_LOCKED_DOWN, dur, dur,
+                    you.set_duration(DUR_DIMENSION_ANCHOR, dur, dur);
+                    you.set_duration(DUR_NO_MOMENTUM, dur, dur,
                                      "You are magically locked in place.");
                 }
                 else
@@ -366,51 +367,6 @@ static const map<spschool, miscast_datum> miscast_effects = {
 
         },
     },
-    {
-        spschool::transmutation,
-        {
-            BEAM_NONE,
-            {
-                "Multicoloured lights dance before your eyes",
-                "You feel a strange surge of energy",
-                "Strange energies run through your body",
-                "Your body is twisted painfully",
-                "Your limbs ache and wobble like jelly",
-                "Your body is flooded with distortional energies",
-                "You feel very strange",
-            },
-            {
-                "The air around @the_monster@ crackles with energy",
-                "Multicoloured lights dance around @the_monster@",
-                "There is a strange surge of energy around @the_monster@",
-                "Waves of light ripple over @the_monster@'s body",
-                "@The_monster@ twitches",
-                "@The_monster@'s body glows momentarily",
-                "@The_monster@'s body twists unnaturally",
-                "@The_monster@'s body twists and writhes",
-                "@The_monster@'s body is flooded with distortional energies",
-            },
-            {
-                "The thin air crackles with energy",
-                "Multicoloured lights dance in the air",
-                "Waves of light ripple in the air",
-            },
-            [] (actor& target, actor* /*source*/,
-                miscast_source_info /*mc_info*/, int dam, string cause) {
-
-                // Double existing contamination, plus more from the damage
-                // roll
-                if (target.is_player())
-                {
-                    contaminate_player(you.magic_contamination
-                                       + dam * MISCAST_DIVISOR, true);
-                }
-                else
-                    target.malmutate(cause);
-            }
-
-        },
-    },
     {
         spschool::fire,
         {
@@ -546,25 +502,29 @@ static const map<spschool, miscast_datum> miscast_effects = {
         },
     },
     {
-        spschool::poison,
+        spschool::alchemy,
         {
-            BEAM_POISON,
+            BEAM_NONE,
             {
-                "You feel odd",
-                "You feel rather nauseous for a moment",
-                "You feel incredibly sick",
+                "You are engulfed in toxic fumes",
+                "There is a flash of cinnabar",
+                "Mercury flows from your @hands@",
+                "Parts of your body briefly turn golden",
             },
             {
-                "@The_monster@ looks faint for a moment",
-                "@The_monster@ has an odd expression for a moment",
-                "@The_monster@ is briefly tinged with green",
-                "@The_monster@ looks rather nauseous for a moment",
+                "@The_monster@ is engulfed in toxic fumes",
+                "@The_monster@ is blasted with cinnabar dust",
+                "@The_monster@ starts coughing violently",
                 "@The_monster@ looks incredibly sick",
             },
             {
                 "The air has a green tinge for a moment",
             },
-            nullptr,
+            [] (actor& target, actor* source, miscast_source_info /*mc_info*/,
+                int dam, string /*cause*/)
+            {
+                target.poison(source, dam * 5 / 2);
+            },
         },
     },
 };
