@@ -4,6 +4,9 @@
 #include "spl-cast.h"
 #include "transformation.h"
 
+// Maximum amount of slaying you can stack with fugue
+const int FUGUE_MAX_STACKS = 7;
+
 class actor;
 
 spret cast_deaths_door(int pow, bool fail);
@@ -26,9 +29,13 @@ int silence_min_range(int pow);
 int silence_max_range(int pow);
 spret cast_silence(int pow, bool fail = false);
 
-spret cast_wereblood(int pow, bool fail);
+spret cast_fugue_of_the_fallen(int pow, bool fail);
+void do_fugue_wail(const coord_def pos);
 
 int liquefaction_max_range(int pow);
 spret cast_liquefaction(int pow, bool fail);
-spret cast_transform(int pow, transformation which_trans, bool fail);
-spret cast_corpse_rot(int pow, bool fail);
+
+bool jinxbite_targets_available();
+spret cast_jinxbite(int pow, bool fail);
+
+spret cast_confusing_touch(int power, bool fail);
