@@ -25,6 +25,7 @@
 #include "env.h"
 #include "fight.h"
 #include "fprop.h"
+#include "ghost.h"
 #include "god-conduct.h"
 #include "god-item.h"
 #include "invent.h"
@@ -32,6 +33,9 @@
 #include "item-status-flag-type.h"
 #include "items.h"
 #include "libutil.h"
+#include "los.h"
+#include "losglobal.h"
+#include "losparam.h"
 #include "mapmark.h"
 #include "message.h"
 #include "mgen-data.h"
@@ -58,6 +62,7 @@
 #include "target.h"
 #include "teleport.h"
 #include "terrain.h"
+#include "tilepick.h"
 #include "timed-effects.h"
 #include "unwind.h"
 #include "viewchar.h"
@@ -114,27 +119,89 @@ spret cast_summon_small_mammal(int pow, god_type god, bool fail)
     return spret::success;
 }
 
+// Mid of an active canine familiar. Should exist only so long as the player
+// has a living one.
+#define CANINE_FAMILIAR_MID "canine_familiar_mid"
+
+monster *find_canine_familiar()
+{
+    if (!you.props.exists(CANINE_FAMILIAR_MID))
+        return nullptr;
+    const int mid = you.props[CANINE_FAMILIAR_MID].get_int();
+    return monster_by_mid(mid);
+}
+
+bool canine_familiar_is_alive()
+{
+    return find_canine_familiar() != nullptr;
+}
+
+void check_canid_farewell(const monster &dog, bool deadish)
+{
+    if (&dog != find_canine_familiar())
+        return;
+
+    you.props.erase(CANINE_FAMILIAR_MID);
+
+    if (deadish)
+    {
+        // Prevent you from resummoning it for a little while.
+        you.duration[DUR_CANINE_FAMILIAR_DEAD] = random_range(13, 21)
+                                                 * BASELINE_DELAY;
+    }
+}
+
 spret cast_call_canine_familiar(int pow, god_type god, bool fail)
 {
-    if (stop_summoning_prompt())
+    // Many parts of this spell behave differently if our familiar has already
+    // been summoned.
+    monster *old_dog = find_canine_familiar();
+
+    if (!old_dog && stop_summoning_prompt())
         return spret::abort;
 
+    if (old_dog && !you.can_see(*old_dog))
+    {
+        mprf(MSGCH_PROMPT, "Your familiar is too far away to imbue with magic.");
+        return spret::abort;
+    }
+
     fail_check();
-    monster_type mon = MONS_PROGRAM_BUG;
 
-    const int chance = pow + random_range(-10, 10);
+    // Summon our dog if one isn't already active
+    if (!old_dog)
+    {
+        mgen_data mg = _pal_data(MONS_INUGAMI, 5, god, SPELL_CALL_CANINE_FAMILIAR);
 
-    if (chance > 59)
-        mon = MONS_WARG;
-    else if (chance > 39)
-        mon = MONS_WOLF;
+        monster* dog = create_monster(mg);
+        if (!dog)
+        {
+            canned_msg(MSG_NOTHING_HAPPENS);
+            return spret::success;
+        }
+
+        // Use a ghost_demon to handle the familiar's scaling damage and stats.
+        // The ghost_demon is created, but not initialized, during the
+        // create_monster call above.
+        ASSERT(dog->ghost);
+        dog->ghost->init_inugami_from_player(pow);
+        dog->inugami_init();
+
+        mpr("You call for your canine familiar and it appears with a howl!");
+        you.props[CANINE_FAMILIAR_MID].get_int() = dog->mid;
+    }
+    // If it's active, instead heal and boost its next attack.
     else
-        mon = MONS_HOUND;
+    {
+        // Heal familiar and make its next attack (within the new few turns,
+        // so that you don't just prebuff for this) an instant cleave.
+        mpr("You imbue your familiar with magical energy and its fangs glint"
+            " viciously.");
 
-    const int dur = min(2 + (random2(pow) / 4), 6);
-
-    if (!create_monster(_pal_data(mon, dur, god, SPELL_CALL_CANINE_FAMILIAR)))
-        canned_msg(MSG_NOTHING_HAPPENS);
+        old_dog->heal(random_range(5, 9) + div_rand_round(pow, 5));
+        old_dog->lose_ench_levels(ENCH_POISON, 1);
+        old_dog->add_ench(mon_enchant(ENCH_INSTANT_CLEAVE, 1, &you, 50));
+    }
 
     return spret::success;
 }
@@ -208,9 +275,8 @@ spret cast_summon_ice_beast(int pow, god_type god, bool fail)
         return spret::abort;
 
     fail_check();
-    const int dur = min(2 + div_rand_round(random2(1 + pow), 4), 4);
 
-    mgen_data ice_beast = _pal_data(MONS_ICE_BEAST, dur, god,
+    mgen_data ice_beast = _pal_data(MONS_ICE_BEAST, 3, god,
                                     SPELL_SUMMON_ICE_BEAST);
     ice_beast.hd = (3 + div_rand_round(pow, 13));
 
@@ -235,7 +301,7 @@ spret cast_monstrous_menagerie(actor* caster, int pow, god_type god, bool fail)
     else
         type = coinflip() ? MONS_MANTICORE : MONS_LINDWURM;
 
-    mgen_data mdata = _summon_data(*caster, type, 4, god,
+    mgen_data mdata = _summon_data(*caster, type, 3, god,
                                    SPELL_MONSTROUS_MENAGERIE);
     if (caster->is_player())
         mdata.hd = get_monster_data(type)->HD + div_rand_round(pow - 50, 25);
@@ -307,7 +373,7 @@ static monster_type _choose_dragon_type(int pow, god_type /*god*/, bool player)
 
 spret cast_dragon_call(int pow, bool fail)
 {
-    if (stop_summoning_prompt(MR_NO_FLAGS, M_NO_FLAGS, "call dragons"))
+    if (stop_summoning_prompt(MR_NO_FLAGS, M_FLIES, "call dragons"))
         return spret::abort;
 
     fail_check();
@@ -511,7 +577,7 @@ spret cast_summon_mana_viper(int pow, god_type god, bool fail)
 
     mgen_data viper = _pal_data(MONS_MANA_VIPER, 2, god,
                                 SPELL_SUMMON_MANA_VIPER);
-    viper.hd = (6 + div_rand_round(pow, 12));
+    viper.hd = (7 + div_rand_round(pow, 12));
 
     if (create_monster(viper))
         mpr("A mana viper appears with a sibilant hiss.");
@@ -757,19 +823,6 @@ static void _animate_weapon(int pow, actor* target)
     montarget->unequip(*(montarget->mslot_item(wp_slot)), false, true);
     montarget->inv[wp_slot] = NON_ITEM;
 
-    // Also steal ammo for launchers.
-    if (is_range_weapon(*wpn))
-    {
-        const int ammo = montarget->inv[MSLOT_MISSILE];
-        if (ammo != NON_ITEM)
-        {
-            ASSERT(mons->inv[MSLOT_MISSILE] == NON_ITEM);
-            mons->inv[MSLOT_MISSILE] = ammo;
-            montarget->inv[MSLOT_MISSILE] = NON_ITEM;
-            env.item[ammo].set_holding_monster(*mons);
-        }
-    }
-
     // Find out what our god thinks before killing the item.
     conduct_type why = god_hates_item_handling(*wpn);
 
@@ -865,26 +918,26 @@ spret cast_summon_lightning_spire(int pow, god_type god, bool fail)
     return spret::success;
 }
 
-spret cast_summon_guardian_golem(int pow, god_type god, bool fail)
+spret cast_summon_blazeheart_golem(int pow, god_type god, bool fail)
 {
     if (stop_summoning_prompt(MR_RES_POISON))
         return spret::abort;
 
     fail_check();
 
-    mgen_data golem = _pal_data(MONS_GUARDIAN_GOLEM, 3, god,
-                                SPELL_SUMMON_GUARDIAN_GOLEM);
+    mgen_data golem = _pal_data(MONS_BLAZEHEART_GOLEM, 3, god,
+                                SPELL_SUMMON_BLAZEHEART_GOLEM);
     golem.flags &= ~MG_AUTOFOE; // !!!
-    golem.hd = 4 + div_rand_round(pow, 16);
+    golem.hd = 6 + div_rand_round(pow, 12);
 
     monster* mons = (create_monster(golem));
 
     if (mons)
     {
-        // Immediately apply injury bond
-        guardian_golem_bond(*mons);
+        mpr("A fiery spirit appears, bound in slag iron.");
 
-        mpr("A guardian golem appears, shielding your allies.");
+        // Give an extra turn of grace period on the turn it is summoned.
+        mons->blazeheart_heat = 4;
     }
     else
         canned_msg(MSG_NOTHING_HAPPENS);
@@ -907,9 +960,7 @@ spret cast_call_imp(int pow, god_type god, bool fail)
 
     fail_check();
 
-    const int dur = min(2 + div_rand_round(random2(1 + pow), 5), 6);
-
-    mgen_data imp_data = _pal_data(MONS_CERULEAN_IMP, dur, god, SPELL_CALL_IMP);
+    mgen_data imp_data = _pal_data(MONS_CERULEAN_IMP, 3, god, SPELL_CALL_IMP);
     if (monster *imp = create_monster(imp_data))
     {
         mpr("A tiny devil pulls itself out of the air.");
@@ -1377,7 +1428,7 @@ spret cast_summon_forest(actor* caster, int pow, god_type god, bool fail, bool t
 
     mgen_data dryad_data = _pal_data(MONS_DRYAD, 1, god,
                                      SPELL_SUMMON_FOREST);
-    dryad_data.hd = 5 + div_rand_round(pow, 18);
+    dryad_data.hd = 6 + div_rand_round(pow, 16);
 
     if (monster *dryad = create_monster(dryad_data))
     {
@@ -1468,25 +1519,53 @@ spret cast_haunt(int pow, const coord_def& where, god_type god, bool fail)
     return spret::success;
 }
 
+spret cast_martyrs_knell(const actor* caster, int pow, god_type god, bool fail)
+{
+    if (caster->is_player() && stop_summoning_prompt(MR_RES_POISON, M_FLIES))
+        return spret::abort;
+
+    fail_check();
+
+    mgen_data mg = _summon_data(*caster, MONS_MARTYRED_SHADE, 2, god,
+                                SPELL_MARTYRS_KNELL);
+    mg.hd = (6 + div_rand_round(pow, 11));
+
+    monster* shade = create_monster(mg);
+    if (shade)
+    {
+        if (caster->is_player())
+            mpr("You call forth a shade to shield your allies.");
+        else if (you.can_see(*shade))
+        {
+            mprf("%s calls forth a shade to shield themselves.",
+                 caster->name(DESC_THE).c_str());
+        }
+
+        martyr_injury_bond(*shade);
+    }
+    else if (caster->is_player())
+        canned_msg(MSG_NOTHING_HAPPENS);
+
+    return spret::success;
+}
+
 static spell_type servitor_spells[] =
 {
     // primary spells
     SPELL_LEHUDIBS_CRYSTAL_SPEAR,
     SPELL_IOOD,
-    SPELL_IRON_SHOT,
-    SPELL_BOLT_OF_COLD, // left in for frederick
+    SPELL_BOMBARD,
     SPELL_PLASMA_BEAM, // maybe should be higher?
     SPELL_FIREBALL,
     SPELL_ARCJOLT,
     SPELL_STONE_ARROW,
     SPELL_LRD,
     SPELL_AIRSTRIKE,
-    SPELL_FORCE_LANCE, // left in for frederick
     // less desirable
-    SPELL_CONJURE_BALL_LIGHTNING,
+    SPELL_IRRADIATE,
+    SPELL_CONJURE_BALL_LIGHTNING, // but VERY funny
     SPELL_FREEZING_CLOUD,
     SPELL_MEPHITIC_CLOUD,
-    SPELL_STICKY_FLAME,
 };
 
 /**
@@ -1498,7 +1577,7 @@ static spell_type servitor_spells[] =
 spell_type player_servitor_spell()
 {
     for (const spell_type spell : servitor_spells)
-        if (you.has_spell(spell) && raw_spell_fail(spell) < 50)
+        if (you.has_spell(spell) && failure_rate_to_int(raw_spell_fail(spell)) <= 20)
             return spell;
     return SPELL_NO_SPELL;
 }
@@ -1523,7 +1602,7 @@ static void _init_servitor_monster(monster &mon, const actor& caster, int pow)
 {
     const monster* caster_mon = caster.as_monster();
 
-    mon.set_hit_dice(9 + div_rand_round(pow, 14));
+    mon.set_hit_dice(7 + div_rand_round(pow, 14));
     mon.max_hit_points = mon.hit_points = 60 + roll_dice(7, 5); // 67-95
                                             // mhp doesn't vary with HD
     int spell_levels = 0;
@@ -1531,7 +1610,7 @@ static void _init_servitor_monster(monster &mon, const actor& caster, int pow)
     for (const spell_type spell : servitor_spells)
     {
         if (caster.has_spell(spell)
-            && (caster_mon || raw_spell_fail(spell) < 50))
+            && (caster_mon || failure_rate_to_int(raw_spell_fail(spell)) <= 20))
         {
             mon.spells.emplace_back(spell, 0, MON_SPELL_WIZARD);
             spell_levels += spell_difficulty(spell);
@@ -1589,7 +1668,7 @@ spret cast_spellforged_servitor(int pow, god_type god, bool fail)
 
     fail_check();
 
-    mgen_data mdata = _pal_data(MONS_SPELLFORGED_SERVITOR, 4, god,
+    mgen_data mdata = _pal_data(MONS_SPELLFORGED_SERVITOR, 3, god,
                                 SPELL_SPELLFORGED_SERVITOR);
 
     if (monster* mon = create_monster(mdata))
@@ -1762,77 +1841,87 @@ vector<spell_type> player_battlesphere_spells()
     return results;
 }
 
-bool aim_battlesphere(actor* agent, spell_type spell)
+static bool _is_valid_battlesphere_target(actor* caster, actor* targ)
 {
-    //Is this spell something that will trigger the battlesphere?
-    if (battlesphere_can_mirror(spell))
+    return targ && targ->alive() && !mons_aligned(caster, targ)
+           && caster->can_see(*targ);
+}
+
+static actor* _find_battlesphere_target(monster* battlesphere)
+{
+    actor* agent = actor_by_mid(battlesphere->summoner);
+    // If we already have a saved foe, check if they're still a viable target.
+    // If they are, keep trying to fire at them.
+    if (battlesphere->props.exists(BATTLESPHERE_FOE_KEY))
     {
-        monster* battlesphere = find_battlesphere(agent);
-
-        // If we've somehow gotten separated from the battlesphere (ie:
-        // abyss level teleport), bail out and cancel the battlesphere bond
-        if (!battlesphere)
-        {
-            agent->props.erase(BATTLESPHERE_KEY);
-            return false;
-        }
-
-        // In case the battlesphere was in the middle of a (failed)
-        // target-seeking action, cancel it so that it can focus on a new
-        // target
-        reset_battlesphere(battlesphere);
-        battlesphere->props.erase(MON_FOE_KEY);
-
-        // Pick a random baddie in LOS
-        vector<actor *> targets;
-        for (actor_near_iterator ai(agent, LOS_NO_TRANS); ai; ++ai)
-        {
-            if (battlesphere->can_see(**ai)
-                && !mons_aligned(agent, *ai)
-                && (ai->is_player() || !mons_is_firewood(*ai->as_monster())))
-            {
-                targets.push_back(*ai);
-            }
-        }
-
-        if (targets.empty())
-            return false;
-
-        const actor * target = *random_iterator(targets);
-        battlesphere->foe = target->mindex();
-        battlesphere->props[MON_FOE_KEY] = battlesphere->foe;
-        battlesphere->props["ready"] = true;
-
-        return true;
+        actor* targ = actor_by_mid(battlesphere->props[BATTLESPHERE_FOE_KEY].get_int());
+        if (_is_valid_battlesphere_target(agent, targ))
+            return targ;
     }
 
-    return false;
+    // If we need a new target, scan visible enemies and pick one at random.
+    vector<actor *> targets;
+    for (actor_near_iterator ai(agent, LOS_NO_TRANS); ai; ++ai)
+    {
+        if (!mons_aligned(agent, *ai)
+            && (ai->is_player() || !mons_is_firewood(*ai->as_monster())))
+        {
+            targets.push_back(*ai);
+        }
+    }
+
+    if (targets.empty())
+        return nullptr;
+
+    return *random_iterator(targets);
 }
 
 bool trigger_battlesphere(actor* agent)
 {
     monster* battlesphere = find_battlesphere(agent);
+
+    // If we've somehow gotten separated from the battlesphere (ie:
+    // abyss level teleport), bail out and cancel the battlesphere bond
     if (!battlesphere)
-        return false;
-
-    if (battlesphere->props.exists("ready"))
     {
-        battlesphere->props.erase("ready");
-        battlesphere->props["firing"] = true;
-
-        // Since monsters may be acting out of sequence, give the battlesphere
-        // enough energy to attempt to fire this round, and requeue if it's
-        // already passed its turn
-        if (agent->is_monster())
-        {
-            battlesphere->speed_increment = 100;
-            queue_monster_for_action(battlesphere);
-        }
-
-        return true;
+        agent->props.erase(BATTLESPHERE_KEY);
+        return false;
     }
 
-    return false;
+    // Reset battlesphere now. Otherwise, if it ran out of energy without being
+    // able to fire at its target on the previous player turn, the pre-action
+    // reset will make it unable to fire THIS turnt, too.
+    reset_battlesphere(battlesphere);
+
+    actor* target = _find_battlesphere_target(battlesphere);
+
+    // If we couldn't find any target at all, bail.
+    if (!target)
+    {
+        agent->props.erase(BATTLESPHERE_FOE_KEY);
+        return false;
+    }
+
+    dprf("Battlesphere targeting %s at (%d, %d).",
+         target->name(DESC_THE).c_str(),
+         target->pos().x,
+         target->pos().y);
+
+    // Otherwise, prime the battlesphere to fire
+    battlesphere->foe = target->mindex();
+    battlesphere->props[BATTLESPHERE_FOE_KEY].get_int() = target->mid;
+    battlesphere->props[BATTLESPHERE_IS_FIRING_KEY] = true;
+
+    // Since monsters may be acting out of sequence, give the battlesphere
+    // enough energy to attempt to fire this round, and requeue if it's
+    // already passed its turn
+    if (agent->is_monster())
+    {
+        battlesphere->speed_increment = 100;
+        queue_monster_for_action(battlesphere);
+    }
+
+    return true;
 }
 
 // Called at the start of each round. Cancels firing orders given in the
@@ -1843,14 +1932,10 @@ void reset_battlesphere(monster* mons)
     if (!mons || mons->type != MONS_BATTLESPHERE)
         return;
 
-    mons->props.erase("ready");
-
-    if (mons->props.exists("tracking"))
+    if (mons->props.exists(BATTLESPHERE_IS_TRACKING_KEY))
     {
-        mons->props.erase("tracking");
-        mons->props.erase("firing");
-        if (mons->props.exists(MON_FOE_KEY))
-            mons->foe = mons->props[MON_FOE_KEY].get_int();
+        mons->props.erase(BATTLESPHERE_IS_TRACKING_KEY);
+        mons->props.erase(BATTLESPHERE_IS_FIRING_KEY);
         mons->behaviour = BEH_SEEK;
     }
 }
@@ -1870,18 +1955,27 @@ bool fire_battlesphere(monster* mons)
 
     bool used = false;
 
-    if (mons->props.exists("firing") && mons->battlecharge > 0)
+    actor* target = actor_by_mid(mons->props[BATTLESPHERE_FOE_KEY].get_int());
+
+    // Double-check that our target still exists
+    if (!target || !target->alive())
+        return false;
+
+    if (mons->props.exists(BATTLESPHERE_IS_FIRING_KEY) && mons->battlecharge > 0)
     {
-        if (mons->props.exists("tracking"))
+        // Was in the process of repositioning to get a better shot at our foe.
+        if (mons->props.exists(BATTLESPHERE_IS_TRACKING_KEY))
         {
+            // We have reached the position we were looking for, so stop tracking.
             if (mons->pos() == mons->props[TRACKING_TARGET_KEY].get_coord())
             {
-                mons->props.erase("tracking");
-                if (mons->props.exists(MON_FOE_KEY))
-                    mons->foe = mons->props[MON_FOE_KEY].get_int();
+                mons->props.erase(BATTLESPHERE_IS_TRACKING_KEY);
+                if (mons->props.exists(BATTLESPHERE_FOE_KEY))
+                    mons->foe = agent->mindex();
                 mons->behaviour = BEH_SEEK;
             }
-            else // Currently tracking, but have not reached target pos
+            // Currently tracking, but have not yet reached target position.
+            else
             {
                 mons->target = mons->props[TRACKING_TARGET_KEY].get_coord();
                 return false;
@@ -1891,42 +1985,27 @@ bool fire_battlesphere(monster* mons)
         {
             // If the battlesphere forgot its foe (due to being out of los),
             // remind it
-            if (mons->props.exists(MON_FOE_KEY))
-                mons->foe = mons->props[MON_FOE_KEY].get_int();
+            if (mons->props.exists(BATTLESPHERE_FOE_KEY))
+                mons->foe = target->mindex();
         }
 
         // Set up the beam.
         bolt beam;
-        beam.source_name = BATTLESPHERE_KEY;
-
-        // If we are locked onto a foe, use its current position
-        if (!invalid_monster_index(mons->foe) && env.mons[mons->foe].alive())
-            beam.target = env.mons[mons->foe].pos();
-
-        // Sanity check: if we have somehow ended up targeting ourselves, bail
-        if (beam.target == mons->pos())
-        {
-            mprf(MSGCH_ERROR, "Battlesphere targeting itself? Fixing.");
-            mons->props.erase("firing");
-            mons->props.erase(MON_FOE_KEY);
-            return false;
-        }
-
-        beam.name       = "barrage of energy";
-        beam.range      = LOS_RADIUS;
-        beam.hit        = AUTOMATIC_HIT;
-        beam.damage     = _battlesphere_damage(mons->get_hit_dice());
-        beam.glyph      = dchar_glyph(DCHAR_FIRED_ZAP);
-        beam.colour     = MAGENTA;
-        beam.flavour    = BEAM_MMISSILE;
-        beam.pierce     = false;
+        beam.source_name = mons->name(DESC_YOUR).c_str();
+        beam.target      = target->pos();
+        beam.name        = "barrage of energy";
+        beam.range       = LOS_RADIUS;
+        beam.hit         = AUTOMATIC_HIT;
+        beam.damage      = _battlesphere_damage(mons->get_hit_dice());
+        beam.glyph       = dchar_glyph(DCHAR_FIRED_ZAP);
+        beam.colour      = MAGENTA;
+        beam.flavour     = BEAM_MMISSILE;
+        beam.pierce      = false;
 
         // Fire tracer.
         fire_tracer(mons, beam);
 
-        // Never fire if we would hurt the caster, and ensure that the beam
-        // would hit at least SOMETHING, unless it was targeted at empty space
-        // in the first place
+        // Never fire if we would hurt the caster or not hit anything at all.
         if (beam.friend_info.count == 0 && beam.foe_info.count > 0)
         {
             beam.thrower = (agent->is_player()) ? KILL_YOU : KILL_MON;
@@ -1938,14 +2017,13 @@ bool fire_battlesphere(monster* mons)
             if (--mons->battlecharge == 0)
                 end_battlesphere(mons, false);
 
-            mons->props.erase("firing");
+            mons->props.erase(BATTLESPHERE_IS_FIRING_KEY);
         }
-        // If we are firing at something, try to find a nearby position
-        // from which we could safely fire at it
+        // We don't have a good shot at our target from our current position.
+        // Evaluate nearby positions to see if one of them has a better shot.
         else
         {
-            const bool empty_beam = (beam.foe_info.count == 0);
-            for (distance_iterator di(mons->pos(), true, true, 2); di; ++di)
+            for (distance_iterator di(mons->pos(), true, true, 4); di; ++di)
             {
                 if (*di == beam.target || actor_at(*di)
                     || cell_is_solid(*di)
@@ -1959,21 +2037,16 @@ bool fire_battlesphere(monster* mons)
                 beam.friend_info.reset();
                 beam.foe_info.reset();
                 beam.fire();
-                if (beam.friend_info.count == 0
-                    && (beam.foe_info.count > 0 || empty_beam))
-                {
-                    if (empty_beam
-                        && find(beam.path_taken.begin(), beam.path_taken.end(),
-                                beam.target) == beam.path_taken.end())
-                    {
-                        continue;
-                    }
 
+                // We found a firing position to shoot at our target without
+                // endangering our controller. Mark this location and have the
+                // battlesphere move towards it over the next few actions.
+                if (beam.friend_info.count == 0 && beam.foe_info.count > 0)
+                {
                     mons->firing_pos = coord_def(0, 0);
                     mons->target = *di;
                     mons->behaviour = BEH_WANDER;
-                    mons->props[MON_FOE_KEY] = mons->foe;
-                    mons->props["tracking"] = true;
+                    mons->props[BATTLESPHERE_IS_TRACKING_KEY] = true;
                     mons->foe = MHITNOT;
                     mons->props[TRACKING_TARGET_KEY] = *di;
                     break;
@@ -1982,7 +2055,7 @@ bool fire_battlesphere(monster* mons)
 
             // If we didn't find a better firing position nearby, cancel firing
             if (!mons->props.exists("tracking"))
-                mons->props.erase("firing");
+                mons->props.erase(BATTLESPHERE_IS_FIRING_KEY);
         }
     }
 
@@ -1991,7 +2064,7 @@ bool fire_battlesphere(monster* mons)
     if ((mons->foe == MHITNOT || !mons->can_see(*agent)
          || (!invalid_monster_index(mons->foe)
              && !agent->can_see(env.mons[mons->foe])))
-        && !mons->props.exists("tracking"))
+        && !mons->props.exists(BATTLESPHERE_IS_TRACKING_KEY))
     {
         mons->foe = agent->mindex();
     }
@@ -2166,9 +2239,10 @@ static const map<spell_type, summon_cap> summonsdata =
     { SPELL_MONSTROUS_MENAGERIE,      { 2, 3 } },
     { SPELL_SUMMON_HORRIBLE_THINGS,   { 8, 8 } },
     { SPELL_SUMMON_LIGHTNING_SPIRE,   { 1, 1 } },
-    { SPELL_SUMMON_GUARDIAN_GOLEM,    { 1, 1 } },
+    { SPELL_SUMMON_BLAZEHEART_GOLEM,  { 1, 1 } },
     { SPELL_SPELLFORGED_SERVITOR,     { 1, 1 } },
     { SPELL_ANIMATE_ARMOUR,           { 1, 1 } },
+    { SPELL_MARTYRS_KNELL,            { 1, 1 } },
     { SPELL_HAUNT,                    { 8, 8 } },
     { SPELL_SUMMON_CACTUS,            { 1, 1 } },
     // Monster-only spells
@@ -2187,7 +2261,7 @@ static const map<spell_type, summon_cap> summonsdata =
     { SPELL_SUMMON_SPECTRAL_ORCS,     { 0, 3 } },
     { SPELL_FIRE_SUMMON,              { 0, 4 } },
     { SPELL_SUMMON_MINOR_DEMON,       { 0, 3 } },
-    { SPELL_CALL_LOST_SOUL,           { 0, 3 } },
+    { SPELL_CALL_LOST_SOULS,          { 0, 3 } },
     { SPELL_SUMMON_VERMIN,            { 0, 5 } },
     { SPELL_FORCEFUL_INVITATION,      { 0, 3 } },
     { SPELL_PLANEREND,                { 0, 6 } },
@@ -2198,13 +2272,12 @@ static const map<spell_type, summon_cap> summonsdata =
     { SPELL_SUMMON_SCARABS,           { 0, 8 } },
     { SPELL_SUMMON_HOLIES,            { 0, 4 } },
     { SPELL_SUMMON_EXECUTIONERS,      { 0, 3 } },
-    { SPELL_AWAKEN_EARTH,             { 0, 9 } },
     { SPELL_GREATER_SERVANT_MAKHLEB,  { 0, 1 } },
     { SPELL_SUMMON_GREATER_DEMON,     { 0, 3 } },
     { SPELL_SUMMON_DEMON,             { 0, 3 } },
     { SPELL_SUMMON_TZITZIMITL,        { 0, 3 } },
     { SPELL_SUMMON_HELL_SENTINEL,     { 0, 3 } },
-    { SPELL_CONJURE_LIVING_SPELLS,    { 0, 6 } },
+    { SPELL_CONJURE_LIVING_SPELLS,    { 0, 4 } },
     { SPELL_SHEZAS_DANCE,             { 0, 6 } },
 };
 
@@ -2598,7 +2671,7 @@ void kiku_unearth_wretches()
 }
 
 static bool _create_foxfire(const actor &agent, coord_def pos,
-                            god_type god, int pow)
+                            god_type god, int pow, bool marshlight = false)
 {
     const auto att = agent.is_player() ? BEH_FRIENDLY
                                        : SAME_ATTITUDE(agent.as_monster());
@@ -2617,6 +2690,8 @@ static bool _create_foxfire(const actor &agent, coord_def pos,
 
     foxfire->add_ench(ENCH_SHORT_LIVED);
     foxfire->steps_remaining = you.current_vision + 2;
+    if (marshlight)
+        foxfire->props[MONSTER_TILE_KEY] = TILEP_MONS_MARSHLIGHT;
 
     // Avoid foxfire without targets always moving towards (0,0)
     if (!foxfire->get_foe()
@@ -2627,7 +2702,7 @@ static bool _create_foxfire(const actor &agent, coord_def pos,
     return true;
 }
 
-spret cast_foxfire(actor &agent, int pow, god_type god, bool fail)
+spret cast_foxfire(actor &agent, int pow, god_type god, bool fail, bool marshlight)
 {
     bool see_space = false;
     for (adjacent_iterator ai(agent.pos()); ai; ++ai)
@@ -2652,7 +2727,7 @@ spret cast_foxfire(actor &agent, int pow, god_type god, bool fail)
 
     for (fair_adjacent_iterator ai(agent.pos()); ai; ++ai)
     {
-        if (!_create_foxfire(agent, *ai, god, pow))
+        if (!_create_foxfire(agent, *ai, god, pow, marshlight))
             continue;
         ++created;
         if (created == 2)
@@ -2661,9 +2736,10 @@ spret cast_foxfire(actor &agent, int pow, god_type god, bool fail)
 
     if (created && you.see_cell(agent.pos()))
     {
-        mprf("%s conjure%s some foxfire!",
+        mprf("%s conjure%s some %s!",
              agent.name(DESC_THE).c_str(),
-             agent.is_monster() ? "s" : "");
+             agent.is_monster() ? "s" : "",
+             marshlight ? "marshlight" : "foxfire");
     }
     else if (agent.is_player())
         canned_msg(MSG_NOTHING_HAPPENS);
@@ -2747,3 +2823,114 @@ spret summon_spiders(actor &agent, int pow, god_type god, bool fail)
 
     return spret::success;
 }
+
+spret cast_broms_barrelling_boulder(actor& agent, coord_def targ, int pow, bool fail)
+{
+    fail_check();
+
+    ray_def ray;
+    if (!find_ray(agent.pos(), targ, ray, opc_solid) || !ray.advance())
+    {
+        mpr("There's something in the way.");
+        return spret::abort;
+    }
+    const coord_def pos = ray.pos();
+
+    // For unseen invisble enemies
+    if (actor_at(pos))
+    {
+        mpr("Something unseen is already there!");
+        return spret::success;
+    }
+
+    mgen_data mg = mgen_data(MONS_BOULDER,
+                             agent.is_player()
+                                ? BEH_FRIENDLY
+                                : SAME_ATTITUDE(agent.as_monster()),
+                             pos, MHITNOT, MG_FORCE_PLACE);
+    mg.set_summoned(&agent, 0, SPELL_BOULDER);
+    monster *boulder = create_monster(mg);
+
+    // If some other reason prevents this from working (I'm not sure what?)
+    if (!boulder)
+    {
+        canned_msg(MSG_NOTHING_HAPPENS);
+        return spret::success;
+    }
+
+    boulder->props[BOULDER_POWER_KEY] = pow;
+    // XX: This will produce weird data if the caster isn't adjacent to the target spot.
+    //     Currently that can't happen, but in future it might.
+    boulder->props[BOULDER_DIRECTION_KEY] = pos - agent.pos();
+
+    mpr("You send a boulder barrelling forward!");
+    return spret::success;
+}
+
+string mons_simulacrum_immune_reason(const monster *mons)
+{
+    if (!mons || !you.can_see(*mons))
+        return "You can't see anything there.";
+
+    if (!mons_can_be_spectralised(*mons))
+        return "You can't make a simulacrum of that!";
+
+    return "";
+}
+
+spret cast_simulacrum(coord_def target, int pow, bool fail)
+{
+    if (cell_is_solid(target))
+    {
+        canned_msg(MSG_UNTHINKING_ACT);
+        return spret::abort;
+    }
+
+    monster* mons = monster_at(target);
+    if (!mons || !you.can_see(*mons))
+    {
+        fail_check();
+        canned_msg(MSG_NOTHING_CLOSE_ENOUGH);
+        // If there's no monster there, you still pay the costs in
+        // order to prevent locating invisible/submerged monsters.
+        return spret::success;
+    }
+
+    if (!mons_can_be_spectralised(*mons))
+    {
+        mpr("You can't make simulacra of that!");
+        return spret::abort;
+    }
+
+    fail_check();
+
+    mprf("You sublimate a sliver of %s essence and reconstitute it in ice.",
+         apostrophise(mons->name(DESC_THE)).c_str());
+
+    int num_simulacra = 2;
+    if (x_chance_in_y(pow, 200))
+        num_simulacra = 3;
+
+    int delay = random_range(3, 5) * BASELINE_DELAY;
+    for (int i = 0; i < num_simulacra; ++i)
+    {
+        // Note that this *not* marked as coming from SPELL_SIMULACRUM
+        mgen_data mg = _pal_data(MONS_BLOCK_OF_ICE, 0, GOD_NO_GOD, SPELL_NO_SPELL);
+        mg.base_type = mons->type;
+        mg.hd = 8; // make them more durable
+        monster *ice = create_monster(mg);
+
+        if (ice)
+        {
+            ice->props[SIMULACRUM_TYPE_KEY] = mons->type;
+            ice->add_ench(mon_enchant(ENCH_SHORT_LIVED, 0, &you, delay));
+            ice->add_ench(mon_enchant(ENCH_SIMULACRUM_SCULPTING, 0, &you, INFINITE_DURATION));
+            ice->flags |= MF_WAS_IN_VIEW;
+
+            // Make each one shift a little later than the last
+            delay += random_range(1, 3) * BASELINE_DELAY;
+        }
+    }
+
+    return spret::success;
+}
