@@ -12,9 +12,15 @@
 
 #define DRAGON_CALL_POWER_KEY "dragon_call_power"
 
+#define SIMULACRUM_TYPE_KEY "simulacrum_type"
+
 spret cast_summon_small_mammal(int pow, god_type god, bool fail);
 
+bool canine_familiar_is_alive();
+monster *find_canine_familiar();
+void check_canid_farewell(const monster &dog, bool deadish);
 spret cast_call_canine_familiar(int pow, god_type god, bool fail);
+
 spret cast_summon_armour_spirit(int pow, god_type god, bool fail);
 spret cast_summon_ice_beast(int pow, god_type god, bool fail);
 spret cast_summon_cactus(int pow, god_type god, bool fail);
@@ -52,7 +58,7 @@ spret cast_malign_gateway(actor* caster, int pow,
                           bool test = false);
 coord_def find_gateway_location(actor* caster);
 spret cast_summon_forest(actor* caster, int pow, god_type god, bool fail, bool test=false);
-spret cast_summon_guardian_golem(int pow, god_type god, bool fail);
+spret cast_summon_blazeheart_golem(int pow, god_type god, bool fail);
 
 spret cast_dragon_call(int pow, bool fail);
 void do_dragon_call(int time);
@@ -67,12 +73,13 @@ spret cast_spellforged_servitor(int pow, god_type god, bool fail);
 monster_type pick_random_wraith();
 spret cast_haunt(int pow, const coord_def& where, god_type god, bool fail);
 
+spret cast_martyrs_knell(const actor* caster, int pow, god_type god, bool fail);
+
 monster* find_battlesphere(const actor* agent);
 spret cast_battlesphere(actor* agent, int pow, god_type god, bool fail);
 void end_battlesphere(monster* mons, bool killed);
 bool battlesphere_can_mirror(spell_type spell);
 vector<spell_type> player_battlesphere_spells();
-bool aim_battlesphere(actor* agent, spell_type spell);
 bool trigger_battlesphere(actor* agent);
 bool fire_battlesphere(monster* mons);
 void reset_battlesphere(monster* mons);
@@ -102,10 +109,16 @@ spret fedhas_grow_oklob(const coord_def& target, bool fail);
 
 void kiku_unearth_wretches();
 
-spret cast_foxfire(actor &agent, int pow, god_type god, bool fail);
+spret cast_foxfire(actor &agent, int pow, god_type god, bool fail,
+                   bool marshlight = false);
 spret foxfire_swarm();
 bool summon_spider(const actor &agent, coord_def pos, god_type god,
                         spell_type spell, int pow);
 spret summon_spiders(actor &agent, int pow, god_type god, bool fail = false);
 
 spret summon_butterflies();
+
+spret cast_broms_barrelling_boulder(actor& agent, coord_def pos, int pow, bool fail);
+
+string mons_simulacrum_immune_reason(const monster *mons);
+spret cast_simulacrum(coord_def target, int pow, bool fail);
