@@ -22,6 +22,7 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_STONE_ARROW, ZAP_STONE_ARROW },
     { SPELL_POISON_ARROW, ZAP_POISON_ARROW },
     { SPELL_IRON_SHOT, ZAP_IRON_SHOT },
+    { SPELL_BOMBARD, ZAP_BOMBARD },
     { SPELL_LIGHTNING_BOLT, ZAP_LIGHTNING_BOLT },
     { SPELL_CHAIN_LIGHTNING, ZAP_CHAIN_LIGHTNING },
     { SPELL_BOLT_OF_MAGMA, ZAP_BOLT_OF_MAGMA },
@@ -32,7 +33,7 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_MEPHITIC_CLOUD, ZAP_MEPHITIC },
     { SPELL_VIOLENT_UNRAVELLING, ZAP_UNRAVELLING },
     { SPELL_DISPEL_UNDEAD, ZAP_DISPEL_UNDEAD },
-    { SPELL_AGONY, ZAP_AGONY },
+    { SPELL_AGONIZING_TOUCH, ZAP_AGONY },
     { SPELL_MINDBURST, ZAP_MINDBURST },
     { SPELL_THROW_ICICLE, ZAP_THROW_ICICLE },
     { SPELL_VAMPIRIC_DRAINING, ZAP_VAMPIRIC_DRAINING },
@@ -75,6 +76,8 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_BOLT_OF_LIGHT, ZAP_BOLT_OF_LIGHT },
     { SPELL_FASTROOT, ZAP_FASTROOT },
     { SPELL_MOMENTUM_STRIKE, ZAP_MOMENTUM_STRIKE },
+    { SPELL_TREMORSTONE, ZAP_TREMORSTONE },
+    { SPELL_CURSE_OF_AGONY, ZAP_CURSE_OF_AGONY },
 
     // monster-specific
     { SPELL_SLUG_DART, ZAP_SLUG_DART },
@@ -89,11 +92,11 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_DRAIN_MAGIC, ZAP_DRAIN_MAGIC },
     { SPELL_HARPOON_SHOT, ZAP_HARPOON_SHOT},
     { SPELL_THROW_PIE, ZAP_THROW_PIE},
-    { SPELL_AGONY_RANGE, ZAP_AGONY_RANGE },
+    { SPELL_AGONY, ZAP_AGONY },
     { SPELL_DISPEL_UNDEAD_RANGE, ZAP_DISPEL_UNDEAD_RANGE },
     { SPELL_NOXIOUS_CLOUD, ZAP_NOXIOUS_CLOUD },
     { SPELL_POISONOUS_CLOUD, ZAP_POISONOUS_CLOUD },
-    { SPELL_ENERGY_BOLT, ZAP_ENERGY_BOLT },
+    { SPELL_BOLT_OF_DEVASTATION, ZAP_BOLT_OF_DEVASTATION },
     { SPELL_METAL_SPLINTERS, ZAP_METAL_SPLINTERS },
     { SPELL_SPLINTERSPRAY, ZAP_SPLINTERSPRAY },
     { SPELL_THORN_VOLLEY, ZAP_THORN_VOLLEY },
@@ -119,12 +122,14 @@ static pair<spell_type, zap_type> _spl_zaps[] =
     { SPELL_STUNNING_BURST, ZAP_STUNNING_BURST },
     { SPELL_SERACFALL, ZAP_ICEBLAST },
     { SPELL_CORONA, ZAP_CORONA },
+    { SPELL_VITRIFY, ZAP_VITRIFY},
+    { SPELL_MALIGN_OFFERING, ZAP_MALIGN_OFFERING},
 
     // These are all for zap -> spell lookup.
     { SPELL_QUICKSILVER_BOLT, ZAP_QUICKSILVER_BOLT },
     { SPELL_QUICKSILVER_BOLT, ZAP_BREATHE_POWER },
     { SPELL_STICKY_FLAME, ZAP_STICKY_FLAME },
-    { SPELL_STICKY_FLAME_RANGE, ZAP_STICKY_FLAME_RANGE },
+    { SPELL_PYRE_ARROW, ZAP_PYRE_ARROW },
     { SPELL_STEAM_BALL, ZAP_BREATHE_STEAM },
     { SPELL_ORB_OF_ELECTRICITY, ZAP_ORB_OF_ELECTRICITY },
     { SPELL_CHILLING_BREATH, ZAP_BREATHE_FROST },
