@@ -54,6 +54,7 @@
 #include "terrain.h"
 #ifdef USE_TILE
  #include "tilepick.h"
+ #include "tilepick-p.h"
 #endif
 #include "tileview.h"
 #include "traps.h" // set_shafted
@@ -152,6 +153,8 @@ static void _initialize()
     if (crawl_state.build_db)
         end(0);
 
+    crawl_state.use_des_cache = true;
+
 #ifdef USE_TILE_LOCAL
     loading_screen_close();
 #endif
@@ -288,7 +291,7 @@ static void _post_init(bool newc)
     {
         // n.b. temple already generated in setup_game at this point
         if (Options.pregen_dungeon == level_gen_type::full
-            && crawl_state.game_standard_levelgen())
+            && crawl_state.game_has_random_floors())
         {
             pregen_dungeon(level_id(NUM_BRANCHES, -1));
         }
@@ -356,6 +359,8 @@ static void _post_init(bool newc)
     init_monster_symbols();
 
 #ifdef USE_TILE
+    if (newc)
+        randomize_doll_base();
     init_player_doll();
 
     tiles.resize();
@@ -427,6 +432,8 @@ static const vector<game_modes_menu_item> entries =
     {GAME_TYPE_HINTS, "Hints Mode for Dungeon Crawl",
         "A mostly normal game that provides more advanced hints "
         "than the tutorial."},
+    {GAME_TYPE_DESCENT, "Dungeon Descent",
+        "Mode with a branching, one-way path through the Dungeon." },
     {GAME_TYPE_SPRINT, "Dungeon Sprint",
         "Hard, fixed single level game mode." },
     {GAME_TYPE_INSTRUCTIONS, "Instructions", "Help menu." },
@@ -441,6 +448,9 @@ static void _construct_game_modes_menu(shared_ptr<OuterMenu>& container)
     for (size_t i = 0; i < entries.size(); ++i)
     {
         const auto& entry = entries[i];
+        if (entry.id == GAME_TYPE_DESCENT && Version::ReleaseType != VER_ALPHA)
+            continue;
+
         auto label = make_shared<Text>();
 
 #ifdef USE_TILE_LOCAL
@@ -449,7 +459,7 @@ static void _construct_game_modes_menu(shared_ptr<OuterMenu>& container)
         auto tile = make_shared<Image>();
         tile->set_tile(tile_def(tileidx_gametype(entry.id)));
         tile->set_margin_for_sdl(0, 6, 0, 0);
-        hbox->add_child(move(tile));
+        hbox->add_child(std::move(tile));
         hbox->add_child(label);
 #endif
 
@@ -458,14 +468,14 @@ static void _construct_game_modes_menu(shared_ptr<OuterMenu>& container)
         auto btn = make_shared<MenuButton>();
 #ifdef USE_TILE_LOCAL
         hbox->set_margin_for_sdl(2, 10, 2, 2);
-        btn->set_child(move(hbox));
+        btn->set_child(std::move(hbox));
 #else
-        btn->set_child(move(label));
+        btn->set_child(std::move(label));
 #endif
         btn->id = entry.id;
         btn->description = entry.description;
         btn->highlight_colour = LIGHTGREY;
-        container->add_button(move(btn), 0, i);
+        container->add_button(std::move(btn), 0, i);
     }
 }
 
@@ -483,9 +493,9 @@ static shared_ptr<MenuButton> _make_newgame_button(int num_chars)
 
     auto btn = make_shared<MenuButton>();
 #ifdef USE_TILE_LOCAL
-    btn->set_child(move(hbox));
+    btn->set_child(std::move(hbox));
 #else
-    btn->set_child(move(label));
+    btn->set_child(std::move(label));
 #endif
     btn->get_child()->set_margin_for_sdl(2, 10, 2, 2);
     btn->id = NUM_GAME_TYPE + num_chars;
@@ -504,7 +514,7 @@ static void _construct_save_games_menu(shared_ptr<OuterMenu>& container,
 #ifdef USE_TILE_LOCAL
         auto tile = make_shared<ui::PlayerDoll>(chars.at(i).doll);
         tile->set_margin_for_sdl(0, 6, 0, 0);
-        hbox->add_child(move(tile));
+        hbox->add_child(std::move(tile));
 #endif
 
         const COLOURS fg = chars.at(i).save_loadable ? WHITE : RED;
@@ -528,20 +538,20 @@ static void _construct_save_games_menu(shared_ptr<OuterMenu>& container,
 
         auto btn = make_shared<MenuButton>();
 #ifdef USE_TILE_LOCAL
-        btn->set_child(move(hbox));
+        btn->set_child(std::move(hbox));
 #else
-        btn->set_child(move(label));
+        btn->set_child(std::move(label));
 #endif
         btn->get_child()->set_margin_for_sdl(2, 10, 2, 2);
         btn->id = NUM_GAME_TYPE + i;
         btn->highlight_colour = LIGHTGREY;
-        container->add_button(move(btn), 0, i);
+        container->add_button(std::move(btn), 0, i);
     }
 
     if (!chars.empty())
     {
         auto btn = _make_newgame_button(chars.size());
-        container->add_button(move(btn), 0, (int)chars.size());
+        container->add_button(std::move(btn), 0, (int)chars.size());
     }
 }
 
@@ -581,7 +591,7 @@ public:
         about->set_margin_for_crt(0, 0, 1, 0);
         about->set_margin_for_sdl(0, 0, 10, 0);
 
-        m_root->add_child(move(about));
+        m_root->add_child(std::move(about));
 
         auto grid = make_shared<Grid>();
         grid->set_margin_for_crt(0, 0, 1, 0);
@@ -597,7 +607,7 @@ public:
         input_text->set_margin_for_crt(0, 0, 1, 0);
         input_text->set_margin_for_sdl(0, 0, 10, 10);
 
-        grid->add_child(move(name_prompt), 0, 0);
+        grid->add_child(std::move(name_prompt), 0, 0);
         grid->add_child(input_text, 1, 0);
 
         descriptions = make_shared<Switcher>();
@@ -617,7 +627,7 @@ public:
         game_modes_menu->min_size().height = 2;
 #endif
 
-        grid->add_child(move(mode_prompt), 0, 1);
+        grid->add_child(std::move(mode_prompt), 0, 1);
         grid->add_child(game_modes_menu, 1, 1);
 
         save_games_menu = make_shared<OuterMenu>(num_saves > 1, 1, num_saves + 1);
@@ -636,7 +646,7 @@ public:
             save_games_menu->descriptions = descriptions;
 
             _construct_save_games_menu(save_games_menu, chars);
-            grid->add_child(move(save_prompt), 0, 2);
+            grid->add_child(std::move(save_prompt), 0, 2);
             grid->add_child(save_games_menu, 1, 2);
 
             game_modes_menu->linked_menus[2] = save_games_menu;
@@ -670,7 +680,7 @@ public:
         grid->column_flex_grow(0) = 1;
         grid->column_flex_grow(1) = 10;
 
-        m_root->add_child(move(grid));
+        m_root->add_child(std::move(grid));
 
         string instructions_text;
         // TODO: these can overflow on console 80x24 and won't line-wrap, is
@@ -730,6 +740,7 @@ private:
         switch (selected_game_type)
         {
         case GAME_TYPE_NORMAL:
+        case GAME_TYPE_DESCENT:
         case GAME_TYPE_CUSTOM_SEED:
         case GAME_TYPE_TUTORIAL:
         case GAME_TYPE_SPRINT:
@@ -909,6 +920,7 @@ void UIStartupMenu::menu_item_activated(int id)
     switch (id)
     {
     case GAME_TYPE_NORMAL:
+    case GAME_TYPE_DESCENT:
     case GAME_TYPE_CUSTOM_SEED:
     case GAME_TYPE_TUTORIAL:
     case GAME_TYPE_SPRINT:
@@ -965,18 +977,14 @@ static void _show_startup_menu(newgame_def& ng_choice,
 {
     unwind_bool no_more(crawl_state.show_more_prompt, false);
 
-#if defined(USE_TILE_LOCAL) && defined(__ANDROID__)
-    jni_keyboard_control(false);
-    sleep(1); // wait for keyboard
-#elif defined(USE_TILE_WEB)
+#ifdef USE_TILE_WEB
     tiles_crt_popup show_as_popup;
 #endif
 
-
     auto startup_ui = make_shared<UIStartupMenu>(ng_choice, defaults);
     auto popup = make_shared<ui::Popup>(startup_ui);
 
-    ui::run_layout(move(popup), startup_ui->done);
+    ui::run_layout(std::move(popup), startup_ui->done);
 
     if (startup_ui->end_game || crawl_state.seen_hups)
     {
@@ -1030,6 +1038,12 @@ bool startup_step()
     if (!SysEnv.crawl_name.empty())
         choice.name = SysEnv.crawl_name;
 
+#ifdef __ANDROID__
+    // Request the Android virtual keyboard. Waiting for the SDLActivity to be
+    // resized avoids some display bugs.
+    jni_keyboard_control(false);
+    sleep(1);
+#endif
 
 #ifndef DGAMELAUNCH
 
