@@ -205,17 +205,17 @@ private:
 class targeter_cloud : public targeter
 {
 public:
-    targeter_cloud(const actor* act, int range = LOS_RADIUS,
-                    int count_min = 8, int count_max = 10);
+    targeter_cloud(const actor* act, cloud_type ctype, int range = LOS_RADIUS,
+                   int count_min = 8, int count_max = 10);
     bool set_aim(coord_def a) override;
     bool valid_aim(coord_def a) override;
     bool can_affect_outside_range() override;
     aff_type is_affected(coord_def loc) override;
+    cloud_type ctype;
     int range;
     int cnt_min, cnt_max;
     map<coord_def, aff_type> seen;
     vector<vector<coord_def> > queue;
-    bool avoid_clouds;
 };
 
 class targeter_splash : public targeter_beam
@@ -273,6 +273,13 @@ public:
     aff_type is_affected(coord_def loc) override;
 };
 
+class targeter_siphon_essence : public targeter_radius
+{
+public:
+    targeter_siphon_essence();
+    aff_type is_affected(coord_def loc) override;
+};
+
 class targeter_thunderbolt : public targeter
 {
 public:
@@ -563,11 +570,22 @@ public:
     targeter_anguish();
     bool affects_monster(const monster_info& mon) override;
 };
-
-class targeter_poisonous_vapours : public targeter_smite
+class targeter_boulder : public targeter_beam
 {
 public:
-    targeter_poisonous_vapours(const actor *act, int range);
-    bool affects_monster(const monster_info& mon) override;
+    targeter_boulder(const actor* caster);
     bool valid_aim(coord_def a) override;
+    bool set_aim(coord_def a) override;
+    aff_type is_affected(coord_def loc) override;
+};
+
+class targeter_petrify : public targeter_beam
+{
+public:
+    targeter_petrify(const actor *act, int r);
+    bool set_aim(coord_def a) override;
+    aff_type is_affected(coord_def loc) override;
+
+private:
+    set<coord_def> chain_targ;
 };
