@@ -10,12 +10,8 @@
 #include "enum.h"
 #include "player.h"
 
-#define MAX_HYDRA_HEADS 20
-
-#define APPENDAGE_KEY "beastly_appendages"
-#define APPENDAGE_LEVEL 2
-
-#define AIRFORM_POWER_KEY "airform_power"
+#define DRAGON_CLAWS 3
+#define DRAGON_FANGS 5
 
 enum form_capability
 {
@@ -69,6 +65,18 @@ public:
     const int max;
 };
 
+class FormScaling {
+public:
+    FormScaling() : base(0), scaling(0), xl_based(false) {}
+    FormScaling& Base(int b) { base = b; return *this; }
+    FormScaling& Scaling(int s) { scaling = s; return *this; }
+    FormScaling& XLBased() { xl_based = true; return *this; }
+
+    int base;      // value at 0 XL/skill (as applicable)
+    int scaling;   // value added to base at max XL/skill
+    bool xl_based; // if false, scale on Shapeshifting skill
+};
+
 struct form_entry; // defined in form-data.h (private)
 class Form
 {
@@ -85,6 +93,13 @@ public:
 
     int get_duration(int pow) const;
 
+    int get_level(int scale) const;
+
+    int mult_hp(int base_hp, bool force_talisman = false) const;
+
+    /// Is the player below the minimum skill for this form?
+    bool underskilled() const { return get_level(1) < min_skill; }
+
     /**
      * What monster corresponds to this form?
      *
@@ -126,14 +141,22 @@ public:
     int res_pois() const;
     bool res_rot() const;
     bool res_acid() const;
-    bool res_sticky_flame() const;
     bool res_miasma() const;
     bool res_petrify() const;
 
     /**
      * Base unarmed damage provided by the form.
      */
-    virtual int get_base_unarmed_damage() const { return base_unarmed_damage; }
+    int get_base_unarmed_damage(bool random = true, bool max = false) const;
+
+    /// Damage done by a custom aux attack of this form.
+    virtual int get_aux_damage(bool /*random*/ = true,
+                               bool /*max*/ = false) const {
+        return 0;
+    }
+
+    /// Does this form care about skill for UC damage and accuracy, or only XL?
+    virtual bool get_unarmed_uses_skill() const { return !unarmed_bonus_dam.xl_based; }
 
     /**
      * The brand of this form's unarmed attacks (SPWPN_FREEZING, etc).
@@ -142,19 +165,25 @@ public:
 
     virtual bool can_offhand_punch() const { return can_wield(); }
     virtual string get_uc_attack_name(string default_name) const;
-    virtual int get_ac_bonus() const;
+    virtual int slay_bonus(bool /*random*/ = true, bool /*max*/ = false) const { return 0; }
+    virtual int contam_dam(bool /*random*/ = true, bool /*max*/ = false) const { return 0; }
+    virtual int get_ac_bonus(bool max = false) const;
+    virtual int ev_bonus(bool /*max*/ = false) const { return 0; }
+    virtual int get_base_ac_penalty(int /*base*/) const { return 0; }
 
     bool enables_flight() const;
     bool forbids_flight() const;
     bool forbids_swimming() const;
+    virtual bool permits_liking_water() const { return !forbids_swimming(); }
 
     bool player_can_fly() const;
     bool player_can_swim() const;
+    bool player_likes_water() const;
 
     string player_prayer_action() const;
     string melding_description() const;
 
-    vector<string> get_fakemuts(bool terse) const;
+    virtual vector<string> get_fakemuts(bool terse) const;
 
 public:
     /// Status light ("Foo"); "" for none
@@ -165,6 +194,11 @@ public:
     /// A struct representing the duration of the form, based on power etc
     const FormDuration duration;
 
+    /// The skill level below which the player gets HP penalties for using the form.
+    const int min_skill;
+    /// The skill level beyond which further skill provides no benefit.
+    const int max_skill;
+
     /// flat str bonus
     const int str_mod;
     /// flat dex bonus
@@ -177,16 +211,10 @@ public:
     const int blocked_slots; // XX check enum size at compile time?
     /// size of the form
     const size_type size;
-    /// 10 * multiplier to hp/mhp (that is, 10 is base, 15 is 1.5x, etc)
-    const int hp_mod;
 
     /// can the player cast while in this form?
     const bool can_cast;
-    /// increase to spell fail rate (value is weird - see raw_spell_fail())
-    const int spellcasting_penalty;
 
-    /// acc bonus when using UC in form
-    const int unarmed_hit_bonus;
     /// colour of 'weapon' in UI
     const int uc_colour;
     /// a set of verbs to use based on damage done, when using UC in this form
@@ -222,8 +250,18 @@ protected:
      */
     const int resists;
 
+    /// bonuses to AC when in this form, potentially scaling with skill or XL
+    const FormScaling ac;
+
     /// See Form::get_base_unarmed_damage().
-    const int base_unarmed_damage;
+    const FormScaling unarmed_bonus_dam;
+
+    /// Calculate the given FormScaling for this form, multiplied by scale.
+    int scaling_value(const FormScaling &sc, bool random,
+                      bool max = false, int scale = 1) const;
+    /// Calculate the given FormScaling for this form, with math internally multiplied by scale.
+    int divided_scaling(const FormScaling &sc, bool random,
+                        bool max = false, int scale = 1) const;
 
 private:
     bool all_blocked(int slotflags) const;
@@ -240,13 +278,6 @@ private:
      */
     const form_capability can_swim;
 
-    /// flat bonus to player AC when in the form.
-    const int flat_ac;
-    /// spellpower-based bonus to player AC; multiplied by power / 100
-    const int power_ac;
-    /// experience level-based bonus to player AC; XL * xl_ac / 100
-    const int xl_ac;
-
     /// See Form::get_uc_brand().
     const brand_type uc_brand;
     /// the name of the uc 'weapon' in the HUD; "" uses species defaults.
@@ -258,9 +289,13 @@ private:
     /// See Form::get_equivalent_mons().
     const monster_type equivalent_mons;
 
+    /// 10 * multiplier to hp/mhp (that is, 10 is base, 15 is 1.5x, etc)
+    const int hp_mod;
+
     vector<pair<string,string>> fakemuts;
 };
 const Form* get_form(transformation form = you.form);
+const Form* cur_form(bool temp);
 
 enum undead_form_reason
 {
@@ -269,7 +304,8 @@ enum undead_form_reason
     UFR_TOO_ALIVE = 1,
 };
 undead_form_reason lifeless_prevents_form(transformation form = you.form,
-                                          bool involuntary = false);
+                                          bool involuntary = false,
+                                          bool temp = true);
 
 bool form_can_wield(transformation form = you.form);
 bool form_can_wear(transformation form = you.form);
@@ -286,25 +322,28 @@ bool feat_dangerous_for_form(transformation which_trans,
 
 bool check_form_stat_safety(transformation new_form, bool quiet = false);
 
-bool transform(int pow, transformation which_trans,
-               bool involuntary = false, bool just_check = false,
-               string *fail_reason = nullptr);
+string cant_transform_reason(transformation which_trans, bool involuntary = false,
+                             bool temp = true);
+bool check_transform_into(transformation which_trans, bool involuntary = false);
+bool transform(int pow, transformation which_trans, bool involuntary = false);
 
 // skip_move: don't make player re-enter current cell
 void untransform(bool skip_move = false);
 
+void unset_default_form();
+void set_default_form(transformation t, const item_def *source);
+
+void set_form(transformation which_trans, int dur);
+void return_to_default_form();
+
 void remove_one_equip(equipment_type eq, bool meld = true,
                       bool mutation = false);
 void unmeld_one_equip(equipment_type eq);
 
 monster_type transform_mons();
 string blade_parts(bool terse = false);
-void set_airform_power(int pow);
 const char* transform_name(transformation form = you.form);
 
-int form_hp_mod();
-
-void emergency_untransform();
 void merfolk_check_swimming(dungeon_feature_type old_grid,
                             bool stepped = false);
 void merfolk_start_swimming(bool step = false);
@@ -312,3 +351,13 @@ void merfolk_stop_swimming();
 void vampire_update_transformations();
 int form_base_movespeed(transformation tran);
 bool draconian_dragon_exception();
+
+transformation form_for_talisman(const item_def &talisman);
+
+struct talisman_form_desc {
+    vector<pair<string, string>> skills;
+    vector<pair<string, string>> defenses;
+    vector<pair<string, string>> offenses; // heh
+};
+void describe_talisman_form(transformation form_type, talisman_form_desc &d,
+                            bool incl_special);
