@@ -15,6 +15,7 @@
 
 #include "act-iter.h"
 #include "artefact.h"
+#include "branch.h"
 #include "cio.h"
 #include "cloud.h"
 #include "clua.h"
@@ -150,7 +151,7 @@ void seen_monsters_react(int stealth)
         if (!mi->visible_to(&you))
             continue;
 
-        if (!mi->has_ench(ENCH_INSANE) && mi->can_see(you))
+        if (!mi->has_ench(ENCH_FRENZIED) && mi->can_see(you))
         {
             // Trigger Duvessa & Dowan upgrades
             if (mi->props.exists(ELVEN_ENERGIZE_KEY))
@@ -249,38 +250,17 @@ static void _genus_factoring(map<const string, details> &types,
     types[name] = {mon, name, num, true};
 }
 
-static bool _is_weapon_worth_listing(const unique_ptr<item_def> &wpn)
-{
-    return wpn && (wpn->base_type == OBJ_STAVES
-                   || is_unrandom_artefact(*wpn.get())
-                   || get_weapon_brand(*wpn.get()) != SPWPN_NORMAL);
-}
-
-static bool _is_item_worth_listing(const unique_ptr<item_def> &item)
-{
-    return item && (item_is_branded(*item.get())
-                    || is_artefact(*item.get()));
-}
-
 static bool _is_mon_equipment_worth_listing(const monster_info &mi)
 {
+    for (unsigned int i = 0; i <= MSLOT_LAST_VISIBLE_SLOT; ++i)
+    {
+        if (!mi.inv[i])
+            continue;
 
-    if (_is_weapon_worth_listing(mi.inv[MSLOT_WEAPON]))
-        return true;
-    const unique_ptr<item_def> &alt_weap = mi.inv[MSLOT_ALT_WEAPON];
-    if (mi.wields_two_weapons() && _is_weapon_worth_listing(alt_weap))
-        return true;
-    // can a wand be in the alt weapon slot? get_monster_equipment_desc seems to
-    // think so, so we'll check
-    if (alt_weap && alt_weap->base_type == OBJ_WANDS)
-        return true;
-    if (mi.inv[MSLOT_WAND])
-        return true;
-
-    return _is_item_worth_listing(mi.inv[MSLOT_SHIELD])
-        || _is_item_worth_listing(mi.inv[MSLOT_ARMOUR])
-        || _is_item_worth_listing(mi.inv[MSLOT_JEWELLERY])
-        || _is_item_worth_listing(mi.inv[MSLOT_MISSILE]);
+        if (item_is_worth_listing(*mi.inv[i].get()))
+            return true;
+    }
+    return false;
 }
 
 /// Return whether or not monster_info::_core_name() describes the inventory
@@ -683,8 +663,8 @@ static colour_t _feat_default_map_colour(dungeon_feature_type feat)
 
 // Returns true if it succeeded.
 bool magic_mapping(int map_radius, int proportion, bool suppress_msg,
-                   bool force, bool deterministic,
-                   coord_def origin)
+                   bool force, bool deterministic, bool full_info,
+                   bool range_falloff, coord_def origin)
 {
     if (!force && !is_map_persistent())
     {
@@ -694,8 +674,6 @@ bool magic_mapping(int map_radius, int proportion, bool suppress_msg,
         return false;
     }
 
-    const bool wizard_map = (you.wizard && map_radius == 1000);
-
     if (map_radius < 5)
         map_radius = 5;
 
@@ -715,7 +693,7 @@ bool magic_mapping(int map_radius, int proportion, bool suppress_msg,
          ri; ++ri)
     {
         coord_def pos = *ri;
-        if (!wizard_map)
+        if (range_falloff)
         {
             int threshold = proportion;
 
@@ -754,7 +732,7 @@ bool magic_mapping(int map_radius, int proportion, bool suppress_msg,
         const bool already_mapped = knowledge.mapped()
                             && knowledge.feat() != DNGN_UNSEEN;
 
-        if (!wizard_map && (knowledge.seen() || already_mapped))
+        if (!full_info && (knowledge.seen() || already_mapped))
             continue;
 
         const dungeon_feature_type feat = env.grid(pos);
@@ -777,7 +755,7 @@ bool magic_mapping(int map_radius, int proportion, bool suppress_msg,
 
         if (open)
         {
-            if (wizard_map)
+            if (full_info)
             {
                 knowledge.set_feature(feat, _feat_default_map_colour(feat),
                     feat_is_trap(env.grid(pos)) ? get_trap_type(pos)
@@ -794,12 +772,14 @@ bool magic_mapping(int map_radius, int proportion, bool suppress_msg,
             if (emphasise(pos))
                 knowledge.flags |= MAP_EMPHASIZE;
 
-            if (wizard_map)
+            if (full_info)
             {
                 if (is_notable_terrain(feat))
                     seen_notable_thing(feat, pos);
 
                 set_terrain_seen(pos);
+                StashTrack.add_stash(pos);
+                show_update_at(pos);
 #ifdef USE_TILE
                 tile_wizmap_terrain(pos);
 #endif
@@ -1052,7 +1032,7 @@ static update_flags player_view_update_at(const coord_def &gc)
     maybe_remove_autoexclusion(gc);
     update_flags ret;
 
-    // Set excludes in a radius of 1 around harmful clouds genereated
+    // Set excludes in a radius of 1 around harmful clouds generated
     // by neither monsters nor the player.
     const cloud_struct* cloud = cloud_at(gc);
     if (cloud && !crawl_state.game_is_arena())
@@ -1088,13 +1068,14 @@ static update_flags player_view_update_at(const coord_def &gc)
     if (!(env.pgrid(gc) & FPROP_SEEN_OR_NOEXP))
     {
         if (!crawl_state.game_is_arena()
+            && !(branches[you.where_are_you].branch_flags & brflag::fully_map)
             && you.has_mutation(MUT_EXPLORE_REGEN))
         {
             _do_explore_healing();
         }
         if (!crawl_state.game_is_arena()
             && cell_triggers_conduct(gc)
-            && !player_in_branch(BRANCH_TEMPLE)
+            && !(branches[you.where_are_you].branch_flags & brflag::fully_map)
             && !(player_in_branch(BRANCH_SLIME) && you_worship(GOD_JIYVA)))
         {
             did_god_conduct(DID_EXPLORATION, 2500);
