@@ -16,7 +16,7 @@ function ($, comm, client, enums, map_knowledge, messages, options, util) {
     var defense_boosters = {
         "ac": "ice-armoured|protected from physical damage|sanguine armoured"
               + "|under a protective aura|curled up|fiery-armoured",
-        "ev": "agile|acrobatic|in a heavenly storm",
+        "ev": "^agile|acrobatic|in a heavenly storm",
         "sh": "divinely shielded",
     }
 
