@@ -1,6 +1,7 @@
 define(["jquery", "comm", "client", "./ui", "./enums", "./cell_renderer",
-    "./util", "./scroller", "./tileinfo-main", "./tileinfo-gui", "./tileinfo-player"],
-function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
+    "./util", "./scroller", "./tileinfo-main", "./tileinfo-gui",
+    "./tileinfo-player", "./options"],
+function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player, options) {
     "use strict";
 
     var describe_scale = 2.0;
@@ -8,19 +9,12 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
     function fmt_body_txt(txt)
     {
         return txt
-            // preserve all leading spaces
-            .split("\n")
-            .map(function (s) { return s.replace(/^\s+/, function (m)
-                    {
-                        // TODO: or mark as preformatted? something else?
-                        return m.replace(/\s/g, "&nbsp;");
-                    }).trim();
-                })
-            .join("\n")
             // convert double linebreaks into paragraph markers
             .split("\n\n")
-            .map(function (s) { return "<p>" + s + "</p>"; })
-            .filter(function (s) { return s !== "<p></p>"; })
+            .map(function (s) {
+                return "<pre>" + util.formatted_string_to_html(s) + "</pre>";
+            })
+            .filter(function (s) { return s !== "<pre></pre>"; })
             .join("")
             // replace single linebreaks with manual linebreaks
             .split("\n")
@@ -274,7 +268,7 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
         if (parts == null || parts.length != 4)
             return fmt_body_txt(desc);
         parts[2] = parts[2].replace(/ /g, '&nbsp;');
-        return fmt_body_txt(parts[1]+parts[2]+parts[3])
+        return fmt_body_txt(parts[1]) + parts[2] + fmt_body_txt(parts[3]);
     }
 
     function describe_spell(desc)
@@ -334,7 +328,7 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
         var $body = $popup.find(".body");
         var $footer = $popup.find(".footer");
         var $muts = $body.children().first(), $vamp = $body.children().last();
-        $muts.html(fmt_body_txt(util.formatted_string_to_html(desc.mutations)));
+        $muts.html(fmt_body_txt(desc.mutations));
         var s = scroller($muts[0]);
         $popup.on("keydown keypress", function (event) {
             scroller_handle_key(s, event);
@@ -429,7 +423,7 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
                 +power+"</div><div>"+cost+"</div></div>");
         }
 
-        desc.powers = fmt_body_txt(util.formatted_string_to_html(desc.powers));
+        desc.powers = fmt_body_txt(desc.powers);
         if (desc.info_table.length !== "")
         {
             desc.powers += "<div class=tbl>"
@@ -439,7 +433,7 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
         $panes.eq(1).html(desc.powers);
 
         $panes.eq(2).html(
-                    fmt_body_txt(util.formatted_string_to_html(desc.wrath)));
+                    fmt_body_txt(desc.wrath));
         if (use_extra_pane)
         {
             $panes.eq(3).html("<div class=tbl>"
@@ -764,7 +758,6 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
     {
         var $popup = $(".templates > .formatted-scroller").clone();
         var $body = $popup.children(".body");
-        var $more = $popup.children(".more");
         var body_html = util.formatted_string_to_html(desc.text);
         if (desc.highlight !== "")
         {
@@ -776,7 +769,20 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
         }
         $popup.attr("data-tag", desc.tag);
         $body.html(body_html);
-        $more.html(util.formatted_string_to_html(desc.more));
+        if (desc.more)
+            $popup.children(".more").html(util.formatted_string_to_html(desc.more));
+        else
+            $popup.children(".more").remove();
+
+        // XX why do some layouts use a span inside of a div, some just use
+        // the div? (Answer remains unclear to me, but something about
+        // preformatting + nested spans did mess this up when I tried to use
+        // a template span here)
+        if (desc.title)
+            $popup.children(".header").html(util.formatted_string_to_html(desc.title));
+        else
+            $popup.children(".header").remove();
+
         var s = scroller($body[0]);
         var scroll_elem = s.scrollElement;
         scroll_elem.addEventListener("scroll", scroller_onscroll);
@@ -784,6 +790,13 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
             if (event.which !== 36 || desc.tag !== "help")
                 scroller_handle_key(s, event);
         });
+        if (desc.easy_exit && options.get("tile_web_mouse_control"))
+        {
+            $popup.on("click", function () {
+                // XX a bit ad hoc
+                comm.send_message("key", { keycode: 27 });
+            });
+        }
         return $popup;
     }
 
@@ -944,7 +957,7 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
     {
         var $popup = $(".templates > .game-over").clone();
         $popup.find(".header > span").html(desc.title);
-        $popup.children(".body").html(fmt_body_txt(util.formatted_string_to_html(desc.body)));
+        $popup.children(".body").html(fmt_body_txt(desc.body));
         var s = scroller($popup.children(".body")[0]);
         $popup.on("keydown keypress", function (event) {
             scroller_handle_key(s, event);
@@ -1018,6 +1031,7 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
         }
         catch (err)
         {
+            console.log(err);
             popup = $("<div>Buggy UI of type " + msg.type + "</div>");
         }
         ui.show_popup(popup, msg["ui-centred"], msg.generation_id);
@@ -1028,12 +1042,19 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
         ui.hide_popup();
     }
 
+    var ui_stack_handled = false;
+
     function recv_ui_stack(msg)
     {
         if (!client.is_watching())
             return;
+        // only process once on load
+        if (ui_stack_handled)
+            return;
+
         for (var i = 0; i < msg.items.length; i++)
             comm.handle_message(msg.items[i]);
+        ui_stack_handled = true;
     }
 
     function recv_ui_state(msg)
@@ -1070,6 +1091,7 @@ function ($, comm, client, ui, enums, cr, util, scroller, main, gui, player) {
 
     function ui_layouts_cleanup()
     {
+        ui_stack_handled = false;
         if (update_server_scroll_timeout)
         {
             clearTimeout(update_server_scroll_timeout);
