@@ -1,6 +1,6 @@
 /**
  * @file
- * @brief Fight simualtion wizard functions.
+ * @brief Fight simulation wizard functions.
 **/
 
 #include "AppHdr.h"
@@ -77,8 +77,13 @@ string fight_data::header(bool tsv)
 string fight_data::summary(const string prefix, bool tsv)
 {
     string s = "";
-    s += player.summary(prefix, tsv) + "\n";
-    s += monster.summary(prefix, tsv);
+
+    if (player.hits > 0)
+        s += player.summary(prefix, tsv) + "\n";
+
+    if (monster.hits > 0)
+        s += monster.summary(prefix, tsv);
+
     return s;
 }
 
@@ -98,7 +103,7 @@ static skill_type _equipped_skill()
     return SK_UNARMED_COMBAT;
 }
 
-static string _equipped_weapon_name()
+static string _equipped_weapon_name(bool show_prefix)
 {
     const int weapon = you.equip[EQ_WEAPON];
     const item_def * iweap = weapon != -1 ? &you.inv[weapon] : nullptr;
@@ -106,17 +111,19 @@ static string _equipped_weapon_name()
 
     if (iweap)
     {
-        string item_buf = iweap->name(DESC_PLAIN);
-        // If it's a ranged weapon, add the description of the missile
-        if (is_range_weapon(*iweap) && missile < ENDOFPACK && missile >= 0)
-            item_buf += " with " + you.inv[missile].name(DESC_PLAIN);
-        return "Wielding: " + item_buf;
+        if (show_prefix)
+            return "Wielding: " + iweap->name(DESC_PLAIN);
+        else
+            return iweap->name(DESC_PLAIN);
     }
 
     if (missile != -1 && you.inv[missile].defined()
                 && you.inv[missile].base_type == OBJ_MISSILES)
     {
-        return "Quivering: " + you.inv[missile].name(DESC_PLAIN);
+        if (show_prefix)
+            return "Quivering: " + you.inv[missile].name(DESC_PLAIN);
+        else
+            return you.inv[missile].name(DESC_PLAIN);
     }
 
     return "Unarmed";
@@ -169,7 +176,7 @@ static void _write_you(FILE * o)
 static void _write_weapon(FILE * o)
 {
     fprintf(o, "%s, Skill: %s\n",
-            _equipped_weapon_name().c_str(),
+            _equipped_weapon_name(true).c_str(),
             skill_name(_equipped_skill()));
 }
 
@@ -434,7 +441,7 @@ static void _do_one_fsim_round(monster &mon, fight_data &fd, bool defend)
         fd.player.time_taken += time_taken;
         if (did_hit)
             fd.monster.hits++;
-        // did player succesfully do some kind of retaliatory damage?
+        // did player successfully do some kind of retaliatory damage?
         // TODO check for damage-less hits
         if (mon.max_hit_points > mon.hit_points)
             fd.player.hits++;
@@ -521,6 +528,8 @@ void wizard_quick_fsim()
     if (!mon)
         return;
 
+    mprf("Fighting %s with %s\n", mon->name(DESC_PLAIN, true).c_str(), _equipped_weapon_name(false).c_str());
+
     const int iter_limit = Options.fsim_rounds;
     fight_data fdata = _get_fight_data(*mon, iter_limit, false);
     mprf("%8s%s", "", fdata.header(false).c_str());
