@@ -82,14 +82,14 @@ static const zap_info zap_data[] =
 },
 
 {
-    ZAP_ENERGY_BOLT,
-    "bolt of energy",
+    ZAP_BOLT_OF_DEVASTATION,
+    "bolt of devastation",
     200,
     nullptr,
     nullptr,
     new dicedef_calculator<3, 20, 0, 1>,
     new tohit_calculator<15, 1, 30>,
-    YELLOW,
+    MAGENTA,
     false,
     BEAM_DEVASTATION,
     DCHAR_FIRED_ZAP,
@@ -109,7 +109,7 @@ static const zap_info zap_data[] =
     false,
     BEAM_FRAG,
     DCHAR_FIRED_ZAP,
-    true,
+    false,
     false,
 },
 
@@ -125,7 +125,7 @@ static const zap_info zap_data[] =
     false,
     BEAM_FRAG,
     DCHAR_FIRED_MISSILE,
-    true,
+    false,
     false,
 },
 
@@ -786,9 +786,9 @@ _mon_hex_zap(ZAP_CHARMING, BEAM_CHARM),
     ZAP_STICKY_FLAME,
     "sticky flame",
     100,
-    new dicedef_calculator<2, 3, 1, 12>,
+    new dicedef_calculator<2, 4, 1, 9>,
     new tohit_calculator<AUTOMATIC_HIT>,
-    new dicedef_calculator<3, 3, 1, 50>,
+    new dicedef_calculator<2, 3, 1, 50>,
     new tohit_calculator<AUTOMATIC_HIT>,
     RED,
     false,
@@ -799,16 +799,17 @@ _mon_hex_zap(ZAP_CHARMING, BEAM_CHARM),
 },
 
 {
-    ZAP_STICKY_FLAME_RANGE,
-    "sticky flame",
+    ZAP_PYRE_ARROW,
+    "pyre arrow",
     100,
-    new dicedef_calculator<2, 3, 1, 12>,
-    new tohit_calculator<AUTOMATIC_HIT>,
-    new dicedef_calculator<3, 3, 1, 50>,
-    new tohit_calculator<18, 1, 15>,
+    nullptr,
+    nullptr,
+    // 0 dice so 'does no damage' is suppresssed
+    new dicedef_calculator<0, 0, 0, 1>,
+    new tohit_calculator<18, 1, 12>,
     RED,
     false,
-    BEAM_FIRE,
+    BEAM_STICKY_FLAME,
     DCHAR_FIRED_ZAP,
     false,
     false,
@@ -820,7 +821,7 @@ _mon_hex_zap(ZAP_CHARMING, BEAM_CHARM),
     100,
     new calcdice_calculator<3, 20, 3, 4>,
     new tohit_calculator<0, 3, 2>,
-    new dicedef_calculator<3, 6, 1, 10>,
+    new dicedef_calculator<3, 3, 1, 10>,
     new tohit_calculator<AUTOMATIC_HIT>,
     BLACK,
     true,
@@ -852,7 +853,7 @@ _mon_hex_zap(ZAP_BANISHMENT, BEAM_BANISH, 150),
     ZAP_STING,
     "sting",
     25,
-    new dicedef_calculator<1, 3, 1, 5>,
+    new dicedef_calculator<1, 3, 1, 4>,
     new tohit_calculator<8, 1, 5>,
     new dicedef_calculator<1, 6, 1, 25>,
     new tohit_calculator<60, 0, 1>,
@@ -896,6 +897,22 @@ _mon_hex_zap(ZAP_BANISHMENT, BEAM_BANISH, 150),
     false,
 },
 
+{
+    ZAP_BOMBARD,
+    "iron shot",
+    200,
+    new calcdice_calculator<9, 13, 2, 3>,
+    new tohit_calculator<7, 1, 15>,
+    new dicedef_calculator<3, 8, 1, 9>,
+    new tohit_calculator<20, 1, 25>,
+    LIGHTCYAN,
+    false,
+    BEAM_MMISSILE,
+    DCHAR_FIRED_MISSILE,
+    false,
+    false,
+},
+
 {
     ZAP_STONE_ARROW,
     "stone arrow",
@@ -966,7 +983,7 @@ _mon_hex_zap(ZAP_BANISHMENT, BEAM_BANISH, 150),
     50,
     new dicedef_calculator<1, 4, 1, 2>,
     new tohit_calculator<5, 1, 6>,
-    new dicedef_calculator<1, 4, 1, 10>,
+    new dicedef_calculator<2, 4, 1, 10>,
     new tohit_calculator<16, 1, 20>,
     GREEN,
     false,
@@ -1105,16 +1122,16 @@ _mon_hex_zap(ZAP_BANISHMENT, BEAM_BANISH, 150),
 },
 
 {
-    ZAP_AGONY_RANGE,
-    "agony",
+    ZAP_CURSE_OF_AGONY,
+    "curse of agony",
     100,
     nullptr,
-    new tohit_calculator<0, 5, 1>,
+    new tohit_calculator<0, 5, 2>,
     nullptr,
     new tohit_calculator<0, 1, 3>,
     BLACK,
     true,
-    BEAM_AGONY,
+    BEAM_CURSE_OF_AGONY,
     NUM_DCHAR_TYPES,
     false,
     false,
@@ -1281,7 +1298,7 @@ _mon_hex_zap(ZAP_SLEEP, BEAM_SLEEP),
     nullptr,
     WHITE,
     false,
-    BEAM_DEVASTATION,
+    BEAM_DESTRUCTION,
     NUM_DCHAR_TYPES, // no dchar, to get bolt.glyph == 0,
                      // hence invisible
     true,
@@ -1534,6 +1551,7 @@ _mon_hex_zap(ZAP_SENTINEL_MARK, BEAM_SENTINEL_MARK),
 _mon_hex_zap(ZAP_VIRULENCE, BEAM_VIRULENCE),
 _mon_hex_zap(ZAP_SAP_MAGIC, BEAM_SAP_MAGIC),
 _mon_hex_zap(ZAP_DRAIN_MAGIC, BEAM_DRAIN_MAGIC),
+_mon_hex_zap(ZAP_VITRIFY, BEAM_VITRIFY),
 
 {
     ZAP_BECKONING,
@@ -1699,7 +1717,7 @@ _mon_hex_zap(ZAP_DRAIN_MAGIC, BEAM_DRAIN_MAGIC),
     ZAP_HAILSTORM,
     "hail",
     100,
-    new calcdice_calculator<3, 10, 1, 2>,
+    new calcdice_calculator<3, 15, 1, 3>,
     new tohit_calculator<9, 1, 10>,
     nullptr,
     nullptr,
@@ -1737,7 +1755,7 @@ _mon_hex_zap(ZAP_DRAIN_MAGIC, BEAM_DRAIN_MAGIC),
     new tohit_calculator<5>,
     RED,
     false,
-    BEAM_DEVASTATION,
+    BEAM_DESTRUCTION,
     DCHAR_FIRED_ZAP,
     true,
     false,
@@ -1795,7 +1813,7 @@ _mon_hex_zap(ZAP_DRAIN_MAGIC, BEAM_DRAIN_MAGIC),
     ZAP_PLASMA,
     "fiery plasma",
     200,
-    new dicedef_calculator<1, 11, 3, 5>,
+    new dicedef_calculator<1, 10, 11, 20>,
     new tohit_calculator<7, 1, 40>,
     new dicedef_calculator<3, 10, 1, 17>,
     new tohit_calculator<16, 1, 40>,
@@ -1804,7 +1822,39 @@ _mon_hex_zap(ZAP_DRAIN_MAGIC, BEAM_DRAIN_MAGIC),
     BEAM_FIRE,
     DCHAR_FIRED_ZAP,
     true,
-    false
+    false,
+},
+
+{
+    ZAP_PLASMA_LIGHTNING, // please keep damage dice identical to ZAP_PLASMA
+    "bolt of lightning",
+    200,
+    new dicedef_calculator<1, 10, 11, 20>,
+    new tohit_calculator<7, 1, 40>,
+    new dicedef_calculator<3, 10, 1, 17>,
+    new tohit_calculator<16, 1, 40>,
+    LIGHTCYAN,
+    false,
+    BEAM_ELECTRICITY,
+    DCHAR_FIRED_ZAP,
+    true,
+    false,
+},
+
+{
+    ZAP_MALIGN_OFFERING,
+    "malign ofering",
+    200,
+    nullptr,
+    nullptr,
+    new dicedef_calculator<2, 4, 1, 10>,
+    nullptr,
+    DARKGRAY,
+    true,
+    BEAM_MALIGN_OFFERING,
+    NUM_DCHAR_TYPES,
+    false,
+    false,
 },
 
 };
